*****************************************************************************
* 0_dataimport.do
* Imports raw TSV files containing HMS data.
*****************************************************************************

*===========================================================================================
*** Directory Set-up

*Set project directories	
	do ../../SetFilePaths.do
		// $terminal = Server directory where project data sis located
		// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/0a_dataconstruct/HMS"	

*Set-up standard directories	
	global logs "${currentstep}/Logs"
	global data "${currentstep}/Data"
	global output "${currentstep}/Output"

*===========================================================================================
*For log files:

	global name="0a_HMSdataimport"

*===========================================================================================
*** Program to run sub-programs 
capture program drop main
program define main

** import raw files **
	import_panelists 		2006 2014 // year_start year_end
	import_trips 			2006 2014 // year_start year_end
	import_purchases 		2006 2014 // year_start year_end
	import_products_extra  	2006 2014 // year_start year_end
	
end


*===========================================================================================
*** Sub-programs
*===========================================================================================

// Panelists

capture program drop import_panelists
program define import_panelists
	args year_start year_end

	forvalues year = `year_start'/`year_end' {
	
		insheet using "${rawHMS}/`year'/Annual_Files/panelists_`year'.tsv", tab clear
		cap rename household_cd household_code
		compress
		sort panel_year household_code
		save "${data}/panelists`year'.dta", replace
		//unique obs id: household_code
	}
	
end

*****************************************************************************
// Trips

capture program drop import_trips
program define import_trips
	args year_start year_end

	forvalues year = `year_start'/`year_end' {
	
		insheet using "${rawHMS}/`year'/Annual_Files/trips_`year'.tsv", tab clear double
		rename purchase_date pd_str
		gen int purchase_date = date(pd_str, "YMD")
		drop pd_str
		format purchase_date %tdCCYY-NN-DD
	
		compress
		sort panel_year trip_code_uc
		save "${data}/trips`year'.dta", replace
			//unique obs id: trip_code_uc
	}

end	

*****************************************************************************
// Purchases

capture program drop import_purchases
program define import_purchases
	args year_start year_end

	forvalues year = `year_start'/`year_end' {

		import delimited using "${rawHMS}/`year'/Annual_Files/purchases_`year'.tsv", delimiters("\t") clear asdouble
		gen panel_year = `year'
		compress
		sort panel_year trip_code_uc upc upc_ver_uc
		save "${data}/purchases`year'.dta", replace
			//unique obs id: ?
	}
	
end


*****************************************************************************
// Products Extra
capture program drop import_products_extra
program define import_products_extra
	args year_start year_end

	forvalues year = `year_start'/`year_end' {
	
		insheet using "${rawHMS}/`year'/Annual_Files/products_extra_`year'.tsv", tab clear
	
		compress
		gen year=`year'
		sort year upc upc_ver_uc
		save "${data}/products_extra_`year'.dta", replace
			//unique obs id: upc upc_ver_uc
	}

end	

*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	main
	capture log close

*==================================================================================================
		
