*===========================================================================================
* 0a_prepcharacteristicinfo.do
* Prepares characteristic information on RMS products and makes product sizes uniform
*===========================================================================================
	
	global endyear = 2014
	
*===========================================================================================
*** Directory Set-up

*Set project directories	
	do ../../SetFilePaths.do
		// $terminal = Server directory where project data sis located
		// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/0a_dataconstruct/RMS"	

*Set-up standard directories	
	global logs "${currentstep}/Logs"
	global data "${currentstep}/Data"
	global output "${currentstep}/Output"

*===========================================================================================
*For log files:
	
	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace

*==================================================================================================
*==================================================================================================	
*==================================================================================================

capture log close
log using ${logs}/0a_RMScharacteristicinfo_`cdate'_`ctime'.log, replace

** Basic product characteristics
	filefilter ${rawRMS}/Master_Files/Latest/products.tsv productsfiltered.tsv, from("\Q") to(" ") replace  
	insheet using productsfiltered.tsv, tab names clear
	format upc %12.0f
	save ${data}/products.dta, replace	
	
** Versions
	forvalues year=2006/$endyear {
		insheet using  ${rawRMS}/`year'/Annual_Files/rms_versions_`year'.tsv, tab names clear
		save ${data}/rms_versions_`year'.dta, replace
		gen panelyear=`year'
		if `year'>2006 {
			append using ${data}/rms_versions_2006-${endyear}.dta
		}
		save ${data}/rms_versions_2006-${endyear}.dta, replace
	}
	
** Stores
	forvalues year=2006/$endyear {
		insheet using ${rawRMS}/`year'/Annual_Files/stores_`year'.tsv, tab names clear
		sort store_code_uc 
		save ${data}/stores_`year', replace
		if `year'>2006 append using ${data}/stores_2006-${endyear}.dta
		save ${data}/stores_2006-${endyear}.dta, replace
	}
	
log close
