/*===========================================================================================
* 0b_listprodmods.do
* Creates a list of all available product modules and the product groups into which they are categorized.
==========================================================================================*/

    global endyear = 2017
    global totyears = ${endyear}-2006+1  //endyear-2006+1
 
*===========================================================================================
*** Directory Set-up

*Set project directories	
	do ../../SetFilePaths.do

	global currentstep "$terminal/0a_dataconstruct/HMS"	

*Set-up standard directories	
	global logs "${currentstep}/Logs"
	global data "${currentstep}/Data"
	global output "${currentstep}/Output"
	cd "$data"
	
*===========================================================================================
*For log files:

	global name="1b_listprodmods"
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	global logsuffix "${name}_`cdate'_`ctime'.log"

*==================================================================================================
*==================================================================================================	
*==================================================================================================

capture log close
log using ${logs}/listproductmods_${logsuffix}, replace

disp "** read in products data and identify which datasets each product module is available, and which product group it is associated with"
	use ${data}/products.dta, clear 
		// created in 0a_prepcharacteristicinfo.do
	gen id = (upc*10)+upc_ver_uc
	foreach dset in hms rms {
		gen `dset' = (dataset_found_uc==upper("`dset'") | dataset_found_uc=="ALL")
	}
	collapse (max) hms rms, by(product_module_code product_group_code)
	drop if product_module_code==.
	
disp "** check if we have a movement file for the particular product group/module **"
	forvalues year=2006/$endyear {
		gen inrms_`year'=0
	}
	local tot=_N
	forvalues i=1/`tot' {
		local pgrp = product_group_code[`i']
		if `pgrp'<1000 local pgrp="0`pgrp'"
		local pmod = product_module_code[`i']
		if `pmod'<1000 local pmod="0`pmod'"
		disp "** checking product module `pmod' (`i' of `tot') in `pgrp' **"
		if ("`pmod'"!="" & "`pgrp'"!="") {
			forvalues year=2006/$endyear {
				noisily capture confirm file "${rawRMS}/`year'/Movement_Files/`pgrp'_`year'/`pmod'_`year'.tsv"
				if _rc==0 replace inrms_`year'=1 if _n==`i'
				else replace inrms_`year' = 0 if _n==`i'
			}
		}
	}
	
disp "** checked all product groups **"
	egen yearsinrms = rowtotal(in*)
	gen notinrms = (yearsinrms==0)
	gen inrms_allyrs = (yearsinrms==$totyears)
	
disp "*** create list of all modules in rms**"
	keep if notinrms==0
	save ${data}/allmodulesrms_2006-${endyear}.dta, replace
	export delimited product_module_code using "${data}/allrmsmodules_2006-${endyear}.txt", replace delimiter(tab) novarnames 		
	
log close
