*===========================================================================================
* 1_createworkingfiles.do
* Generates dataset of movement file data for a specified product module and year
*		at the frequency specified in the "timeagg" argument"
*===============================================================================================*/


args pcode timeagg minyear maxyear checkwf wflocation 

disp "pcode `pcode' timeagg `timeagg' minyear `minyear' maxyear `maxyear'"

if "`pcode'" == ""{
 	local pcode 1179 		// product_module_code
 	local timeagg "month" 	// specifies whether we want obs. in the temporary/working file to be 
							//  at the "week"ly, the "month"ly, the "qtr"ly or the "year"ly level. 
 	local minyear 2006		//  the earliest year for which we want data
 	local maxyear 2014		//  the latest year for which we want data
 }
 
foreach arg in pcode timeagg minyear maxyear { 
	if "``arg''"=="0" local `arg'=""
	global `arg' "``arg''"
}  
	
*===========================================================================================
*** Directory Set-up

*Set project directories	
	do ../../SetFilePaths.do
		// $terminal = Server directory where project data sis located
		// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/0a_dataconstruct/HMS"	

*Set-up standard directories	
	global logs "${currentstep}/Logs"
	global data "${currentstep}/Data"

*===========================================================================================
*For log files:
	
	global name="1_createworkingfiles"

*===========================================================================================

cap prog drop main
prog define main

	clear 
	
	**Get product module and group codes 
		identifyproducts //Movement files are in folders denoted by product group, identify products, gets product group for given module
	
	**Run working file creation program
		
		forval year = ${minyear}/${maxyear} {									
			
			generatewf

		}	
	
end


*===================================================================================================
***		SUB-PROGRAMS
*===================================================================================================

cap prog drop identifyproducts
prog define identifyproducts
disp "** identify product group for module ${pcode} **"

	use ${data}/allmodulesrms_2006-${maxyear}.dta, clear 
			//created in 0b_listprodmods, list of all modules that appear in rms data
	keep product_module_code product_group_code inrms_*
	duplicates drop
	isid product_module_code

	keep if product_module_code == ${pcode}
	di "MAKE SURE ONLY ONE OBSERVATION"
	count 
	assert r(N)==1 if !inlist(${pcode},7811,9999)
	di "One observation or exception"
	if !inlist(${pcode},7811,9999) {
		qui gen pmod=string(product_module_code)
		qui gen pgrp_mod = string(product_group_code) + "_" + string(product_module_code)
		qui replace pgrp_mod = "0"+pgrp_mod if product_group_code<1000
		foreach v in pgrp_mod pmod {
			local id = `v'[1]
			global `v' "`id'"
		}
		
		forvalues year = 2006(1)$maxyear {
			qui su inrms_`year'
			assert r(N)==1
			global inrms_`year' = r(max)
			assert inlist(${inrms_`year'},0,1)
			di "In RMS `year' Data: ${inrms_`year'}"
		}
		disp "pgrp_mod: ${pgrp_mod}"
		disp "pmod: ${pmod}"
	}
	else di "Special Pcode, either 7811 or 9999"
	
end

*==================================================================================================	
cap prog drop generatewf
prog define generatewf

** identify group and module to pull data for
	local k=subinstr("${pgrp_mod}","_"," ",.) 
	tokenize "`k'" //seperates components of pgrp_mod
	global pgrp=trim("`1'") //extracts group (1st component)
	local pmod=trim("`2'") //extracts module (2nd component)
	if $pcode == 9999 {
		local pmod = 9999
		global pgrp = 0 
	}
	if $pcode == 7811 {
		local pmod = 7811
		global pgrp = 4509 
	}
	*Module 8621 change product code in 2014
	if ${year} < 2014 & `pmod' == 8621 global pgrp = 5507

	disp "***Processing module `pmod' from group ${pgrp}"

** imports movement data **
	quietly insheet using ${rawRMS}/${year}/Movement_Files/${pgrp}_${year}/`pmod'_${year}.tsv, tab names clear double
	quietly compress
			
	
	dis " Calculate sales and unitvalue"
	** prmult used to indicate deals such 3 for $1.
	gen double value=units*price/prmult
	gen double unitvalue=price/prmult
	
	timeagg ${timeagg} // collapses to monthly/quarterly/yearly frequency
	
	quietly gen panelyear=${year}
	
	disp "Identify module" 
	quietly gen product_module_code = `pmod'

	disp "...add UPC version counts"
		merge m:1 upc panelyear using ${RMSdata}/rms_versions_2006-${maxyear}.dta, keep(1 3) keepusing(upc_ver_uc) nogen // imported from ${raw}/`year'/Annual_Files/rms_versions_`year'.tsv in 0_prepcharacteristicinfo_v2 !!!!!!!!dataset outdated
	
	disp "...reaggregate to ${timeagg} level frequency of obs. across year-ends"
		gcollapse (sum) value* units*, by(year ${timeagg} store_code_uc upc upc_ver_uc product_module_code) fast

disp "...saving working file"
	compress
	gzsave "${data}/WorkingFiles/${timeagg}_${pcode}_${year}.dta", replace

end

*==================================================================================================	
capture program drop timeagg
program define timeagg

	args freq
	syntax [anything] [, corrected ]
	if "`corrected'" != "" local suf "_corrected"
	else local suf ""
	quietly tostring week_end, replace

	if "`freq'"!="week"  {
		disp "...deal with weeks that overlap month beginning/end"		
		quietly {
			*capture drop value
			gen cwe=date(week_end,"YMD")
			gen day=day(cwe)
			gen month=month(cwe)
			gen year=year(cwe)
			gen overlap=1 if day<7
			** prorate to each month
			preserve
				keep if overlap==1
				replace month=month(cwe-6)
				replace year=year(cwe-6)
				foreach v in value units {
					replace `v'=`v'*(7-day(cwe))/7
				}	

				gen overlapend=1
				tempfile temp
				save `temp', replace
			restore
		
			foreach v in value units {
				replace `v'=`v'*(day(cwe))/7 if overlap==1
			}
			append using `temp'
			drop if value==0
		}		
	}

	else {
		disp "...get weeks formatted correctly "
			qui gen cwe=date(week_end,"YMD")
			qui gen week=floor(cwe/7)	
			drop week_end
	}

	disp "...sum by `freq'"
		rename month monthinyear
		qui gen month=ym(year, monthinyear)
		format month %tm
		qui gen qtrinyear=ceil(monthinyear/3)
		qui gen qtr=yq(year,qtrinyear)
		format qtr %tq
		gcollapse (sum) value`suf' = value units`suf' = units, by(year `freq' store_code_uc upc) fast
		gen double unitvalue`suf'=value`suf'/units`suf'

end



*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	main
	capture log close

*==================================================================================================
		