*===========================================================================================
*** 0a_rawdataconvert.do
*** Defines chain code and prepares miscellaneous inputs to other programs in 0b_dataimport and beyond: 
*** stores_`year'.dta, RMS_retailer_groupchain.dta, storechainloc.dta, product_module_department_concordance.dta, productmodule_list.dta/txt
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"
	
* Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	
*Name/date/time
	global name="0_rawdataconvert"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')

*Set directory to data directory
	cd "$data"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	set memory 5000m
	set more off, perm
	set matsize 800
	#delimit cr

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	RMSstoreconvert, yrstrt(2006) yrend(2014)
	storechar, yrstrt(2006) yrend(2014)
	pmoduledep_concordance
	
end

*===================================================================================================
*===================================================================================================
*===================================================================================================
cap prog drop RMSstoreconvert
prog define RMSstoreconvert
	syntax [anything], yrstrt(string) yrend(string) 
	
if 1==1{
	local i = 0
	foreach yr of numlist `yrstrt'/`yrend'{
		use ${RMSdata}/stores_`yr'.dta, clear
						// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
			keep store_code_uc year retailer_code parent_code channel_code
		
			di "Replace missing retailer code with a parent-code based number"
			count if retailer_code==.
			sum retailer_code, d
			local base = strlen("`r(max)'", "%10.0g")
			gen chain_code= retailer_code 
			replace chain_code = parent_code + 10^`base' if retailer_code==.
		
			save ${data}/stores_`yr'.dta, replace
		
			if `i'>0 append using ${data}/RMS_retailer_groupchain.dta
			save ${data}/RMS_retailer_groupchain.dta, replace
			local i = `i'+1
	}
	
	use ${data}/RMS_retailer_groupchain.dta, clear
	keep chain_code
	duplicates drop
	count if chain_code==.
	egen groupchain=group(chain_code)
	save ${data}/RMS_retailer_groupchain.dta, replace
}

end
*===================================================================================================		
cap prog drop storechar
prog define storechar
	syntax [anything], yrstrt(string) yrend(string) 
	
if 1==1{
	local i = 0
	foreach yr of numlist `yrstrt'/`yrend'{
		use ${RMSdata}/stores_`yr'.dta, clear
					// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
			keep store_code_uc year retailer_code channel_code parent_code store_zip3 fips*code dma_code
		
			di "Replace missing retailer code with a parent-code based number"
			count if retailer_code==.
			sum retailer_code, d
			local base = strlen("`r(max)'", "%10.0g")
			gen chain_code= retailer_code 
			replace chain_code = parent_code + 10^`base' if retailer_code==.
		
			if `i'>0 append using ${data}/storechainloc.dta
			save ${data}/storechainloc.dta, replace
			local i = `i'+1
	}
}

end
*===================================================================================================		
cap prog drop pmoduledep_concordance
prog define pmoduledep_concordance

if 1==1{
	
	use "${RMSdata}/products_2006-2014.dta", clear
							// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
		keep product_module_code product_group_code department_code
		duplicates drop
		save ${data}/product_module_department_concordance.dta, replace
		
		keep product_module_code
		cap isid product_module_code
		if _rc != 0 bys product_module_code: keep if _n==1
		
		sort product_module_code
		isid product_module_code
		save ${data}/productmodule_list.dta, replace
		export delimited using ${programs}/productmodule_list.txt, replace novar delimiter(tab)
			// Note: these lists are used in the 0_ step code, i.e., up to 0c_createproductids.do.
			//		Later code uses a subset of these lists including only product modules that don't
			//		have "CT" or "EXP" as their units.  These lists have a _noncount suffix.
			
		isid product_module_code
		local nyrs = 2014-2006 + 1
		expand `nyrs'
		bys product_module_code: gen year = 2006 + _n-1
		isid product_module_code year
		export delimited using ${programs}/productmodule_year_list.txt, replace novar delimiter(tab)

}

end
*=========================================================================================================================================================
*==================================================================================================	
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	cd "$data"
	main
	cd "$programs"
	capture log close

*==================================================================================================
*==================================================================================================
	
