*==========================================================================================
*** 0b_createproductids_ctlbrandsRMS.do
***	Identify brand information for each product in RMS data and assigns retailer-specific brand id for control brands 
*** 	the output of this do file is to be used in 0c_createproductids.do to create a brand data set of all products in RMS
***				and in 1c_RMS_datasetup.do to merge in upc brand info 
*==========================================================================================
*** Directory Set-up		

	args runprogram pmodule year firstmodline lastmodline
	
	global runprogram "`runprogram'"
	global pmodule "`pmodule'"
	global year "`year'"
	global firstmodline "`firstmodline'"
	global lastmodline "`lastmodline'"

*Set project directories
	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global repooutput "$programs/../RepoOutput"
		
*Set directory to data directory
	cd "$data"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	set more off, perm
	set matsize 10000
	#delimit cr

*===================================================================================================
* Sub-programs
*===================================================================================================

capture program drop ctlbrandsRMS_bymodyr
program define ctlbrandsRMS_bymodyr

if 1==1{
		
	* identify product brands
		di "Module -- ${pmodule} -- ${year}"
		
		capture confirm file ${RMSdata}/WorkingFiles/month_${pmodule}_${year}.dta
		if _rc==0{
			use upc upc_ver_uc store_code_uc year using ${RMSdata}/WorkingFiles/month_${pmodule}_${year}.dta, clear
					// created in 0a_dataconstruct/RMS/1_createworkingfiles.do
			
			bys upc upc_ver_uc store_code_uc year: keep if _n==1
			
			di "Merge in chain code of each store"
				merge m:1 store_code_uc year using ${data}/storechainloc.dta, keepusing(chain_code) keep(1 3)
					// created in 0a_rawdataconvert.do
					// contains store information, including chain, channel, dma, and location
					// chain_code = retailer_code if non-missing, parent_code+10000 otherwise
				
				rename chain_code retailer_code
				count if retailer_code==.
			
			di "Collapse data to upc-retailer-year level"
				des, fullname
				keep upc upc_ver_uc year retailer_code
				bys upc upc_ver_uc year retailer_code: keep if _n==1
			
			di "Merge in product info (brand, module, etc.)"
				merge m:1 upc upc_ver_uc using ${RMSdata}/products.dta, keep(1 3)
						// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
				tab _merge, m
				drop if _merge<3
				rename_products
				
				gen ctlbr=(substr(brand_descr,1,6)=="CTL BR") 
				checkretailernum
				
		*Generate new retailer-specific brand codes and descriptions for control brands
			capture drop _merge
			rename retailer_code chain_code
			merge m:1 chain_code using ${data}/RMS_retailer_groupchain.dta, keep(1 3)
					// created in 0a_rawdataconvert.do
			tab _merge, m
			tab _merge if chain_code==., m 
			drop _merge
			
			sum brand
			local magbrand=length(string(`r(max)',"%10.0g"))
			replace brand=brand+groupchain*10^(`magbrand') if ctlbr==1
			tostring chain_code, gen(chainstr)
			replace brand_descr=brand_descr+" chain "+chainstr if ctlbr==1
			di "check that no control brands are sold in stores without retailer ids:"
				count if chainstr=="" & ctlbr==1
			keep year upc upc_ver_uc pm brand brand_descr chain_code ctlbr
			bys year upc upc_ver_uc pm brand brand_descr chain_code ctlbr: keep if _n==1
			sort year upc upc_ver_uc chain_code
			
			save ${data}/RMSbrand_bymodule/RMSupcbrand_${pmodule}_${year}.dta, replace						
		}

}
end
*===================================================================================================
cap prog drop ctlbrandsRMS_smallappend
prog define ctlbrandsRMS_smallappend

if 1==1{

	use ${data}/productmodule_list.dta, clear
			// created in 0a_rawdataconvert.do (pmoduledep_concordance, which also creates productmodule_list.txt)
		
		sort product_module_code
		keep if _n >= ${firstmodline} & _n <= ${lastmodline}
		levelsof product_module_code, local(pmod)
		isid product_module_code
			
	* append together upc brand information across module and year	
		local first = 1
		foreach p of local pmod{
			foreach yr of numlist 2006/2014{
				di "Module -- `p' -- `yr'"						
				capture use ${data}/RMSbrand_bymodule/RMSupcbrand_`p'_`yr'.dta, clear
				if _rc==0{
					if `first' == 0 append using ${data}/temp/RMSbrand_bymodule_smallappend/RMSbrands_${firstmodline}_${lastmodline}.dta
					save ${data}/temp/RMSbrand_bymodule_smallappend/RMSbrands_${firstmodline}_${lastmodline}.dta, replace
					local first = 0
				}
			}
		}

}
end
*===================================================================================================
cap prog drop ctlbrandsRMS_bigappend
prog define ctlbrandsRMS_bigappend

if 1==1{

	local first = 1
	forv i = 1(100)1302{
		local j = `i' + 100 - 1 
		di "`i' -- `j'"						
		capture use ${data}/temp/RMSbrand_bymodule_smallappend/RMSbrands_`i'_`j'.dta, clear
		if _rc==0{
			if `first' == 0 append using ${data}/RMSbrands.dta
			save ${data}/RMSbrands.dta, replace
			local first = 0
		}
	}

}
end

*===========================================================================================
* Programs called in ctlbrandsRMS_bymodyr
*===========================================================================================
if 1==1{
	*** Programs to rename variables in Kilts data
	capture program drop rename_products
	program define rename_products

		foreach var in "upc upc" "upc_ver_uc upc_ver_uc" "upc_descr upc_descr" ///
			"pm product_module_code" "pm_descr product_module_descr" ///
			"pg product_group_code" "pg_descr product_group_descr" ///
			"dept department_code" "dept_descr department_descr" ///
			"brand brand_code" "brand_descr brand_descr" {
			local vname=word("`var'",1)
			local vlabel=word("`var'",2)
			disp "`vname' `vlabel'"
			if "`vname'" != "`vlabel'" {
				rename `vlabel' `vname'
			}
			label var `vname' "`vlabel'"
		}

	end

	cap prog drop checkretailernum
	prog define checkretailernum
	
		*Check whether control brand UPCs are sold in more than one retailer
		disp "check how many retailers per brand generally:"
			bys brand: egen nretailers_perbrand=nvals(retailer_code)
			sum nretailers, d
		disp "check how many retailers per control brand:"
			sum nretailers if ctlbr==1, d
		disp "check whether control brand UPCs are sold in more than one retailer"
			bys upc upc_ver_uc brand: egen nretailers=nvals(retailer_code)
			sum nretailers if ctlbr==1, d
		disp "in the same year?"
			capture bys upc upc_ver_uc brand panel_year: egen nretailers_yr=nvals(retailer_code)
			if _rc !=0{
				bys upc upc_ver_uc brand year: egen nretailers_yr=nvals(retailer_code)
			}
			sum nretailers_yr if ctlbr==1, d
	
	end
}

*===================================================================================================
*	Execute programs
*===================================================================================================
	
	${runprogram}
