*==========================================================================================
*** 0c_createproductids.do
***	Create product id for all products in RMS and HMS data
*==========================================================================================
*** Directory Set-up		
		
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global repooutput "$programs/../RepoOutput"
	
*Name/date/time
	global name="0c_createproductids"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	
*Set directory to data directory
	cd "$data"

*===========================================================================================
*** Preliminary Set-up						

	clear
	set more off, perm
	set matsize 10000
	#delimit cr

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	di "adjust control brand code and description in HMS data so that control brand code and descriptions are store-specific" 
		p_ctlbrandsHMS, strtyr(2006) endyr(2014)
			// ctlbrandsRMS created in 0b_createproductids_ctlbrandsRMS.do
			
	di "identifies modal units used in each module"
		p_units		
	
	di "creates product identifiers and a concordance between productids and upc/upc_ver_uc "
		p_productids, datasource("RMS"), strtyr(2006) endyr(2014)
		p_productids, datasource("HMS"), strtyr(2006) endyr(2014)
		prodidsync_RMS_HMS

	di "save RMS productid module by module"
		RMSprodid_bymodule

end

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
*	Replace control brands with store categorization or channelid categorization (p_ctlbrandsHMS)
*===================================================================================================
capture program drop p_ctlbrandsHMS
program define p_ctlbrandsHMS
	syntax [anything], strtyr(integer) endyr(integer)

if 1==1{

	clear 
	capture log close
	log using "$logs/${name}_ctlbrands_${cdate}_${ctime}.log", replace

	*Start with trips data for grouped retailer_codes
		multiyearinput "trips" "trip_code_uc retailer_code panel_year" `strtyr' `endyr' ""
		disp "number of trips without chain_ids:"
		count if retailer_code==.
		egen groupchain=group(retailer_code)
		sum groupchain
		tostring retailer_code, gen(retailerstr)
		sort panel_year trip_code_uc
		tempfile trips
		save `trips', replace
	
	*Merge trips data with trip and upc identifiers from purchases data
		multiyearinput "purchases" "trip_code_uc upc upc_ver_uc" `strtyr' `endyr' panel_year
		bys panel_year trip_code_uc upc upc_ver_uc: keep if _n==1
		merge m:1 panel_year trip_code_uc  using `trips', keep(3) nogen
		keep upc upc_ver_uc retailer_code panel_year
		bys upc upc_ver_uc retailer_code panel_year: drop if _n>1
		compress
		sort upc upc_ver_uc 
		tempfile retailerupc
		save `retailerupc'
	
	*Merge with products data
		use "${RMSdata}/products.dta", replace 
				// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
					
		* retrieve retailer information for control brand upcs
			rename_products	
			sort upc upc_ver_uc
			merge 1:m upc upc_ver_uc using `retailerupc', keep(3) nogen
		
		*Identify control brands
			gen ctlbr=(substr(brand_descr,1,6)=="CTL BR")
	
		*Check whether control brand UPCs are sold in more than one retailer
			checkretailernum
	
		***Control brand goods are sold in different chains under the same UPC.
		*These UPCs will have different brands for each retailer.
		*For these UPCs, there will be more than one productid.

		**NB retailer_code indicates a retail chain

		*Generate new retailer-specific brand codes and descriptions for control brands
			egen groupchain=group(retailer_code)
		 	sum brand
			local magbrand=length(string(`r(max)',"%10.0g"))
			gen brand_old = brand
			label var brand_old "brandid before recoding for control brands" 
			replace brand=brand+groupchain*10^(`magbrand') if ctlbr==1
			tostring retailer_code, gen(retailerstr)
			gen brand_descr_old = brand_descr 
			replace brand_descr=brand_descr+" chain "+retailerstr if ctlbr==1
			di "check that no control brands are sold in stores without retailer ids:"
			count if retailerstr=="" & ctlbr==1
			keep panel_year upc upc_ver_uc pm brand brand_descr brand_descr_old retailer_code ctlbr brand_old
			duplicates drop
			sort panel_year upc upc_ver_uc retailer_code
			save "$data/HMSbrands.dta", replace				

	***Look at number of brands per module dealing with control brands in different ways
		use "$data/HMSbrands.dta", clear
		checkbrandnum
	
	capture log close

}
end

*===================================================================================================		
*	Determine an uniform unit for products in each module (p_units)
*===================================================================================================		

capture program drop p_units
program define p_units

if 1==1{

	capture log close
	log using "$logs/${name}_units_${cdate}_${ctime}.log", replace

	import excel using ${rawmisc}/measurementunitconversion.xlsx, clear firstrow
	tempfile tempmeasure
	save `tempmeasure'
	
	*** Decide on units to use for each module and drop modules where it's unclear and UPCs that don't have these units

	use "${RMSdata}/products.dta", clear	
			// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
		
	*Rename product identifier variables to make more manageable
		rename_products
	
	*Figure out units
		*Based on 3rd and 4th characters, as advised in documentation
			gen size1_units_clean=subinstr(size1_units," ", "", .)
			gen size1_units_last2=subinstr(size1_units," ", "", .)
		
		*Deal with count issue:
			replace size1_units_last2="CT" if size1_units=="COUNT" | size1_units=="CTEXP"
			replace size1_units_last2="FT" if size1_units_last2=="YD" | size1_units=="MLM"
			replace size1_units_last2="OZ" if size1_units_last2=="PO" | size1_units_last2=="LB" | size1_units_last2=="UN"
			replace size1_units_last2="ML" if  size1_units_last2=="LI" | ///
				size1_units_last2=="QU" | size1_units_last2=="QT" |  size1_units_last2=="CF"
		
		*adjust size1_amount accordingly
			merge m:1 size1_units_clean size1_units_last2 using `tempmeasure', nogen keep(1 3)
			count if conversionrate==.
			count if size1_units_clean == size1_units_last2
			count if conversionrate==. & size1_units_clean == size1_units_last2
			replace conversionrate=1 if conversionrate==. & size1_units_clean == size1_units_last2
			count if conversionrate==.
			
			count if size1_amount==.
			gen size1_amount_updated= size1_amount*conversionrate
			count if size1_amount_updated==.
			rename size1_units_last2 size1_units_updated
			
		*Look at modules with low modal units shares
			sort pm size1_units_updated
			by pm: egen pm_upccount=nvals(upc upc_ver_uc)
			by pm size1_units_updated: egen pmsize_upccount=nvals(upc upc_ver_uc)
			gen sizeshare=pmsize_upccount/pm_upccount
			by pm: egen pmsize_maxshare=max(sizeshare)

		*Drop these modules where there isn't a clear dominant units 
			*(this is generally because some UPCs have "count" units and others have "OZ" units 
		disp "modules without a clearly dominant units categorization - dropped"
			tab pm_descr if pmsize_maxshare<0.75, m
			drop if pmsize_maxshare<0.75
			
		*Drop the UPCs that aren't in the "modal" units category
		disp "UPCs dropped because not measured in modal units for the module"
			drop if sizeshare!=pmsize_maxshare
		disp "remaining UPCs"
			count
			
	*Save for merging with purchases data
		sort upc upc_ver_uc
		save "${data}/size1_units.dta", replace	

	*Identify modules by their updated units
		keep pm size1_units_updated
		capture rename size1_units_last2 size1_units_updated
		bys pm size1_units_updated: keep if _n==1
		save "${data}/size1_units_pm.dta", replace

	*Create an updated list of product modules that doesn't include those with "CT" or "EXP" as units
		use ${data}/productmodule_list.dta, clear
					// created in 0a_rawdataconvert.do
		gen order=_n
		tempfile temp
		save `temp'
		
		use "${data}/size1_units_pm.dta", clear
		rename pm product_module_code 
		merge 1:1 product_module_code using `temp', keep(2 3)
		drop if size1_units_updated=="" | size1_units_updated=="CT" | size1_units_updated=="EXP"
		sort order
		
		preserve
			keep product_module_code
			isid product_module_code
			save ${data}/productmodule_list_noncount.dta, replace
			export delimited using ${programs}/productmodule_list_noncount.txt, replace novar delimiter(tab)
		restore
		
		expand 9
		bys product_module_code: gen year = 2006 + _n - 1
		sort order year
		keep product_module_code year
		isid product_module_code year
		export delimited using ${programs}/productmodule_year_list_noncount.txt, replace novar delimiter(tab)
		
	capture log close

}
end

*===================================================================================================
*	Create product ids (p_productids)
*===================================================================================================
capture program drop p_productids
program define p_productids
	syntax [anything], datasource(string) strtyr(integer) endyr(integer)

if 1==1{

	clear 
	capture log close
	log using "$logs/${name}_productids_${cdate}_${ctime}.log", replace
	
	* Merge in product characteristics with brands and sizes
		use "${data}/`datasource'brands.dta", clear
				// created in 0b_createproductids_ctlbrandsRMS.do for RMS data
				// created in subprogram p_ctlbrandsHMS in this do file for HMS data
		capture confirm variable panel_year
		if _rc!=0 rename year panel_year

		capture rename chain_code retailer_code
		gen ctlbr_retailer_id=retailer_code if ctlbr==1
		keep panel_year upc upc_ver_uc pm brand brand_descr ctlbr_retailer_id
		duplicates drop

		sort upc upc_ver_uc
		merge m:1 upc upc_ver_uc using "${data}/size1_units.dta"
				// created in subprogram p_units
		tab _merge, m
		drop if _merge<3
		drop _merge
		sort panel_year upc upc_ver_uc

	* Look where characteristics are missing
		foreach var in pm brand size1_amount_updated multi {
			capture count if `var'==.
			capture count if `var'==""
			local miss=r(N)
			display "`var': `miss' missing"
		}

	* Drop where pm brand or size are missing
		gen drop = 0
		foreach var in brand size1_amount_updated {
			count if `var' == .
			replace drop=1 if `var' == .
		}
		drop if drop==1

	* Replace other missing product characteristics with a number representing a "missing" category
		foreach v in multi {
				egen min`v'=min(`v')
				replace `v'=min`v'-10 if `v'==.
				replace `v'=-10 if `v'==.
				drop min`v'
		}

	*Create product characteristics
		egen productid=group(pm brand)

	*Check productid is never missing
		count if productid==.

	*Drop duplicates
		disp "**first duplicates by all relevant productid characteristics"
			duplicates drop
			sort panel_year upc upc_ver_uc productid pm brand size1_amount_updated multi
			by panel_year upc upc_ver_uc productid pm brand size1_amount_updated multi: gen dup1=(_n>1)
			tab dup1, m
			drop if dup1>0
		disp "**now drop duplicates that show that within a brand, upcs have more than one set of characteristics in a year"
			bys panel_year upc upc_ver_uc brand: gen dup2=(_n>1)
			tab dup2, m
			drop if dup2>0
		disp "**now figure out how many upc-brands have changing characteristics"
			bys upc upc_ver_uc brand: gen dup3=(_N)
			tab dup3, m
			collapse dup1, by(panel_year upc upc_ver_uc ctlbr_retailer_id productid pg pm brand brand_descr size1_amount_updated multi) fast
			drop dup1
			sort panel_year upc upc_ver_uc brand
			save "${data}/`datasource'productids.dta", replace
			
	capture log close

}
end

*===================================================================================================
*	Create product id that is same across RMS and HMS data  (prodidsync_RMS_HMS)
*===================================================================================================
cap prog drop prodidsync_RMS_HMS
prog define prodidsync_RMS_HMS

if 1==1{
			
	di "Load RMS productid info"
		use productid brand pm using ${data}/RMSproductids.dta, clear

		duplicates drop		
		isid productid
		rename productid RMSproductid
		tempfile temp
		save `temp'
		
	di "Load HMS productid info"
		use productid brand pm using ${data}/HMSproductids.dta, clear

		duplicates drop 
		isid productid
		rename productid HMSproductid
		
	di "Merge in RMS productid by product characteristics"
		merge 1:1 brand pm using `temp', keepusing(RMSproductid)
		tab _merge, m
		drop _merge
		
		isid brand pm
		gen masterproductid = _n
		
		isid masterproductid
		tempfile tempmaster
		save `tempmaster'
		
	di "Save consistent ids for all products appearing in either RMS or HMS data"
		drop RMSproductid HMSproductid
		rename masterproductid productid
		save ${data}/productids.dta, replace
		
		foreach v in "HMS" "RMS" {
			use ${data}/`v'productids.dta, clear
			
			merge m:1 brand pm using `tempmaster', keepusing(`v'productid masterproductid) keep(1 3)
			tab _merge
			drop _merge
			count
			count if productid == `v'productid
			
			drop productid `v'productid
			rename masterproductid productid
			
			save ${data}/`v'productids.dta, replace
			
			* keep only food products for later reference
				rename pm product_module_code
				merge m:1 product_module_code using ${data}/product_module_department_concordance.dta, keep(1 3) keepusing(product_group_code department_code)
						// created in 0a_rawdataconvert.do
				
				tab _merge
				drop _merge
				
				keep if (department_code>=1 & department_code<=6)  | product_group_code==6018
					** department_code==1: dry grocery
					** department_code==2: frozen food
					** department_code==3: dairy
					** department_code==4: deli
					** department_code==5: packaged meat
					** department_code==6: fresh produce
					** department_code==8 is alcohol (now dropped)
					** product_group_code==6108 is vitamins 
					
				rename product_module_code pm 
				drop product_group_code department_code

				save ${data}/`v'productids_food.dta, replace
		}

}
end 

*===================================================================================================
*	Break down RMS productid data set by module (RMSprodid_bymodule)
*===================================================================================================

cap prog drop RMSprodid_bymodule
prog define RMSprodid_bymodule

if 1==1 {
		
	use ${data}/RMSproductids.dta, clear
	keep productid brand pm
	bys productid brand pm: keep if _n==1
	isid productid

	cap mkdir "${data}/RMSproductid_bymodule/"
	di "${data}/RMSproductid_bymodule/"

	levelsof pm, local(pmlist)
	foreach p of local pmlist{
		preserve
			keep if pm == `p'
			save ${data}/RMSproductid_bymodule/RMSproductids_`p'.dta, replace
		restore
	}

}
end

*===================================================================================================
* Reference programs (called within the sub-programs above)
*===================================================================================================
	
	*===================================================================================================
	***   Program to input multi-year HMS datasets (multiyearinput)
	capture program drop multiyearinput
	program define multiyearinput
		args dataset inputvar minyear maxyear yearvar
			
	if 1==1{

		// data created in 0a_dataconstruct/HMS/0_dataimport_vN.do
			* trips: trip_code_uc household_code retailer_code store_code_uc panel_year store_zip3 total_spent purchase_date
			* purchase: trip_code_uc upc upc_ver_uc quantity total_price_paid coupon_value deal_flag_uc panel_year
		tempfile inputdata
		forvalues year=`minyear'/`maxyear' {
			if "`inputvar'"=="" {
				use "$HMSdata/`dataset'`year'.dta", clear
			}
			if "`inputvar'"!="" {
				use `inputvar' using "$HMSdata/`dataset'`year'.dta", clear
			}
			if "`yearvar'"!="" {
				gen `yearvar'=`year'
			}
			if `year'>`minyear' {
				append using `inputdata'
			}
			save `inputdata', replace
		}

	}
	end

	*===================================================================================================
	* called in p_ctlbrandsHMS
	cap prog drop checkretailernum
	prog define checkretailernum
	
	if 1==1{

		*Check whether control brand UPCs are sold in more than one retailer
		disp "check how many retailers per brand generally:"
			bys brand: egen nretailers_perbrand=nvals(retailer_code)
			sum nretailers, d
		disp "check how many retailers per control brand:"
			sum nretailers if ctlbr==1, d
		disp "check whether control brand UPCs are sold in more than one retailer"
			bys upc upc_ver_uc brand: egen nretailers=nvals(retailer_code)
			sum nretailers if ctlbr==1, d
		disp "in the same year?"
			capture bys upc upc_ver_uc brand panel_year: egen nretailers_yr=nvals(retailer_code)
			if _rc !=0{
				bys upc upc_ver_uc brand year: egen nretailers_yr=nvals(retailer_code)
			}
			sum nretailers_yr if ctlbr==1, d

	}
	end
	*===================================================================================================
	* called in p_ctlbrandsRMS
	cap prog drop checkbrandnum
	prog define checkbrandnum
	
	if 1==1{

	*Check number of brands in each product module with and without control brands
		bys pm: egen nbrands=nvals(brand)
		gen brand_nonctl = brand if ctlbr!=1
		by pm: egen nbrands_nonctl=nvals(brand_nonctl) if ctlbr!=1		
		by pm: gen pmfirst=(_n==1)
		sum nbrands if pmfirst==1, d
		sum nbrands_nonctl if pmfirst==1, d

	*How many brands grouping control brands?
		use "${RMSdata}/1_moduleyear/Data/products.dta", replace 
			// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo_vN.do
		
		rename_products	
		bys pm: egen nbrands_ctlgp=nvals(brand)
		by pm: gen pmfirst=(_n==1)
		sum nbrands_ctlgp if pmfirst==1, d
	
	}
	end
	
	*===================================================================================================
	*** Programs to rename variables in Kilts data
	capture program drop rename_products
	program define rename_products
		
	if 1==1{

		foreach var in "upc upc" "upc_ver_uc upc_ver_uc" "upc_descr upc_descr" ///
			"pm product_module_code" "pm_descr product_module_descr" ///
			"pg product_group_code" "pg_descr product_group_descr" ///
			"dept department_code" "dept_descr department_descr" ///
			"brand brand_code" "brand_descr brand_descr" {
			local vname=word("`var'",1)
			local vlabel=word("`var'",2)
			disp "`vname' `vlabel'"
			if "`vname'" != "`vlabel'" {
				rename `vlabel' `vname'
			}
			label var `vname' "`vlabel'"
		}

	}
	end
	*===================================================================================================
	* rename variables in products data
	capture program drop rename_products_extra
	program define rename_products_extra

	if 1==1{

		foreach var in flavor form formula container salt_content style type product ///
			variety organic_claim usda_organic_seal common_consumer_name ///
			strength scent dosage gender target_skin_condition use {
				rename `var'_code `var'
				label var `var' "`var'_code"
		}

	}
	end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	cd "$data"
	main
	cd "$programs"
	capture log close

*==================================================================================================
*==================================================================================================
	

