*===========================================================================================
*** 1a_HMS_purchasedata.do
***	Clean household purchase data
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"
	
* Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"

*Name/date/time
	global name="1a_HMS_purchasedata"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	
*Set directory to data directory
	cd "$data"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	set more off, perm
	set matsize 10000
	#delimit cr

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main

	di "Create a trip data at household-store-month level recording households total expenditure and number of visit"
		HHtrips
		
	di "Select households who report their purchase continuously and whose records are most accurate"	
		p_households week
		p_households month
		p_households quarter
		p_households semester
		p_households year

	di "Clean household purchase data"
		* household-product-month
			p_NHPdata, time("month") 
			
		* household-product-quarter
			p_NHPdata, time("quarter")

		* household-product-week
			p_NHPdata, time("week week_end")
			
		* household-product-year
			p_NHPdata, time("year")

	di "generate HMSdata_.dta by collapsing HMSstoreleveldata_.dta"
		p_collapse2HMSdata, time("month")
		p_collapse2HMSdata, time("year")
			
end

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
* create household purchase data sets at weekly, monthly, quarterly, and semesterly level 
*===================================================================================================
capture prog drop HHtrips
prog define HHtrips  

if 1==1{

	multiyearinput "trips" "trip_code_uc household_code purchase_date panel_year store_code_uc total_spent" 2006 2014 ""
	
	isid trip_code_uc panel_year
	gen year = year(purchase_date)
	gen month = month(purchase_date)
	
	* calculate total expenditure and total number of trips each household makes to each store in each month 
	gen numtrips=1
	collapse (sum) numtrips totalexp = total_spent, by(household_code store_code_uc year month) fast
	
	tab numtrips, m
	sum totalexp, d
	
	save ${data}/HHtrips.dta, replace

}
end

*===================================================================================================
* figure out which households are purchasing goods over entire months and entire quarters
*===================================================================================================
capture program drop p_households
program define p_households
	args time
	
if 1==1{

	clear 

	*Calculate dates from the trips data
		multiyearinput "trips" "trip_code_uc panel_year purchase_date household_code" 2006 2014 ""
		sum purchase_date, d
		tab purchase_date if _n<20
		gen year=year(purchase_date)
		gen month=month(purchase_date)
		gen day=day(purchase_date)
	
	if "`time'"!="week"{
		*If we have daily data, dropping households that:
		* a) aren't in the sample for 3 or more weeks in a month, or
		* b) drop out of the sample for 2 or more weeks in a month
		if `r(N)'>0 {
			gen date=mdy(month,day,year)
			sort household_code date
			bys household_code year month: egen mindate=min(date)
			by household_code year month: egen maxdate=max(date)
			gen timeframe=maxdate-mindate+1
			by household_code year month: gen timeframehh=timeframe if _n==1
			sum timeframehh, d
			gen prob=1 if timeframe<21
			sort household_code date
			bys household_code year month: gen gap=date-date[_n-1]
			replace prob=1 if gap>14 & gap!=.
				by household_code year month: egen drop=max(prob)
			drop if drop==1
		}
		drop drop prob timeframe date
		
		*If we are going to look at the data on a quarterly frequency, 
		* drop households that aren't in the data for all three months in a quarter
		if "`time'"=="quarter" {
			drop if month==.
			tab year
			tab month
			gen quarter=year*10+floor((month-1)/3)+1
			bys household_code year quarter: egen nmonths=nvals(month)
			drop if nmonths<3
			drop nmonths
		}	
		
		* for semesterly data, keep households that are in the data for all six months		
		if "`time'"=="semester" {
			drop if month==.
			tab year
			tab month
			gen semester = yh(year, halfyear(dofm(ym(year, month))))
			bys household_code year semester: egen nmonths=nvals(month)
			drop if nmonths<6
			drop nmonths
		}	
		
		if "`time'"=="year" {
			drop if month==.
			tab year
			tab month
			bys household_code year: egen nmonths=nvals(month)
			drop if nmonths<12
			drop nmonths
		}	
	}
	else{
		preserve
		keep year purchase_date
		duplicates drop
		gen weekday = dow(purchase_date)
		gen week_end = purchase_date + (6-weekday)
		isid purchase_date
		tempfile tempweek
		save `tempweek'
		restore
		
		merge m:1 purchase_date using `tempweek', keepusing(weekday week_end)
		tab _merge, m
		drop if _merge<3
		drop _merge
		
		count if week_end ==.
		egen week = group(week_end)
		sum week, d
	}
	
	sort panel_year trip_code_uc 
	isid panel_year trip_code_uc
	save "${data}/households`time'.dta", replace

}
end
		
*===================================================================================================
* clean household purchase data
*===================================================================================================
capture program drop p_NHPdata
program define p_NHPdata
	syntax [anything], time(string) [test(string)]

if 1==1{

	clear 
	capture log close
	log using "$logs/${name}_NHPdata_`time'_${cdate}_${ctime}.log", replace

	local timesuffix "`time'"
	
	local minyear 2006
	local maxyear 2014
	
	di "timesuf: `timesuffix'; years: `minyear' to `maxyear' "
	
	*Input trips data (only use 2012 for previous _oldtest)
		multiyearinput "trips" "trip_code_uc retailer_code store_code_uc panel_year" `minyear' `maxyear' ""
		sort trip_code_uc panel_year
		tempfile trips
		save `trips'

	*Merge purchases data with productids and collapse out upc and upc_ver_uc
		tempfile purchases
		forvalues year=`minyear'/`maxyear' {
			disp "Year: `year'"
			if "`test'"=="test" use "$HMSdata/purchases`year'.dta" if _n<10000, clear
			else use "$HMSdata/purchases`year'.dta", clear
					// data created in 0a_dataconstruct/HMS/0_dataimport.do

			*Merge with trips data to get retailer_id and household code
				capture gen panel_year=`year'
				sort trip_code_uc panel_year
				merge m:1 trip_code_uc panel_year using `trips'
				disp "Purchases in `year' merged with trips in all years (to get retailer_id)"
				tab _merge, m
				drop if _merge<3
				drop _merge 
			
			*Merge with brands data to get control brand brands
				capture drop brand
				sort panel_year upc upc_ver_uc retailer_code
				merge m:1 panel_year upc upc_ver_uc retailer_code using "$data/HMSbrands.dta"
						// created in 0c_createproductids.do (p_ctlbrandsHMS)
																				
				disp "Purchases in `year' merged with brands in all years (to get brands)"
					tab _merge
					drop if _merge<3
					drop _merge
				
			*Merge with product_ids and characteristics data
				sort panel_year upc upc_ver_uc brand
				merge m:1 panel_year upc upc_ver_uc brand using "${data}/HMSproductids.dta"
						// created in 0c_createproductids.do (p_productids and prodidsync_RMS_HMS)
																	
				disp "Purchases in `year' merged with all product_ids from all years"
					tab _merge, m
					drop if _merge<3
					drop _merge
				
			*Calculate prices and quantities and collapse to productid level
				gen value = (total_price_paid - coupon_value)
				gen amt = quantity*size1_amount_updated*multi
				gen uv=value/amt
				bys upc upc_ver_uc: egen medianuv=median(uv)
				gen deviationuv=uv/medianuv
				sum deviationuv,d
				drop if deviationuv>3 | deviationuv<1/3
				drop medianuv uv deviationuv
				
			*Collapse to productid level
				collapsesum, sumvars("quantity value amt") byvars(trip_code_uc retailer_code store_code_uc pg pm brand productid)
				gen panel_year=`year'
				compress
				
			*Merge with households data
				capture drop _merge
				sort panel_year trip_code_uc
				merge m:1 panel_year trip_code_uc using "${data}/households`timesuffix'.dta"
					// created in subprogram p_households
				tab _merge, m
				drop if _m<3

			*Collapse trip dimension and append to save
				gcollapse (sum) quantity value amt, by(year `time' retailer_code store_code_uc pg pm brand productid household_code)
				if `year'>`minyear' append using "${data}/HMSstoreleveldata_`timesuffix'`test'.dta"
				save "${data}/HMSstoreleveldata_`timesuffix'`test'.dta", replace
					// note 1: duplicates for store_code_uc = 0 taking multiple retailer_code values
					// note 2: duplicates due to December purchases appearing in next year's data 
								
		}
		
	capture log close

}
end

*===================================================================================================
* collapse out store from HMS purchase data, for stylized facts
*===================================================================================================
capture program drop p_collapse2HMSdata
program define p_collapse2HMSdata
	syntax [anything], time(string) [test(string)]
	
if 1==1 {

	local timesuffix "`time'"
	if strpos("`time'", "week")!=0 local timesuffix "week"
	
	if "`test'"=="test" local test="test"
	else local test=""
	
	use "${data}/HMSstoreleveldata_`timesuffix'`test'.dta", clear
			// created in subprogram p_NHPdata
	
	*Collapse store dimension 
		gcollapse (sum) quantity value amt, by(year `time' pg pm brand productid household_code)

	*Calculate unit value paid by household 
		gen uv=value/amt

	*Drop brands not purchased by 20 or more households
		bys brand: egen npurchases=nvals(household_code)
			
			// output list of dropped brands for comparison later in pipeline
			preserve
				keep if npurchases <20 
				bys brand pm: keep if _n == 1
				keep brand pm 
				save ${terminal}/2_preestimation_analysis/STATAData/HMS_droppedbrands_`timesuffix'`test'.dta, replace
			restore 

		drop if npurchases<20

	*Double check that there aren't too many brands (or too few products per module)
		bys pm: gen first=(_n==1)
		bys pm: egen nbrand=nvals(brand)
		sum nbrand if first==1, d
		local nbrand=r(max)
		assert `nbrand'<5000
		bys pm: egen nproduct=nvals(productid)
		sum nproduct if first==1, d
		drop nbrand nproduct first

	*Generate module "counter"
		egen groupmod=group(pm)
		sum groupmod

	*** Save dataset
		compress
		save "${data}/HMSdata_`timesuffix'`test'.dta", replace
}	
end

*===================================================================================================
* Reference programs (called within the sub-programs above)
*===================================================================================================
	
	*===================================================================================================
	***   Program to input multi-year HMS datasets (multiyearinput)
	capture program drop multiyearinput
	program define multiyearinput
		args dataset inputvar minyear maxyear yearvar
			
	if 1==1{

		// data created in 0a_dataconstruct/HMS/0_dataimport.do
			* trips: trip_code_uc household_code retailer_code store_code_uc panel_year store_zip3 total_spent purchase_date
			* purchases: trip_code_uc upc upc_ver_uc quantity total_price_paid coupon_value deal_flag_uc panel_year
		tempfile inputdata
		forvalues year=`minyear'/`maxyear' {
			if "`inputvar'"=="" {
				use "$HMSdata/`dataset'`year'.dta", clear
			}
			if "`inputvar'"!="" {
				use `inputvar' using "$HMSdata/`dataset'`year'.dta", clear
			}
			if "`yearvar'"!="" {
				gen `yearvar'=`year'
			}
			if `year'>`minyear' {
				append using `inputdata'
			}
			save `inputdata', replace
		}

	}
	end

*==================================================================================================
*==================================================================================================

**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	main
	cd "$programs"
	capture log close

*==================================================================================================
*==================================================================================================
	

