*==========================================================================================
*** 1b_HMS_demographicdata.do		
***	Clean up household demographic data and create household size-adjusted income
*==========================================================================================
*** Directory Set-up	
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"
	
* Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"

*Name/date/time
	global name="1b_HMS_demographicdata"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	
*Set directory to data directory
	cd "$data"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	set more off, perm
	set matsize 10000
	#delimit cr

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	* clean up household demographic data
		p_hhdata
	
	* adjust household income with household size and number of kids
		p_hhincadj
	
end

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
* Demographic data
*===================================================================================================
capture program drop p_hhdata
program define p_hhdata

if 1==1{

	*Which households are used in the analysis (i.e. purchase frequently enough in a month)
		use panel_year household_code using "${data}/householdsmonth.dta", clear
				// created in 1a_HMS_purchasedata.do
				
		bys panel_year household_code: keep if _n==1
		tempfile hhs
		save `hhs'

	*Pull data for each year...
		forvalues year=2006/2014 {
			use "$HMSdata/panelists`year'.dta", clear
					// created in 0a_dataconstruct/HMS/0_dataimport.do
			rename_panelists 
			disp "`year'"
			tab hhinc 
			drop if fips_county==.

		*Keep useful variables and check that these variables don't vary within a household in a panel_year
			gen fipscode=fips_state*1000+fips_county
			keep household_code region_code fipscode scantrack_marketid hhzip hhsize hhinc hhkids ///
				f_age m_age marital race hisp m_ed f_ed wic f_occ m_occ hhcomp member_*_birth
			duplicates drop
			gen i=1
			bys household_code: egen count=count(i)
			tab count
			local n=r(r)
			if `n'>1 {
			disp "error: more than one market per household-year"
				assert 1==2
			} 
			gen panel_year=`year'
			tempfile hhdata`year'
			save `hhdata`year''
		}

	*Append datasets together		
		use `hhdata2006', clear
		forvalues y=2007/2014 {
			append using `hhdata`y''
		}

	*Keep households that are in the analysis
		capture drop merge
		sort panel_year household_code
		merge panel_year household_code using `hhs'
		tab _merge, m
		drop if _merge<3

	*Interpret codes for each demographic variable
		**Household Income (using 1.3*topcoded income level)
			gen income=.
			replace income=2500 if hhinc==3
			replace income=6500 if hhinc==4
			replace income=9000 if hhinc==6
			replace income=11000 if hhinc==8
			replace income=13500 if hhinc==10
			replace income=17500 if hhinc==11
			replace income=22500 if hhinc==13
			replace income=27500 if hhinc==15
			replace income=32500 if hhinc==16
			replace income=37500 if hhinc==17
			replace income=42500 if hhinc==18
			replace income=47500 if hhinc==19
			replace income=55000 if hhinc==21
			replace income=65000 if hhinc==23
			replace income=85000 if hhinc==26
			replace income=112500 if hhinc==27
			replace income=100000*1.3 if (panel_year<2006 | panel_year>2009) & hhinc==27
			replace income=137500 if hhinc==28
			replace income=175000 if hhinc==29
			replace income=200000*1.3 if hhinc==30
		    gen lninc=ln(income)

		**Head of Household Ages
			foreach v in m f {
				gen `v'_age_yrs=23 if `v'_age==1
				replace `v'_age_yrs=27 if `v'_age==2
				replace `v'_age_yrs=32 if `v'_age==3
				replace `v'_age_yrs=37 if `v'_age==4
				replace `v'_age_yrs=42 if `v'_age==5
				replace `v'_age_yrs=47 if `v'_age==6
				replace `v'_age_yrs=52 if `v'_age==7
				replace `v'_age_yrs=60.5 if `v'_age==8
				replace `v'_age_yrs=70 if `v'_age==9
				replace `v'_age_yrs=. if `v'_age==0
			}
			gen avgage=(m_age_yrs+f_age_yrs)/2
			replace avgage=m_age_yrs if f_age_yrs==.
			replace avgage=f_age_yrs if m_age_yrs==.

		**Education levels
			foreach v in m f {
				gen `v'_ed_yrs=8 if `v'_ed==1
				replace `v'_ed_yrs=10 if `v'_ed==2
				replace `v'_ed_yrs=12 if `v'_ed==3
				replace `v'_ed_yrs=14 if `v'_ed==4
				replace `v'_ed_yrs=16 if `v'_ed==5
				replace `v'_ed_yrs=18 if `v'_ed==6
				replace `v'_ed_yrs=. if `v'_ed==0
			}
			gen avged=(m_ed_yrs+f_ed_yrs)/2
			replace avged=m_ed_yrs if f_ed_yrs==.
			replace avged=f_ed_yrs if m_ed_yrs==.		

		**Number of children
			gen nkids=0
			forvalues m=1/7 {
				gen member_`m'_birthyear=substr(member_`m'_birth,1,4)
				destring member_`m'_birthyear, replace
				sum member_`m'_birthyear
				gen member_`m'_age=panel_year-member_`m'_birthyear
				gen member_`m'_kid=(member_`m'_age<=18 & member_`m'_age!=.)
				replace nkids=nkids+(member_`m'_kid)
			}
			tab nkids hhsize
			tab nkids hhkids
			disp "hhkids==9 implies no children present"
			replace nkids=0 if hhkids==9
			replace nkids=1 if hhkids==1 & nkids==0
			replace nkids=2 if hhkids==4 & nkids==1
			replace nkids=2 if hhkids==5 & nkids==1
			replace nkids=4 if hhkids==7 & nkids==1

		*Drop students and WIC recipients, and look at remaining household incomes
			tab income panel_year
			tab income panel_year if (hhsize==1 & (f_occ==10 | m_occ==10)) | (f_occ==10 & m_occ==10)
			tab income panel_year if wic== 1      //wic=="Y"
		*These variables are sparsely populated, so stick with dropping households with incomes below $8,000
			
		sort household_code panel_year
		save "${data}/hhid_char.dta", replace


	*Look at variables
		foreach var in marital race hisp m_age f_age m_ed f_ed {
			sort `var'
			tab `var', gen(`var'_d)
		}
	
}
end
 

*===================================================================================================
*** Household income measurements
*===================================================================================================
capture program drop p_hhincadj
program define p_hhincadj

if 1==1{

	clear

	*Calculate annual household expenditures
		use household_code value year month using "${data}/HMSdata_month.dta", clear
				// created in 1a_HMS_purchasedata.do
														
		collapse (sum) totalexp=value, by(year month household_code) fast
		collapse (sum) totalexp (count) nmonths=totalexp, by(year household_code) fast
		tab nmonths, m
		replace totalexp=totalexp*12/nmonths
		gen panel_year=year
		sort household_code panel_year
		tempfile exp
		save `exp'

	*Merge hh characteristics with expenditures
		use "$data/hhid_char.dta", clear
				// created in subprogram p_hhdata
		
		* drop households with income below $12,000
			drop if hhinc<8
			drop hhinc
		
		sort household_code panel_year
		capture drop  _merge
		merge household_code panel_year using `exp'
		tab _merge
		drop if _merge<3
		drop _merge

	*Replace missings with zeros for single-member households
		replace m_ed=0 if m_ed==.
		replace f_ed=0 if f_ed==.
		replace m_age=0 if m_age==.
		replace f_age=0 if f_age==.

	*Calculate outside good expenditures
		gen outexp=income-totalexp
		gen lnoutexp=ln(outexp)
		rename lninc lnincome
		
	*Adjust income and outside good expenditures for household size
		foreach v in income outexp {
			rename `v' `v'_unadj
			rename ln`v' ln`v'_unadj
			gen `v'=`v'/(hhsize^0.5)
			gen ln`v'=ln(`v')
			
		}
		keep income* lninc* outexp* lnout* nkids hhsize household_code panel_year hhzip fipscode

		sort household_code panel_year
		save "${data}/incomeadj.dta", replace

}
end

*===================================================================================================
* Reference programs (called within the sub-programs above)
*===================================================================================================
capture program drop rename_panelists
program define rename_panelists

if 1==1{

	foreach var in "hhinc household_income" ///
		"hhsize household_size" "residence type_of_residence" ///
		"hhcomp household_composition" "hhkids age_and_presence_of_children" ///
		"m_age male_head_age" "f_age female_head_age" ///
		"m_emp male_head_employment" "f_emp female_head_employment" ///
		"m_ed male_head_education" "f_ed female_head_education" ///
		"m_occ male_head_occupation" "f_occ female_head_occupation" ///
		"m_birth male_head_birth" "f_birth female_head_birth" ///
		"scantrack_marketid scantrack_market_code" ///
		"hhzip panelist_zip_code" "fips_state fips_state_code" "fips_county fips_county_code" ///
		 "wic wic_indicator_current" {
		local vname=word("`var'",1)
		local vlabel=word("`var'",2)
		disp "`vname' `vlabel'"
		if "`vname'" != "`vlabel'" {
			rename `vlabel' `vname'
		}
		label var `vname' "`vlabel'"
	}			
	rename scantrack_market_descr scantrack_marketid_descr

}
end

*==================================================================================================	
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	main
	cd "$programs"
	capture log close

*==================================================================================================
*==================================================================================================
	

