*==========================================================================================
*** 1c_RMS_datasetup.do
***	calculate product sales value and amount at store-month level 
*==========================================================================================
	
	args pmodule year initialfreq
	* pmodule = product_module_code to process data for
	* year = year of data to process data for
	* initialfreq == "month" if RMS data read in at the beginning is at monthly frequency; output data is at monthly; quarterly; semesterly; and annually frequency

	foreach x in pmodule year initialfreq {
		global `x' "``x''"
	}

*===========================================================================================
*** Directory Set-up	

*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/0b_dataimport"
	
* Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global processeddata "${currentstep}/../0_dataimport/STATAData"

*Name/date/time for log files
	global name="1c_RMS_datasetup"
	
*Set directory to data directory
	cd "$data"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	set more off, perm
	set matsize 10000
	#delimit cr

*==================================================================================================
* Primary program
*==================================================================================================
capture prog drop RMS_product_month 
prog define RMS_product_month

if 1==1{

	di "Set up directory"
		cap mkdir ${data}/store_semester_product${pdef}
		cap mkdir ${data}/store_month_product${pdef}
		cap mkdir ${data}/store_quarter_product${pdef}
		cap mkdir ${data}/store_year_product${pdef}
		
	di "Directory for raw data"
		global rawdir "${RMSdata}"
		
	di "Load data for module ${pmodule} in ${year}"
		
		cap use ${rawdir}/WorkingFiles/${initialfreq}_${pmodule}_${year}.dta
				// created in 0a_dataconstruct/RMS/1_createworkingfiles.do

		if _rc==0 {
			* confirm data is at store-upc-${initialfreq} level
				cap isid store_code_uc upc upc_ver_uc product_module_code year ${initialfreq}
				if _rc != 0	collapse (sum) value units, by(store_code_uc upc upc_ver_uc product_module_code year ${initialfreq}) fast				
				
				di "Merge in retailer code of each store"
					merge m:1 store_code_uc year using ${data}/storechainloc.dta, keepusing(chain_code) keep(1 3)
							// created in 0a_rawdataconvert.do
							// contains store information, including chain, channel, dma, and location
							// chain_code = retailer_code if non-missing, parent_code+10000 otherwise
				
					count if chain_code==.
					drop if _merge<3
					drop _merge
								
				di "Merge in brand information"
					merge m:1 year upc upc_ver_uc chain_code using ${data}/RMSbrand_bymodule/RMSupcbrand_${pmodule}_${year}.dta, keep(1 3) keepusing(brand)
							// created in 0b_createproductids_ctlbrandsRMS.do
					tab _merge, m
					drop if _merge<3
					drop _merge
				
				di "Merge in product id"
					rename year panel_year
					merge m:1 upc upc_ver_uc panel_year brand using ${data}/RMSproductids.dta, keep(1 3) keepusing(multi size1_amount_updated productid)
							// created in 0c_createproductids.do
				
					tab _merge, m
					drop if _merge<3
					drop _merge
				
					count 
					if r(N)>0{
						di "Convert units into common units"
							gen commonunits = units*multi*size1_amount_updated
						
						di "Generate mean and std of upc-level unit value"
							gen unitvalue=value/commonunits
							quietly sum unitvalue, d
							
						di "Collapse data to store-${initialfreq}-product level"
							rename panel_year year
							bys store_code_uc year ${initialfreq} productid product_module_code: gen ttvalue = sum(value)
							bys store_code_uc year ${initialfreq} productid product_module_code: gen ttcommonunits = sum(commonunits)
							bys store_code_uc year ${initialfreq} productid product_module_code (ttvalue): keep if _n==_N
							drop value commonunits
							rename ttvalue value
							rename ttcommonunits commonunits
							
						di "Calculate unit value of each product in each store-${initialfreq}"
							isid store_code_uc year ${initialfreq} productid
							cap drop unitvalue
							gen unitvalue=value/commonunits
							quietly sum unitvalue, d
							
						di "Calculate within-module sales share of each product in each store-${initialfreq}"
							bys store_code_uc year ${initialfreq}: egen ttvalue = total(value)
							gen expshare = value/ttvalue
							
							keep store_code_uc year ${initialfreq} productid product_module_code value commonunits unitvalue expshare
						
							save ${data}/store_${initialfreq}_product/${initialfreq}_${pmodule}_${year}_productlevel.dta, replace
						
						if "${initialfreq}" == "month"{
							
							timeagg, timevar("quarter")							
							save ${data}/store_quarter_product/quarter_${pmodule}_${year}_productlevel.dta, replace
							
							timeagg, timevar("semester")	
							save ${data}/store_semester_product/semester_${pmodule}_${year}_productlevel.dta, replace
							
							timeagg, timevar("year")	
							save ${data}/store_year_product/year_${pmodule}_${year}_productlevel$dta, replace
							
						}
					}
		}

}
end

*===================================================================================================
* Reference program (called by RMS_product_month)
*===================================================================================================

cap prog drop timeagg
prog define timeagg
	syntax [anything], timevar(string) 
	
if 1==1{
	if "`timevar'" == "quarter"{
		gen quarter = yq(year(dofm(month)), quarter(dofm(month)))
		local timevarlist "year quarter"
	}
	else if "`timevar'" == "semester"{
		gen semester = yh(year(dofq(quarter)), halfyear(dofq(quarter)))
		local timevarlist "year semester"
	}
	else if "`timevar'" == "year" local timevarlist "year"
	
	di "Collapse data to store-`timevar'-product level"
		drop unitvalue expshare
		bys store_code_uc `timevarlist' productid product_module_code: gen ttvalue = sum(value)
		bys store_code_uc `timevarlist' productid product_module_code: gen ttcommonunits = sum(commonunits)
		bys store_code_uc `timevarlist' productid product_module_code (ttvalue): keep if _n==_N
		drop value commonunits
		rename ttvalue value
		rename ttcommonunits commonunits

	di "Calculate unit value of each product in each store-month"
		isid store_code_uc `timevarlist' productid
		gen unitvalue=value/commonunits
		
	di "Calculate within-module sales share of each product in each store-month"
		bys store_code_uc `timevarlist': egen ttvalue = total(value)
		gen expshare = value/ttvalue
		
		keep store_code_uc `timevarlist' productid product_module_code value commonunits unitvalue expshare

}
end

*==================================================================================================	
*==================================================================================================
**** Run programs and reset directory

	di "Product module: ${pmodule}"
	di "Year: ${year}"
	
	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_${pmodule}_`cdate'_`ctime'.log", replace
	RMS_product_month
	cd "$programs"
	capture log close

	
*==================================================================================================
*==================================================================================================
	

