 *===========================================================================================
*** 2_incomedistchecks.do
*** compare distribution of household income in HMS data with that in ACS
*** compare distribution of income around stores to that around stores in the CBP
*==========================================================================================

*===========================================================================================	
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/0b_dataimport"	

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global logs "$currentstep/STATALogs"
	global output "$currentsteprepo/RepoOutput"

*Directory to tmp data
	global temp "${data}/temp"

*===========================================================================================
*For log files:

	global name="2_incomedistchecks"

*==================================================================================================	
*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	HMSincomecheck
		
	RMSincomecheck

end

*==================================================================================================	
*==================================================================================================
**** Sub-programs

capture program drop HMSincomecheck
program define HMSincomecheck	

if 1==1{
	di "Load and clean ACS income data"
		import delimited using ${rawcensus}/ACS/ACS_12_1YR_S1901.csv, clear varn(1)
		keep hc01_est_vc*
		
		foreach n of numlist 12/20{
			capture des hc01_est_vc`n', fullname
			capture drop hc01_est_vc`n'
		}
		
		rename hc01_est_vc01 ttHHnum
		foreach n of numlist 2/11{
			local incgrp = `n'-1
			if `n'<10{
				rename hc01_est_vc0`n' hhinc`incgrp'
			}
			else{
				rename hc01_est_vc`n' hhinc`incgrp'
			}
		}
		
		keep if _n== 2
		destring *, replace
		
		reshape long hhinc@, i(ttHHnum) j(inccat)
		
		replace hhinc = round((hhinc*ttHHnum)/100)
		gen z1 = .
		gen z2 = .
		
		replace z1 = 0 if inccat == 1
		replace z2 = 10000 if inccat == 1
		
		replace z1 = 10000 if inccat == 2
		replace z2 = 15000 if inccat == 2
		
		replace z1 = 15000 if inccat == 3
		replace z2 = 25000 if inccat == 3
		
		replace z1 = 25000 if inccat == 4
		replace z2 = 35000 if inccat == 4
		
		replace z1 = 35000 if inccat == 5
		replace z2 = 50000 if inccat == 5 
		
		replace z1 = 50000 if inccat == 6
		replace z2 = 75000 if inccat == 6 

		replace z1 = 75000 if inccat == 7
		replace z2 = 100000 if inccat == 7 
		
		replace z1 = 100000 if inccat == 8
		replace z2 = 150000 if inccat == 8 

		replace z1 = 150000 if inccat == 9
		replace z2 = 200000 if inccat == 9 
		
		replace z1 = 200000 if inccat == 10
		replace z2 = 200000*1.3 if inccat == 10 
		
		gen midpoint = (z1+z2)/2
		replace z2 = . if inccat == 10 
		
		list
		count
		local numobs = r(N) * 5
		
		capture ssc install dagfit
		dagfit hhinc, z1(z1) z2(z2)
		set obs `numobs'
		gen inctest = 4000*(_n-1)
		gen acs_hhinc_fitted =  e(ba)*e(bp)*e(bb)^(-1*e(ba)*e(bp))*inctest^(-1+e(ba)*e(bp))*(1+(inctest/e(bb))^e(ba))^(-1-e(bp)) 
		
		keep acs_hhinc_fitted inctest
		tempfile tempacs2012
		save `tempacs2012'
	
	di "Load panelist income data"
		use "${HMSdata}/panelists2012.dta", clear 
		rename household_income HHInc
		
		gen count = 1
		collapse (sum) count, by(HHInc) fast
	
		gen z1 = .
		gen z2 = .
		
		replace z1 = 0 if HHInc == 3
		replace z2 = 5000 if HHInc == 3
		
		replace z1 = 5000 if HHInc == 4
		replace z2 = 8000 if HHInc == 4
		
		replace z1 = 8000 if HHInc == 6
		replace z2 = 10000 if HHInc == 6
		
		replace z1 = 10000 if HHInc == 8
		replace z2 = 12000 if HHInc == 8
		
		replace z1 = 12000 if HHInc == 10
		replace z2 = 15000 if HHInc == 10
		
		replace z1 = 15000 if HHInc == 11
		replace z2 = 20000 if HHInc == 11
		
		replace z1 = 20000 if HHInc == 13
		replace z2 = 25000 if HHInc == 13

		replace z1 = 25000 if HHInc == 15
		replace z2 = 30000 if HHInc == 15
		
		replace z1 = 30000 if HHInc == 16
		replace z2 = 35000 if HHInc == 16
		
		replace z1 = 35000 if HHInc == 17
		replace z2 = 40000 if HHInc == 17
		
		replace z1 = 40000 if HHInc == 18
		replace z2 = 45000 if HHInc == 18
		
		replace z1 = 45000 if HHInc == 19
		replace z2 = 50000 if HHInc == 19
		
		replace z1 = 50000 if HHInc == 21
		replace z2 = 60000 if HHInc == 21
		
		replace z1 = 60000 if HHInc == 23
		replace z2 = 70000 if HHInc == 23
		
		replace z1 = 70000 if HHInc == 26
		replace z2 = 100000 if HHInc == 26
		
		replace z1 = 100000 if HHInc == 27
		replace z2 = 125000 if HHInc == 27
		
		replace z1 = 125000 if HHInc == 28
		replace z2 = 150000 if HHInc == 28
		
		replace z1 = 150000 if HHInc == 29
		replace z2 = 200000 if HHInc == 29
		
		replace z1 = 200000 if HHInc == 30
		replace z2 = 200000*1.3 if HHInc == 30
		
		gen midpoint = (z1+z2)/2
		replace z2 = . if HHInc == 27
	
	di "Kernel comparison plot"
		list
		count
		local numobs = r(N) * 3
		
		dagfit count, z1(z1) z2(z2)
		set obs `numobs'
		gen inctest = 4000*(_n-1)
		gen HMS_hhinc_fitted =  e(ba)*e(bp)*e(bb)^(-1*e(ba)*e(bp))*inctest^(-1+e(ba)*e(bp))*(1+(inctest/e(bb))^e(ba))^(-1-e(bp)) 
		
		merge 1:1 inctest using `tempacs2012', nogen
		
		label variable HMS_hhinc_fitted "Homescan Household Income"
		label variable acs_hhinc_fitted "ACS Household Income"
		twoway (line HMS_hhinc_fitted inctest, lpattern(solid) lc(black)) (line acs_hhinc_fitted inctest, lpattern(dash) lc(black)),     ///
			legend(col(1)) xtitle("Household Income") graphregion(color(white)) bgcolor(white) 
		graph export ${output}/ACS_HMS_IncomeDist_2012.eps, replace
	}
	
}

end

********************************************************************************
********************************************************************************

capture program drop RMSincomecheck
program define RMSincomecheck	

* import census tempfile

	nhgis_pcincomepop_countyuse ${data}/countyincome,clear
	rename countypcincome pcincome
	keep county pcincome
	tempfile tempcensus
	save `tempcensus',replace
	
	use store_code_us fips_state_code fips_county_code using ${step0adata}/stores_2012.dta
		// created 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
	gen county = fips_state_code*1000 + fips_county_code
	sort county
	merge m:1 county using `tempcensus' 
	keep if  _merge == 3
	drop _merge
	keep store_code_uc pcincome 
	gen dataset = 1
	rename store_code_uc storeid
	tempfile RMS
	save `RMS'

* import CBP data
	import delimited ${rawdata}/cbp/2016/cbp16co/cbp16co.txt, clear
	keep if inlist(naics,"445110","445120", "446110", "447110", "452910", "452990", "7225") 
		//445110: Supermarket; 
		//445120: Convenience stores  
		//446110: Pharmacies and Drug Stores
		//447110: Gasoline Stations with Convenience stores
		//452910: Warehouse Clubs and Supercenters
		//452990: All Other General Merchandise Stores including dollar stores
	gen county = fipstate*1000 + fipscty
	rename est stores
	keep county stores
	merge m:1 county using `tempcensus', keep(match) nogenerate
	gen dataset = 2
	append using `RMS'

	* equal-weighted (i.e. by store counts)
	twoway (kdensity pcincome if dataset ==1)(kdensity pcincome [weight = stores] if dataset ==2,clpattern(dash) clcolor(black)), ///
	xtitle("Store-weighted median county income") ytitle("") legend(rows(1) label(1 "Nielsen") label(2 "CBP")) xlabel(,labsize(small)) ylabel(,labsize(small))
	graph export "${repooutput}/NielsenCBP_income_equalweight.eps", replace 
}
	
end

*==================================================================================================
capture program drop nhgis_pcincomepop_county  
	program define nhgis_pcincomepop_county
	
	syntax [anything]
	
	insheet using "${rawNHGIS}/2014/nhgis0008_ds206_20145_2014_county.csv", names comma clear 
		// downloaded from nhgis.org 07/07/2017
		// Dataset: 2006-2012 ACS 5-year estimate, All counties within the United States
	keep name_e statea countya aba1e001 abfie001
	gen county=statea*1000+countya
	drop statea countya
	rename name_e countyname
	rename aba1e001 countypopulation
	rename abfie001 countypcincome // Per Capita Income in the Past 12 Months (in 2014 Inflation-Adjusted Dollars)
		
end			


*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	set linesize 200
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*==================================================================================================
