*===========================================================================================
*** 0a_infer_storezip_from_HMS.do
*** Infer store zip locations based on the location of its modal customer
*===========================================================================================

*** Directory Set-up

*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "${terminal}/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentsteprepo/RepoOutput"
	global logs "$currentstep/STATALogs"
	
*==================================================================================================
**** Program to run sub-programs

cap prog drop main 
prog def main 

	storezip_from_number_of_hh

end

*===================================================================================================
* Sub-programs
*===================================================================================================

cap prog drop storezip_from_number_of_hh
prog define storezip_from_number_of_hh

	clear 
	tempfile tripdata
	save `tripdata', replace emptyok
	
	foreach yr of numlist 2006/2017 {
		di "Read trip data `yr'"

		use ${HMSdata}/trips`yr'.dta, clear 
				// created in 0a_dataconstruct/HMS/0_dataimport.do

		drop if store_code_uc == 0 | mi(store_code_uc)  //select scanner stores
		keep store_code_uc household_code  store_zip3
		gduplicates drop
		
		cap merge m:1 household_code using ${HMSdata}/panelists`yr'.dta, keepusing(panelist_zip_code) keep(3) nogen
				// created in 0a_dataconstruct/HMS/0_dataimport.do
		if _rc != 0 {
			merge m:1 household_code using ${HMSdata}/panelists`yr'.dta, keepusing(panelist_zipcd) keep(3) nogen
			rename panelist_zipcd panelist_zip_code
		}
		
		** drop households that are not from the store zip3
		gen hh_zip3 = int(panelist_zip_code/100) 
		drop if store_zip3 != hh_zip3 & !mi(store_zip3)
		sort store_cod panel
		gcollapse (count) nhousehold = household_code ,by(store_code_uc panelist_zip_code) fast

		append using `tripdata'

		** sum over years
		gcollapse (sum) nhousehold, by(store_code_uc panelist_zip_code) fast
		save `tripdata', replace		
	}
	
	dis "assign stores with the zipcode where highest number of trips come from"

		sort store_code_uc panelist_zip_code nhousehold
		bys store_code_uc: egen max_household = max(nhousehold)
		keep if nhousehold == max_household
		drop if max_household == 1
		bys store_code_uc: gen n = _N
		drop max_household
		distinct store_code_uc	
		save "${data}/storezip_from_HMS_nhouseholds.dta",replace
	
end

*==================================================================================================
**** Run programs

main

*==================================================================================================
