*===========================================================================================
*** 0b_storedensityestimation.do
*** Program to estimate density of household shopping trips/expenditure around stores
*===========================================================================================

*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "${terminal}/1_dataprep"

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"
	global temp "${data}/temp"
	global logs "$currentstep/STATALogs"
	global output "$currentsteprepo/RepoOutput"

*===========================================================================================
**** Program to run sub-programs

cap prog drop main 
prog def main 
if 1 == 1 {

	** Step (1) - calculate share of store expenditure to each household within a 30km radius of the store 
	
		** (a) create store-household year data including: 
		** 		- store expenditure spent by household x at distance d 
		** 		- distance d between store and household zip 
			distanceDensity
		
		** (b) create concordance between store and store type and population density 
			storetypeConcord
		
	** Step (2) - estimate density of sales (expenditure) by distance from store; generate plots for draft appendix
		
		shareexpint
		
	** Step (3) - estimate income distirbution as a function of distance 
	
		** (a) create store-bracket level dataset with estimated number of hh that shop at the store in a given bracket
			incdist
			
		** (b) estimate income parameters for inc dist at store
			* separate dofile: 0c_store_incomeparameterest.do

}
end

*===================================================================================================
* Sub-programs
*===================================================================================================

cap prog drop distanceDensity
prog def distanceDensity
if 1 == 1 {

	dis "** (A) Create household-store-year level data with distance between store and household **"
	if 1 == 1 { 
		
		** zipcode locations
			insheet using ${rawcensus}/Gaz_zcta_national.txt, clear
				// downloaded from http://census.gov/geographies/reference-files/time-series/geo/gazetteer-files.2010.html
			rename geoid zipcode
			rename intptlat zclat
			rename intptlong zclong
			tempfile tempzip_poploc
			save `tempzip_poploc', replace
			
		** prepare the geo location of household residence zipcode
			tempfile temphhloc
			foreach yr of numlist 2010/2014 {
				use "${HMSdata}/panelists`yr'.dta", clear
					// created in: 0b_dataimport/1b_HMS_demographicdata.do
				keep household_code panelist_zip_code
				rename panelist_zip_code zipcode
				gen year = `yr'
				
				if `yr' > 2010 append using `temphhloc' 
				save `temphhloc', replace
			}		
			* merge in zipcode location
			merge m:1 zipcode using `tempzip_poploc', keepusing(zclat zclong) keep(3) nogen
				// created by above
			isid household_code year
			keep household_code year zipcode zclat zclong
			rename zipcode hhzip
			save `temphhloc', replace

		** Stores assigned zips by the modal zip of visiting households
			use store_code_uc panelist_zip_code using ${data}/storezip_from_HMS_nhouseholds.dta, clear
				// created in 0a_infer_storezip_from_HMS.do
			rename panelist_zip_code zipcode
			tostring zipcode, replace format(%05.0f)
			* merge in zipcode location
			merge m:1 zipcode using `tempzip_poploc', keepusing(zclat zclong) nogen
				// created by above
			drop if zclat == . | zclong == .
			bysort store_code_uc: keep if _N == 1 // drop ties
			rename (zipcode zclat zclong) (stzip slat slong)
			tempfile tempstoreloc
			save `tempstoreloc'
			
		** household trips data
			tempfile temptrips
			foreach yr of numlist 2010/2014{
				use ${HMSdata}/trips`yr'.dta, clear
					// created in 0a_dataconstruct/HMS/0_dataimport.do
				keep household_code store_code_uc purchase_date total_spent
				gen year = year(purchase_date)
				gen month = month(purchase_date)
				
				gen count = 1
				collapse (sum) count exp = total_spent, by(household_code store_code_uc year month) fast
				
				if `yr' > 2010 append using `temptrips'
				save `temptrips', replace
			}
			
			use `temptrips', clear
			collapse (sum) count exp, by(household_code store_code_uc year month) fast
			
		** merge in household location (centroid location of residence zipcode)
			merge m:1 household_code year using `temphhloc', nogen keep(3)
			
		** merge in store location
			merge m:1 store_code_uc using `tempstoreloc', nogen keep(3)
				
		** calculate approximate distance between households and stores
			geodist slat slong zclat zclong, gen(hh_store_dist)
			sum hh_store_dist, d
			
		** collapse to month level 
			bys household_code store_code_uc year: egen count_sum = sum(count)
			bys household_code store_code_uc year: egen exp_sum = sum(exp)
			bys household_code store_code_uc year: keep if _n == 1
			drop month count exp
			rename *_sum *
			
			save ${data}/HH_store_trip_datacheck.dta, replace
			
		** output list of stores and location for concordance (step B) 
			bys store_code_uc: keep if _n == 1
			export delimited store_code_uc slat slong using ${data}/store_longlat_HMS_modalHH.csv, replace
	}

	dis "** (B) Prepare storezip to hhzip concordance **"
	if 1 == 1 {	
		
		** create one observations per year 
			cap confirm file ${data}/zip2zip_pairDistance_HMS_modalHH.dta
			if _rc != 0 zip2zipprep
			use ${data}/zip2zip_pairDistance_HMS_modalHH.dta, replace
			gen year = 2010 
			forvalues yr = 2011(1)2014 {
				append using ${data}/zip2zip_pairDistance_HMS_modalHH.dta
				replace year = `yr' if year == . 
			}
			
			rename hhzip zipcode			
	
		** merge in zipcode population counts - to household zipcode 
			cap confirm file ${data}/zipcode_pop.dta
			if _rc != 0 zipcodepopulation
			merge m:1 zipcode year using ${data}/zipcode_pop.dta, keep(1 3)  
				// merge == 2 - zipcodes that are no represented in our store data
				// merge == 1 - zipcodes with no population data - less zips in Census population data -- see if issue later 	
			tab _merge
			rename _merge popmerge 
			label var popvar "household zipcode population"
		
		** merge in zipcode store counts - to household zipcode
			cap confirm file ${data}/HMS_modalHH_storecount_zip.dta
			if _rc != 0 zipcodeStoreCount
			merge m:1 zipcode using ${data}/HMS_modalHH_storecount_zip.dta, keep(1 3) 
				// _merge == 2 - zipcodes with no store-households - delete
				// _merge == 1 - zipcodes where households live but no stores 
			rename _merge storemerge
			label var storecount "household zipcode store count"	
		
		** calculate cummulative population
			gen negdist = -1*distance
			
			bys store_code_uc year (negdist): gen cumpop = sum(popvar) if popvar != . 
			bys store_code_uc year (negdist): gen cumstore = sum(storecount) if storecount != .  
		
		** save for merge 			
			save ${data}/hhzip2stzip_concordance.dta, replace
	}

	dis "** (C) Merge store-household-year data with store-household zip concordance **"
	if 1 == 1 {
		use ${data}/HH_store_trip_datacheck.dta, replace
			// created above in part (A)
		
		rename hhzip zipcode	
		merge m:1 store_code_uc zipcode year using ${data}/hhzip2stzip_concordance.dta, keepusing(cumpop cumstore distance) keep(1 3)
			// created above in part B 
			// _merge == 2 - hhzip-stzip match that doesn't exist in our data 
			// _merge == 1 - zips that didn't match -- issue 
		tab _merge
		
		** check that pairs with no match are further than 100miles away from one another
			replace distance = distance*1.609344 // miles to km
			sum distance hh_store_dist
			sum hh_store_dist if _merge == 1
			count if _merge == 1 & hh_store_dist < 160
				// all distance here is above 160 km (as expected)
			sum hh_store_dist if _merge == 3
				// some stores are greater than 160 kms (maybe these zips are really large)
				
			gen diff = abs(hh_store_dist - distance) 
			sum diff, d
				// average 0.06 km difference
				// median 0.01 km difference
	
		** keep only matched pairs
		drop if _merge == 1
		drop _merge
		
		save ${data}/finaldata.dta, replace
	}

	dis "** (D) Calculate shares and save **"
	if 1 == 1 { 	
		** calculate share of store sales going to specific distance 
		
			** collapse to store-distance-year level 
			bys store_code_uc year hh_store_dist: egen Texp = sum(exp)
			bys store_code_uc year hh_store_dist: egen Tcount = sum(count)
			bys store_code_uc year hh_store_dist: keep if _n == 1
			drop exp count
			rename T* *
			
			** calculate share of store sales going to specific distance 
			foreach var in exp count { 
				bys store_code_uc year: egen sum_`var' = sum(`var')
				gen share_`var' = `var'/sum_`var'
			}
			label var share_exp "Share of store expenditures"
			label var share_count "Share of store trips"		
			
		** label variables for clarity
			label var stzip "store zipcode"
			rename zipcode hhzip
			label var hhzip "household zipcode"
			label var zclat "zipcode latitude"
			label var zclong "zipcode longtitude"
			label var slat "store latitude"
			label var slong "store longitude"
			label var count "number of household-store trips"
			label var exp "expenditure of household in store"
			label var cumpop "Cumulative population from store location to household zip" 
			label var cumstore "Cumulative store count from store location to household zip" 
			label var distance "Distance between store location and potential household zips (km)"
			label var diff "difference between distance measures"
			label var hh_store_dist "Distance (km) between store location and household zip"
		
		* save data 
		isid hh_store_dist store_code_uc year
		save ${data}/household_tripexpshare.dta, replace
	}
	
	** remove temp files 
	rm ${data}/HH_store_trip_datacheck.dta
	rm ${data}/hhzip2stzip_concordance.dta
	rm ${data}/finaldata.dta
	
}
end

********************************************************************************
********************************************************************************
cap prog drop storetypeConcord
prog def storetypeConcord
if 1 == 1 {
	
	** list of stores used in our data
		use ${data}/household_tripexpshare.dta, replace
			// created above in distanceDensity
		bys store_code_uc year: keep if _n == 1
		keep store_code_uc year
	
		** merge in store type and store county
		merge m:1 store_code_uc using ${RMSdata}/1_moduleyear/Data/stores_2012.dta, keep(1 3) keepusing(channel_code fips_state_code fips_county_code) nogen
				// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
		gen county_2000 = 1000*fips_state_code + fips_county_code
		drop fips_state_code fips_county_code

		** split by type of store
		tab channel_code
		gen storetype = 1 if channel_code == "F"
		replace storetype = 2 if channel == "M"
		replace storetype = 3 if channel == "C" | channel == "D"
		lab def typelbl 1 "Food" 2 "Mass Merch." 3 "Drug/Convenience"
		label val storetype typelbl
		drop channel
		tab storetype, missing
		drop if storetype == .
			
	** keep one observation per year
		bys store_code_uc: keep if _n == 1
		
	** split by population density of their counties 
		cap confirm file ${data}/county2000_popdens.dta
		if _rc != 0 countypopdens
		merge m:1 county_2000 using ${data}/county2000_popdens.dta, keep(1 3) nogen
			// all match 
			
		_pctile popdense, nq(100)
		gen density = 1 if popdense <= `r(r33)'
		replace density = 2 if popdense > `r(r33)' & popdense <= `r(r66)'
		replace density = 3 if popdense > `r(r66)' & popdense != . 
		label def denslbl 1 "Low" 2 "Medium" 3 "High"
		label val density denslbl
		drop popdense
		tab density
		
	tab density storetype
	
	** save concordance 
		label var storetype "type of store"
		label var density "density category (terciles)"
		label var county_2000 "store county code - 2000 codes"
		drop year
		
		save ${data}/storetypeConcordance.dta, replace
		
}

end

********************************************************************************
********************************************************************************

cap prog drop shareexpint
prog def shareexpint
if 1 == 1 {

	dis "** (A) prepare list of all stores - tract pairs within 30 kms of one another **"
		
		** list of all stores in our data
			use ${data}/household_tripexpshare.dta, replace
				// created in subprogram distanceDensity
			bys store_code_uc: keep if _n == 1
			keep store_code_uc
			tempfile storelist 
			save `storelist'
		
		** list of all tracts that are within a 30 km radius of the store 
			cap confirm file ${data}/ctract10_store_distances_HMS_modalHH.dta
			if _rc != 0 store2tractDist
			use store_code_uc tract state county hdist using ${data}/ctract10_store_distances_HMS_modalHH.dta, replace
				// created in reference program store2tractDist
			rename hdist store2tractdist
				
		** limit to stores in our data 
			merge m:1 store_code_uc using `storelist', nogen keep(3)
			
		** include store type and density level 
			merge m:1 store_code_uc using ${data}/storetypeConcordance.dta, nogen keep(1 3)
				// created in subprogram storetypeConcord
			
			save ${temp}/store2tract.dta, replace
			
	dis "** (B) append store-tract pairs to store-household-year data **"
	
		use ${data}/household_tripexpshare.dta, replace
			// created in subprogram distanceDensity
		
		** drop store-households that are above 50km b/c limited to tracts < 30km from store
		drop if hh_store_dist > 50 & hh_store_dist != . 
		
		** record store type and population density level 
		merge m:1 store_code_uc using ${data}/storetypeConcordance.dta, nogen keep(1 3)
			// created in subprogram storetypeConcord
		
		** append store-tract pairs 
		append using ${temp}/store2tract.dta
			// created above
		keep store_code_uc year store2tractdist hh_store_dist cumpop cumstore exp count storetype density tract state county county_2000
		mdesc
	
	dis "** (C) output sales density plots for paper **"
			
		forvalues s = 1(1)3 {
		
			local store_1 "Grocery Stores"
			local store_2 "Mass Merch. Stores"
			local store_3 "Drug/Convenience Stores"
			
			preserve
				keep if storetype == `s'
		
				twoway (kdensity hh_store_dist [aw = exp] if density == 1, lp(dot)) ///
					(kdensity hh_store_dist [aw = exp] if density == 2, lp(dash)) ///
					(kdensity hh_store_dist [aw = exp] if density == 3, lp(l)), ///
					legend(lab(1 "Low Pop. Density") lab(2 "Medium Pop. Density") lab(3 "High Pop. Density") ///
					row(1) size(small)) ///
					xtitle("Distance from Store (km)", size(medsmall)) ///
					ytitle("Density of Sales", size(medsmall))
				graph export ${output}/salesdensity_storetype`s'_bypopdens.eps, replace
					
			restore 
		}
		
	dis "** (D) interpolate exp. density for each store type x pop density level **"
	
		local first = 1 
		forvalues s = 1(1)3 { 
			forvalues p = 1(1)3 {
			
				** plot labels 
				local store_1 "Grocery Stores"
				local store_2 "Mass Merch. Stores"
				local store_3 "Drug/Convenience Stores"
				local pop_1 "Low Density"
				local pop_2 "Medium Density"
				local pop_3 "High Density"
				
				preserve
				
					keep if storetype == `s' & density == `p'
			
					** estimate density over 100 point distance grid
					kdensity hh_store_dist [aw = exp], ///
						gen(dist exp_hat_st`s'_pop`p') n(100) nograph 

					** interpolate for distance between tracts and stores ** need to interpolate on st
					replace dist = store2tractdist if store2tractdist != . 
					
					** interpolate for distance between tracts and stores 
					pchipolate exp_hat_st`s'_pop`p' dist, gen(exp_int_st`s'_pop`p')  
					sort dist
					
					** save interpolated data 
					keep if store2tractdist != . 
					keep store_code_uc state county tract store2tractdist exp_int*
					if `first' != 1 merge 1:1 store_code_uc state county tract using ${data}/storeexpnditure_tractDist_interpolate.dta, nogen
					save ${data}/storeexpnditure_tractDist_interpolate.dta, replace
				
					local first = `first'+1 
				restore

			}
		}
				
		
	dis "** (D) create store X tract level dataset with expected expenditure **"
		use ${data}/storeexpnditure_tractDist_interpolate.dta, replace
		
		** instead of missing data, have one variable which differs by store type X density
		egen expdensity = rowtotal(exp*)
		drop exp_int*
		label var expdensity "interpolated expenditure density"
		
		isid store_code_uc county state tract
		order store_code_uc state county tract 
		
		save ${data}/storeexpnditure_tractDist_interpolate.dta, replace
		
}
end

********************************************************************************
********************************************************************************
** program to interpolate expenditure share of store purches based on distance
cap prog drop incdist
prog def incdist
if 1 == 1 {

	** 2000 to 2010 tract relationship file 
		import delimited ${rawcensus}/us2010trf.txt, clear
			// downloaded from https://www.census.gov/geographies/reference-files/2010/geo/relationship-files.html
		rename v1 state00
		rename v2 county00
		rename v3 tract00
		rename v4 fips00
		rename v10 state10
		rename v11 county10
		rename v12 tract10
		rename v13 fips10
		rename v21 areapct00
		rename v23 areapct10
		rename v26 poppct00
		rename v27 poppct10
		drop v*
				
		** keep 2010 tract code with largest population crossover
		distinct fips00
		gen negpop = -1*poppct10
		bys fips10 (negpop): keep if _n == 1
		distinct fips00
			
		** create crosswalk from 2000 tract to 2010 tract
		keep state* county* tract*
		rename *00 *
		tempfile tract2tract
		save `tract2tract'
	

	** store-tract level data with estimated expenditure density by distance 
		use ${data}/storeexpnditure_tractDist_interpolate.dta, replace
			// created in subprogram shareexpint
			// 2010 tract codes 
		
		replace county = state*1000 + county
		drop state
		
		label var county "state-county 2010 code"
		label var tract "tract 2010 code"

	** merge in tract level income distribution
		// use 2012 Census data (2010-2014 ACS data) in 2010 tract codes
		cap confirm file ${data}/reg10demo_tract2012_household.dta
		if _rc != 0 {
			preserve
			cleanNHGIS2012
			restore
		}
		merge m:1 county tract using ${data}/reg10demo_tract2012_household.dta, keep(1 3)
				// created in subprogram cleanNHGIS2012
				// _1 = tracts that aren't in income data
			tab _merge
				// 0.02% missing income data 
			drop if _merge == 1
			drop _merge 
	
	** calculate weights for expenditure shares
		egen tractpop = rowtotal(inc*)
		gen popXexp = tractpop*expdensity
		bys store_code_uc: egen denom = sum(popXexp)
		gen weight = popXexp / denom
		bys store_code_uc: egen check = sum(weight)
		sum check
		drop popXexp denom check
		label var weight "expenditure density distance weight"
		
	** calculate number of people shopping at store s with income y 
		forvalues i = 1(1)16 {
			gen inc`i'_wgt = inc`i' * weight
		}
		gen tractpop_wgt = tractpop * weight
		
		collapse (sum) inc*_wgt tractpop_wgt weight, by(store_code_uc)
		sum weight
		
		* check # of people by income is same as # of people total 
		egen check = rowtotal(inc*_wgt)
		sum check tractpop
		drop weight check
		
		rename tractpop_wgt storepop
		label var storepop "number of total people shopping at store from surrounding tracts within 30km radius"
	
	** reshape long 
		rename inc*_wgt inc*
		reshape long inc, i(store_code_uc storepop) j(brkt)
		rename inc freq
	
	** record income stats for given income bracket 
		// put in 2000 dollars 
		
		local brktList 10 15 20 25 30 35 40 45 50 60 75 100 125 150 200 
		gen maxinc = . 
		forvalues i = 1(1)15 {
			local inc: word `i' of `brktList'
			replace maxinc = `inc'*1000*0.704 if brkt == `i'
		}
		gen mininc = maxinc[_n-1]
		replace mininc = 0 if brkt == 1
		
	** re-scaled densities (freq) so they sum to 1 across stores 
		bys store_code_uc: egen totpop = sum(freq)
		gen density = freq/totpop
		drop totpop

	** record midpoint of income
		gen midinc = (mininc+maxinc)/2
		
	** store groups
		egen storeN = group(store_code_uc)

	** clean and save
		label var maxinc "upper bound of inc brackt (2000$)"
		label var mininc "lower bound of inc brackt (2000$)"
		label var brkt "income bracket"
		label var freq "number of people of income i shopping in store s"
		label var density "share of store s belonging to income i"
		label var midinc "midpoint of income bracket"
			
		save ${data}/storeexpenditure_byincome.dta, replace	

}
end

*===================================================================================================
* Reference programs (called within the sub-programs above)
*===================================================================================================

** program to calculate distance between pairs of zips

cap prog drop zip2zipprep
prog def zip2zipprep
if 1 == 1 {

	** zipcode locations
		insheet using ${rawcensus}/Gaz_zcta_national.txt, clear
			// downloaded from http://census.gov/geographies/reference-files/time-series/geo/gazetteer-files.2010.html
			rename geoid zipcode
			rename intptlat zclat
			rename intptlong zclong
		tempfile tempzip_poploc
		save `tempzip_poploc', replace
		
	** Do this in groups of 1000
	local ngroups = ceil(_N/1000)
	tempfile zipappend
	forvalues group = 0/`ngroups' {
		import delimited using ${data}/store_longlat_HMS_modalHH.csv, clear
			// created in step (A) of distanceDensity

		keep if floor(_n/1000) == `group'

		** For each store, get every zip within 100 mi (distance from store's assigned zip's centroid to zip centroid)
		cross using `tempzip_poploc'
		geodist slat slong zclat zclong, gen(distance) miles
		keep if distance <= 100

		capture confirm file `zipappend'
		if _rc == 0 append using `zipappend'
		save `zipappend', replace
	}

	use `zipappend', clear

	** clean data
			rename zipcode hhzip
			label var hhzip "(potential) household zipcode within 100 miles of store zipcode"
			label var distance "distance between store and hh zipcode (miles)"
			//label var stzip "store zipcodes"
			drop *lat* *long*
			order store_code_uc hhzip distance
		
		** string zipcodes
			tostring hhzip, replace
			replace hhzip = "0" + hhzip if length(hhzip) <5
			replace hhzip = "0" + hhzip if length(hhzip) <5
		
		** save data 
		save ${data}/zip2zip_pairDistance_HMS_modalHH.dta, replace

}
end

********************************************************************************
** program to append zipcode population data across years 

cap prog drop zipcodepopulation
prog def zipcodepopulation
if 1 == 1 {

	preserve

	** append raw data 
	local files: dir "${rawNHGIS}/zipcode_population/" files "*.csv" 
	local a: word count `files'
	dis "there are `a' files"
	
	local first 1
	foreach file in `files' {
		
		import delimited using ${rawNHGIS}/zipcode_population/`file', clear
		
		tab year
		ds
		local varN: word count `r(varlist)'
		local popvar: word `varN' of `r(varlist)'
		rename `popvar' popvar
		
		keep gisjoin year zcta5a popvar
		tostring year, replace
		
		if `first' != 1 append using ${data}/zipcode_pop.dta
		save ${data}/zipcode_pop.dta, replace
		local first = `first' + 1
	}
	
	** clean year variable (for 5 yr samples, take final year as year)	
	replace year = substr(year, -4, 4)
	destring year, replace
	tab year
	
	** clean zipcode variable 
	rename zcta5a zipcode	
	tostring zipcode, replace
	replace zipcode = "0" + zipcode if length(zipcode) <5
	replace zipcode = "0" + zipcode if length(zipcode) <5
	
	keep year zipcode popvar
	save ${data}/zipcode_pop.dta, replace
	
	restore

}
end

********************************************************************************
** program to count number of stores in zipcode by year 

cap prog drop zipcodeStoreCount
prog def zipcodeStoreCount
if 1 == 1 {
	
	preserve

		* zip codes assigned to all stores
		use store_code_uc panelist_zip_code using ${data}/storezip_from_HMS_nhouseholds.dta, clear
			// created in 0a_infer_storezip_from_HMS.do
		rename panelist_zip_code zipcode
		tostring zipcode, replace
		replace zipcode = "0" + zipcode if length(zipcode) <5
		replace zipcode = "0" + zipcode if length(zipcode) <5

		* count number of stores by zipcode
		bys store_code_uc: keep if _N == 1 // drop ties
		bys zipcode: gen storecount = _N
		bys zipcode: keep if _n == 1
		keep zipcode storecount

		save ${data}/HMS_modalHH_storecount_zip.dta, replace
	
	restore

}
end

********************************************************************************

** program to calculate county population density with 2000 county codes 

cap prog countypopdens
prog def countypopdens
if 1 == 1 {
	
	** 2000 county area 
		clear
		infile using "${rawsocial}/R11667808.dct", using("${rawsocial}/R11667808_SL050.txt")

		destring FIPS, gen(county_2000)
		rename T004_001 area
		
		keep county_2000 area
		save ${data}/county2000_area.dta, replace
		
	** 2000 population 
		use ${data}/countypop00.dta, replace
		rename county county_2000
		
		merge 1:1 county_2000 using ${data}/county2000_area.dta, nogen
		
	** population density
		gen popdense = pop_county/area
		keep county_2000 popdense
		label var popdense "2000 county population density"
		save ${data}/county2000_popdens.dta, replace

}
end

********************************************************************************
** program to interpolate expenditure share of store purches based on distance

cap prog drop store2tractDist
prog def store2tractDist
if 1 == 1 {

	import delimited using ${rawNHGIS}/Gaz_tract_national.txt, clear
		// list of all census tracts with lat/long of centroids
		// downloaded from census.gov/geographies/reference-files/time-series/geo/gazetteer-files.2010.html
		keep geoid intptlong intptlat
		rename intptlong ctlong
		rename intptlat ctlat
		tempfile tracts
		save `tracts'

	** Do this in groups of 1000
	local ngroups = ceil(_N/1000)
	tempfile tractappend
	forvalues group = 0/`ngroups' {
		import delimited using ${data}/store_longlat_HMS_modalHH.csv, clear
			// created in step (A) of distanceDensity
		
		keep if floor(_n/1000) == `group'

		** For each store, get every tract within 30 km (distance from store's assigned zip's centroid to tract centroid)
		cross using `tracts'
		geodist slat slong ctlat ctlong, gen(hdist)
		drop if hdist > 30

		capture confirm file `tractappend'
		if _rc == 0 append using `tractappend'
		save `tractappend', replace

		use `tractappend', clear
	}

	** get fips codes 
	format geoid %12.0f
	tostring geoid, replace usedisplayformat 
	replace geoid = "0" + geoid if length(geoid) <11
	
	gen state = substr(geoid, 1, 2)
	gen county = substr(geoid, 3, 3)
	gen tract = substr(geoid, 6, 6)
	destring state county tract, replace
	
	keep store_code_uc state county tract hdist 
	
	save ${data}/ctract10_store_distances_HMS_modalHH.dta, replace

}
end

********************************************************************************
** program to process raw NHGIS data

cap prog drop cleanNHGIS2012
prog def cleanNHGIS2012
if 1 == 1 {

	local year = 2012
	local acsyr = 2014
			
	import delimited using ${rawNHGIS}/nhgis_medinc_`acsyr'_tract.csv, clear

	* process income variable
	keep gisjoin countya statea tracta abdoe*
	drop abdoe001	// total households
	rename abdoe00* abdoe*
	rename abdoe0* abdoe*
	
	forvalues i = 1(1)16 {
		local j = `i' + 1
		rename abdoe`j' hhinc`i'_hh
	}
	
	* clean tract variable
	gen tractid1 = string( tracta, "%06.0f")
	gen tractid2 = string(countya, "%03.0f")
	gen tractid3 = string(statea, "%02.0f")
	gen tractid = tractid3 + tractid2 + tractid1
	drop tractid1 tractid2 tractid3
	
	gen county = substr(tractid, 1, 5)
	gen tract = substr(tractid, 6, .)
	drop tractid
	destring county tract, replace

	order tract county
	sort county tract
	drop gisjoin statea countya tracta

	rename hhinc*_hh inc*
	
	save ${data}/reg10demo_tract`year'_household.dta, replace

}
end

*==================================================================================================
*==================================================================================================
**** Run programs

main

*==================================================================================================
