*===========================================================================================
*** 0c_store_incomeparameterest.do
*** Program to estimate income parameters for store income distribution 
*===========================================================================================

	args storeN loglbl

	if "`storeN'" == "" {
		local storeN 0
		local loglbl "_ln"	// "_ln" // ""
	}

	foreach arg in storeN loglbl {
		global `arg' "``arg''"
		di "`arg' : ${`arg'}"
	}
	
*===========================================================================================
*** Directory Set-up

*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "${terminal}/1_dataprep"

*Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentsteprepo/RepoOutput"
	global logs "$currentstep/STATALogs"

* Output directory
	cap mkdir ${data}/ParameterEstimation
	
*==================================================================================================
**** Program to run sub-programs

cap prog drop main 
prog def main 

	if ${storeN} == 0 {
		** get percentile groupings from national inc distribution 
		pctilegroups, loglbl("${loglbl}")
	}	
	else {
		** estimate income at each percentile group  by store
		incquants, storeN(${storeN}) loglbl("${loglbl}")
	}

end 	
	
*===================================================================================================
* Sub-programs
*===================================================================================================

cap prog drop pctilegroups
prog def pctilegroups
	syntax[anything], [loglbl(string)]
	
if 1 == 1 {
	
	** store x income level density 
		use ${data}/storeexpenditure_byincome.dta, replace
			// created in 0b_storedensityestimation.do
	
	** collapse to income level 
		collapse (sum) freq (mean) mininc maxinc, by(brkt)
		
		gen count = round(freq)
			// need integer frequencies for the bins 
		
	** log income 
	if "`loglbl'" == "_ln" {
		replace mininc = ln(mininc)
		replace maxinc = ln(maxinc) 
		replace mininc = 0 if brkt == 1
	}
		
	** calculate best fit distribution 
		mgbe count mininc maxinc, saving(${data}/nationastoreincdist`loglbl')
		
	** group percentiles --> inverse share of points proportionate to range covered by that pctile
		use ${data}/nationastoreincdist`loglbl'.dta, replace
		
		** reshape to long
		keep P*
		gen a=1
		reshape long P,i(a) j(pctile)
		
		** range of percentile
		sort pctile
		gen incdiff=P-P[_n-1]
		replace incdiff=P if _n==1
		
		** share of range to given pctile
		egen totalincdiff=total(incdiff)
		gen share = incdiff/totalincdiff
		gen cumshare = sum(share)
		
		** assign percentile groups with roughly equal range shares
		gen pctgroup = . 
		forvalues i = 1(1)100 {
			replace pctgroup = `i' if cumshare <= `i'/100 & pctgroup == . 
		} 
		
		distinct pctgroup
			// 50 groups 
		egen pctgroupN = group(pctgroup)	
		drop pctgroup	
		rename pctgroupN pctgroup
		
		bys pctgroup: egen pctgrpshare = sum(share)
		sum pctgrpshare
		
	** output pctile to pctgroup crosswalk
		preserve
			keep pctile pctgroup 
			save ${data}/pctile2pctgroup_crosswalk_storeincdist`loglbl'.dta, replace
		restore
	
	** calculate average income within pctile groups
		bys pctgroup: egen avginc = mean(P)
		bys pctgroup: egen cumpct = max(pctile)
				
}
end

*===================================================================================================

cap prog drop incquants
prog def incquants
	syntax[anything], storeN(integer) [loglbl(string)]

if 1 == 1 {
	
	** read in store specific inc distribution data 
	use if storeN == `storeN' using ${data}/storeexpenditure_byincome.dta, replace
		// created in 0b_storedensityestimation.do
	
	levelsof store_code_uc, local(store)	
	
	** replace log income 
	if "`loglbl'" == "_ln" {
		replace mininc = ln(mininc)
		replace maxinc = ln(maxinc) 
		replace mininc = 0 if brkt == 1
	}
	
	** estimate income parameters 
	gen count = round(freq)
		// need integer frequencies for the bins 
	
	mgbe count mininc maxinc, saving(${data}/ParameterEstimation/incparam_bestfit_`store'_pct`loglbl'.dta)
	
	** get percentile level data 
	use ${data}/ParameterEstimation/incparam_bestfit_`store'_pct`loglbl'.dta, replace
		
	keep dist mean sd median P*
	gen store_code_uc = `store'
	reshape long P, i(mean sd median store_code_uc) j(pctile)
	rename P income
	
	** assign to pctile groups 
	merge 1:1 pctile using ${data}/pctile2pctgroup_crosswalk_storeincdist`loglbl'.dta, nogen
	
	** calculate average income within pctile group
	bys pctgroup: egen avginc = mean(income)
	
	** collapse to pctgroup level
	collapse (count) weight = pctile (mean) avginc, by(store_code_uc pctgroup)
	
	save ${data}/ParameterEstimation/incpctiles_`store'`loglbl'.dta, replace

}
end 

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	cap log close 
	log using ${logs}/JMP_incparam_${storeN}, replace
	cd ${programs}
		main
	cd ${programs}
	log close

*==================================================================================================
