*===========================================================================================
*** 1_priceinstruments_v[].do
*** Creates price instruments for products, to be merged into estimation data in step 2
*** 	Instrument 1: "other-chain other-city"
*** 	Instrument 2: "same chain-other city"
*===========================================================================================

	args pmodule year freq
	
	foreach arg in pmodule year freq {
		global `arg' "``arg''"
		di "`arg' : ${`arg'}"
	}
		
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"
	
*===========================================================================================
*** Preliminary Set-up						

	clear
	clear matrix
	set more off, perm
	set matsize 11000
	set maxvar 20000

*==================================================================================================
* Primary program
*==================================================================================================
capture prog drop avguvinstr
prog define avguvinstr

if 1==1{

	cap mkdir "${output}/priceinstr_avguv_${freq}"

	di "Load county-MSA crosswalk data"
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
		// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
			//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		rename county fipscounty
		destring fipscounty cbsa, replace
		drop if cbsa==.
		duplicates drop
		tempfile tempcbsa
		save `tempcbsa'
	
	di "Load data for module id ${pmodule} in year ${year}"
		capture use store_code_uc year ${freq} productid value commonunits  ///
			using ${step0bdata}/store_${freq}_product/${freq}_${pmodule}_${year}_productlevel.dta, clear
					// created by /0b_dataimport/1c_RMS_datasetup.do
			
	if _rc==0{		
		di "Merge in store info"
			merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(dma_code chain_code channel_code fips_state_code fips_county_code) keep(1 3)
						// created by /0b_dataimport/0a_rawdataconvert.do
						// contains store information, including chain, channel, dma, and location
						// chain_code = retailer_code if non-missing, parent_code+10000 otherwise
												
			tab _merge
			gen fipscounty = fips_state_code *1000 + fips_county_code
			merge m:1 fipscounty using `tempcbsa', keep(1 3) nogen
		
		di "check that all stores have market & chain information"
			count if _merge==1
			capture assert r(N)==0
			if _rc == 0{
				drop _merge

				di "Collapse, save tempfile"

					gcollapse (sum) value commonunits, by(productid year ${freq} chain_code channel_code dma_code cbsa) fast
					tempfile prod_chain_dma_cbsa
					save `prod_chain_dma_cbsa'

				di "Calculate price instrument 1"

					* Instrument 1: "other-chain other-city" ; saved at product-(freq)-dma-cbsa level
					* average unit value charged for same product by stores that are in other DMAs and that do not belong to any chain located in the subject CBSA

						* get the set of cbsas each chain is in
						use `prod_chain_dma_cbsa', clear
						bys year ${freq} chain_code cbsa: keep if _n == 1
						keep year ${freq} chain_code cbsa
						drop if cbsa == .
						tempfile chains_in_cbsas
						save `chains_in_cbsas'

						* per product-cbsa: get total sales of the product within all chains that are in the subject cbsa
						use `prod_chain_dma_cbsa', clear
						gcollapse (sum) value commonunits, by(productid year ${freq} chain_code)
						joinby year ${freq} chain_code using `chains_in_cbsas'
						gcollapse (sum) value commonunits, by(productid year ${freq} cbsa)
						rename (value commonunits) (value_coloc commonunits_coloc)
						tempfile coloc_sales
						save `coloc_sales'

						* per product-dma-cbsa: get total sales of the product that are in that dma and within all chains that are in the subject cbsa
						use `prod_chain_dma_cbsa', clear
						gcollapse (sum) value commonunits, by(productid year ${freq} chain_code dma_code)
						joinby year ${freq} chain_code using `chains_in_cbsas'
						gcollapse (sum) value commonunits, by(productid year ${freq} dma_code cbsa)
						rename (value commonunits) (value_coloc_dma commonunits_coloc_dma)
						tempfile coloc_sales_bydma
						save `coloc_sales_bydma'

						* for value and units: sum of all sales of the product, less same DMA sales, less cbsa-co-located chain sales, 
						* 		plus same DMA - co-located chain sales
						use `prod_chain_dma_cbsa', clear
						gcollapse (sum) value commonunits, by(productid year ${freq} dma_code cbsa)
						merge m:1 productid year ${freq} cbsa using `coloc_sales', nogen keep(1 3)
						merge 1:1 productid year ${freq} dma_code cbsa using `coloc_sales_bydma', nogen keep(1 3)

						foreach var of varlist value commonunits {
							bys productid year ${freq}: egen `var'_total = total(`var')
							bys productid year ${freq} dma_code: egen `var'_total_dma = total(`var')
							gen `var'_instr1 = `var'_total - `var'_total_dma - `var'_coloc + `var'_coloc_dma
							
							* this step addresses the computing issue where `var'_instr2 is negative or slightly positive when it should be zero.
								* 0.001 is not large enough to remove all such cases; but it will help us avoid dropping correct small values of the instrument
							replace `var'_instr1 = 0 if `var'_instr1 < 0.001
						}

						* calculate instrument price
						gen avguvinstr_instr1 = value_instr1/commonunits_instr1

						keep productid year ${freq} dma_code cbsa avguvinstr_instr1
					
						save ${output}/priceinstr_avguv_${freq}/${freq}_${pmodule}_${year}_product_prinstr1_avguv.dta, replace
					
				di "Calculate price instrument 2"

					* Instrument 2: "same chain-other city" ; saved at product-(freq)-chain-DMA level
					* average unit value charged for same product by all stores in the same retail chain but in different DMAs

						* collapse to product-chain-DMA
						use `prod_chain_dma_cbsa', clear
						gcollapse (sum) value commonunits, by(productid year ${freq} chain_code dma_code) fast

						* for value and units: sum of same chain sales in all DMAs, less same chain - same DMA sales
						foreach var of varlist value commonunits {
							bys productid year ${freq} chain_code: egen `var'_total_chain = total(`var')
							gen `var'_instr2 = `var'_total_chain - `var'

							replace `var'_instr2 = 0 if `var'_instr2 < 0.001
						}

						* calculate instrument price
						gen avguvinstr_instr2 = value_instr2/commonunits_instr2

						keep productid year ${freq} dma_code chain_code avguvinstr_instr2
					
						save ${output}/priceinstr_avguv_${freq}/${freq}_${pmodule}_${year}_product_prinstr2_avguv.dta, replace
		

			}
	}

}
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	di "product module: ${pmodule}"
	di "Year: ${year}"
	di "Time frequency: ${freq}"
	
	avguvinstr

*==================================================================================================
*==================================================================================================
