*===========================================================================================
*** 2a_outputforMATLAB_prep.do
*** Defines a unique market id and estimates an income distribution for both store-freq and cbsa-freq markets
*** 	For store-freq, income distribution is based on HMS households
*** 	For cbsa-freq, income distribution is based on ACS data
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"

*Set-up output directories
	global outputincbrkt_nocd "$currentstep/STATAOutput/dataMatLab_incbrkt_nocd"
	global incparmdata "${data}/ParameterEstimation"
	
	global name="2a_outputforMATLAB_prep"

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	
		
	* STEP 1: create unique market id, where a market is defined as a store-`freq'
		createmarketid, freq("month")
		createmarketid, freq("quarter")

	* STEP 2: output data set of estimated household income distribution in each store-`freq'
	* and a list of markets with estimated income distribution using nonparametric income distribution
		storelnincdistcsv_incpctiles, freq("month") loglbl("log") typedrop("_nocd")
		storelnincdistcsv_incpctiles, freq("quarter") loglbl("log") typedrop("_nocd")

	* STEP 3: create cbsa-`freq' market id and output cbsa-level income distribution using lognormal estimates
		estcntyinc_lognormal, cbsa
		distcsv_county_cbsa, marketlevel("cbsa") freq("month")
		distcsv_county_cbsa, marketlevel("cbsa") freq("quarter")

end 

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
* Create unique id per store-`freq'
*===================================================================================================
capture prog drop createmarketid
prog define createmarketid
	syntax [anything], freq(string)

if 1==1{

	di "Append together store code"
		tempfile temp
		foreach yr of numlist 2006/2014{
			use store_code_uc using ${step0bdata}/stores_`yr'.dta, clear
					// created in 0b_dataimport/0a_rawdataconvert.do
			
			if `yr'>2006 append using `temp'
			save `temp', replace
		}	
		
		des, fullname
		duplicates drop
	
	if "`freq'" == "month" {
		expand 108 
		bys store_code_uc: gen month = ym(2006, 1) + _n-1
		format month %tm
		tab month, m
	}
	else if "`freq'" == "quarter" {
		expand 36
		bys store_code_uc: gen quarter = yq(2006, 1) + _n - 1
		format quarter %tq
		tab quarter, m
	}
	else if "`freq'" == "semester" {
		expand 18
		bys store_code_uc: gen semester = yh(2006, 1) + _n-1
		format semester %th
		tab semester, m
	}
	else if "`freq'" == "year" {
		expand 9
		bys store_code_uc: gen year = 2006 + _n-1
		tab year, m
	}
	else if "`freq'" == "week" {
		local expandnum = 9*52
		expand `expandnum'
		bys store_code_uc: gen week = yw(2006, 1) + _n-1
		format week %tw
		distinct week
	}
	
	cap noisily tab `freq', m
	isid store_code_uc `freq'
	
	* define market as a store-`freq'
	if "`freq'" != "week" gen mktid = _n
	else {
		gen mktid = string(store_code_uc) + string(week)
		destring mktid, replace
	}
		
	isid mktid
	
	save ${data}/store_`freq'_mktid_correspondence.dta, replace

}
end

*===================================================================================================
* Generate 50 income brackets from store density estimation and merge with market data
*===================================================================================================
cap prog drop storelnincdistcsv_incpctiles
prog define storelnincdistcsv_incpctiles

	syntax [anything], freq(string) [loglbl(string)] [typedrop(string)]

if 1==1 {	

	cap confirm file "${data}/storeincdist_`loglbl'incpctiles.dta"
		// created below

	if _rc != 0 {

		cd "${incparmdata}"       
		if "`loglbl'"=="log" quietly fs "${incparmdata}/incpctiles*_ln.dta"
		else if "`loglbl'"=="" quietly fs "${incparmdata}/incpctiles*.dta"

		* appending x(different) and w(same) for each store
		local first = 1
		foreach f in `r(files)'{
			if "`loglbl'"=="log" | ("`loglbl'"=="" & strpos("`f'","_ln")==0 & strpos("`f'","_level")==0) {
				dis "`f'"
				use `f', clear
					// created in 0c_store_incomeparameterest.do
				if `first' == 1 local first =0
				else append using "${data}/storeincdist_`loglbl'incpctiles_long.dta"
				save "${data}/storeincdist_`loglbl'incpctiles_long.dta", replace	
			}
		}
		
		reshape wide weight avginc, i(store_code_uc) j(pctgroup)
		save "${data}/storeincdist_`loglbl'incpctiles.dta", replace
		cap rm "${data}/storeincdist_`loglbl'incpctiles_long.dta", replace
		
	}
	
	use "${data}/storeincdist_`loglbl'incpctiles.dta", clear
	
	preserve
		* calculate store-level mean income...
		forval i=1/50 {
			gen w_avginc_level`i'=exp(avginc`i')*weight`i'
		}
		egen sum_w = rowtotal(weight*)
		egen sum_avginc_level = rowtotal(w_avginc_level*)
		gen storemeaninc = sum_avginc_level/sum_w
		
		drop avginc* weight* w_avginc_level* sum_avginc_level sum_w
		save "${data}/storeincdist_`loglbl'incpctiles_meaninc.dta", replace
	restore			
			
	if "`typedrop'" == "_nocd" {
	* drop all drugstores & convenience stores
		merge m:1 store_code_uc using "${data}/storetypeConcordance.dta", keepusing(store_code_uc)
			// created by 0b_storedensityestimation.do
		keep if _merge==3
		drop _merge
	}
	
	* merge in mktid
	merge 1:m store_code_uc using ${data}/store_`freq'_mktid_correspondence.dta
			// created in subprogram createmarketid
	isid mktid
	format mktid %15.0g
	keep if _merge==3
	drop _merge

	if "`freq'" == "month" {
		* merge in store-freq (e.g. market level) sales
		merge 1:1 store_code_uc `freq' using ${step0bdata}/store_`freq'lysales.dta
			// created by 0b_dataimport/Code/1d_RMS_monthlysales.do
		drop if _merge ==2
		drop _merge
	}
	else if "`freq'" == "quarter" {
	
		* expand to monthly level
	
		gen temp_date = dofq(quarter)
		gen temp_month = month(temp_date)
		gen temp_year = year(temp_date)
		
		expand 3
		bys mktid: gen month = ym(temp_year, temp_month) + _n - 1
		format month %tm
		
		drop temp_year temp_month temp_date
		
		* merge in store sales
		merge 1:1 store_code_uc month using ${step0bdata}/store_monthlysales.dta
			// created by 0b_dataimport/Code/1d_RMS_monthlysales.do
		drop if _merge ==2
		drop _merge
		
		* collapse sales to quarterly level
		rename value old
		bys mktid (month): gen value = sum(old)
		by mktid: keep if _n==_N
		drop old month
	}
	
	* drop markets with missing income brackets BEFORE entering matlab
		gen missing_w = 0
		gen missing_v = 0
		foreach v of varlist weight* {
			di "`v'"
			replace missing_w=1 if `v'==.
		}
		foreach v of varlist avginc* {
			di "`v'"
			replace missing_v=1 if `v'==.
		}
		tab missing_w missing_v
			*monthly: 648 out of 1,319,112
			*quarterly: 216 out of 439704
		sum avginc46 avginc47 avginc48 avginc49 avginc50 if missing_v==1
		
		drop if missing_w==1 | missing_v==1
		drop missing_w missing_v
		
	
	save "${data}/storeincdist_`loglbl'incpctiles_`freq'`typedrop'.dta", replace
	export delimited using "${outputincbrkt`typedrop'}/storeincdist_`loglbl'incpctiles_`freq'`typedrop'.csv", replace		

	keep mktid
	save ${data}/List_mktid_withincdist_`loglbl'incpctiles_`freq'`typedrop'.dta, replace
	export delimited using ${outputincbrkt`typedrop'}/List_mktid_withincdist_`loglbl'incpctiles_`freq'`typedrop'.csv, replace

}
end

*===================================================================================================
* Generate county-level or cbsa-level lognormal income distribution approximation
*===================================================================================================
cap prog drop estcntyinc_lognormal
prog define estcntyinc_lognormal

	syntax [, cbsa]
	if "`cbsa'" == "" local geography "county"
	else local geography "cbsa"

if 1==1{

	if "`geography'" == "cbsa" {
		di "Load county-CBSA crosswalk data"
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
			// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
				//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		destring county cbsa, replace
		drop if cbsa==.
		tempfile tempcbsa
		save `tempcbsa'
	}

	di "Import data"
		import delimited "${rawsocial}/county_income_acs_2010_2014.csv", varnames(1) clear
			// Downloaded from https://www.socialexplorer.com/tables/ACS2014_5yr, table A14001. Household Income
		
		drop if _n == 1
		keep statefips county households*
		drop households
		destring county statefips households*, replace
		gen fullfips = statefips*1000 + county
		drop statefips county
		rename fullfips county
	
	di "Rename income variable"
		foreach comb in "1 0 10000" "2 10000 15000" "3 15000 20000" "4 20000 25000" "5 25000 30000"   ///
						"6 30000 35000" "7 35000 40000" "8 40000 45000" "9 45000 50000" "10 50000 60000"  ///
						"11 60000 75000" "12 75000 100000" "13 100000 125000" "14 125000 150000" "15 150000 200000" "16 200000" {
							local cat=word("`comb'", 1)
							local low=word("`comb'", 2)
							local high=word("`comb'", 3)
							
							di "`cat'-`low'-`high'"
							
							if "`high'" != "" & `low' != 0 local h2 = `high'-1
							else if `low' == 0 local h2 = `high'
							if `low' == 0 local oldname "householdslessthan`h2'"
							else if "`high'" == "" local oldname "households`low'ormore"
							else local oldname "households`low'to`h2'"

							if "`high'" == "" local high = 400000

							rename `oldname' hhinc_`low'_`high'

							gen midpoint_`low'_`high'=(`low'+`high')/2
						}

	if "`geography'" == "cbsa" {
		di "Merge in cbsa information, collapse to cbsa"
			merge 1:1 county using `tempcbsa', keep(1 3) nogen
			count if cbsa == .
			drop if cbsa == .
			collapse (sum) hhinc_* (first) midpoint_*, by(cbsa)
	}
	
	di "Prepare for estimation"
		isid `geography'
		egen geoid = group(`geography')
		isid geoid
			
		distinct geoid
		local matrixrow = r(ndistinct)
		
		matrix dagumdist_lognormal=J(`matrixrow', 5, .)
		if "`geography'" == "county" matrix colnames dagumdist_lognormal = geoid fipscounty mean variance error
		else if "`geography'" == "cbsa" matrix colnames dagumdist_lognormal = geoid cbsa mean variance error
		
		reshape long hhinc_@ midpoint_@, i(geoid) j(z) string
		rename *_ *
		split z, p("_") destring
		count if z1==. | z2==.
		replace z2=. if z2==250000
		des, fullname

		gen lnmidpoint=ln(midpoint)
		levelsof geoid, local(geolist)
	
	di "Estimate moments"
		local i=1
		foreach c of local geolist{
			preserve
			
			keep if geoid==`c'
			isid midpoint

			matrix dagumdist_lognormal[`i', 1]=`c'

			sum `geography'
			matrix dagumdist_lognormal[`i', 2]=r(max)
			
			sum hhinc
			local expandsize = r(max)
			
			expand `expandsize'
			
			bysort midpoint: keep if _n<=hhinc
			
			collapse (mean) meanlnincome=lnmidpoint (sd) sdlnincome=lnmidpoint, fast
			gen varlnincome = sdlnincome^2
			
			matrix dagumdist_lognormal[`i', 3]=meanlnincome[1]
			matrix dagumdist_lognormal[`i', 4]=sdlnincome[1]
							
			local i=`i'+1
			restore
		}	
	
	di "Output estimates"
		clear
		svmat dagumdist_lognormal, names(col)
		save "${data}/incomedist_lognormal_moments_by`geography'.dta", replace

}
end

*===================================================================================================
* Use meanlninc and vlninc from county-level lognormal estiamtes
*===================================================================================================
cap prog drop distcsv_county_cbsa
prog define distcsv_county_cbsa

syntax [anything], marketlevel(string) freq(string) 

if 1==1{

	use ${data}/store_`freq'_mktid_correspondence.dta, clear
			// created in subprogram createmarketid
			// just to use the occurence & date, NOT using mktid from this file

	di "Merge in store location"
		if "`freq'" == "month" gen year = year(dofm(month))
		else if "`freq'" == "quarter" gen year = year(dofq(quarter))
		else if "`freq'" == "week" gen year = year(dofw(week))
		
		merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta
				// created by 0b_dataimport/0a_rawdataconvert.do
				// contains store information, including chain, channel, dma, and location
		tab _merge, m
		drop if _merge<3
		drop _merge
	
		rename fips_*_code *
		gen fipscounty = state*1000 + county

		if "`marketlevel'" == "cbsa" {
			preserve
				import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
					// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
					//  maps into panelist fips codes perfectly and NHGIS data for all but PR
				rename county fipscounty
				destring fipscounty cbsa, replace
				drop if cbsa==.
				tempfile tempcbsa
				save `tempcbsa', replace
			restore
			merge m:1 fipscounty using `tempcbsa', keep(1 3)
			drop _merge
		}

	di "Merge in store `freq'ly sales"
		if "`freq'" == "month" {
			* merge in store-freq (e.g. market level) sales
			merge 1:1 store_code_uc `freq' using ${step0bdata}/store_monthlysales.dta
				// created by 0b_dataimport/1d_RMS_montlysales.do
			drop if _merge ==2
			drop _merge
		}
		else if "`freq'" == "quarter" {
		
			* expand to monthly level
		
			gen temp_date = dofq(quarter)
			gen temp_month = month(temp_date)
			gen temp_year = year(temp_date)
			
			expand 3
			bys mktid: gen month = ym(temp_year, temp_month) + _n - 1
			format month %tm
			
			drop temp_year temp_month temp_date
			
			* merge in store sales
			merge 1:1 store_code_uc month using ${step0bdata}/store_monthlysales.dta
				// created by 0b_dataimport/1d_RMS_montlysales.do
			drop if _merge ==2
			drop _merge
			
			* collapse sales to quarterly level
			rename value old
			bys mktid (month): gen value = sum(old)
			by mktid: keep if _n==_N
			drop old month
		}
		
		replace value = 0 if value==.
		
	di "Merge in income dist for each location"
		if "`marketlevel'" == "county" {
			merge m:1 fipscounty using ${data}/incomedist_lognormal_moments_bycounty.dta
				// created in subprogram estcntyinc_lognormal
		}
		else if "`marketlevel'" == "cbsa" {
			merge m:1 cbsa using ${data}/incomedist_lognormal_moments_bycbsa.dta
				// created in subprogram estcntyinc_lognormal
		}
		
		tab _merge, m
		drop if _merge <3
		drop _merge
		
		rename mean meanlninc
		rename variance vlninc
		
		count if fipscounty==.
		count if meanlninc==.
		count if vlninc==.
		
		drop if fipscounty==.
		drop if meanlninc==.
		drop if vlninc==.

		if "`marketlevel'" == "cbsa" {
			count if cbsa == .
			drop if cbsa == .
		}

		if "`marketlevel'" == "county" local geovar "fipscounty"
		else if "`marketlevel'" == "cbsa" local geovar "cbsa"

		sort `geovar' `freq' store_code_uc
		rename value value_raw
		by `geovar' `freq': gen value = sum(value_raw)
		drop value_raw
		
		by `geovar' `freq': keep if _n==_N
		keep `geovar' `freq' year meanlninc vlninc value
			* note: previous mktid defined by stores is now dropped
		
		sort year `freq' `geovar'
		gen mktid=_n
		order `geovar' `freq' mktid year meanlninc vlninc value

	export delimited using "${output}/dataMatLab_`marketlevel'/storeincdist_`freq'.csv", replace
	save "${output}/dataMatLab_`marketlevel'/storeincdist_`freq'.dta", replace
		
	keep mktid
	export delimited using "${output}/dataMatLab_`marketlevel'/List_mktid_withincdist_`freq'.csv", replace
	save "${output}/dataMatLab_`marketlevel'/List_mktid_withincdist_`freq'.dta", replace

}
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	set linesize 200
	cd "$programs"
	main
	cd "$programs"
	capture log close

*==================================================================================================
