*===========================================================================================
*** 2b_outputforMATLAB_RMS.do
*** (1) clean RMS data sample for estimation and output into csv file for analysis in MATLAB
***	(2) create a data set of market id for each module, which is used to select HMS estimation data
*** (3) output intermediate data at each data cleaning step for data cleaning accounting tables
*===========================================================================================

	args pmodule freq outsidegoodscut byyear cbsa marketlevel

	if "`pmodule'"=="" {
		local pmodule = 1031 // 3602 // 1203 // 1463 // 1002 // 8411
		local freq = "month" // quarter
		local outsidegoodscut = 60 // 40 // 60 // 80
		local byyear = 2012     // 2006...2014 -- export data in the year specified; 0 -- export data across all years
		local cbsa = 0 // 0 //35620 for New York // 31080 for LA // 16980 for Chicago
		local marketlevel="cbsa" 	// "county" or "cbsa" if "mktid" is by county/cbsa & frequency
									// "store" if "mktid" in the output data is by store & frequency
	}
	
	foreach arg in cbsa {
		if "``arg''"=="0" local `arg' ""
	}
	
	foreach arg in pmodule freq outsidegoodscut byyear cbsa marketlevel {
		global `arg' "``arg''"
		di "`arg' : ${`arg'}"
	}
		
	if ${byyear} != 0 global year "${byyear}"
	else global year "2006 2007 2008 2009 2010 2011 2012 2013 2014"

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"
	
*==================================================================================================
* Primary program
*	Define and create directories for output (setupdirectory)
* 	Import RMS data and merge with markets, products, instruments (importandmerge)
* 	Clean and output RMS data module by module into CSV file (cleandata)
* 	Flag RMS sample for an additional cleaning criterion based on outside good share implemented in Matlab (flagsample)
*==================================================================================================

cap prog drop storedatacsv
prog define storedatacsv

if 1==1 {		
	
	setupdirectory

	capture log close
	log using "${logdir}/RMSstore_${freq}_${pmodule}.log", replace
	
	disp "***Check if the output file already exists"
	cap noisily confirm file ${storeMatlab}/store_module${pmodule}_data.csv
	if _rc == 0 {
		di "...CSV file already exists for module -- ${pmodule} and cutoff -- ${outsidegoodscut}"
		di "--> erase exisiting file"
		erase ${storeMatlab}/store_module${pmodule}_data.csv
	}
		
	di "Merge RMS data with other data"	
		foreach yr of global year{
			clear
			cap noisily importandmerge, yr(`yr')
			if _rc == 0{
				tempfile temp`yr'
				save `temp`yr''
			}
		}
		
	di "Append yearly datasets"
		clear 
		tempfile temp
		save `temp', empty
		
		use `temp', clear
		foreach yr of global year{
			di "--> Year -- `yr'"
				cap noisily append using `temp`yr''
				if _rc!=0 disp "- no data found"
		}

		count
		if r(N) > 0 {
			
			di "Clean data (outlier prices, outside goods) and output (if there are still observations)"
				cap noisily cleandata

			local noobs=_rc
			di "noobs: `noobs'" 
			if `noobs'!=0 disp "no observations left after cleaning"
			else {
											
				* identify market samples based markets's sales share of outside goods 
					* sampleid == 0 if outside goods share <1%
					*		   == 1 if outside goods share >=1% and <3%
					*	       == 3 if outside goods share >=3% and <5%
					*		   == 5 if outside goods share >=5% and <10%
					*		   == 10 if outside goods share >=10%
					
					flagsample 
					
				* output data for matlab
					keep mktid ${freq} prodid brandid sjt x Z* vjt outsidegoods sampleid
					sort mktid prodid
					
					if ${byyear} == 0 drop ${freq}
					else {
						if "${freq}" == "month" {
							rename month ym
							local newfreqvar "month"
							local freqvar "ym"
							local datefunc "dofm"
							local freqfunc "month"
							format ym %tm
						}
						else if "${freq}" == "quarter"{
							rename quarter yq
							local newfreqvar "quarter"
							local freqvar "yq"
							local datefunc "dofq"
							local freqfunc "quarter"
							format yq %tq
						}
						else if "${freq}" == "semester"{
							rename semester yh
							local newfreqvar "semester"
							local freqvar "yh"
							local datefunc "dofh"
							local freqfunc "halfyear"
						}
						
						if "${freq}" != "year"{
							gen year = year(`datefunc'(`freqvar'))
							gen `newfreqvar' = `freqfunc'(`datefunc'(`freqvar'))
						}
						
						tab year, m	
					}
					
					order `freqvar' prodid vjt x sjt mktid Z1 Z2 brandid outsidegoods sampleid year ${freq}						
					
					export delimited using ${storeMatlab}/store_module${pmodule}_data.csv, replace delimiter(tab)
							// data to be used in Matlab estimation code (step 3a)
							// also read in in (this step) 3a_RMS_test2sls.do - Stata version of matlab code
					
				* output list of markets for household data
					keep mktid sampleid
					bys mktid: keep if _n==1
					count
					save ${RMSmkts}/mkts_${pmodule}_${freq}.dta, replace	
						// list of markets to limit HMS data to only markets observed in RMS data
						
			}
		}
	
	log close

}
end
	
*==================================================================================================
* Sub-programs
*==================================================================================================

cap prog drop setupdirectory
prog define setupdirectory
	
if 1==1{
	
	if "${marketlevel}"=="store" {
		global marketlevelsuf = ""
	}
	else {
		global marketlevelsuf="_${marketlevel}"
	}
	
	di "$marketlevel , $marketlevelsuf"
	
	* directory for CSV output
		if ${byyear} == 0 global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/outside${outsidegoodscut}/${cbsa}"
		else global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
		mkdirectory, startpath(${output}) fullpath(${storeMatlab})

	* directory for data cleaning accounting - keeping track of remaining products and sales in markets after each step
		if ${byyear} == 0 global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
		mkdirectory, startpath(${output}) fullpath(${cleaningaccounting})
		
	* directory for outsidegoods
		if ${byyear} == 0 global outsidegood "${output}/outsidegoods${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global outsidegood "${output}/outsidegoods${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
		mkdirectory, startpath(${output}) fullpath(${outsidegood})
		
	* directory for remaining markets in RMS data after cleaning
		if ${byyear} == 0 global RMSmkts "${data}/RMSmkts_bymodule${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global RMSmkts "${data}/RMSmkts_bymodule${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
		mkdirectory, startpath(${data}) fullpath(${RMSmkts})
		
	* directory for log file
		if ${byyear} == 0 global logdir "${logs}/2b_outputforMATLAB_RMS${marketlevelsuf}/bymodule/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global logdir "${logs}/2b_outputforMATLAB_RMS${marketlevelsuf}/bymodule/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"

		mkdirectory, startpath(${logs}) fullpath(${logdir})
	
}
end
	
*===================================================================================================

cap prog drop importandmerge
prog define importandmerge	
	syntax [anything], yr(integer)

if 1==1{

	di "Load county-CBSA crosswalk data"
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
		// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
			//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		rename county fipscounty
		destring fipscounty cbsa, replace
		drop if cbsa==.		
		duplicates drop
		tempfile tempcbsa
		save `tempcbsa', replace

	di "Module -- ${pmodule}; Year -- `yr'"	
		capture noisily use ${step0bdata}/store_${freq}_product/${freq}_${pmodule}_`yr'_productlevel.dta, clear
				// created in /0b_dataimport/Code/1c_RMS_datasetup.do

		if _rc!=0 error _rc  // data set doesn't exist
	
	di "Drop data from December in the previous year"
		keep if year==`yr'		
		* drop data from December in the previous year, but reported in the current year to avoid duplicates when appending data across years
			* such year-mismatched data account for very small portion of monthly sales in the December

	di "Merge in store info"
		merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(dma_code chain_code channel_code fips_state_code fips_county_code) keep(1 3)
			// created in /0b_dataimport/Code/0_rawdataconvert.do
				// contains store information, including chain, channel, dma, and location
				// chain_code = retailer_code if non-missing, parent_code+10000 otherwise 
		gen fipscounty = fips_state_code *1000 + fips_county_code
		merge m:1 fipscounty using `tempcbsa', keep(1 3) nogen
		
	di "Keep stores in the selected cbsa"
		destring cbsa, replace
		if "${cbsa}" != "" keep if cbsa == ${cbsa}

		count 
		if r(N)==0 error 4  // no obs in the selected cbsa

	* save list of products at this stage for cleaning accounting
		preserve
			gcollapse (sum) sales_total=value, by(productid)
			gen pm = ${pmodule}
			save "${cleaningaccounting}/preclean_prods_${pmodule}.dta", replace
		restore
	* save sales by store-freq at this stage for cleaning accounting
		preserve
			gcollapse (sum) sales_total=value, by(store_code_uc ${freq})
			gen pm = ${pmodule}
			save "${cleaningaccounting}/preclean_mkts_${pmodule}.dta", replace
		restore

	di "Drop if missing store info"
		drop if _merge < 3
		drop _merge

	di "Merge in Price Instruments for each product"
		merge m:1 dma_code chain_code productid ${freq} using ${output}/priceinstr_avguv_${freq}/${freq}_${pmodule}_`yr'_product_prinstr2_avguv.dta, ///
			keepusing(avguvinstr_instr2) assert(3) keep(3) nogen
		merge m:1 dma_code cbsa productid ${freq} using ${output}/priceinstr_avguv_${freq}/${freq}_${pmodule}_`yr'_product_prinstr1_avguv.dta, ///
			keepusing(avguvinstr_instr1) assert(3) keep(3) nogen
				// created in 1_priceinstruments.do 
	
	di "Merge in brand id"
		merge m:1 productid using ${step0bdata}/RMSproductid_bymodule/RMSproductids_${pmodule}.dta, keep(1 3) keepusing(brand)
				// created in 0b_dataimport/Code/0c_createproductid
			tab _merge
			keep if _merge==3
			drop _merge
			
	if "${marketlevel}"=="store" {
	
		di "Only keep list of markets with estimated income distributions"
		di "Merge in market id"
			merge m:1 store_code_uc ${freq} using ${data}/store_${freq}_mktid_correspondence.dta, keepusing(mktid) keep(1 3)
				// created in 2a_outputforMATLAB_prep.do (createmarketid)
			tab _merge, m
			keep if _merge ==3
			drop _merge
				
		di "Keep market id with estimated income distribution"
			merge m:1 mktid using ${data}/List_mktid_withincdist_logincpctiles_${freq}_nocd.dta, keep(1 3)
				// created in 2a_outputforMATLAB_prep.do (storelnincdistcsv)
			tab _merge
			drop if _merge < 3
			drop _merge

			count			
			if r(N) == 0 error 1   // no markets with estimated income distribution

			* save list of products at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=value, by(productid)
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postmerge_prods_${pmodule}.dta, replace
				restore
			* save sales by store-freq at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=value, by(store_code_uc ${freq})
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postmerge_mkts_${pmodule}.dta, replace
				restore

	}
	else if "${marketlevel}"=="county" | "${marketlevel}" == "cbsa" {
	
		di "...Merge in ${marketlevel}-freq level mktid"
			if "${marketlevel}" == "county" {
				merge m:1 fipscounty year ${freq} using "${output}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid) 
					// created in 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)
			}
			else if "${marketlevel}" == "cbsa" {
				merge m:1 cbsa year ${freq} using "${output}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid)
					// created in 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)
			}

			tab _merge, m
			keep if _merge == 3
			drop _merge

			count			
			if r(N) == 0 error 1   // no markets with estimated income distribution

			* save list of products at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=value, by(productid)
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postmerge_prods_${pmodule}.dta, replace
				restore
			* save sales by store-freq at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=value, by(store_code_uc ${freq})
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postmerge_mkts_${pmodule}.dta, replace
				restore

	}
			
	* rename variables and cleanup the format
	di "Rename variables"	
		rename expshare sjt
		rename unitvalue x
		rename value vjt
		rename avguvinstr_instr1 Z1
		rename avguvinstr_instr2 Z2
		rename productid prodid
		rename brand brandid
		keep store_code_uc mktid ${freq} prodid chain_code brandid sjt x vjt Z1 Z2 commonunits fipscounty cbsa



	quietly sum prodid, d
	global minprod=`r(min)'

	di "Drop observations with missing value in key variables"
		foreach v in sjt x Z2 vjt {    
			di "drop if ln`v' is missing"
				gen ln`v' = ln(`v')
				drop if ln`v'==.
				drop ln`v'
		}
		foreach v in Z1 {
			di "replace `v'=0 if ln`v' is missing"
				gen ln`v' = ln(`v')
				replace Z1=0 if ln`v'==.
				drop ln`v'
		}

	* save list of products at this stage for cleaning accounting
		preserve
			gcollapse (sum) sales_total=vjt, by(prodid)
			gen pm = ${pmodule}
			save ${cleaningaccounting}/postdropmiss_prods_${pmodule}.dta, replace
		restore
	* save sales by store-freq at this stage for cleaning accounting
		preserve
			gcollapse (sum) sales_total=vjt, by(store_code_uc ${freq})
			gen pm = ${pmodule}
			save ${cleaningaccounting}/postdropmiss_mkts_${pmodule}.dta, replace
		restore
		
	count
	if r(N)== 0 error 3    //no brands that are available in more than 5 markets

}
end

*===================================================================================================

cap prog drop cleandata
prog define cleandata
	
if 1==1{

	isid store_code_uc ${freq} prodid

	disp "*Step 1: drop store-${freq}s with outlier prices"
		
		* calculate dist of unit price across all markets for each product
			gen lnx = ln(x)
			bys prodid: egen mnlnx = mean(lnx)
			bys prodid: egen sdlnx = sd(lnx)
			gen outlier_withinprod = 0
			replace outlier_withinprod = 1 if abs(lnx-mnlnx) > 3*sdlnx
		
		* calculate dist of unit price across all markets and all products in a module			
			drop mnlnx sdlnx
			egen mnlnx = mean(lnx)
			egen sdlnx = sd(lnx)
			gen outlier_withinmod = 0
			replace outlier_withinmod = 1 if abs(lnx-mnlnx) > 3*sdlnx
		
			gen outlier = 1 if outlier_withinprod == 1 | outlier_withinmod == 1

		* looking closer at outlier counts/sales shares: getting number & sales values of outlier product-markets & markets dropped
			preserve
				sort store_code_uc ${freq}
				by store_code_uc ${freq}: gen sales_total = sum(vjt)
				by store_code_uc ${freq}: gen n_total = _N
				gen temp = vjt if outlier == 1
				by store_code_uc ${freq}: gen sales_outlier = sum(temp)
				by store_code_uc ${freq}: gen n_outlier = sum(outlier)
				by store_code_uc ${freq}: keep if _n==_N
				keep store_code_uc ${freq} sales_outlier sales_total n_outlier n_total
				save ${cleaningaccounting}/outliers_${pmodule}.dta, replace
			restore
		
		* drop store-freqs that sell products with outlier prices		
			bys store_code_uc ${freq}: egen outliermkt = max(outlier)
			drop if outliermkt == 1
			
			keep store_code_uc mktid ${freq} prodid chain_code brandid sjt x vjt Z1 Z2 commonunits fipscounty cbsa

		count
		if r(N)==0 error 1 //exit if no observations left 

		* save list of products at this stage for cleaning accounting
			preserve
				gcollapse (sum) sales_total=vjt, by(prodid)
				gen pm = ${pmodule}
				save ${cleaningaccounting}/postoutlier_prods_${pmodule}.dta, replace
			restore
		* save sales by store-freq at this stage for cleaning accounting
			preserve
				gcollapse (sum) sales_total=vjt, by(store_code_uc ${freq})
				gen pm = ${pmodule}
				save ${cleaningaccounting}/postoutlier_mkts_${pmodule}.dta, replace
			restore
			
		* pull total number of stores that sell any products
			isid store_code_uc ${freq} prodid
			distinct store_code_uc ${freq}
			local nummkt_anyprod = r(ndistinct)
			distinct prodid
			local numprod = r(ndistinct)



		if "${marketlevel}"=="county" | "${marketlevel}" == "cbsa" {
	 
			di "Further collapse the data to get ${marketlevel}-freq level output"
			
			di "...Deal with missing/nonpositive instruments: for instr2, drop observation; for instr1: replace with 0"
				count
				replace Z1=0 if Z1<=0 | Z1==.
				drop if Z2<=0 | Z2==.

			di "...Create new mkt-product level total values and sales"
				drop x sjt
				
				sort mktid prodid store_code_uc
				isid mktid prodid store_code_uc 
				
				by mktid prodid: gen ttvalue = sum(vjt)
				by mktid prodid: gen ttcommonunits = sum(commonunits)
			
			di "...Create new price instruments: average of previous store-product level instruments, weighted by value."
			foreach v in Z1 Z2 { 
				rename `v' `v'_raw
				by mktid prodid: gen `v'_sum = sum(`v'_raw*vjt)
				gen `v' = `v'_sum/ttvalue
				drop `v'_raw `v'_sum
			}
			
			di "...Collapse out the store level (keeping last observation in the group, with full sum)"
				by mktid prodid: keep if _n==_N
			
				drop vjt commonunits 
				rename ttvalue vjt
				
			di "...Calculate unit value of each product in each mktid"
				gen x = vjt/ttcommonunits
			
			di "...Calculate within-module sales share of each product in each mktid"
				bys mktid: egen ttvalue = total(vjt)
				gen sjt = vjt/ttvalue
				drop ttvalue

		}

		keep mktid ${freq} prodid brandid sjt x vjt Z1 Z2 cbsa


				
		disp "*Step 2: identify outside good and drop markets that don't sell that, or sufficient other goods"
			* identify outside goods
				* (a) low average sales shares relative to other products in the same module
				* OR (b) products in the brand with the lowest average sales shares 

				* (a) low average sales shares relative to other products in the same module
					preserve
						collapse (mean) sjt, by(prodid) fast
						isid prodid
						_pctile sjt, p(10 20 30 40 50 60 70 80) 

						foreach n of numlist ${outsidegoodscut} {    //10 20 30 40 50 60 70 80
							local tempn = `n'/10
							di "`n'th Percentile: `r(r`tempn')'"
							gen outsidegoods = sjt < r(r`tempn')  
						}
						
						keep prodid outsidegoods
						tempfile templowsalessh
						save `templowsalessh'
					
					restore, preserve
		
				* (b) products in the brand with the lowest average sales shares 
						collapse (sum) sjt, by(brandid mktid) fast
						collapse (mean) sjt, by(brandid) fast
						sort sjt
						keep if _n == 1
						gen outsidegoodbrand = 1
						keep brandid outsidegoodbrand
						tempfile tempbrand
						save `tempbrand'
					
					restore
						
				* create outside goods dummy
					merge m:1 prodid using `templowsalessh', nogen
					merge m:1 brandid using `tempbrand'
					replace outsidegoodbrand = 0 if _merge < 3
					drop _merge
				
					replace outsidegoods = ((outsidegoods + outsidegoodbrand) > 0)
					tab outsidegoods, m
					
				count if outsidegoods == 0
				if r(N)==0 error 2   // exit if no non-outside good observations	
			
			* pull number of markets that sell outside goods
				distinct mktid if outsidegoods == 1
				local nummkt_outsidegood = r(ndistinct)
				
			* pull number of markets that sell at least 2 non-outside goods
				isid mktid prodid
				bys mktid: gen tempnumprod = _N
				bys mktid: egen numoutside = total(outsidegoods)
				gen numinside = tempnumprod - numoutside
				distinct mktid if numinside >= 2
				local nummkt_insidegood = r(ndistinct)
				drop tempnumprod numoutside numinside
				
			* get sales of total and outside goods
				sum vjt
				local total_sales=r(sum)
				sum vjt if outsidegoods==1
				local outsidegoods_sales=r(sum)
				
				
			* collapse data for outside good(s)				
				preserve 
					keep if outsidegoods == 1
					
				* get the mean and standard deviation of unit price of outside goods across all store-${freq}
					quietly sum x [aweight = sjt]
					local mnx_outsidegoods = r(mean)
					local sdx_outsidegoods = r(sd)
					
					foreach v of varlist x Z1 Z2 {   
						quietly replace `v' = sjt*`v'
					}
					sort mktid ${freq}
					foreach v in sjt x Z1 Z2 vjt {
						rename `v' old
						by mktid ${freq}: gen `v'=sum(old)
						drop old
					}
					by mktid ${freq}: keep if _n==_N
					keep mktid ${freq} sjt x Z1 Z2 vjt
					foreach v of varlist x Z1 Z2 {    
						quietly replace `v' = `v'/sjt
					}
					gen prodid=${minprod}-1
					gen brandid=0
					gen outsidegoods = 1
					tempfile outsidegooddata
					save `outsidegooddata'	
				restore
				
				preserve
					keep if outsidegoods == 1
					keep prodid brandid
					bys prodid brandid: keep if _n==1
					rename prodid prodid_raw
					gen prodid = ${minprod}-1 
					save ${outsidegood}/outsidegoods_${pmodule}_${freq}.dta, replace 
						// list of outside good products to be used to identify (and drop) outside goods in HMS data
				restore
				
				* get the mean and standard deviation of unit price of non outside goods across all store-${freq}
				drop if outsidegoods == 1
					quietly sum x [aweight = sjt]
					local mnx_nonoutsidegoods = r(mean)
					local sdx_nonoutsidegoods = r(sd)
				
				append using `outsidegooddata'	
				
													
		disp "* drop markets where there is only one product above and beyond the outside good"
				isid mktid prodid
				gen insideprod=(outsidegoods==0)
				bys mktid: egen ninsideprod=total(insideprod)
				tab ninsideprod, m
				drop if ninsideprod < 2
				tab ninsideprod, m
				drop ninsideprod insideprod
				
			count
			if r(N) != 0 {
		disp "* drop markets where there is only one brand above and beyond the outside good"
				isid mktid prodid
				bys mktid outsidegoods: egen nbrand = nvals(brandid)
				by mktid: gen ninsidebrand = nbrand[1] if outsidegoods[1] == 0
				by mktid: replace ninsidebrand = 0 if outsidegoods[1] == 1
				tab ninsidebrand, m
				drop if ninsidebrand < 2
				tab ninsidebrand, m
				drop nbrand ninsidebrand
			}

			* save list of products at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=vjt, by(prodid outsidegoods)
					isid prodid
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postoutsidegood1_prods_${pmodule}.dta, replace
				restore
			* save sales by market at this stage for cleaning accounting
				preserve
					gcollapse (sum) sales_total=vjt, by(mktid outsidegoods)
					reshape wide sales_total, i(mktid) j(outsidegoods)
					gen pm = ${pmodule}
					save ${cleaningaccounting}/postoutsidegood1_mkts_${pmodule}.dta, replace
				restore

		disp "* drop markets that don't sell an outside good"
				bys mktid: egen outsidegoodmkt = max(outsidegoods)
				drop if outsidegoodmkt == 0
				drop outsidegoodmkt
			
			count
			if r(N)==0 {     // exit if no observations left
				local nummkt_cutoff = 0
				local numprod_cutoff = 0
				local nummktprod_inside = 0
				error 3   
			}
			else {

				* save list of products at this stage for cleaning accounting
					preserve
						gcollapse (sum) sales_total=vjt, by(prodid outsidegoods)
						isid prodid
						gen pm = ${pmodule}
						save ${cleaningaccounting}/postoutsidegood2_prods_${pmodule}.dta, replace
					restore
				* save sales by market at this stage for cleaning accounting
					preserve
						gcollapse (sum) sales_total=vjt, by(mktid outsidegoods)
						reshape wide sales_total, i(mktid) j(outsidegoods)
						gen pm = ${pmodule}
						save ${cleaningaccounting}/postoutsidegood2_mkts_${pmodule}.dta, replace
					restore

				* pull number of markets 
					distinct mktid
					local nummkt_cutoff = r(ndistinct) 				
					
				* pull number of inside goods	
					distinct prodid if outsidegoods != 1
					local numprod_cutoff = r(ndistinct)
					
				* pull number of market-inside goods (excluding observations on outside goods)	
					count if outsidegoods == 1
					local nummktprod_inside = _N - r(N)

			}
	
	preserve
		di "Output number of markets and products"
			clear
			set obs 1
			gen nummkt_anyprod = `nummkt_anyprod'		// number of markets selling any products
			gen nummkt_outsidegood = `nummkt_outsidegood'	// number of markets selling outside goods
			gen nummkt_insidegood = `nummkt_insidegood'	// number of markets selling at least 2 inside goods 
			gen nummkt_cutoff = `nummkt_cutoff'            // number of markets selling outside goods and at least 2 inside goods
			gen numprod = `numprod'                        // number of products in a module (after all the cleaning, before identifying outside goods)
			gen numprod_cutoff = `numprod_cutoff'          // number of inside products in a module (after all the cleaning and identifying outside goods)
			gen nummktprod_inside = `nummktprod_inside'    // number of market-product in module (excluding outside goods and after all the cleaning) 
			gen mnx_outsidegoods = `mnx_outsidegoods'         // sales share-weighted average unit price of outside goods across all markets (store-${freq})
			gen sdx_outsidegoods = `sdx_outsidegoods'         // sales share-weighted standard deviation of unit price of outside goods across all markets (store-${freq})
			gen mnx_nonoutsidegoods = `mnx_nonoutsidegoods'   // sales share-weighted average unit price of non outside goods across all markets (store-${freq})
			gen sdx_nonoutsidegoods = `sdx_nonoutsidegoods'   // sales share-weighted standard deviation of unit price of non outside goods across all markets (store-${freq})
			gen total_sales = `total_sales'   // total value
			gen outsidegoods_sales = `outsidegoods_sales'   // outsidegoods value
			
			save ${RMSmkts}/mktscount_${pmodule}_${freq}.dta, replace	
					// number of markets selling any products in a module, selling outside goods, selling at least 2 non-outside goods, and selling outside goods and at least 2 inside goods 
	restore
		
}
end

*===================================================================================================

cap prog drop flagsample
prog define flagsample

if 1==1{

	gen tempsampleid = 0
	foreach n of numlist 1 3 5 10{
		replace tempsampleid = `n' if sjt >= `n'/100 & outsidegoods == 1
	}
	
	tab tempsampleid if outsidegoods == 1, m
	* check if outside goods observations are assigned the correct value of tempsampleid
		foreach n of numlist 0 1 3 5 10{
			di "`n'"
			sum sjt if outsidegoods == 1 & tempsampleid == `n', d
		}
		
	* expand tempsampleid to market level
		isid mktid prodid
		bys mktid: egen sampleid = max(tempsampleid)
		tab sampleid if outsidegoods == 1, m 
		drop tempsampleid

}
end

*===================================================================================================
* Reference programs (called within the sub-programs above)
*===================================================================================================
capture program drop mkdirectory
program define mkdirectory

if 1==1 {

	syntax [anything], startpath(string) fullpath(string)
	
	local returndir `c(pwd)'
	quietly cd "`startpath'"
	
	
	local subdir=substr("`fullpath'",strlen("`startpath'")+2,strlen("`fullpath'")-strlen("`startpath'"))
	
	local cut=strpos("`subdir'","/")
	
	while `cut'>0 {
		
		local cut=strpos("`subdir'","/")
		if `cut'==0 local nextdir = "`subdir'"
		else local nextdir=substr("`subdir'",1,`cut'-1)
		
		cap cd "`nextdir'"
		if _rc!=0 {
			mkdir "`nextdir'"
			quietly cd "`nextdir'"
		}
		
		local subdir=substr("`subdir'",`cut'+1,strlen("`subdir'")-`cut')
		
	}
	
	quietly cd `returndir'

}
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	cd ${programs}
	storedatacsv
	cd ${programs}

*==================================================================================================
