*===========================================================================================
*** 2c_outputforMATLAB_HMS.do
*** clean HMS data sample based on markets left in RMS estimation data 
*** and output HMS data into csv file for analysis in MATLAB
*===========================================================================================

	args freq outsidegoodscut byyear cbsa marketlevel
	
	if "`pmodule'"=="" {
		local freq = "month" // quarter
		local outsidegoodscut = 60 // 40 // 60 // 80
		local byyear = 2012     // 2006...2014 -- export data in the year specified; 0 -- export data across all years
		local cbsa = 0 // 0 //35620 for New York // 31080 for LA // 16980 for Chicago
		local marketlevel="cbsa" 	// "county" or "cbsa" if "mktid" is by county/cbsa & frequency
									// "store" if "mktid" in the output data is by store & frequency
	}
	
	foreach arg in cbsa {
		if "``arg''"=="0" local `arg' ""
	}
	
	foreach arg in freq outsidegoodscut byyear cbsa marketlevel {
		global `arg' "``arg''"
	}
	
	if ${byyear} != 0 global year "${byyear}"
	else global year "2006 2007 2008 2009 2010 2011 2012 2013 2014"
	
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"

*Name/date/time for log naming
	global name="2c_outputforMATLAB_HMS"

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	* output HMS data module by module  
		householddatacsv
		
end 
*==================================================================================================
cap prog drop householddatacsv
prog define householddatacsv

if 1==1{

	if "${marketlevel}"=="store" {
		global marketlevelsuf = ""
	}
	else {
		global marketlevelsuf="_${marketlevel}" 
	}		
	
	* outside good directory
		if ${byyear} == 0 global outsidegood "${output}/outsidegoods${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global outsidegood "${output}/outsidegoods${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
	* RMS market directory
		if ${byyear} == 0 global RMSmkts "${data}/RMSmkts_bymodule${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global RMSmkts "${data}/RMSmkts_bymodule${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
	
	* RMS output directory
		if ${byyear} == 0 global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/outside${outsidegoodscut}/${cbsa}"
		else global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/${year}/outside${outsidegoodscut}/${cbsa}"

	* directory for data cleaning accounting - keeping track of remaining products and sales in markets after each step
		if ${byyear} == 0 global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/outside${outsidegoodscut}/${cbsa}"
		else global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}/${cbsa}"

	di "Set up save directory"
		if ${byyear} == 0  global HHMatlab "${output}/dataMatLab${marketlevelsuf}/HHcsv_${freq}/outside${outsidegoodscut}/${cbsa}"
		else global HHMatlab "${output}/dataMatLab${marketlevelsuf}/HHcsv_${freq}/${year}/outside${outsidegoodscut}/${cbsa}"
		
		mkdirectory, startpath(${output}) fullpath( ${HHMatlab})


	di "Put together purchase data"
		tempfile temppurchase
		clear 
		save `temppurchase', empty
		foreach yr of numlist ${year} {
			di "Year: `yr'"

			capture use upc upc_ver_uc quantity total_price_paid coupon_value trip_code_uc year using ${HMSdata}/purchases`yr'.dta, clear
			if _rc!=0 use upc upc_ver_uc quantity total_price_paid coupon_value trip_code_uc panel_year using ${HMSdata}/purchases`yr'.dta, clear
				// created in 0a_dataconstruct/HMS/0_dataimport.do
			else rename year panel_year

			gen value = (total_price_paid - coupon_value)
			drop total_price_paid coupon_value
			
			append using `temppurchase'
			save `temppurchase', replace
		}

	
	di "Put together trips data"
		tempfile temptrips
		clear
		save `temptrips', empty
		foreach yr of numlist ${year} {
			use trip_code_uc household_code retailer_code store_code_uc panel_year purchase_date using ${HMSdata}/trips`yr'.dta, clear
				// created in 0a_dataconstruct/HMS/0_dataimport.do
			gen puryr=year(purchase_date)
			
			if "${freq}" == "quarter" {
				gen purqrt=quarter(purchase_date)
				gen quarter=yq(puryr, purqrt)
				drop purchase_date puryr purqrt
				local timevar "quarter"
			
			}
			else if "${freq}" == "semester" {
				gen purhy=halfyear(purchase_date)
				gen semester=yh(puryr, purhy)
				drop purchase_date puryr purhy
				local timevar "semester"
			}
			else if "${freq}" == "year" {
				gen year = puryr
				drop if year != panel_year
				drop purchase_date puryr year
				local timevar "year"
			}
			else {
				gen purmon=month(purchase_date)
				gen month=ym(puryr, purmon)
				drop purchase_date puryr purmon
				local timevar "month"
			}
			
			append using `temptrips'
			save `temptrips', replace 
		}
	
	di "Select households"
		use `temptrips', clear
		merge 1:1 panel_year trip_code_uc using ${step0bdata}/households${freq}.dta, keep(3) nogen keepusing(panel_year trip_code_uc) 
				// created in 0b_dataimport/Code/1a_HMS_purchasedata.do

	di "Merge in purchase data"
		merge 1:m trip_code_uc panel_year using `temppurchase', keepusing(upc upc_ver_uc quantity value)
			tab _merge, m
			drop if _merge <3 
			drop _merge
			tab panel_year, m

	di "Merge in HMS brand info"
		merge m:1 panel_year upc upc_ver_uc retailer_code using ${step0bdata}/HMSbrands.dta, keep(1 3)
				// created in 0b_dataimport/Code/0c_createproductids.do
			tab _merge, m
			drop if _merge<3
			drop _merge

	* save sales by household-market at this stage for cleaning accounting
		preserve
			gcollapse (sum) purchases_total=value, by(household_code store_code_uc `timevar' pm)
			save ${cleaningaccounting}/HMS_preprodiddrop_hhmkts.dta, replace
		restore
	
	di "Merge in HMSproductid and product characteristics"
		merge m:1 upc upc_ver_uc panel_year brand using ${step0bdata}/HMSproductids.dta, keepusing(size1_amount_updated multi productid pm)
				// created in 0b_dataimport/Code/0c_createproductids.do
			rename panel_year year
			tab _merge, m
			drop if _merge <3 
			drop _merge

	* save sales by household-market at this stage for cleaning accounting
		preserve
			gcollapse (sum) purchases_total=value, by(household_code store_code_uc `timevar' pm)
			save ${cleaningaccounting}/HMS_postprodiddrop_hhmkts.dta, replace
		restore
	
	di "Convert to common units"
		gen units = quantity*size1_amount_updated*multi

	di "Collapse to HH-store-${freq}-product level"
		collapse (sum) units value, by(household_code store_code_uc `timevar' productid pm year) fast 
	
	if "${marketlevel}"=="store" {
	di "Merge in store info"
		merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(dma_code chain_code channel_code fips_state_code fips_county_code) keep(1 3)
				// created in /0b_dataimport/Code/0_rawdataconvert.do
				// contains store information, including chain, channel, dma, and location
		gen fipscounty = fips_state_code *1000 + fips_county_code
	} 
	else if "${marketlevel}"=="county" | "${marketlevel}" == "cbsa" {
	di "Merge in HH location info"
		rename year panel_year
		merge m:1 household_code panel_year using ${step0bdata}/hhid_char.dta, keepusing(fipscode) keep(1 3)
				// created in 0b_dataimport/Code/1b_HMS_demographicdata.do
				// contains household information
		rename panel_year year
		rename fipscode fipscounty
	}
	
		drop if _merge < 3
		drop _merge
		
		tempfile tempHHstore
		save `tempHHstore'
		
	di "Load county-CBSA crosswalk data"
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
			// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
				//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		rename county fipscounty
		destring fipscounty cbsa, replace
		drop if cbsa==.
		tempfile tempcbsa
		save `tempcbsa'
	
	di "Merge in cbsa"
		use `tempHHstore'
		merge m:1 fipscounty using `tempcbsa', keep(1 3)
			drop _merge
	
	di "Keep stores in the selected cbsa"
		destring cbsa, replace
		if "${cbsa}" != "" keep if cbsa == ${cbsa}
	
		count 
		if r(N)==0 error 4  // no obs in the selected cbsa

	* save sales by household-market at this stage for cleaning accounting
		preserve
			gcollapse (sum) purchases_total=value, by(household_code store_code_uc `timevar' pm)
			save ${cleaningaccounting}/HMS_preclean_hhmkts.dta, replace
		restore

	if "${marketlevel}"=="store" {
		di "Merge in mktid"
			merge m:1 store_code_uc `timevar' using ${data}/store_${freq}_mktid_correspondence.dta, keepusing(mktid)
					// created in 2a_outputforMATLAB_prep.do (createmarketid)
				tab _merge, m
				keep if _merge ==3
				drop _merge

			* save sales by household-market at this stage for cleaning accounting
			preserve
				gcollapse (sum) purchases_total=value, by(household_code mktid pm)
				save ${cleaningaccounting}/HMS_postmerge1_hhmkts.dta, replace
			restore
		
		di "Keep market id with estimated income distribution"
			merge m:1 mktid using ${data}/List_mktid_withincdist_logincpctiles_${freq}_nocd.dta, keep(1 3)
					// created in 2a_outputforMATLAB_prep.do (storelnincdistcsv)
				tab _merge
				drop if _merge < 3
				drop _merge
	}
	else if "${marketlevel}"=="county" | "${marketlevel}"=="cbsa" {	
		di "Merge in ${marketlevel}-freq level mktid and keep only mktid with income distribution estimates"
			
			if "${marketlevel}" == "county" {
				merge m:1 fipscounty year ${freq} using "${output}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid) 
					// created by 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)
			}
			else if "${marketlevel}" == "cbsa" {
				merge m:1 cbsa year ${freq} using "${output}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid)
					// created by 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)
			}
			tab _merge, m
			keep if _merge == 3
			drop _merge

			* save sales by household-market at this stage for cleaning accounting
			preserve
				gcollapse (sum) purchases_total=value, by(household_code mktid pm)
				save ${cleaningaccounting}/HMS_postmerge1_hhmkts.dta, replace
			restore
	}
	
	di "Merge in size-adjusted income"
		if "${freq}" == "quarter" gen panel_year = year(dofq(quarter))
		else if "${freq}" == "semester" gen panel_year = year(dofh(semester))
		else if "${freq}" == "year" gen panel_year = year
		else gen panel_year = year(dofm(month))
	
		tab panel_year, m
		merge m:1 household_code panel_year using ${step0bdata}/incomeadj.dta, keepusing(lnincome) keep(1 3)
				// created in 0b_dataimport/Code/1b_HMS_demographicdata.do
		tab _merge, m
		drop if _merge < 3
		drop _merge

		rename household_code hhid
		rename productid selection
		rename lnincome lninc

	* save sales by household-market at this stage for cleaning accounting
		preserve
			gcollapse (sum) purchases_total=value, by(hhid mktid pm)
			save ${cleaningaccounting}/HMS_postmerge2_hhmkts.dta, replace
		restore
	
	di "Output household data module by module"
		rename pm product_module_code	
		
		distinct product_module_code
		levelsof product_module_code, local(pmod)
	
		tempfile tempraw
		save `tempraw'

		foreach p of local pmod {			
			use `tempraw', clear
			
			di "product: `p'"
			keep if product_module_code ==`p'

			if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {

				* drop store-freqs that are not in RMS after outlier drop step 
					cap merge m:1 store_code_uc ${freq} using ${cleaningaccounting}/postoutlier_mkts_`p'.dta, keep(1 3) keepusing(sales_total)
							// created in 2b_outputforMATLAB_RMS.do
						
						if _rc != 0{
							di "RMS postoutlier store-month data for module: `p' -- frequency: ${freq} doesn't exist"
							continue
						}
						
						tab _merge
						drop if _merge == 1 | sales_total == 0
						drop _merge sales_total
					
					count
					if r(N) == 0 continue

				di "...Collapse out the store level (keeping last observation in the group, with full sum), keeping the chain info"	
				
					local sortvars "hhid mktid selection"
					
					isid hhid mktid selection store_code_uc
					sort `sortvars' store_code_uc
					
					by `sortvars' : gen ttunits = sum(units)
					by `sortvars' : gen ttvalue = sum(value)
					by `sortvars' : keep if _n==_N
					
					drop units value
					rename (ttunits ttvalue) (units value)

			}
			
			keep mktid hhid selection value lninc units
			
			* drop markets that are not in RMS after cleaning 
				cap merge m:1 mktid using ${RMSmkts}/mkts_`p'_${freq}.dta, keep(1 3)
						// created in 2b_outputforMATLAB_RMS.do
					
					if _rc != 0{
						di "RMS market data for module: `p' -- frequency: ${freq} doesn't exist"
						continue
					}
					
					tab _merge
					drop if _merge == 1
					drop _merge
				
				count
				if r(N) == 0 continue

			* identify outside goods
				rename selection prodid_raw
				merge m:1 prodid_raw using ${outsidegood}/outsidegoods_`p'_${freq}.dta, keep(1 3) keepusing(prodid)
						// created in 2b_outputforMATLAB_RMS.do
					tab _merge
					gen outsidegoods = 0 
					replace outsidegoods = 1 if _merge == 3
					drop _merge
				
				count if outsidegoods == 1
				if r(N) == 0 continue
				
			* group all outside goods as one product
				preserve 
				keep if outsidegoods == 1
				isid mktid hhid prodid_raw
				collapse (sum) units value, by(mktid hhid lninc prodid outsidegoods) fast
				rename prodid selection
				isid mktid hhid selection
				tempfile temp`p'
				save `temp`p''
				restore
				
				drop if outsidegoods == 1
				rename prodid_raw selection
				keep mktid hhid selection lninc units value outsidegoods
				append using `temp`p''
				
			isid mktid hhid selection
			sort mktid selection
			
			egen w = total(units)
			replace w = units/w
			
			order hhid selection units value mktid lninc outsidegoods w

			* save sales by household-market at this stage for cleaning accounting
			preserve
				gcollapse (sum) purchases_total=value, by(hhid mktid outsidegoods)
				reshape wide purchases_total, i(hhid mktid) j(outsidegoods)
				cap gen purchases_total0 = 0
				cap gen purchases_total1 = 0
				rename (purchases_total0 purchases_total1) (purchases_nonoutside purchases_outside)
				save ${cleaningaccounting}/HMS_postclean_hhmkts_`p'.dta, replace
			restore
			drop value
			
			outsheet using ${HHMatlab}/HH_module`p'_data_outside.csv, replace
		}
	
}
end


*================================================================================================
capture program drop mkdirectory
program define mkdirectory

if 1==1 {

	syntax [anything], startpath(string) fullpath(string)
	
	local returndir `c(pwd)'
	quietly cd "`startpath'"
	
	
	local subdir=substr("`fullpath'",strlen("`startpath'")+2,strlen("`fullpath'")-strlen("`startpath'"))
	
	local cut=strpos("`subdir'","/")
	
	while `cut'>0 {
		
		local cut=strpos("`subdir'","/")
		if `cut'==0 local nextdir = "`subdir'"
		else local nextdir=substr("`subdir'",1,`cut'-1)
		
		cap cd "`nextdir'"
		if _rc!=0 {
			mkdir "`nextdir'"
			quietly cd "`nextdir'"
		}
		
		local subdir=substr("`subdir'",`cut'+1,strlen("`subdir'")-`cut')
		
	}
	
	quietly cd `returndir'
}

end

*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	set linesize 200
	cd "$data"
	main
	cd "$programs"
	capture log close

*==================================================================================================
