*==========================================================================================
*** 3a_RMS_test2sls_regs.do
*** using RMS data outputted for analysis in MATLAB, tests 2SLS estimation
*==========================================================================================

	args pmodule freq outsidegoodscut year storedirsfx instroption
	
	if "`pmodule'"=="" {
		local pmodule = 1016 // 1016 // 8411 //  0 // 6049 
		local freq = "month" // "quarter"
		local outsidegoodscut = 60 // 40 60 80
		local year = 2012
		local storedirsfx = "_cbsa" // suffix of input store data "_incbrkt_nocd", "_cbsa", "_county"
		local instroption = 4 // income iv options: 0,1,2,3 or 4
	}
	
	foreach arg in pmodule freq outsidegoodscut year storedirsfx instroption {
		global `arg' "``arg''"
	}

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global output "$currentstep/STATAOutput"
	global logs "$currentstep/STATALogs"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"

*Extra data necessary
	
	* directory for test RMS data
		global storeMatlab "${output}/dataMatLab${storedirsfx}/storecsv_${freq}/${year}/outside${outsidegoodscut}"		
	
	* incomde distribution data
		if "${storedirsfx}"=="_incbrkt_nocd" global incdistdata "${data}/storeincdist_logincpctiles_${freq}_nocd.dta" // in matlab used for instroption=1/4
		else if inlist("${storedirsfx}","_cbsa","_county") global incdistdata "${output}/dataMatLab${storedirsfx}/storeincdist_${freq}.dta" // in matlab used for county-level data
		
	* directory for test result output
		global estoutput "${output}/RMS_test2sls${storedirsfx}"
		cap mkdir ${estoutput}
		cap mkdir ${estoutput}/${freq}
		cap mkdir ${estoutput}/${freq}/outside${outsidegoodscut}

*==================================================================================================
*==================================================================================================
*** Main program to run subprograms defined below

capture program drop main
	program define main
	
	global instrvarlist "Z1 Z2"
	global reglist "lnZ2lesslnZ1 lnZ1 lnZ2"
	
	disp "... load store data from: ${storeMatlab}"
	disp "... save test results to ${estoutput}/${freq}/outside${outsidegoodscut}"

	regdataprep // prep data for 2SLS - replicates code in microblp.m
	
	local first = 1
	foreach t in 3 { // 0 1 3 5 10 
		foreach r in lnZ2 lnZ2lesslnZ1 lnZ2_lnZ2lesslnZ1 {
			preserve
				run2sls, z(`r') first(`first') threshold(`t')   // - run 2SLS - replicates code in thetalin_twostep.m
			restore
			local first = 0
		}
	}
	
end

*==================================================================================================
*==================================================================================================
* 	prep data for 2SLS - replicates code in microblp.m (with additional step up to to drop markets with outside goods below sales threshold
*==================================================================================================

cap prog drop regdataprep
prog define regdataprep

if 1==1 {

	cap confirm file ${storeMatlab}/store_module${pmodule}_data.csv
	if _rc!=0 di "... input data for module ${pmodule} is not available"
	else {
		import delimited "${storeMatlab}/store_module${pmodule}_data.csv", case(preserve) clear
					// created in 2b_outputforMATLAB_RMS.do
					// variables: mktid prodid (unique identifiers) brandid sjt x Z1 Z2 vjt
	
		* take logs of prices and shares 
			foreach v in sjt x ${instrvarlist} {
				if strpos("`v'", "Z3") == 0 gen ln`v' = ln(`v')
				else gen ln`v' = `v'
				if "`v'" != "sjt" drop `v'
			}
			
			foreach v in sjt x ${instrvarlist} {
				drop if ln`v'==.
			}		
	
		* merge data with market income data
			if "${storedirsfx}"=="_incbrkt_nocd" {
				* 50 income brackets
				merge m:1 mktid using ${incdistdata}, keepusing(avginc* weight*) keep(1 3)
						// created in 2a_outputforMATLAB_prep.do 
				
				di "calculate within-store log of mean income from 50 brackets"
				
					forval i=1/50 {
						gen w_avginc_level`i'=exp(avginc`i')*weight`i'
					}
					egen sum_avginc_level = rowtotal(w_avginc_level*)
					egen sum_w = rowtotal(weight*)
					
					gen meanlninc = log(sum_avginc_level/sum_w)
					drop weight* sum_w w_avginc_level* sum_avginc_level 
					
					drop if meanlninc==. 
			}
			else {
			disp "${incdistdata}"
				merge m:1 mktid using ${incdistdata}, keep(1 3)
						// created in 2a_outputforMATLAB_prep.do 
				drop if meanlninc==. | vlninc==.
			}
					
			drop if _m<3
			drop _merge

		* de-mean income variables
			gen dmlninc = meanlninc - ln(37500)
			
		*confirm that outside good has lowest brand id value
			quietly sum brandid if outsidegoods==1
			local outsidebrand=`r(max)'
			quietly sum brandid
			assert `outsidebrand'==`r(min)'
	
		*create brand dummies for all but the outside good and interact with moments of market income
			foreach v in dbrand* int* {
				capture drop `v'
			}
		
			tab brandid, gen(dbrand) matrow(brands) 
			global nbrands=`r(r)'
			drop dbrand1

		*residualize instrument where appropriate
			global dinstrlist
			foreach z in ${reglist} {
				if strpos("`z'", "less") != 0 {
					local z=subinstr("`z'","less","^",.)
					tokenize `z', parse("^")
					disp "`1' `2' `3' `4'"
					local instr1 = "`1'"
					local instr2 = "`3'"
					reg `instr1' `instr2'
					predict `instr1'less`instr2', resid
				}
				if  strpos("`z'", "_") == 0 global dinstrlist="${dinstrlist} `z'"
			}
		
		*list of variables related to instruments
			local dinstrlist_vague ""
			foreach i in ${instrvarlist} {
				local dinstrlist_vague "`dinstrlist_vague' *`i'*"
			}

		*list of single variable instruments to be interacted
			global dinstrlist
			foreach z in ${reglist} {
				if  strpos("`z'", "_") == 0 global dinstrlist="${dinstrlist} `z'"
			}

		*interact instruments with moments of income distribution
			foreach v of varlist dbrand* lnx ${dinstrlist} { 
				if ${instroption}==0 {
					gen int`v'_dmlninc = `v'*dmlninc
					gen int`v'_dmlninc2 = `v'*(dmlninc^2)
					gen int`v'_vlninc = `v'*vlninc
				}
				else {
					if inlist(${instroption},1,4) {
						gen int`v'_dmlninc = `v'*dmlninc
						gen int`v'_dmlninc2 = `v'*(dmlninc^2)
						gen int`v'_interq = avginc36 - avginc26 // p75-p25
					}
					if inlist(${instroption},2,3,4) {
						gen int`v'_p10 = avginc20
						gen int`v'_p25 = avginc26 
						gen int`v'_p50 = avginc31
						gen int`v'_p75 = avginc36
						gen int`v'_p90 = avginc39 
					}
					if inlist(${instroption},3,4) {
						gen int`v'_p5 = avginc16
						gen int`v'_p95 = avginc41
					}
				}
			}
			cap drop avginc*	
		
		*demean variables to remove market fixed effects
			foreach var of varlist lnsjt lnx dbrand* intdbrand*_* `dinstrlist_vague' {
				capture rename `var' notdm`var'
				if _rc==0 {
					bys mktid: egen mn`var' = mean(notdm`var')
					quietly gen `var' = notdm`var'-mn`var'
					drop mn`var'
				}
			}
	
		* save intermediate result in test runs 
			save ${estoutput}/${freq}/outside${outsidegoodscut}/regdata_module${pmodule}.dta, replace
	}

}
end

*==================================================================================================
*	run2sls - replicates code in thetalin_twostep.m
*==================================================================================================

cap prog drop run2sls
prog define run2sls
	syntax [anything], [z(string)] first(integer) threshold(integer)

if 1==1 {

	foreach v in linearpred alpha* beta resid X* W* gamma fsF* fscoef* fsse* {
		capture drop `v'
	}

	* Step 0: market selection
	
	* first, keep markets whose sales share of outside goods exceeds `threshold' if `threshold' > 0; use all markets if `threshold'==0
		if `threshold' > 0{
			keep if sampleid>=`threshold'
		}

		disp "Check brand dummies..."
		forvalues b = 2/${nbrands} { // dbrand1 was for outside good
			quietly count if dbrand`b'!=0
			if `r(N)'==0 disp "obs for brand `b': `r(N)'"
		}

	* Step 1: regress log relative shares against brand dummies (for all but outside good) and log relative prices
		if "`z'"=="" reg lnsjt dbrand* lnx, nocons	
		else if strpos("`z'", "_") == 0 ivreghdfe lnsjt dbrand* (lnx  = `z'* int`z'_* intdbrand*_*), absorb(mktid) robust gmm2s 
		else{
			tokenize `z', parse("_")
			local instr1 = "`1'"
			local instr2 = "`3'"
			ivreghdfe lnsjt dbrand* (lnx  = `instr1'* `instr2'* int`instr1'_* int`instr2'_* intdbrand*_*),  absorb(mktid) robust gmm2s 
		}

		disp "Check brand dummies for regression sample..."
		forvalues b = 2/${nbrands} { // dbrand1 was for outside good
			quietly count if dbrand`b'==1 & e(sample)
			if `r(N)'==0 disp "no obs for brand `b'"
		}
	
		* pull sample information
			count if e(sample)
			gen numobs = r(N)
			distinct mktid if e(sample)
			gen nummkt = r(ndistinct)
					
		* construct alpha0 and beta
			predict linearpred, xb
			gen alpha0 = -_b[lnx]
			gen beta = .
			forvalues b=2/${nbrands} {  // dbrand1 was for outside good
				cap noisily replace beta = _b[dbrand`b']/alpha0 if brand==brands[`b',1]
			}
				// alpha0 = coefficient on log relative prices
				// beta = coefficients on brand dummies/alpha0
		
		* run first-stage regression and pull estimated coef and F-stats
			gen fscoef = .
			gen fsse = .
			gen fsF = .
			gen fsRsquared = .
			if "`z'" != ""{
				if strpos("`z'", "_") == 0 regress lnx `z'* int`z'_* intdbrand*_* dbrand*
				else regress lnx `instr1'* `instr2'* int`instr1'_* int`instr2'_* intdbrand*_* dbrand*
				
				replace fsF = e(F)
				replace fsRsquared = e(r2)
				if strpos("`z'", "_") == 0 {
					replace fscoef =_b[`z']
					replace fsse = _se[`z']
				}
				else{
					replace fscoef = _b[`instr1']
					replace fsse = _se[`instr1']
					gen fscoef2 = _b[`instr2']
					gen fsse2 = _se[`instr2'] 
				}
			}
						
	*Step 2: predict residual log relative share and regress against (beta*alpha0*dmlninc, (beta - rellnp)*dmlninc, beta*(dmlninc^2))
		gen resid = lnsjt - linearpred
		gen X1 = beta*alpha0*dmlninc
		gen X2 = (beta - lnx)*dmlninc
		gen X3 = beta*(dmlninc^2)
		
		if "`z'"=="" reg resid X1 X3 X2
		else if strpos("`z'", "_") == 0{
			gen W1 = beta*dmlninc
			gen W2 = `z'*dmlninc
			ivregress gmm resid X1 X3 (X2 = W1 W2) 
		}
		else {
			gen W1 = beta*dmlninc
			gen W2 = `instr1'*dmlninc
			gen W3 = `instr2'*dmlninc
			ivregress gmm resid X1 X3 (X2 = W1 W2 W3) 
		}
		
		gen gamma = _b[X1]
		gen alpha1 = _b[X2]
			// gamma = coefficient on beta*alpha0*dmlninc
			// alpha1 = coefficient on (beta - rellnp)*dmlninc
		gen alpha1_2 = _b[X3]/_b[X2]
		
	*Output coefficients
		collapse (mean) beta alpha* gamma nummkt numobs fsF fsRsquared fscoef* fsse*, by(brandid) fast
		gen instrument = "`z'"
		gen threshold = `threshold'
		order instrument nummkt numobs threshold
		if `first'==0 append using ${estoutput}/${freq}/outside${outsidegoodscut}/testestimates_newZ2_module${pmodule}.dta
		save ${estoutput}/${freq}/outside${outsidegoodscut}/testestimates_newZ2_module${pmodule}.dta, replace	

}			
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	log using "${logs}/3_RMS_test2sls/3a_regs_mod`pmodule'.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	log close
	
*==================================================================================================
