*===========================================================================================
*** 3b_RMS_test2sls_compare.do
*** using RMS data outputted for analysis in MATLAB, tests 2SLS estimation
*===========================================================================================

	args freq
	
	if "`freq'"=="" {
		local freq="month"
	}
	
	foreach arg in freq {
		global `arg' "``arg''"
	}
	
*===========================================================================================
*** Directory Set-up
	
*Set project directories	
	do ../../SetFilePaths.do
	
	global currentstep "$terminal/1_dataprep"
	global currentsteprepo "$dir/.."

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global logs "$currentstep/STATALogs"

*Output directories
	global dataoutput "$currentstep/STATAOutput/RMS_test2sls_cbsa"
	global repooutput "$currentsteprepo/RepoOutput/RMS_test2sls_cbsa"
	cap mkdir "$currentsteprepo/RepoOutput/RMS_test2sls_cbsa"
	cap mkdir "$currentsteprepo/RepoOutput/RMS_test2sls_cbsa/Plots"
	
*==================================================================================================
*==================================================================================================
*** Main program to run subprograms defined below

capture program drop main
program define main

	* append together regression estimates across modules
		appendestimates, outsidecutlab("60")

	* plot parameters for different specs/module set
		estalphadist_format, outsidecutlab("60")

end

*==================================================================================================

*==================================================================================================
*	appendestimates - append together regression estimates
*==================================================================================================

cap prog drop appendestimates
prog define appendestimates
	syntax [anything], outsidecutlab(string)

if 1==1{

	* module list
		import delimited ${step0bdata}/productmodule_list_noncount.txt, clear
				// created in 0b_dataimport/Code/0c_createproductids.do
		levelsof v1, local(pmodlist)

	clear
	save ${dataoutput}/testestimates_newZ2_outsidecut`outsidecutlab'_${freq}.dta, emptyok replace
	
		gen product_module_code = .
		foreach p of local pmodlist {
				di "`p'"
				cap noisily append using ${dataoutput}/${freq}/outside`outsidecutlab'/testestimates_newZ2_module`p'.dta
						// created in 3a_RMS_test2sls_regs.do
				if _rc == 0 replace product_module_code = `p' if product_module_code ==.
					
		}
		
		gen outsideshcutoff = "`outsidecutlab'"
		order product_module_code outsideshcutoff instrument nummkt numobs
		sort product_module_code instrument outsideshcutoff
		save ${dataoutput}/testestimates_newZ2_outsidecut`outsidecutlab'_${freq}.dta, replace

}
end
	
*======================================================================================================
*	estalphadist_format -- PLOT ESTIMATED ALPHA 0 ACROSS MODULES AND INSTRUMENTS 
*======================================================================================================

cap prog drop estalphadist_format
prog define estalphadist_format
	syntax [anything],  outsidecutlab(string)

if 1==1{

		use ${step0bdata}/size1_units_pm.dta, clear
					// created in 0b_dataimport/Code/0c_createproductids.do
			* to only consider modules that don't have "CT" as units
			rename pm product_module_code
			bys product_module_code: gen first=(_n==1)
			tab size1_units_updated if first==1
			drop if size1_units_updated=="" | size1_units_updated=="CT" | size1_units_updated=="EXP"	
			
		merge 1:m product_module_code using ///
			${dataoutput}/testestimates_newZ2_outsidecut`outsidecutlab'_${freq}.dta, keep(3) nogen
			
		* keep only one observation per product_module_code instrument (since only alpha0 is plotted and alpha0 doesn't change within product_module_code outsidecutoff instrument)
			bys product_module_code instrument: keep if _n == 1
			bys product_module_code instrument: gen numcatpermodule = _N
			tab numcatpermodule, m
			tab instrument, m
			replace instrument = "OLS" if instrument == ""
			tab instrument, m
							
		* calculate tstat for the first-stage coef
			gen fststat = fscoef/fsse
			cap gen fststat2 = fscoef2/fsse2 
			
			foreach var of varlist fscoef* fsse* fststat* fsF alpha0 {
				_pctile `var', p(99) 
				replace `var' = . if `var' > r(r1)
			}
			
		* plot instrument title	
			local tt_OLS "OLS"
			local tt_lnZ2 "IV (Main)"
			local tt_lnZ2lesslnZ1 "IV (Residualized)"
			
			local tt_lnZ "IV"
			
			local def0 "Outside Goods Def 0"
			local def1 "Outside Goods Def 1"
			local def2 "Outside Goods Def 2"
			
			local labfsF="F-Statistic"
			local labfscoef="Price Coefficient: Point Estimate"
			local labfststat="Price Coefficient: T-Statistic"
			local linefsF=10
			local linefscoef=1
			local linefststat=1.96
			
		* plot line pattern	
			local lpset "l dash dot dash_dot longdash shortdash longdash_dot shortdash_dot"
		
		* plot var & instrument list
			local parmlist "fsF fscoef fststat"
			local instrlist "lnZ2"  // "lnZ" dlnZ2 dlnZ1
			
			local ln10=log(10)
			foreach parm in `parmlist' {
				if substr("`parm'", 1, 2) != "fs" {
					local xrange "range(-2 3)"
					local xlineadd ""
					local ylineadd ""
				}
				else {
					local xrange ""
					local xlineadd "xline(`line`parm'')"
					local ylineadd "yline(`line`parm'')"
				}
				if substr("`parm'", 1, 3) == "fsF" {
					local xscale "xscale(log)"
					local xlabel "xlabel(10 100 1000 10000 100000)"
				}
				else {
					local xscale ""
					local xlabel ""
				}
	
			disp "`parm': `lab`parm''"
			* for each cutoff, plot the distribution of estimated `parm' for each instruments
				local outputeps ""
				local boxeps ""
				foreach cutoff in ${outsidelist} {
					if substr("`parm'", 1, 2) != "fs" local looplist="OLS `instrlist'"
					else {
						local looplist="`instrlist'"
						drop if instrument == "OLS"
					}
					
					disp "`looplist'"
					tab instrument
					local kdensityplot ""
					local legendopt ""
					local i = 1
					foreach instr in `looplist' {
					
							* checking!
							di "`instr'"
							* check outliers
							count if outsideshcutoff == "`cutoff'" & instrument == "`instr'" & `parm' != .
							count if outsideshcutoff == "`cutoff'" & instrument == "`instr'" & `parm' == .
							
							local lpopt = word("`lpset'", `i')
							local kdensityplot `"`kdensityplot' (kdensity `parm' if outsideshcutoff == "`cutoff'" & instrument == "`instr'", lp(`lpopt') `xlabel' ylabel(none) `xrange' `xlineadd' `xscale')"'
							sum `parm' if outsideshcutoff == "`cutoff'" & instrument == "`instr'"
							local legendopt `"`legendopt' label(`i' "`tt_`instr''")"'
							local i = `i' + 1

					} // end of instrlist
					if `i'==1 local legendopt="none"
					
					twoway `kdensityplot', legend(`legendopt' cols(3)) title("`lab`parm''") ytitle("") ///
							graphregion(fcolor(white)) name(`parm', replace)
					graph export ${repooutput}/Plots/${freq}_dist_`parm'.eps, replace

				}	 // end of outside list
			} // end of parmlist
			graph combine fsF fscoef fststat, cols(1)
			graph export ${repooutput}/Plots/${freq}_dist.eps, replace
				
}
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	cd "$data"
	main
	capture log close

*==================================================================================================
