*===========================================================================================
*** 4a_datacleaning_accounting.do
*** produce tables on remaining products and markets after each step of data cleaning, in RMS and HMS data
*===========================================================================================

args freq marketlevel outsidegoodscut byyear

if "`freq'"=="" {
	local freq="month"
	local marketlevel="store"
	local outsidegoodscut = 60 // 40 // 60 // 80
	local byyear = 2012     // 2006...2014
}

foreach arg in freq marketlevel outsidegoodscut byyear {
	global `arg' "``arg''"
	di "`arg' : ${`arg'}"
}
	
if ${byyear} != 0 global year "${byyear}"
else global year "2006 2007 2008 2009 2010 2011 2012 2013 2014"

*===========================================================================================
*** Directory Set-up

*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "${terminal}/1_dataprep"

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	cd ${dir}

* Set-up standard directories
	global data "$currentstep/STATAData"
	global stataoutput "$currentstep/STATAOutput"
	global temp "${data}/temp"
	global output "$currentsteprepo/RepoOutput"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"

* Set-up dataprep directories

	if "${marketlevel}"=="store" {
		global marketlevelsuf = ""
	}
	else {
		global marketlevelsuf="_${marketlevel}"
	}

	if ${byyear} == 0 global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/outside${outsidegoodscut}"
	else global cleaningaccounting "${output}/cleaning_acct${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}"

	if ${byyear} == 0 global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/outside${outsidegoodscut}"
	else global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/${year}/outside${outsidegoodscut}"

*==================================================================================================
**** Program to run sub-programs

cap prog drop main 
prog define main

	RMS_cleaning_steps
	HMS_cleaning_steps
	cleaning_steps_analysis

end

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
* Append together RMS data from various cleaning steps and simulate cleaning if necessary
*===================================================================================================

cap prog drop RMS_cleaning_steps
prog define RMS_cleaning_steps

	import delimited "${step0bdata}/productmodule_list_noncount.txt", clear
		// created in 0b_dataimport/Code/0c_createproductids.do
	qui levelsof v1, clean local(productmodule_list)
	import delimited "${step0data}/productmodule_list.txt", clear
		// created in 0b_dataimport/Code/0a_rawdataconvert.do
	qui levelsof v1, clean local(productmodule_list_all)

	if "${marketlevel}" == "store" local mktvar "store_code_uc"
	else if "${marketlevel}" == "county" local mktvar "fipscounty"
	else if "${marketlevel}" == "cbsa" local mktvar "cbsa"

	*** 1. drop if not measured in the modal units for a given module or in a module that doesn’t have dominant modal units
	*** 	(step in 1c_RMS_datasetup)

		global rawdir "${RMSdata}/1_moduleyear/Output"

		clear 
		save "${temp}/cleaning_acct_prodiddrop_store_modules1.dta", replace emptyok
		save "${temp}/cleaning_acct_prodiddrop_store_mkts1.dta", replace emptyok

		foreach module in `productmodule_list_all' {

			disp "`module'"
			cap noisily gzuse "${rawdir}/WorkingFiles/month_`module'_${year}.dta", clear
					// created in 0a_dataconstruct/RMS/1_createworkingfiles.do
			if _rc==0{

				* confirm data is at store-upc-month level
					cap isid store_code_uc upc upc_ver_uc product_module_code year month
					if _rc != 0	collapse (sum) value units, by(store_code_uc upc upc_ver_uc product_module_code year month) fast
					qui assert product_module_code == `module'

				preserve
					gcollapse (sum) sales_total=value, by(store_code_uc month product_module_code)
					tempfile preprodiddrop
					qui save `preprodiddrop'
				restore

				* simulate product id drop
					if strpos("`productmodule_list'", "`module'") {
						di "Merge in retailer code of each store"
							qui merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(chain_code) keep(3) nogen
									// created in 0b_dataimport/Code/0a_rawdataconvert.do
										
						di "Merge in brand information"
							qui merge m:1 year upc upc_ver_uc chain_code using ${step0bdata}/RMSbrand_bymodule/RMSupcbrand_`module'_${year}.dta, keep(3) keepusing(brand) nogen
									// created in 0b_dataimport/Code/0b_createproductids_ctlbrandsRMS.do
						
						di "Merge in product id"
							rename year panel_year
							qui merge m:1 upc upc_ver_uc panel_year brand using ${step0bdata}/RMSproductids.dta, keep(3) keepusing(productid) nogen
									// created in 0b_dataimport/Code/0c_createproductids.do
					}
					else {
						replace value = 0
					}
					
				gcollapse (sum) sales_total=value, by(store_code_uc month product_module_code)

				rename sales_total sales_postprodiddrop
				qui merge 1:1 store_code_uc month product_module_code using `preprodiddrop', nogen
				rename sales_total sales_preprodiddrop
				rename product_module_code pm

				preserve
					gen nmkts_preprodiddrop = 1
					gen nmkts_postprodiddrop = 1 if sales_postprodiddrop > 0 & sales_postprodiddrop != .
					gcollapse (sum) sales_* nmkts_*, by(pm)
					qui append using "${temp}/cleaning_acct_prodiddrop_store_modules1.dta"
					qui save "${temp}/cleaning_acct_prodiddrop_store_modules1.dta", replace
				restore
					drop pm
					gen nmods_preprodiddrop = 1
					gen nmods_postprodiddrop = 1 if sales_postprodiddrop > 0 & sales_postprodiddrop != .
					qui append using "${temp}/cleaning_acct_prodiddrop_store_mkts1.dta"
					gcollapse (sum) sales_* nmods_*, by(store_code_uc month)
					qui save "${temp}/cleaning_acct_prodiddrop_store_mkts1.dta", replace

			}
		}

	*** 2. all steps in 2b_outputforMATLAB_RMS

		** merge stages & append modules of datacleaning_accounting "mkts" files; sum to (1) market level, (2) module level

		clear
		save "${temp}/cleaning_acct_${marketlevel}_mkts.dta", replace emptyok
		save "${temp}/cleaning_acct_${marketlevel}_modules.dta", replace emptyok

		if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
			** Load county-CBSA crosswalk data
			import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
				// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
			rename county fipscounty
			destring fipscounty cbsa, replace
			drop if cbsa==.
			keep fipscounty cbsa
			tempfile tempcbsa
			save `tempcbsa'
		}

		* stages at store-level
		local stages1 "preclean postmerge postdropmiss postoutlier"
		foreach module in `productmodule_list' {
			disp "`module'"
			clear
			local done = 0

			foreach stage in `stages1' {
				if "`stage'" == "preclean" {
					capture use "${cleaningaccounting}/`stage'_mkts_`module'.dta", clear
						// created in 2b_outputforMATLAB_RMS.do
					if _rc == 601 {
						disp "No input data for this module; skipping"
						continue, break
					}
				}
				else {
					capture merge 1:1 store_code_uc ${freq} pm using "${cleaningaccounting}/`stage'_mkts_`module'.dta", nogen
						// created in 2b_outputforMATLAB_RMS.do
				}
				if _rc == 601 {
					disp "No data after certain stage for this module; skipping"
					local done = 1
					continue, break
				}

				qui replace sales_total = 0 if sales_total == .
				rename sales_total sales_`stage'
			}
			if _N == 0 continue

			* merge in mktid - for county/cbsa, first merge in county/cbsa info, then mktid, then collapse to county/cbsa level
			if "${marketlevel}" == "store" {
				qui merge 1:1 store_code_uc ${freq} using ${data}/store_${freq}_mktid_correspondence.dta, keepusing(mktid) keep(1 3) nogen
						// created in 2a_outputforMATLAB_prep.do (createmarketid)
			}
			if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
				qui gen year = $year
				qui merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(fips_state_code fips_county_code) keep(1 3) nogen
						// created in 0b_dataimport/Code/0_rawdataconvert.do
				qui gen fipscounty = fips_state_code *1000 + fips_county_code
				qui merge m:1 fipscounty using `tempcbsa', keep(1 3) nogen
				qui merge m:1 `mktvar' ${freq} using "${stataoutput}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid) keep(1 3) nogen
						// created in 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)
				qui replace `mktvar' = 0 if `mktvar' == .
				qui replace mktid = -${freq} if mktid == .
				gcollapse (sum) sales_*, by(`mktvar' ${freq} mktid pm)
			}

			* stages at county/cbsa level
			if `done' == 0 {
				local stages2 "postoutsidegood1 postoutsidegood2"
				foreach stage in `stages2' {
					capture merge 1:1 mktid pm using "${cleaningaccounting}/`stage'_mkts_`module'.dta", nogen
						// created in 2b_outputforMATLAB_RMS.do
					if _rc == 601 {
						disp "No data after certain stage for this module; skipping"
						continue, break
					}

					cap gen sales_total0 = 0
					cap gen sales_total1 = 0
					qui replace sales_total0 = 0 if sales_total0 == .
					qui replace sales_total1 = 0 if sales_total1 == .
					qui gen sales_`stage' = sales_total0 + sales_total1
					drop sales_total0 sales_total1
				}
			}
			
			foreach stage in `stages1' `stages2' {
				cap gen n_`stage' = (sales_`stage' > 0)
			}

			preserve
				rename n_* nmkts_*
				gcollapse (sum) sales_* nmkts_*, by(pm)
				qui append using "${temp}/cleaning_acct_${marketlevel}_modules.dta"
				qui save "${temp}/cleaning_acct_${marketlevel}_modules.dta", replace
			restore
				drop pm
				rename n_* nmods_*
				qui append using "${temp}/cleaning_acct_${marketlevel}_mkts.dta"
				gcollapse (sum) sales_* nmods_*, by(`mktvar' ${freq} mktid)
				isid `mktvar' ${freq}
				qui save "${temp}/cleaning_acct_${marketlevel}_mkts.dta", replace

		}

	*** 3. (done in MatLab, simulated here) drop markets whose total outside good share is <3%

		clear
		save "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta", replace emptyok // save at mkt-module level for HMS merge later

		foreach module in `productmodule_list' {
			disp "`module'"
			capture confirm file "${storeMatlab}/store_module`module'_data.csv"
			if _rc==0 {
				import delimited "${storeMatlab}/store_module`module'_data.csv", case(preserve) clear
					// created in 2b_outputforMATLAB_RMS.do
					// mktid ${freq} prodid brandid sjt x Z* vjt outsidegoods sampleid  
				qui gen pm = `module' 
					
				** products sold in markets with outside good share < 3%
					qui drop if (sampleid<3)

				if _N > 0 {
					qui gcollapse (sum) sales_postoutsidegood3=vjt, by(mktid pm)
					qui append using "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta"
					qui save "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta", replace
				}
			}
		}
		use "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta"
		gen nmkts_postoutsidegood3 = 1 if sales_postoutsidegood3 > 0
		gcollapse (sum) sales_postoutsidegood3 nmkts_postoutsidegood3, by(pm)
		save "${temp}/cleaning_acct_matlabstep_${marketlevel}_modules.dta", replace
		use "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta"
		gen nmods_postoutsidegood3 = 1 if sales_postoutsidegood3 > 0
		gcollapse (sum) sales_postoutsidegood3 nmods_postoutsidegood3, by(mktid)
		save "${temp}/cleaning_acct_matlabstep_${marketlevel}_mkts.dta", replace

end

*===================================================================================================
* Append together HMS data from 2c_outputforMATLAB_HMS.do steps and simulate cleaning based on RMS drops
*===================================================================================================

cap prog drop HMS_cleaning_steps
prog define HMS_cleaning_steps

	import delimited "${step0bdata}/productmodule_list_noncount.txt", clear
		// created in 0b_dataimport/Code/0c_createproductids.do
	rename v1 pm
	qui levelsof pm, clean local(productmodule_list)
	keep pm
	tempfile modules
	save `modules'

	if "${marketlevel}" == "store" local mktvar "store_code_uc"
	else if "${marketlevel}" == "county" local mktvar "fipscounty"
	else if "${marketlevel}" == "cbsa" local mktvar "cbsa"

	*** Merge HMS data

		use "${cleaningaccounting}/HMS_preprodiddrop_hhmkts.dta", clear
				// created in 2c_outputforMATLAB_HMS.do
		rename purchases_total purchases_preprodiddrop
		merge 1:1 household_code store_code_uc ${freq} pm using "${cleaningaccounting}/HMS_postprodiddrop_hhmkts.dta", nogen
				// created in 2c_outputforMATLAB_HMS.do
		replace purchases_total = 0 if purchases_total == .
		rename purchases_total purchases_postprodiddrop

		merge 1:1 household_code store_code_uc ${freq} pm using "${cleaningaccounting}/HMS_preclean_hhmkts.dta", nogen
				// created in 2c_outputforMATLAB_HMS.do
		replace purchases_total = 0 if purchases_total == .
		rename purchases_total purchases_preclean

		if "${marketlevel}" == "store" {
			qui merge 1:1 store_code_uc ${freq} using ${data}/store_${freq}_mktid_correspondence.dta, keepusing(mktid) keep(1 3) nogen
					// created in 2a_outputforMATLAB_prep.do (createmarketid)
		}
		else if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {

			di "Merge in HH location info"
				gen panel_year = $year
				merge m:1 household_code panel_year using ${step0bdata}/hhid_char.dta, keepusing(fipscode) keep(1 3) nogen
						// created in 0b_dataimport/Code/1b_HMS_demographicdata.do
				rename panel_year year
				rename fipscode fipscounty
				tempfile tempHHstore
				save `tempHHstore'
			di "Load county-CBSA crosswalk data"
				import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
					// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
				rename county fipscounty
				destring fipscounty cbsa, replace
				drop if cbsa==.
				keep fipscounty cbsa
				tempfile tempcbsa
				save `tempcbsa'
			di "Merge in cbsa"
				use `tempHHstore'
				merge m:1 fipscounty using `tempcbsa', keep(1 3) nogen

			qui merge m:1 `mktvar' ${freq} using "${stataoutput}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", keepusing(mktid) keep(1 3) nogen
					// created in 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)

			qui replace `mktvar' = 0 if `mktvar' == .
			qui replace mktid = -${freq} if mktid == .

		}

		merge m:1 household_code mktid pm using "${cleaningaccounting}/HMS_postmerge1_hhmkts.dta", nogen
				// created in 2c_outputforMATLAB_HMS.do
		replace purchases_total = 0 if purchases_total == .
		rename purchases_total purchases_postmerge1
		rename household_code hhid

		merge m:1 hhid mktid pm using "${cleaningaccounting}/HMS_postmerge2_hhmkts.dta", nogen
				// created in 2c_outputforMATLAB_HMS.do
		replace purchases_total = 0 if purchases_total == .
		rename purchases_total purchases_postmerge2

		* set purchases to 0 for observations across all stages except preprodiddrop that are not in productmodule_list_noncount
		merge m:1 pm using `modules', keep(1 3)
		foreach stage in postprodiddrop preclean postmerge1 postmerge2 {
			replace purchases_`stage' = 0 if _merge == 1
		}
		drop _merge

	*** Get markets dropped at each stage after "merge" up until outlier by merging in store-freq-pms with nonzero sales

		foreach stagepair in "postmerge2 postmerge" "postmerge postdropmiss" "postdropmiss postoutlier" {

			local stage : word 2 of `stagepair'
			local prev_stage : word 1 of `stagepair'

			gen sales_total = .

			foreach module in `productmodule_list' { 
				disp "`module'"
				cap merge m:1 store_code_uc ${freq} pm using "${cleaningaccounting}/`stage'_mkts_`module'.dta", update keep(1 3 4 5) nogen
						// created in 2b_outputforMATLAB_RMS.do
				if _rc == 601 disp "No data after certain stage for this module; skipping"
			}
				
			qui rename sales_total sales_`stage'
			gen purchases_`stage' = purchases_`prev_stage'
			replace purchases_`stage' = 0 if sales_`stage' == 0 | sales_`stage' == .
			drop sales_`stage'

		}

		rename purchases_postmerge purchases_postRMSmerge
		if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
			gcollapse (sum) purchases_preprodiddrop purchases_postprodiddrop purchases_preclean purchases_postRMSmerge purchases_postdropmiss purchases_postoutlier /// 
				(first) purchases_postmerge1 purchases_postmerge2, by(hhid mktid pm `mktvar' ${freq})
			order purchases_preprodiddrop purchases_postprodiddrop purchases_preclean purchases_postmerge1 purchases_postmerge2 purchases_postRMSmerge /// 
				purchases_postdropmiss purchases_postoutlier
		}

	*** Get markets dropped at each step afterwards by merging in mkt-pms with nonzero sales
		
		foreach stagepair in "postoutlier postoutsidegood1" "postoutsidegood1 postoutsidegood3" {

			local stage : word 2 of `stagepair'
			local prev_stage : word 1 of `stagepair'

			if "`stage'" != "postoutsidegood3" {
				gen sales_total0 = .
				gen sales_total1 = .

				foreach module in `productmodule_list' { 
					disp "`module'"
					cap merge m:1 mktid pm using "${cleaningaccounting}/`stage'_mkts_`module'.dta", update keep(1 3 4 5) nogen
							// created in 2b_outputforMATLAB_RMS.do
					if _rc == 601 disp "No data after certain stage for this module; skipping"
				}
				
				qui gen sales_`stage' = sales_total0 + sales_total1
				drop sales_total0 sales_total1
			}
			else {
				merge m:1 mktid pm using "${temp}/cleaning_acct_matlabstep_${marketlevel}_mktmodules.dta", keep(1 3) nogen
						// created in subprogram RMS_cleaning_steps
			}

			gen purchases_`stage' = purchases_`prev_stage'
			replace purchases_`stage' = 0 if sales_`stage' == 0 | sales_`stage' == .
			drop sales_`stage'

		}

		* collapse to household-product module level
		gcollapse (sum) purchases_*, by(hhid pm)

		save "${temp}/cleaning_acct_hms_${marketlevel}_hhmodules.dta", replace

end

*===================================================================================================
* Export tables based on sales/purchases remaining after each cleaning step
*===================================================================================================

cap prog drop cleaning_steps_analysis
prog define cleaning_steps_analysis

	if "${marketlevel}" == "store" local mktvar "store_code_uc"
	else if "${marketlevel}" == "county" local mktvar "fipscounty"
	else if "${marketlevel}" == "cbsa" local mktvar "cbsa"

	* Titles
	if "${marketlevel}" == "store" {
		local mktname "Store"
		local inclbl "store neighborhood"
	}
	else if "${marketlevel}" == "county" {
		local mktname "County"
		local inclbl "county"
	}
	else if "${marketlevel}" == "cbsa" {
		local mktname "CBSA"
		local inclbl "CBSA"
	}

	*** RMS stages
		local pre_stage "preprodiddrop"
		local stages "postprodiddrop postmerge postdropmiss postoutlier postoutsidegood1 postoutsidegood3"

		local descript1 "(1) Missing product ids"
		local descript2 "(2) Missing `inclbl' income"
		local descript3 "(3) Missing price instrument"
		local descript4 "(4) Store-${freq}s with outlier-price items"
		local descript5 "(5) Not enough non-outside good"
		local descript6 "(6) Outside good share <1%"

	*** (RMS) Table: aggregate share dropped, plus distribution of share dropped across modules

		use "${temp}/cleaning_acct_prodiddrop_store_modules.dta"
			// created in subprogram RMS_cleaning_steps
		merge 1:1 pm using "${temp}/cleaning_acct_${marketlevel}_modules.dta", nogen
		merge 1:1 pm using "${temp}/cleaning_acct_matlabstep_${marketlevel}_modules.dta", nogen
		rename pm module

		local iprev = 0
		foreach stage in `stages' {

			if `iprev'>0 local prev_stage : word `iprev' of `stages'
			else local prev_stage "`pre_stage'"
			local iprev = `iprev'+1

			replace sales_`stage' = 0 if sales_`stage' == .

			* share dropped compared to sales at preprodiddrop stage, per module
			gen shrdrop_`stage' = (sales_`prev_stage' - sales_`stage') / sales_`pre_stage'

			* aggregate share dropped compared to sales at preprodiddrop stage
			cap egen tot_`prev_stage' = total(sales_`prev_stage')
			cap egen tot_`stage' = total(sales_`stage')
			gen agg_shrdrop_`stage' = (tot_`prev_stage' - tot_`stage') / tot_`pre_stage'

		}

		drop *sales* nmkts_*
		reshape long shrdrop_ agg_shrdrop_, i(module) j(stage) string
		rename (shrdrop_ agg_shrdrop_) (shrdrop agg_drop)

		local collapsestr ""
		foreach stat in min p10 p25 p50 p75 p90 max {
			local collapsestr "`collapsestr' (`stat') `stat' = shrdrop"
		}
		collapse (mean) agg_drop `collapsestr', by(stage)

		* reorder observations and better names
		gen stagenum = .
		local i = 1
		foreach stage in `stages' {
			replace stagenum = `i' if stage == "`stage'"
			replace stage = "`descript`i''" if stage == "`stage'"
			local i = `i'+1
		}
		replace stage = subinstr(stage, "<", "\$<\$", .)
		replace stage = subinstr(stage, "%", "\%", .)
		sort stagenum
		drop stagenum
		order stage agg_drop min p10 p25 p50 p75 p90 max
		format agg_drop min p10 p25 p50 p75 p90 max %6.2g

		listtab stage agg_drop min p10 p25 p50 p75 p90 max using "${output}/datacleaning_accounting_${marketlevel}_table_rms.tex", ///
			rstyle(tabular) replace ///
			headlines(" \begin{tabular}{lcccccccc} \toprule" ///
			" & Aggregate & \multicolumn{7}{c}{Share Dropped by Module} \\ " /// 
			"\cmidrule(lr){3-9} Stage & Share Dropped & min & 10th & 25th & 50th & 75th & 90th & max \\ \midrule") ///
			footlines("\bottomrule \end{tabular}")

	*** (RMS) Regress share dropped after each step on market log income

		_eststo clear

		** preprocess income distribution
		if "${marketlevel}" == "store" {
			** store-level income data
			use "${data}/storeincdist_logincpctiles_${freq}_nocd.dta", clear
				// created in 2a_outputforMATLAB_prep.do (storelnincdistcsv_incpctiles)
				// avginc in the 30th bucket of the weighted income distribution of tracts in the vicinity of the store

				* first period in dataset
				bysort store_code_uc (${freq}): keep if _n == 1

				* calculate store-level mean income...
				keep store_code_uc avginc* weight*
				reshape long avginc weight, i(store_code_uc) j(quantile)
				gen w_avginc_level=exp(avginc)*weight
				keep store_code_uc w_avginc_level weight
				collapse (sum) weight w_avginc_level, by(store_code_uc)
				gen storepcincome = w_avginc_level/weight
				gen lnincome = log(storepcincome)
				keep store_code_uc lnincome
				tempfile income
				save `income'
		}
		else if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
			use "${stataoutput}/dataMatLab${marketlevelsuf}/storeincdist_${freq}.dta", clear
				// created in 2a_outputforMATLAB_prep.do (distcsv_county_cbsa)

			* first period in dataset
			bysort `mktvar' (${freq}): keep if _n == 1

			rename meanlninc lnincome
			tempfile income
			save `income'
		}

		* bring in data created in RMS_cleaning_steps
		use "${temp}/cleaning_acct_prodiddrop_store_mkts.dta", clear

		if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
			preserve
				di "Load county-CBSA crosswalk data"
					import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
						// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html)
					rename county fipscounty
					destring fipscounty cbsa, replace
					drop if cbsa==.
					keep fipscounty cbsa
					tempfile tempcbsa
					save `tempcbsa'
			restore
			di "Merge in store info"
				gen year = $year
				merge m:1 store_code_uc year using ${step0bdata}/storechainloc.dta, keepusing(fips_state_code fips_county_code) keep(1 3) nogen
					// created in 0b_dataimport/Code/0_rawdataconvert.do
				gen fipscounty = fips_state_code *1000 + fips_county_code
				drop fips_state_code fips_county_code
				merge m:1 fipscounty using `tempcbsa', keep(1 3) nogen

			gcollapse (sum) sales_* nmods_*, by(`mktvar' ${freq})
			replace `mktvar' = 0 if `mktvar' == .
		}

		merge 1:1 `mktvar' ${freq} using "${temp}/cleaning_acct_${marketlevel}_mkts.dta", nogen
			// created in subprogram RMS_cleaning_steps
		replace mktid = -${freq} if mktid == .
		merge 1:1 mktid using "${temp}/cleaning_acct_matlabstep_${marketlevel}_mkts.dta", nogen

		* merge in income
		merge m:1 `mktvar' using `income', keep(1 3) nogen

		* collapse to store / county / cbsa level (i.e. sum across time)
		collapse (sum) sales_* (first) lnincome, by(`mktvar')

		local i = 1
		foreach stage in `stages' {

			local iprev = `i'-1
			if `iprev'>0 local prev_stage : word `iprev' of `stages'
			else local prev_stage "`pre_stage'"

			replace sales_`stage' = 0 if sales_`stage' == .

			* sales share dropped between this and previous stage, relative to preprodiddrop levels
			gen shrdrop_`stage' = (sales_`prev_stage' - sales_`stage') / sales_`pre_stage'

			* regress and save
			eststo: reg shrdrop_`stage' lnincome

			local i = `i'+1
		}

		* regress share dropped across all steps on income

		local nstages : word count `stages'
		local last_stage : word `nstages' of `stages'
		gen cumulative = (sales_`pre_stage' - sales_`last_stage') / sales_`pre_stage'
		eststo: reg cumulative lnincome

		* combine regressions

		local esttabopts = subinstr("${esttabopts}", "se(a2) b(a2)", "se(%6.2g) b(%6.2g)", .)
		esttab using "${output}/datacleaning_accounting_${marketlevel}_rms_incregs.tex", replace ///
			label wrap `esttabopts' ///
			stats(N r2, fmt(0 %6.2g %6.2g 2) labels("Observations" "\$R^2\$")) coeflabel(lnincome "Ln(Income)") /// 
			prehead("{ \begin{tabular}{l*{7}{c}}" "\toprule & \multicolumn{6}{c}{Dependent Variable: Share of `mktname' Sales Dropped at Stage \#} & \\" /// 
				"& (1) & (2) & (3) & (4) & (5) & (6) & Cumulative \\") 

	*** HMS stages

		local pre_stage "preprodiddrop"
		if "${marketlevel}" == "store" {
			local stages "postprodiddrop postmerge1 postmerge2 postdropmiss postoutlier postoutsidegood1 postoutsidegood3"
			local descript2 "(2.0) RMS store-${freq} merge"
			local descript3 "(2.1) Missing `inclbl'/household income"
		}
		else if "${marketlevel}" == "county" | "${marketlevel}" == "cbsa" {
			local stages "postprodiddrop postmerge2 postRMSmerge postdropmiss postoutlier postoutsidegood1 postoutsidegood3"
			local descript2 "(2.0) Missing `inclbl'/household income"
			local descript3 "(2.1) RMS store-${freq} merge"
		}
		local descript1 "(1) Missing product ids"
		local descript4 "(3) Missing price instrument"
		local descript5 "(4) Store-${freq}s with outlier-price items"
		local descript6 "(5) Not enough non-outside good"
		local descript7 "(6) Outside good share <3%"

	*** (HMS) Table: aggregate share dropped, plus distribution of share dropped across modules

		use "${temp}/cleaning_acct_hms_${marketlevel}_hhmodules.dta", clear
			// created in subprogram HMS_cleaning_steps

		collapse (sum) purchases_*, by(pm)
		rename pm module

		local iprev = 0
		foreach stage in `stages' {

			if `iprev'>0 local prev_stage : word `iprev' of `stages'
			else local prev_stage "`pre_stage'"
			local iprev = `iprev'+1

			replace purchases_`stage' = 0 if purchases_`stage' == .

			* share dropped compared to purchases at preprodiddrop stage, per module
			gen shrdrop_`stage' = (purchases_`prev_stage' - purchases_`stage') / purchases_`pre_stage'

			* aggregate share dropped compared to purchases at preprodiddrop stage
			cap egen tot_`prev_stage' = total(purchases_`prev_stage')
			cap egen tot_`stage' = total(purchases_`stage')
			gen agg_shrdrop_`stage' = (tot_`prev_stage' - tot_`stage') / tot_`pre_stage'

		}

		drop purchases_*
		reshape long shrdrop_ agg_shrdrop_, i(module) j(stage) string
		rename (shrdrop_ agg_shrdrop_) (shrdrop agg_drop)

		local collapsestr ""
		foreach stat in min p10 p25 p50 p75 p90 max {
			local collapsestr "`collapsestr' (`stat') `stat' = shrdrop"
		}
		collapse (mean) agg_drop `collapsestr', by(stage)

		* reorder observations and better names
		gen stagenum = .
		local i = 1
		foreach stage in `stages' {
			replace stagenum = `i' if stage == "`stage'"
			replace stage = "`descript`i''" if stage == "`stage'"
			local i = `i'+1
		}
		replace stage = subinstr(stage, "<", "\$<\$", .)
		replace stage = subinstr(stage, "%", "\%", .)
		sort stagenum
		drop stagenum
		order stage agg_drop min p10 p25 p50 p75 p90 max
		format agg_drop min p10 p25 p50 p75 p90 max %6.2g

		listtab stage agg_drop min p10 p25 p50 p75 p90 max using "${output}/datacleaning_accounting_${marketlevel}_table_hms.tex", ///
			rstyle(tabular) replace ///
			headlines(" \begin{tabular}{lcccccccc} \toprule" ///
			" & Aggregate & \multicolumn{7}{c}{Share Dropped by Module} \\ " /// 
			"\cmidrule(lr){3-9} Stage & Share Dropped & min & 10th & 25th & 50th & 75th & 90th & max \\ \midrule") ///
			footlines("\bottomrule \end{tabular}")

	*** (HMS) Regress share dropped after each step on household log income

		_eststo clear

		use "${temp}/cleaning_acct_hms_${marketlevel}_hhmodules.dta", clear
			// created in subprogram HMS_cleaning_steps
		rename hhid household_code

		* merge in income
		gen panel_year = $year
		merge m:1 household_code panel_year using ${step0bdata}/incomeadj.dta, keepusing(lnincome) keep(1 3) nogen
				// created in 0b_dataimport/Code/1b_HMS_demographicdata.do

		* collapse to household level
		collapse (sum) purchases_* (first) lnincome, by(household_code)

		local i = 1
		foreach stage in `stages' {

			local iprev = `i'-1
			if `iprev'>0 local prev_stage : word `iprev' of `stages'
			else local prev_stage "`pre_stage'"

			replace purchases_`stage' = 0 if purchases_`stage' == .

			* purchase share dropped between this and previous stage, relative to preprodiddrop levels
			gen shrdrop_`stage' = (purchases_`prev_stage' - purchases_`stage') / purchases_`pre_stage'

			* regress and save
			eststo: reg shrdrop_`stage' lnincome

			local i = `i'+1
		}

		* regress share dropped across all steps on income

		local nstages : word count `stages'
		local last_stage : word `nstages' of `stages'
		gen cumulative = (purchases_`pre_stage' - purchases_`last_stage') / purchases_`pre_stage'
		eststo: reg cumulative lnincome

		* combine regressions

		local esttabopts = subinstr("${esttabopts}", "se(a2) b(a2)", "se(%6.2g) b(%6.2g)", .)
		esttab using "${output}/datacleaning_accounting_${marketlevel}_hms_incregs.tex", replace ///
			label wrap `esttabopts' ///
			stats(N r2, fmt(0 %6.2g %6.2g 2) labels("Observations" "\$R^2\$")) coeflabel(lnincome "Ln(Income)") /// 
			prehead("{ \begin{tabular}{l*{8}{c}}" "\toprule & \multicolumn{7}{c}{Dependent Variable: Share of Household Purchases Dropped at Stage \#} & \\" /// 
				"& (1) & (2.0) & (2.1) & (3) & (4) & (5) & (6) & Cumulative \\") 

end

*==================================================================================================
*==================================================================================================
*** Run programs

	main

*==================================================================================================
