*===========================================================================================
*** 4b_producttable.do
*** checks which modules exist throughout pipeline
*===========================================================================================

args freq marketlevel outsidegoodscut byyear

if "`freq'"=="" {
	local freq="month"
	local marketlevel="store"
	local outsidegoodscut = 60 // 40 // 60 // 80
	local byyear = 2012     // 2006...2014
}

foreach arg in freq marketlevel outsidegoodscut byyear {
	global `arg' "``arg''"
	di "`arg' : ${`arg'}"
}
	
if ${byyear} != 0 global year "${byyear}"
else global year "2006 2007 2008 2009 2010 2011 2012 2013 2014"

*===========================================================================================
*** Directory Set-up

* Set project directories	
	do ../../SetFilePaths.do
		
	global currentstep "${terminal}/1_dataprep"
		
*Set-up standard directories	
	global data "$currentstep/Data"	
	global output "$currentstep/Output"
	global logs "$currentstep/Logs"
	global repooutput "$programs/../RepoOutput"
	global step0bdata "${currentstep}/../0_dataimport/STATAData"

* Set-up dataprep directories

	if "${marketlevel}"=="store" {
		global marketlevelsuf = ""
	}
	else {
		global marketlevelsuf="_${marketlevel}"
	}

	if ${byyear} == 0 global datacleaning "${output}/cleaning_acct${marketlevelsuf}/${freq}/outside${outsidegoodscut}"
	else global datacleaning "${output}/cleaning_acct${marketlevelsuf}/${freq}/${year}/outside${outsidegoodscut}"

	if ${byyear} == 0 global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/outside${outsidegoodscut}"
	else global storeMatlab "${output}/dataMatLab${marketlevelsuf}/storecsv_${freq}/${year}/outside${outsidegoodscut}"

	if ${byyear} == 0  global householdMatlab "${output}/dataMatLab${marketlevelsuf}/HHcsv_${freq}/outside${outsidegoodscut}"
	else global householdMatlab "${output}/dataMatLab${marketlevelsuf}/HHcsv_${freq}/${year}/outside${outsidegoodscut}"
	
* Directory to save the tracking results in
	global moduletrackoutput "${terminal}/4_postestimation_analysis/Output/ModuleTracking"

*==================================================================================================
**** Program to run sub-programs

cap prog drop main
prog define main

	di "track modules and products over course of data cleaning"
		track_cleaning

	di "create table of upc/product/module conts for draft"
		producttable, lab(estimation) proddata("${moduletrackoutput}/producttracking_est.dta") hhdata("${step0bdata}/HMSproductids.dta")
		
end

*===================================================================================================
* Sub-programs
*===================================================================================================

*===================================================================================================
*	Track modules and products over the course of data cleaning
*===================================================================================================

cap prog drop track_cleaning
prog define track_cleaning
if 1==1 {

	*************			
	** Initial full set of modules and UPCs
		use upc upc_ver_uc product_module_code product_group_code department_code brand_code_uc dataset_found_uc ///
			using "${RMSdata}/1_moduleyear/Data/products.dta", clear
					// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfo.do
		foreach var in "pm product_module" "pg product_group" "dept department"  {
			local vname=word("`var'",1)
			local vlabel=word("`var'",2)
			rename `vlabel'_code `vname'
		}
		gen food=((dept>=1 & dept<=6) | pg==6018)
					** department_code==1: dry grocery
					** department_code==2: frozen food
					** department_code==3: dairy
					** department_code==4: deli
					** department_code==5: packaged meat
					** department_code==6: fresh produce
					** department_code==8 is alcohol (now dropped)
					** product_group_code==6108 is vitamins 
		tempfile raw
		save `raw', replace
		
	*************
	** Identify UPCs that do/don't get productids (don't have modal units or are in modules where modal units = count)
		use pm upc upc_ver_uc panel_year brand productid using "${step0bdata}/RMSproductids.dta", clear
				// created in 0b_dataimport/Code/0c_createproductids.do
		keep if panel_year==2012
		merge m:1 pm upc upc_ver_uc using `raw'
		
		gen storebrand=(brand_code_uc!=brand) if brand!=. & brand_code_uc!=.
		gen prodid=(_merge==3) 
		drop _merge
		save ${moduletrackoutput}/producttracking.dta, replace

	*************
	** Cleaning steps in 2b_outputforMATLAB_RMS
		
		* list of all modules with indicators for which datasets its in
			use ${moduletrackoutput}/producttracking.dta, clear
			keep pm dataset_found_uc
			gen inboth=(dataset_found_uc=="ALL")
			gen inRMS=(dataset_found_uc=="RMS")
			gen inHMS=(dataset_found_uc=="HMS")
			sort pm
			foreach v in inboth inRMS inHMS  {
				by pm: replace `v'=sum(`v')
			}
			by pm: keep if _n==_N
			foreach v in inboth inRMS inHMS  {
				replace `v'=(`v'>0 & `v'!=.)
			}
			replace inRMS=max(inboth,inRMS)
			replace inHMS=max(inboth,inHMS)
			merge 1:1 pm using "${step0bdata}/size1_units_pm.dta", gen(hasdominantunits)
					// created in 0b_dataimport/Code/0c_createproductids.do
			tab hasdominantunits
			replace hasdominantunits=(hasdominantunits>1)
			gen hasusefulunits=hasdominantunits-(size1_units_updated=="CT" | size1_units_updated=="EXP")
			tab hasdominantunits hasusefulunits
			save modlist, replace
		
		* pull in estimation data for each module
			use modlist, clear
			keep if hasusefulunits+inboth==2
			local nmods=_N
			forvalues i=1/`nmods' {
				local mod`i'=pm[`i']
			}
			local first=1
			forvalues i = 1(1)`nmods' {	

				disp "`mod`i''"
				disp "${storeMatlab}/store_module`mod`i''_data.csv"
				capture confirm file "${storeMatlab}/store_module`mod`i''_data.csv"
				if _rc==0 {
					import delimited "${storeMatlab}/store_module`mod`i''_data.csv", case(preserve) clear
						// created in 2b_outputforMATLAB_RMS.do
						// mktid ${freq} prodid brandid sjt x Z* vjt outsidegoods sampleid   
						
					** products sold in markets with outside good share < 3%
						gen suffOGshare = (sampleid >= 3)
						keep mktid prodid suffOGshare
						tempfile tempstore
						save `tempstore', replace
			
					** modules with at least one household purchasing any of the remaining products in one of the sampled markets
					local inhhdata=0
					capture confirm file "${householdMatlab}/HH_module`mod`i''_data_outside.csv"
					if _rc==0 {
						import delimited "${householdMatlab}/HH_module`mod`i''_data_outside.csv", case(preserve) clear
							// created in 2c_outputforMATLAB_HMS.do
							// hhid selection units mktid lninc outsidegoods w
						rename selection prodid
						drop if outsidegoods==1
						keep mktid prodid
						bys mktid prodid: keep if _n==1
						merge 1:1 mktid prodid using `tempstore'
						drop if _merge<3
						drop if suffOGshare==0
						if _N>0 local inhhdata=1
					}
				
				* create dummies for products in markets with sufficient OG shares and modules with usable HH data	
					use `tempstore', clear
					sort prodid suffOGshare
					by prodid: keep if _n==_N 
						// keep the indicator if the product appears in at least one mkt with sufficientOG share

					rename suffOGshare suffOGsharesomewhere
					gen hhdata=`inhhdata'
				
				*identify which products/modules survived this cleaning and which went into the outside good
					merge 1:1 prodid using "${datacleaning}/postoutsidegood1_prods_`mod`i''.dta", assert(2 3) keep(3) nogen keepusing(outsidegoods sales_total)
						// created in 2b_outputforMATLAB_RMS.do	
						// product level data to identify which products (after cleaning) when into outside good and total sales
					
					rename sales_total tot_prod_sales
					keep prodid suffOGsharesomewhere hhdata outsidegoods tot_prod_sales
					save `tempstore', replace
					
				*append and merge with pre-cleaning	
					if `first'==1 gen pm=`mod`i''
					else {
						restore
						append using `tempstore'
						replace pm=`mod`i'' if pm==.
					}
					local first=0
					disp "module `mod`i'' appended."
					preserve

				} // end _rc==0
				else disp "---> module `mod`i'' store estimation data not found"
			} // end pmod loop

	*************
	** Save
			
		restore
		rename prodid productid
		capture drop _merge
		merge 1:m pm productid using ${moduletrackoutput}/producttracking.dta
			// now contains, for each product: avg_mkt_share, tot_prod_sales and outsidegoods = 1 if in outside good
		gen inestdata=(_merge==3)
		gen inestsample=(inestdata+suffOGsharesomewhere+hhdata==3)
		drop _merge
		save ${moduletrackoutput}/producttracking.dta, replace

		keep if inestsample
		save ${moduletrackoutput}/producttracking_est.dta, replace

}
end

*===================================================================================================
*	Create table with RMS data summary statistics on raw data
*===================================================================================================
cap prog drop producttable
prog define producttable
	syntax [anything], proddata(string) lab(string) [hhdata(string)]

if 1==1{

	local HHvar="totHMS_"
	use "`hhdata'" , clear
	keep if panel_year==2012
	keep pm productid upc 
	duplicates drop
	tempfile HMSupcs
	save `HMSupcs', replace
	keep pm productid
	duplicates drop
	tempfile HMSprods
	save `HMSprods', replace
	keep pm 
	duplicates drop
	tempfile HMSpms
	save `HMSpms', replace
	
	use `proddata', clear
	keep if panel_year==2012
	keep pm productid upc 
	duplicates drop
	sort pm productid upc

	merge 1:1 pm productid upc using `HMSupcs', keep(1 3)
	gen totHMS_nu=(_merge==3)
	replace totHMS_nu=sum(totHMS_nu)

	by pm productid: egen pp_nu=nvals(upc)
	by pm: egen pm_nu=nvals(upc)
	egen tot_nu=nvals(upc)
	by pm productid: keep if _n==_N

	drop _merge
	merge 1:1 pm productid using `HMSprods', keep(1 3)
	gen totHMS_np=(_merge==3)
	replace totHMS_np=sum(totHMS_np)

	foreach v in pp_nu  {
		sum `v', d
		gen min_`v'=`r(min)'
		gen max_`v'=`r(max)'
		gen med_`v'=`r(p50)'
		drop `v'
	}
	by pm: egen pm_np=nvals(productid)
	egen tot_np=nvals(productid)
	by pm: keep if _n==_N
	drop _merge
	merge 1:1 pm using `HMSpms', keep(1 3)
	foreach v in pm_np pm_nu {
		sum `v', d
		gen min_`v'=`r(min)'
		gen max_`v'=`r(max)'
		gen med_`v'=`r(p50)'
		drop `v'
	}
	gen tot_nm=_N
	gen totHMS_nm=(_merge==3)
	replace totHMS_nm=sum(totHMS_nm)
	drop _merge

	keep if _n==_N
	gen a=1
	drop upc pm productid
	reshape long tot_ `HHvar' min_pm_ med_pm_ max_pm_ min_pp_ med_pp_ max_pp_, i(a) j(countof nm np nu) string
	replace countof="Modules" if countof=="nm"
	replace countof="Products" if countof=="np"
	replace countof="UPCs" if countof=="nu"
	foreach v in tot_ `HHvar' min_pm_ med_pm_ max_pm_ min_pp_ med_pp_ max_pp_ {
		tostring `v', replace force format(%9.0gc) 
		replace `v'="-" if `v'=="."
	}
	
	listtab countof tot_ min_pm_ med_pm_ max_pm_ min_pp_ med_pp_ max_pp_ `HHvar' ///
		using "${repooutput}/countstable_`lab'.tex", ///
		rstyle(tabular) replace ///
		headlines("\begin{tabular}{lcccccccc} \toprule " ///
		"\multicolumn{1}{r}{Data:} & \multicolumn{7}{c}{RMS (Store)} & HMS (HH) \\ "  ///
			" \cmidrule(lr){2-8} \cmidrule(lr){9-9} & Total & \multicolumn{3}{c}{Count Per Module} & \multicolumn{3}{c}{Count Per Product} & Total \\  \cmidrule(lr){3-5} \cmidrule(lr){6-8}" ///
			"& Count & Min & Median & Max & Min & Median & Max & Count \\ \midrule " "") ///
		footlines("\bottomrule \end{tabular}")
	
}
end

*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	global logsuffix "`cdate'_`ctime'"
	log using "${logs}/modulecheck_${logsuffix}.txt", replace text
	cd "${programs}"
	main
	cd "${programs}"
	log close

*==================================================================================================
*==================================================================================================
