 *===========================================================================================
*** 1_stylizedfact1.do
* This code generates a plot showing that high-income households purchase different, more expensive products that low-income households.
*==========================================================================================
	
	args freq food test
	
	if "`freq'"=="" {
		local freq="month"
		local food="" // _food
		local test="" // "_test"
	}
	
	foreach arg in food freq test { 
		if "``arg''"=="0" local `arg'=""
		global `arg' "``arg''"
	}  

*===========================================================================================
*** Directory Set-up
	
*Set project directories	
	do ../../SetFilePaths.do
		// $terminal = Server directory where project data sis located
		// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/2_preestimation_analysis"	

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global logs "$currentstep/STATALogs"
	global output "$currentsteprepo/RepoOutput"

*Directory for extra inputs
	global step0bdata "${currentstep}/../0b_dataimport/STATAData"
	
*===========================================================================================
*For log files:

	global name="1_stylizedfact1"

*==================================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	foreach y in 2012 { 
		p_income_quality, time(${freq}) test(${test}) foodsuffix(${food}) y(`y')
	}
	
end 

*===========================================================================================
*===========================================================================================
*===========================================================================================
* Sub-program definition

capture program drop p_income_quality
program define p_income_quality
	
	syntax [anything], time(string) y(integer) [test(string) foodsuffix(string)]

if 1==1 {

	*===========================================================================================
	di "**** DATA PREP ****"
	di "prep household markets"
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
			// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
				//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		rename county fipscounty
		destring fipscounty, replace
		drop if cbsa==""
		tempfile tempcbsa
		save `tempcbsa'
			
		use household_code panel_year fips_state_code fips_county_code using ${HMSdata}/panelists`y'.dta, clear
			// created in 0a_dataconstruct/HMS/0_dataimport_vN.do
			gen fipscounty = fips_state_code *1000 + fips_county_code
			merge m:1 fipscounty using `tempcbsa', keep(1 3)
			drop _merge
			keep cbsa cbsaname household_code panel_year
			rename cbsa marketid
			rename cbsaname marketidname
			tempfile tempHHmkt
			save `tempHHmkt', replace		
	
	di "prep HH demographics"
		use household_code panel_year income hhsize hhinc marital m_ed f_ed m_age f_age race hisp using ${step0bdata}/hhid_char`foodsuffix'.dta, clear
			// created in 0b_dataimport/1b_HMS_demographicdata_vN.do; observations unique to household_code panel_year
			sort household_code panel_year
			tempfile temphhs
			save `temphhs'
			bys hhinc: keep if _n==1
			sort hhinc
			tempfile tempinc
			save `tempinc', replace
		
	di "import hh-store-product level purchase data"
		if "`test'"!=""  use household_code year store_code_uc retailer_code `time' pg pm brand productid value amt using ${step0bdata}/HMSstoreleveldata`foodsuffix'_`time'test.dta if year==`y', clear
		 else use household_code year store_code_uc retailer_code `time' pg pm brand productid value amt using ${step0bdata}/HMSstoreleveldata`foodsuffix'_`time'.dta if year==`y', clear
			// created by /0b_dataimport/Code/1a_HMS_purchasedata_v[].do
				// contains HH purchase at product-HH-store-`time' level, observations identified by household_code store_code_uc year `time' productid
		gen uv = value/amt
				
	di "merge in HH markets"
		rename year panel_year
		merge m:1 household_code panel_year using `tempHHmkt', keep(1 3)
		drop if _merge <3
		drop _merge
	
	di "merge in HH demographics"
		sort household_code panel_year
		merge m:1 household_code panel_year using `temphhs'
		tab _m
		drop if _m<3

	di "drop households in income categories below $10K"
		tab hhinc income
		drop if income<10000
		sum hhinc
		local mininc=`r(min)'
		
	di "final variable prep"
		gen lnuv=ln(uv)
		destring marketid, replace
		drop if marketid==.
		drop if hhinc==. | hhinc==0
		
	*===========================================================================================
	di "**** REGRESSION ANALYSIS: How does unit value paid vary with income? ****"	
	
		reghdfe lnuv io`mininc'.hhinc i.hhsize i.m_ed i.f_ed i.f_age i.m_age i.race i.hisp , absorb(pm)
		regsave using "$hpcoutput/income_quality_`y'_`time'`test'.dta", replace addlabel(productcntrl, "pm")
			
		reghdfe lnuv io`mininc'.hhinc i.hhsize i.m_ed i.f_ed i.f_age i.m_age i.race i.hisp , absorb(pm)
		regsave using "$hpcoutput/income_quality_`y'_`time'`test'.dta", append addlabel(productcntrl, "pm")	
	
	*===========================================================================================
	di "**** PLOT ****"
	
	di "**Import coefficients"
		use "$hpcoutput/income_quality_`y'_`time'`test'.dta", clear
			// created in p_income_quality_calcs above
		keep if strpos(var,".hhinc")!=0
		replace var = subinstr(var,"b","",.)
		replace var = subinstr(var,"bn","",.)
		replace var = subinstr(var,"o.",".",.)
		gen hhinc = subinstr(var,".hhinc","",.) if strpos(var,".hhinc")!=0
		destring hhinc, replace

	di "*difference coefficients from min income base"
		sum hhinc
		gen temp=coef if hhinc==`r(min)'
		bys productcntrl (hhinc): gen bbase=sum(temp)
		drop temp
		replace coef=coef-bbase
		
	di "*reshape"
		keep hhinc coef stderr productcntrl
		rename coef b
		rename stderr se
		replace productcntrl="_"+productcntrl
		reshape wide b se, i(hhinc) j(productcntrl) string
		
		merge 1:1 hhinc using `tempinc', keep(3) nogen 

		label var b_pm "Relative to Module Average"
		label var b_productid "Relative to Product Average"
		
		scatter b_pm b_productid income, msymbol(O T) ///
			xscale(log range(10000 175000)) xlabels(10000 "$10,000" 15000 "$15,000" 25000 "$25,000" 50000 "$50,000" 150000 "$150,000" ) ///
			xtitle("Household Income (Log Scale)") ytitle("Relative Price Paid") ///
			graphregion(fcolor(white))
		graph export "$output/wu_income_quality_`y'_`time'`test'.eps", as(eps) replace	

}

end
	
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	main
	capture log close

*==================================================================================================
