 *===========================================================================================
*** 2_stylizedfact2_v[].do
***		code to study variation in availability and pricing across markets
*==========================================================================================

*** Directory Set-up		
	args market tasks channel mktspecificsh sample sampleV test
	
	if "`market'"=="" {
		local market="cbsa"			// market definition "cbsa", "stores", "counties"
		local tasks = "hhshares" 	// hhshares, mktsales, joinshares, Pcalc, Splot, Pplot, or all
		local incg = 10				// what `incg'-tiles to look at (baseline = 10)
		local channel="0" 			// "_F" limit attention to food stores
		local mktspecificsh="mktspecific" // "mktspecific" // "0"
		local sample = "_limit50" 	// limit to CBSAs with at least X stores, random sample of X stores in CBSAs with more than X stores 
		local sampleV = "0"			// "_v`i'" version of random sample of stores to use (multiple bc of bootstrapping)
				// if equal 0 or missing when sample!=missing, code will compile bootstrapped results
		local test=""		
	}
	
	foreach arg in market tasks incg channel mktspecificsh sample sampleV test { 
		if "``arg''"=="0" local `arg' ""
		global `arg' "``arg''"
		disp "`arg' ${`arg'}"
	}  
		
	** sample size for number of stores in each CBSA
	if "${sample}" != "" global sampleN = subinstr("${sample}", "_limit", "", .)
		
	** additional specs
	global incg 10

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/2_preestimation_analysis"	

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	local a=strpos("$currentsteprepo","2_preestimation_analysis")
	if strpos("$currentsteprepo","2_preestimation_analysis")==0 {
		 disp "Need to run from step-specific directory"
		 exit
	}
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global logs "$currentstep/STATALogs"
	global output "$currentsteprepo/RepoOutput"

*===========================================================================================
*For log files:

	global name="2_stylizedfacts_${market}"

*===========================================================================================
* Preliminary Set-up						

* Graph preferences
	set printcolor automatic, perm
	graph set eps fontface Times
	graph set eps logo off
	set scheme s2color, perm

*===========================================================================================================================================
*===========================================================================================================================================

**** Program to run sub-programs

capture program drop main
program define main	

	di "Market: ${market}"

	global marketvarcbsa="cbsa"
	global marketvarstores="store"
	global marketvarcounties="county"
	global cbsalab="CBSA"
	global storeslab="Store"
	global countieslab="County"
		
		if "${sample}" != "" global sampleN = subinstr("${sample}", "_limit", "", .)

		tempfile tempHHmkt tempcbsa  tempcountycbsa tempmktcbsa tempcounties tempstores				
		foreach tempdataset in tempHHmkt tempcbsa  tempcountycbsa tempmktcbsa tempcounties tempstores {
			global `tempdataset' ``tempdataset''
			disp "`tempdataset': ${`tempdataset'}"
		}
		
		** market data
			p_mktdata, test(${test}) market("${market}") y(2012) channel(${channel}) 
	
		** process purchase data
			if ("${tasks}"=="all" | strpos("${tasks}","hhshares")>0) p_incspecprodshares, test(${test}) market("${market}") incg(${incg}) y(2012)  /// 
				mktspecificsh("${mktspecificsh}")  channel(${channel}) 
					// calculates expenditures shares by income on different products
		** process store availablility data
			if "${tasks}"=="all" | strpos("${tasks}","mktsales")>0 p_productmarketsales, test(${test}) market("${market}") incg(${incg}) y(2012)  /// 
				 mktspecificsh("${mktspecificsh}")  channel(${channel})  ///
				sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")
					// identifies products available in each city
		** join datasets for market avaiability by inc group
			if "${tasks}"=="all" | strpos("${tasks}","joinshares")>0 p_cityincomeshares, test(${test}) market("${market}") incg(${incg}) y(2012)  /// 
				 mktspecificsh("${mktspecificsh}")  channel(${channel})   ///
				sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")
					// calculates expenditures shares by income on products available in each city
		
		** hedonic price indexes
			if ("${tasks}"=="all" | strpos("${tasks}","Pcalc")>0) SF2_hedonic, test(${test}) market("${market}") incg(${incg}) y(2012)   ///
				 mktspecificsh("${mktspecificsh}") channel(${channel})   ///
				sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")

		** price index and relative share plots/regs
		if   "${sampleV}"==""  | "${sample}"=="" {
			
			if ("${tasks}"=="all" | strpos("${tasks}","Splot")>0) SF2_reg_plot, conditional(1) var(share) test(${test}) market("${market}") incg(${incg}) y(2012)  ///
				 mktspecificsh("${mktspecificsh}") channel(${channel})   ///
				sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")
							// plots relative expenditure shares against city income + runs regressions 

			if ("${tasks}"=="all" | strpos("${tasks}","Splot")>0) SF2_reg_plot, var(share) test(${test}) market("${market}") incg(${incg}) y(2012)  ///
				 mktspecificsh("${mktspecificsh}") channel(${channel})   ///
				sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")
							// plots relative expenditure shares against city income + runs regressions 

			if ("${tasks}"=="all" | strpos("${tasks}","Pplot")>0) 	SF2_reg_plot, var(hedonic) test(${test}) market("${market}") incg(${incg}) y(2012) ///
					 mktspecificsh("") channel(${channel})   ///
					sample("${sample}") sampleV("${sampleV}") sampleN("${sampleN}")
							// plots hedonic price indexes against city income + runs regressions 
		}	

	}
	
	
end 

*==================================================================================================
** Subprograms ** 
*==================================================================================================	
*** Market-level datasets

cap prog drop p_mktdata
prog define p_mktdata

	syntax [anything], market(string) y(integer) [ channel(string) test(string)] 

if 1==1 {
	
	di "*=================================================================================================="
	di "*Prep market data"
		
	*** Create temp market-type-specific datasets

	if "`market'"=="cbsa" {

	**===========================================================================================================
		di "*Prep income data at the CBSA level"
		
		*merge in 2000-2014 ACS data with 2013 CBSA codes (6/25/2019 commit switched from 2010 dicennial census data with 2003 CBSA codes)
			nhgis_pcincomepop_cbsa
			rename cbsa marketid
			merge 1:1 marketid using ${rawmisc}/cbsa_abbr.dta, keep(1 3)	nogen
				// created manually for list of 125 CBSA with 50 or more stores
			rename marketid cbsa
			save ${tempcbsa}, replace	
				// overwritten below to only keep CBSAs with 50 or more stores


		**===========================================================================================================
		di "*Prep county to CBSA cross-walk"
			import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
				// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
					//  maps into panelist fips codes perfectly and NHGIS data for all but PR
					// CBSA codes = new 2013 codes 

			destring county cbsa, replace
			drop if cbsa==.
			save ${tempcountycbsa}, replace
		
		**===========================================================================================================
		di "Identify cbsa for each HH"	
			use household_code panel_year fips_state_code fips_county_code using ${HMSdata}/panelists`y'.dta, clear
				// created in 0a_dataconstruct/HMS/0_dataimport_vN.do
			gen county = fips_state_code *1000 + fips_county_code
			merge m:1 county using ${tempcountycbsa}, keep(1 3) nogen
				// created above
			keep cbsa cbsaname fips_state_code household_code panel_year
			rename cbsa marketid
			save ${tempHHmkt}, replace

		**===========================================================================================================
		dis "Store-cbsa concordance"
		
				use ${data}/RMSmarketcoverage.dta, clear
					// created manually using DMA descriptions and coverage table in Kilts-Nielsen documentation
				destring *share, replace ignore("%")
				merge 1:m dma_code using "${RMSdata}/1_moduleyear/Data/stores_`y'.dta", keep(3) nogen
					// created in  0a_dataconstruct/RMS/0a_prepcharacteristicinfor_2017.do
				gen coverage=foodshare if channel_code=="F"
				replace coverage=massshare if channel_code=="M"
				replace coverage=drugshare if channel_code=="D"
				gen county = fips_state_code *1000 + fips_county_code
				merge m:1 county using ${tempcountycbsa}, keep(1 3) nogen
					// created above
				keep cbsa dma_code *share
				bys cbsa dma_code: keep if _n==1
				collapse (mean) *share (count) ndmas=foodshare, by(cbsa) fast
				sum *share, d
				drop if cbsa==.
				save "${data}/cbsacoverage.dta", replace
					// used again in index analysis
				
			* merge with store list by county code
				use "${RMSdata}/1_moduleyear/Data/stores_`y'.dta", clear
				gen county = fips_state_code *1000 + fips_county_code
				merge m:1 county using ${tempcountycbsa}, keep(1 3) nogen
					// created above
				drop if county == . 
				cap noisily replace county = 12086 if county == 12025	// MIAMI-DADE
					// make sure fipscodes correspond to 2010 cbsa codes
				drop if retailer_code==9104 //problematic chain
				drop if cbsa==32580 // drop McAllen Texas (v. low income border CBSA) 
				if "`channel'" == "_FM" {
					keep if channel_code=="F" | channel_code=="M"
				}
				if "`channel'" == "_F" {
					keep if channel_code=="F" 
				}
				keep cbsa cbsaname fips_state_code store_code_uc 
				duplicates drop
				tempvar a
				bys store_code_uc: gen `a'=_N
				list if `a'>1 // no stores in multiple CBSAs
				bys store_code_uc: keep if _n==1
				sort store_code_uc
				keep store_code_uc cbsa cbsaname
				destring cbsa, replace
				save ${data}/storetocbsa_`y'`channel'.dta, replace
					// used here and in step 4/2_moduleindex_... code
						
				disp "- number of stores per CBSA in whole sample:"
					isid store_code_uc
					bys cbsa: gen numstores = _N

				*CBSA stats for output
					preserve
						bys cbsa: keep if _n==_N				
						merge 1:1 cbsa using ${tempcbsa}, nogen keep(3)
						
						format cbsapcincome %9.0gc
						format cbsapopulation %12.0gc
						drop if cbsaname==""
						merge 1:1 cbsa using ${tempcbsa}, nogen keep(3)
						merge 1:1 cbsa using "${data}/cbsacoverage.dta", nogen keep(1 3) 
						tab ndmas
						drop ndmas
						save ${tempcbsa}, replace
						
						di "*keep only CBSAs with 50 or more stores for table"
							keep if numstores>=50
						
						/* make latex table for sample CBSAs */
						/* requires LaTeX package `booktabs` */
						replace cbsaname=subinstr(cbsaname," Metro Area","",.)
						replace cbsaname=cbsaname+" ("+cbsaabbr+")" if cbsaabbr!=""
						listtab cbsaname numstores cbsapcincome cbsapopulation using "${output}/MarketStats.tex", ///
							rstyle(tabular) replace ///
							head("\\ \hline" ///
							" & Store & Per Capita &  \\" ///
							"CBSA Name & Count & Income & Population  \\ \hline \endfirsthead" ///
							"\multicolumn{4}{l}{\textit{Continued from previous page}} \\ \hline " ///
							" & Store & Per Capita &  \\" ///
							"CBSA Name & Count & Income & Population  \\ \hline \endhead" ///
							"\hline \multicolumn{4}{r}{\textit{Continued on next page}} \\ \endfoot" ///
							"\hline \endlastfoot") ///
							foot("")	
						correl cbsapcincome cbsapopulation	
						
					restore
					
				drop numstores
				rename store_code_uc store
				save ${tempstores}, replace
	}

	*==================================================================================================	
	*==================================================================================================

	else if "`market'"=="counties" | "`market'"=="stores" {

		di "*Prep county to CBSA cross-walk"
			import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
				// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
					//  maps into panelist fips codes perfectly and NHGIS data for all but PR
			destring county cbsa, replace
			drop if cbsa==.			
			save ${tempcbsa}, replace
			
		di "*Prep income data at the CBSA level"
			nhgis_pcincomepop_cbsa 
			tempfile tempmktcbsa
			save ${tempmktcbsa}, replace	
			
		di "*Prep income data at the county level"
			nhgis_pcincomepop_county
			tempfile tempcounties
			save ${tempcounties}, replace	

		**===========================================================================================================
			di "Identify county for each HH"
			use household_code panel_year fips_state_code fips_county_code using ${HMSdata}/panelists`y'.dta, clear
						// created in: KiltsProcessing/HMS/Programs\0_dataimport_vN.do
				gen county = fips_state_code*1000+fips_county_code
				merge m:1 county using ${tempcounties}, keep(1 3) nogen
				rename fips_state_code state
				keep county state household_code panel_year
				rename county marketid
				save ${tempHHmkt}, replace
				
		**===========================================================================================================
			di "Store-county concordance, with alternative store-level income measure"
				
				use ${RMSdata}/1_moduleyear/Data/stores_`y'.dta, clear
					// created in  0a_dataconstruct/RMS/0a_prepcharacteristicinfor_2017.do
					gen county = fips_state_code*1000+fips_county_code
					rename fips_state_code state
					drop if retailer_code==9104 //problematic chain
					if "`channel'" == "_FM" {
						keep if channel_code=="F" | channel_code=="M"
					}
					if "`channel'" == "_F" {
						keep if channel_code=="F" 
					}
					keep county state store_code_uc retailer_code
					duplicates drop
					tempvar a
					bys store_code_uc: gen `a'=_N
					list if `a'>1
					bys store_code_uc: keep if _n==1
					sort store_code_uc
					keep store_code_uc county retailer_code
					tempfile temp
					save `temp', replace
			
			
				use "${step1data}/storeincdist_logincpctiles.dta", clear
					keep store_code_uc avginc* weight*
					reshape long avginc weight, i(store_code_uc) j(quantile)
					gen w_avginc_level=exp(avginc)*weight
					keep store_code_uc w_avginc_level weight
					collapsesum, sumvars(weight w_avginc_level) byvars(store_code_uc)
					gen storepcincome = w_avginc_level/weight
					keep store_code_uc storepcincome
					merge 1:1 store_code_uc using `temp', keep(3) nogen
					rename store_code_uc store
					save ${tempstores}, replace
	}
}		
end
		
*==================================================================================================	
*** Calculate product-level market sales
		
cap prog drop p_productmarketsales
prog define p_productmarketsales

	syntax [anything], incg(integer) market(string) y(integer) [mktspecificsh(string) test(string) channel(string) sample(string) sampleV(string) sampleN(string)]

if 1==1 {
	di "*=================================================================================================="
	di "*Prep market sales data"
		
	cap confirm file ${data}/product_`y'_sales_storelevel.dta
		* store-level intermediate file, created below
	if _rc != 0  {
		di "... append sales data by module"
		
		local first = 1
		local j = 1
		local lastp = 8777
			// highest module number
		if "`test'"!="" {
			local lastp = 8777
		}
		
		forv p = 1/`lastp'{		
			capture confirm file ${step0bdata}/store_year_product/year_`p'_`y'_productlevel.dta
								// created by 0b_dataimport/Code/1c_RMS_datasetup_v[].do
								// contains store sales at store-year-product level	
			if _rc == 0 {
				use store_code_uc productid year value commonunits using ${step0bdata}/store_year_product/year_`p'_`y'_productlevel.dta, clear
					// created by 0b_dataimport/Code/1c_RMS_datasetup_v[].do
				count
				if `r(N)'>0 {
					matrix appendcheck[`j',2] = -99
					gen pm = `p'
					if `first' == 0 append using ${data}/product_`y'_sales_storelevel.dta
					save ${data}/product_`y'_sales_storelevel.dta, replace
					local first = 0
				}
			}
			
			local j = `j' + 1
			di "module `p'"
		}
				
	} // end of append product-store level sales data across modules
	else di "... store-level data already available"

	di "Load store-level data"
		use ${data}/product_`y'_sales_storelevel.dta, clear

	di "Limit to sample of consistent store counts across markets" 
		if strpos("`sample'", "_limit")> 0 & "`market'"!="stores" {
			count
			
			** check if crosswalk for selecting stores exists - if not, create
				cap confirm file ${data}/StoreSample_Crosswalks/storecodesample`sampleN'_`market'`channel'`sampleV'_`year'.dta
					// created in: samplestores subprogram (below)
				if _rc != 0 {
					preserve
					if strpos("`sampleN'", "cbp") > 0 samplestores_cbpwt, sampleN("`sampleN'") sampleV(`sampleV') year(`y') market("`market'") channel("`channel'")
					else samplestores, sampleN(`sampleN') sampleV(`sampleV') year(`y') market("`market'") channel("`channel'")
					restore
				}
	
			merge m:1 store_code_uc year using ${terminal}/4_postestimation_analysis/Data/StoreSample_Crosswalks/storecodesample`sampleN'_`market'`channel'`sampleV'_`y'.dta, keep(3) nogen
				// created below (subprogram: samplestores, samplestores_cbpwt)
				// list of N randomly sampled stores 

		}
			
	di "Merge in market ids for each store (and drop stores not under consideration - problem chain + non-food and mass merch, if relevant)"
		cap drop marketid
		rename store_code_uc store
		merge m:1 store using ${tempstores}, keep(3) nogen keepusing(${marketvar`market'}) 
			// created above in p_mktdata: store to cbsa/county concordance
		rename store store_code_uc
		
	di "*Drop problem chain (9104) and (if relevant) keep only food and mass merchandiser stores"
		merge m:1 store_code_uc using ${RMSdata}/1_moduleyear/Data/stores_`y'.dta, keepusing(retailer_code channel_code) keep(1 3)
		drop if retailer_code == 9104
		drop retailer_code _merge
		if "`channel'" == "_FM" {
			di "*keep only food and mass merchandiser"
			keep if channel_code=="F" | channel_code=="M"
		}
		if "`channel'" == "_F" {
			di "*keep only food stores"
			keep if channel_code=="F" 
		}
		drop channel_code
			
	di "Collapse data to `market'-product level"
		if "`market'"!="stores" rename  ${marketvar`market'} marketid
		else rename store_code_uc marketid
		collapsesum, sumvars("value commonunits") byvars(productid marketid year)
	
	save ${data}/product_`market'_`y'_no9104`channel'_sales`sample'`sampleV'.dta, replace

}
end


*==================================================================================================	
*** Calculate product expenditure shares by income group
		
cap prog drop p_incspecprodshares
prog define p_incspecprodshares

	syntax [anything], incg(integer) market(string) y(integer) [mktspecificsh(string) test(string) channel(string)]

if 1==1 {
	di "*=================================================================================================="
	di "Identify products available in each market (for conditional shares)"
		use ${data}/product_`market'_`y'_no9104`channel'_sales`sample'`sampleV'.dta, clear
			// created above
		keep marketid productid
		capture tostring marketid, replace
		drop if marketid=="" | marketid=="."
		bys marketid productid: keep if _n==1
		rename productid masterproductid
		tempfile tempprodlist
		save `tempprodlist', replace
		
	di "*=================================================================================================="
	di "*Prep HH size-adjusted income"
	
		use household_code panel_year income using ${step0bdata}/incomeadj.dta, clear
			// created in: 0_ndataimport/1b_HMS_demographicdata_v[].do
			drop if income==.
			xtile pct=income, nq(100) 
			local incg `incg'
			foreach k in `incg' {
				gen incgroup`k'=floor(pct/(100/`k'))+1
				replace incgroup`k'=`k' if incgroup`k'==`k'+1
				bys incgroup`k': egen income`k'=median(income)
				bys incgroup`k': egen minincome`k'=min(income)
				bys incgroup`k': egen medincome`k'=median(income)
				bys incgroup`k': egen maxincome`k'=max(income)
				disp "`k'"
			}
			tab incgroup`incg' income`incg'
			compress
			sort household_code
			tempfile temphhs
			save `temphhs', replace
	
	di "*=================================================================================================="
	di "Load HH purchase data"
		use household_code year productid value brand pm if year == `y' using "${step0bdata}/HMSdata_year`test'.dta", clear
			// created by 0b_dataimport/Code/1a_HMS_purchasedata_v[].do
			// contains HH purchase at product-HH-month level, observations identified by household_code year month productid
		rename year panel_year
		

	di "Merge in HH market"
		merge m:1 household_code panel_year using ${tempHHmkt}, keep(3) nogen 
			// created above

		if "`availsource'"=="HMS" {
			preserve
			keep marketid productid
			duplicates drop
			
			rename productid masterproductid
			tempfile tempprodlist
			save `tempprodlist', replace
			
			restore 
		}
		
	di "Merge in HH size-adjusted income"
		merge m:1 household_code panel_year using `temphhs', keep(3) keepusing(incgroup`incg' income`incg') nogen
			// created above
				
		preserve
			collapsesum, sumvars("value") byvars(productid incgroup`incg' income`incg' brand pm)
			rename pm product_module_code 
			rename productid prodid
			save ${data}/hhexp_by10groups.dta, replace
		restore
					
		** keep high income and low income households only for this stylized fact
		drop income*
		
	di "Collapse data to market-income-product level"
		gen count=1
		collapsesum, sumvars("value") byvars(productid marketid incgroup`incg' brand pm)
		
		rename productid masterproductid

		keep marketid incgroup`incg' masterproductid value brand pm
		capture tostring marketid, replace
		drop if marketid=="" | marketid=="."
		
		
	di "Calculate total purchases by income group in each market (to construct product-specific denominator)"
		preserve
			collapsesum, sumvars("value") byvars(marketid incgroup`incg')
			tempfile mktincpurchases
			save `mktincpurchases', replace
		restore
		
	di "Identify group-specific purchases in markets where products are available, Identify which products are available in which markets (what is in RMS + what is purchased in HMS)"
		preserve
			bys marketid masterproductid: keep if _n==1
			merge m:1 marketid masterproductid using `tempprodlist', nogen
			keep marketid masterproductid
			joinby marketid using `mktincpurchases'
			rename value totvalue_ifavailable
			tempfile prodmktincpurchases
			save `prodmktincpurchases', replace
			collapsesum, sumvars("totvalue_ifavailable") byvars(masterproductid incgroup`incg')
			tempfile prodincpurchases
			save `prodincpurchases', replace
		restore
	
	if "`mktspecificsh'"=="mktspecific" {
			
		merge 1:1 masterproductid marketid incgroup`incg' using `prodmktincpurchases'
		
		di "loop by market"
			levelsof marketid, local(mkt)
			local first = 1
			foreach m of local mkt{
				
			di `m'			
			preserve

			di "Calculate market-specific expenditure share on each product by HI/LI HH"
			
				drop if marketid == "`m'"

				gcollapse (sum) value totvalue_ifavailable, by(masterproductid incgroup`incg') fast
								
				** calculate product expenditure share
				bys incgroup`incg': egen totalvalue= total(value)
				gen prodshare = value/totalvalue
				
				** calculate conditional product expenditure share (conditional on being available) rescaled to sum to 1 across products
				gen condprodshare = value/totvalue_ifavailable
				bys incgroup`incg': egen totcondprodshare= total(condprodshare)
				replace condprodshare = condprodshare/totcondprodshare
				
				disp "`m'"
				gen marketid = `m'
				
				isid marketid masterproductid incgroup`incg'
				keep marketid masterproductid incgroup`incg' prodshare condprodshare value totvalue_ifavailable
				
				if `first' == 0 append using ${data}/`market'specificprodshare.dta
				save ${data}/`market'specificprodshare.dta, replace
				
				local first = 0
				
			restore	
			}
		}	
		di "Calculate national expenditure share on each product by HI/LI HH"
			gcollapse (sum) value, by(masterproductid incgroup`incg' brand pm) fast 
			merge m:1 masterproductid incgroup`incg' using `prodincpurchases', keep(3) nogen
			
			cap rename brand brandid
			cap rename pm product_module_code
			
			** calculate product expenditure share
			bys incgroup`incg': egen totalvalue= total(value)
			gen prodshare = value/totalvalue
				
			** calculate conditional product expenditure share (conditional on being available) rescaled to sum to 1 across products
			gen condprodshare = value/totvalue_ifavailable
			bys incgroup`incg': egen totcondprodshare= total(condprodshare)
			replace condprodshare = condprodshare/totcondprodshare
			
			keep masterproductid incgroup`incg' prodshare brandid product_module_code value condprodshare value totvalue_ifavailable
			save ${data}/natlprodshare.dta, replace
}				
end

*==================================================================================================	
*** Calculate the share of high- and low-income baskets represented in the products sold in stores or CBSAs

cap prog drop p_cityincomeshares
prog define p_cityincomeshares

	syntax [anything], incg(integer) market(string) y(integer) [mktspecificsh(string) test(string) channel(string) sample(string) sampleV(string) sampleN(string)]

if 1==1 {
	di "*=================================================================================================="
	di "*Join HH purchase and availability data for market availability shares"
		
		**===========================================================================================================
		di "identify products available in each market"
			use ${data}/product_`market'_`y'_no9104`channel'_sales`sample'`sampleV'.dta, clear
				// created above 
			keep marketid productid
			bys marketid productid: keep if _n==1
			rename productid masterproductid
			tempfile tempprodlist
			save `tempprodlist', replace

		**===========================================================================================================
		di "Merge income group expenditure shares with product availability data"
		
		if "`mktspecificsh'"=="mktspecific" {
			*product expenditure share is market-specific
			use ${data}/`market'specificprodshare.dta, clear
				// calculated above 
				// unique identifier: marketid masterproductid incgroup`incg'
			isid marketid masterproductid incgroup`incg'
			if "`market'"!="stores" {
				merge m:1 marketid masterproductid using `tempprodlist', keep(3)
					// unique identifier: marketid masterproductid
			}
			else {
				*using county instead of store-specific shares --> because only know household county
				joinby marketid masterproductid using `tempprodlist'
					// unique identifier: store_code_uc  marketid maserproductid
				cap drop _merge
			}
		}
		else {
			* product expenditure share is not market-specific
			use ${data}/natlprodshare.dta
			// calculated above 
			// unique identifier: marketid masterproductid incgroup`incg'
			isid masterproductid incgroup`incg'
			joinby masterproductid using `tempprodlist' 
		}
		
	di "Collapse data to market-incomegroup level"
		drop if marketid==.
		gen prodcount=(prodshare>0 & prodshare!=.)
		collapse (sum) *prodshare prodcount, by(marketid `bsvar' incgroup`incg') fast
		reshape wide *prodshare prodcount, i(marketid `bsvar') j(incgroup`incg')
		rename marketid ${marketvar`market'}
			
	save "${data}/tmp0_`mktspecificsh'sharesdiffby`market'`channel'_`incg'_`y'_RMSavail`sample'`sampleV'.dta", replace 

} // end collapse if 1==1
end	

*==================================================================================================
** Run hedonic regressions

cap prog drop p_hedonic
prog define p_hedonic

syntax [anything], incg(integer) market(string) y(integer) [mktspecificsh(string) test(string) channel(string) micro(string) cbsa(string) estdir(string) sample(string) sampleV(string) sampleN(string)  ]
	

if 1==1 {
	di "*=================================================================================================="
	di "*Join HH purchase and market price data for weighted hedonic calcs"
		
	use ${data}/product_`market'_`y'_no9104`channel'_sales`sample'`sampleV'.dta, clear
		sort productid marketid
		by productid: egen natlvalue=total(value)
		by productid: egen natlunits=total(commonunits)
		gen rellnuv=ln(value/commonunits)-ln(natlvalue/natlunits)
		keep marketid productid rellnuv
		tempfile tempmktdata
		save `tempmktdata'
		
	use ${data}/natlprodshare.dta, clear
		keep masterproductid incgroup`incg' value
		rename masterproductid productid
		joinby productid using `tempmktdata'
		gen wrellnuv=value*rellnuv
		sort incgroup`incg' marketid 
		by  incgroup`incg' marketid: gen sumw=sum(value)
		by  incgroup`incg' marketid: gen coef=sum(wrellnuv)
		by  incgroup`incg' marketid: keep if _n==_N
		replace coef=coef/sumw
		keep coef marketid incgroup`incg'
		reshape wide coef, i(marketid) j(incgroup`incg')
		save "${data}/hedonic_`market'`channel'_`incg'_`y'_RMSavail`sample'`sampleV'.dta", replace
}

end

		
*==================================================================================================
** Create regression tables and trend plots for different market levels

cap prog drop p_reg_plot
prog define p_reg_plot

syntax [anything], var(string) incg(integer) market(string) y(integer) [conditional(string) mktspecificsh(string) test(string) channel(string) micro(string) cbsa(string) estdir(string) sample(string) sampleV(string) sampleN(string) ]
	
if 1==1 {
	di "*=================================================================================================="
	di "*Plots/regressions with lhs: `var'"
		
	global sharedifflab="Difference in Basket Shares Available in a ${`market'lab}"
	global sharedifflabshort="Difference in Basket Shares"
	global hedonicdifflab="Difference in ${`market'lab} Price Level"
	global hedonicdifflabshort="Difference in Price Level"
	global sharelevellab="Decile-Specific Basket Shares Available in a ${`market'lab}"
	global sharelevellabshort="Decile-Specific Basket Share"
	global hedoniclevellab="Decile-Specific ${`market'lab} Price Level"
	global hedoniclevellabshort="Decile-Specific Price Level"	
	global lnpcinclab=			"Ln(Per Capita Income\$\_c\$)  "
	global lnpoplab=			"Ln(Population\$\_c\$)"
	
	if strpos("`sample'","_limit")>0 & "`sampleV'"=="" local bsvar="bsid"
		
	di "Process Data"
		local prefshare="tmp0_`mktspecificsh'sharesdiffby"
		local prefhedonic="hedonic_"
		
		tempfile storecounts
		if "`bsvar'"!="" {
			local first=1 
			clear
			forvalues bssample=1/100 {			
				capture confirm file "${data}/`pref`var''`market'`channel'_`incg'_`y'_RMSavail`sample'_v`bssample'.dta"
					// created by by running this code through 2_stylizedfact2_bs_script.sh
				if _rc==0 {
					append using "${data}/`pref`var''`market'`channel'_`incg'_`y'_RMSavail`sample'_v`bssample'.dta"
					if `first'==1 gen `bsvar'=.
					else quietly replace `bsvar'=`bssample' if `bsvar'==.
					local first=0
				}
			}
			
		}	
			
		desc

		else use "${data}/`pref`var''`market'`channel'_`incg'_`y'_RMSavail`sample'`sampleV'.dta", clear
	
	if "`conditional'"=="1" local var "cond`var'"
	
		capture rename *prodshare* *share*
		capture rename coef* hedonic*
		capture drop a
		gen a=1
		foreach i in 1 `incg' {
			replace `var'`i'=100*`var'`i'
			bys a `bsvar': egen sd_`var'`i'=sd(`var'`i')
			bys a `bsvar': egen mean_`var'`i'=mean(`var'`i')
			gen z`var'`i'=(`var'`i'-mean_`var'`i')/sd_`var'`i'
		}
		sum mean_`var'* sd_`var'*
		gen z`var'diff=z`var'`incg'-z`var'1
		gen `var'diff = (`var'`incg'-`var'1) //`var'1
		capture rename marketid ${marketvar`market'}

	di "Collapse out bootstrap dimension"
		if "`bsvar'"!="" collapse (mean) `var'diff `var'1 `var'`incg' z`var'diff z`var'1 z`var'`incg', by(${marketvar`market'}) fast
		
		local weight=""
	
	di "Merge in market per capita income"
		if "`market'"=="stores" merge m:1 ${marketvar`market'} using ${temp`market'}, keep(3) nogen
		desc
		else merge m:1 ${marketvar`market'} using ${temp`market'}, keep(3) nogen
		gen lnpcincome=log(${marketvar`market'}pcincome)
		if "`market'"=="stores" {
			merge m:1 county using ${tempcounties}
			keep if _merge==3
			drop _merge
			gen lncountypcincome=log(${marketvarcounties}pcincome)
		}
		if "`market'"!="cbsa" {
			merge m:1 county using ${tempcbsa}, keep(3) nogen
			merge m:1 cbsa using ${tempmktcbsa}, keep(3) nogen
			gen lncbsapcincome=log(${marketvarcbsa}pcincome)
		}
		
		if "`market'"=="cbsa" {
			rename ${marketvar`market'}population population
			gen lnpop=log(population)
		
			_eststo clear
			foreach wgt in "" "wgt" {
				if "`wgt'"=="wgt" local weight = "[aweight=population]"
				
				reg `var'diff lnpcincome `weight'
				eststo `var'a`wgt'
						if "`wgt'"=="wgt" estadd local weights "Population"
						if "`wgt'"=="" estadd local weights "None"
				reg `var'diff lnpcincome lnpop `weight'
				eststo `var'b`wgt'
						if "`wgt'"=="wgt" estadd local weights "Population"
						if "`wgt'"=="" estadd local weights "None"
			} // end of this RHS specifications
			
			esttab `var'a `var'b `var'awgt `var'bwgt using "${output}/wu_${mktspecificsh}`var'diffby`market'`cov'`channel'_regs_productid_`incg'_`y'_RMSavail`sample'`sampleV'.tex", replace ///
				label  wrap ${esttabopts} ///
				stats(weights N r2, fmt(0 %9.0gc %9.0gc 2) labels("Weights" "Observations" "\$R^2\$")) ///
				coeflabel(lnpcincome "${lnpcinclab}" lnpop "${lnpoplab}") ///
				prehead("{ \begin{tabular}{l*{@M}{c}}" "\toprule \multicolumn{5}{c}{Dependent Variable: ${`var'difflab}} \\" ///
				"& ${numline4} \\" ) 

		} // end of if cbsa
	
	di "Summarize data"
		sum `var'*, d
		
	di "Prep for plots"
		dollarlablist, outvarname("inclistcbsa") labvals("20000 30000 40000 60000") 
		dollarlablist, outvarname("inclistcounty") labvals("15000 20000 30000 40000 60000")
		dollarlablist, outvarname("incliststores") labvals("15000 20000 30000 40000 60000 90000")

		regress `var'diff lnpcincome
		local b = round(_b[lnpcincome],.001)
		local se = round(_se[lnpcincome],.001)
			
		drop if `var'diff==.
		sort `var'diff
		gen `var'diff_up=1 if (`var'diff-`var'diff[_n-1])<0.5
		gen `var'diff_down=1 if (`var'diff[_n+1]-`var'diff)<0.5
		gen pcincome_up=1 if abs(${marketvar`market'}pcincome-${marketvar`market'}pcincome[_n-1])<1000
		gen pcincome_down=1 if abs(${marketvar`market'}pcincome[_n+1]-${marketvar`market'}pcincome)<1000		

	************************************************************************************************************
	**if "`market'"=="stores", the following outputs storelevel regression results and lpoly chart
	**for other market types the next section outputs scatter plots
	
	if "`market'"=="stores" {

	*plots
		drop if `var'diff==.
		lpoly `var'diff lncountypcincome, ci noscatter ///
			xtitle("County Per Capita Income (Log Scale)") ///
			ytitle("Difference in Basket Shares Available in a Store (%)") ///
			legend(label(2 "local smooth polynomial")) ///
			title(" ") ///
			graphregion(fcolor(white)) xlabels(`inclistcounty')  
		graph export "${output}/wupoly_`mktspecificsh'`var'diffby`market'`channel'_lfit_productid_`incg'_`y'_RMSavail.eps", replace 
		
		lpoly `var'diff lnpcincome, ci msize(small) msymbol(oh) ///
			xtitle("Local Per Capita Income (Log Scale)") ///
			ytitle("Difference in Basket Shares Available in a Store (%)") ///
			legend(label(2 "local smooth polynomial")) ///
			title(" ") ///
			graphregion(fcolor(white)) xlabels(`incliststores')  
		graph export "${output}/wupoly_`mktspecificsh'`var'diffby`market'`channel'_lfit_productid_`incg'_`y'_RMSavail_storeinc.eps", replace 
		
		
		regress `var'diff lncountypcincome
		local b = round(_b[lncountypcincome],.01)
		local se = round(_se[lncountypcincome],.01)
			
			twoway (scatter `var'diff lncountypcincome, msize(small)) ///
				(lfit `var'diff lncountypcincome), xtitle("County Per Capita Income (Log Scale)") ///
				ytitle("${`var'difflab} (%)") subtitle("Slope =`b', Standard Error = `se'") legend(off)  ///
					graphregion(fcolor(white)) xlabels(`inclistcounty')    
			graph export "${output}/wu_`mktspecificsh'`var'diffby`market'`channel'_lfit_productid_`incg'_`y'_RMSavail.eps", replace 
			capture erase "${output}/wu_`mktspecificsh'`var'diffby`market'`channel'_lfit_productid_`incg'_`y'_RMSavail.eps"
			
		regress `var'diff lnpcincome
		local b = round(_b[lnpcincome],.01)
		local se = round(_se[lnpcincome],.01)
			
			twoway (scatter `var'diff lnpcincome, msize(small)) ///
				(lfit `var'diff lnpcincome), xtitle("Local Per Capita Income (Log Scale)") ///
				ytitle("${`var'difflab} (%)") subtitle("Slope =`b', Standard Error = `se'") legend(off)  ///
					graphregion(fcolor(white)) xlabels(`incliststores')    
			graph export "${output}/wu_`mktspecificsh'`var'diffby`market'`channel'_lfit_productid_`incg'_`y'_RMSavail_storeinc.eps", replace 
					
		
	*identify high and low income counties
	
		di "* Identify H and L income neighborhoods"
		preserve
		capture gen storepcincome=lnpcincome
		foreach mkt in store {
			keep `mkt' `mkt'pcincome 
			duplicates drop
			xtile `mkt'inc=`mkt'pcincome, n(2) 
			bys `mkt'inc: sum `mkt'pcincome
			gen `mkt'incgp="H" if `mkt'inc==2
			replace `mkt'incgp="L" if `mkt'inc==1
			keep `mkt' `mkt'incgp
			tempfile temp`mkt'incgp
			save `temp`mkt'incgp', replace
			restore, preserve
		}
		restore
		merge m:1 store using `tempstoreincgp', nogen
	
	*regressions

		gen byte constant =1
		bysort retailer_code: gen multi_store = 1 if _N>1
		count if multi_store != 1
		keep if multi_store == 1
		* Note: for all stores, only 2 are not within multi-S chain, so not much difference 			
		
		gen chain=retailer_code
		
		foreach secondfes in "" "chain" {
		
			if "`secondfes'"=="" local chainfelab="No"
			if "`secondfes'"=="chain" local chainfelab="Yes"
			
			reghdfe `var'diff lnpcincome `weight', absorb(constant  `secondfes') vce(cluster cbsa)
			eststo reg1`secondfes'
			estadd local cbsafe "No"
			estadd local chainfe "`chainfelab'"
			estadd local storeset "All"
			estadd local Ncbsa "-"
			
			reghdfe `var'diff lnpcincome `weight', absorb(cbsa  `secondfes') vce(cluster cbsa)
			eststo reg2`secondfes'
			estadd local cbsafe "Yes"
			estadd local chainfe "`chainfelab'"
			estadd local storeset "All"
			estadd local Ncbsa "-"
			
			reghdfe `var'diff lncbsapcinc  `weight', absorb(constant `secondfes') vce(cluster cbsa)
			eststo reg3`secondfes'
			estadd local cbsafe "No"
			estadd local chainfe "`chainfelab'"
			estadd local storeset "All"
			estadd local Ncbsa  `e(N_clust1)'

		}	
		
		esttab reg1 reg1chain reg2 reg2chain reg3 reg3chain   ///
			using "${output}/reg_`mktspecificsh'`var'diffby`market'`channel'_regression_productid_`incg'_`y'_RMSavail_storeinc.tex" , replace ///
			wrap ${esttabopts}  coeflabel(lnpcincome "Ln(Local Per Capita Income)" lncbsapcincome "Ln(CBSA Per Capita Income)") ///
			prehead("{ \begin{tabular}{l*{@M}{c}}" "\toprule \multicolumn{7}{c}{Dependent Variable: ${`var'difflabshort} (\%)}\\" ///
			"& ${numline6} \\")  ///
			stats(cbsafe chainfe Ncbsa N r2_a, fmt(0 0 %9.0gc  %9.0gc 2) labels("CBSA Fixed Effects"  "Chain Fixed Effects" "Number of CBSAs" "Observations" "adj. \$R^2\$")) 
		
		eststo clear 

	}
	************************************************************************************************************
	**if "`market'"=="cbsa", the following outputs the SF scatter plot
	if "`market'"=="cbsa" {

	**Plots...
		if "`sample'"=="_limit50" gen mlabels=cbsaabbr
		else gen mlabels=""
		
		gen cov=foodshare+drugshare+massshare
		foreach cov in "" { // highcov lowcov {
			if "`cov'"=="highcov" local restrict="if cov>150 & cov!=."
			if "`cov'"=="lowcov" local restrict="if cov<=150 & cov!=."
			if "`cov'"=="" local restrict=""
		*
			regress `var'diff lnpcincome `restrict'
			local b = round(_b[lnpcincome],.001)
			local se = round(_se[lnpcincome],.001)
		
			twoway 	(scatter `var'diff lnpcincome `restrict', mlabel(mlabels) mcolor(navy) msymbol(o) msize(vsmall) mlabsize(vsmall) mlabg(*0.25)) ///
				(lfit `var'diff lnpcincome `restrict'), xtitle("CBSA Per Capita Income (Log Scale)") ///
				ytitle("${`var'difflab} (%)") subtitle("Slope =`b', Standard Error = `se'") legend(off)  ///
					graphregion(fcolor(white)) xlabels(`inclistcbsa') name(`var', replace)
					** xlabels(10000  "$10,000" 20000 "$20,000" 30000  "$30,000" 40000  "$40,000" 50000  "$50,000" )	
			graph export "${output}/wu_${mktspecificsh}`var'diffby`market'`cov'`channel'_lfit_productid_`incg'_`y'_RMSavail`sample'`sampleV'.eps", replace 
		
			local std="" // "z" // 
			regress `std'`var'1 lnpcincome `restrict'
			local b1 = round(_b[lnpcincome],.001)
			local se1 = round(_se[lnpcincome],.001)
			regress `std'`var'10 lnpcincome `restrict'
			local b10 = round(_b[lnpcincome],.001)
			local se10 = round(_se[lnpcincome],.001)
		
			twoway 	(scatter `std'`var'1 lnpcincome `restrict', mlabel(mlabels) mcolor(navy) msymbol(o) msize(vsmall) mlabcolor(navy) mlabsize(vsmall) mlabg(*0.25)) ///
				(lfit `std'`var'1 lnpcincome `restrict', lcolor(navy)) ///
				(scatter `std'`var'10 lnpcincome `restrict', mlabel(mlabels) mcolor(maroon) msymbol(o) msize(vsmall) mlabcolor(maroon) mlabsize(vsmall) mlabg(*0.25)) ///
				(lfit `std'`var'10 lnpcincome `restrict', lcolor(maroon)),  xtitle("CBSA Per Capita Income (Log Scale)") ///
				ytitle("${`var'levellab} (%)") subtitle("Slope (Std Error): Low Inc. `b1' (`se1') and High Inc. `b10' (`se10')") legend(order(1 "Bottom Decile" 3 "Top Decile"))  ///
					graphregion(fcolor(white)) xlabels(`inclistcbsa') name(`var'both, replace)
			graph export "${output}/wu_${mktspecificsh}`var'levelsby`market'`cov'`channel'_lfit_productid_`incg'_`y'_RMSavail`sample'`sampleV'.eps", replace 
		
		}	
	
	} 

}
end


*==================================================================================================
*==================================================================================================
** Reference Programs 
*==================================================================================================
*==================================================================================================
capture program drop nhgis_pcincomepop_cbsa
		program define nhgis_pcincomepop_cbsa
		
		syntax [anything]
		
	*2000-2014 ACS data with 2013 CBSA codes 
	insheet using "${rawNHGIS}/2014/nhgis0007_ds206_20145_2014_cbsa.csv", names comma clear // downloaded from nhgis.org 06/25/2019
	*	// Dataset: 2010 Dicennial Census, All CBSAs within the United States, per capita income
	rename aba1e001 cbsapopulation
	rename abfie001 cbsapcincome // Per Capita Income in the Past 12 Months (in 2014 Inflation-Adjusted Dollars)
	rename cbsa cbsaname
	rename cbsaa cbsa
	keep cbsaname cbsa cbsapcincome cbsapopulation


end

*==================================================================================================
capture program drop nhgis_pcincomepop_county  
	program define nhgis_pcincomepop_county
	
	syntax [anything]
	
	insheet using "${rawNHGIS}/2014/nhgis0008_ds206_20145_2014_county.csv", names comma clear 
		// downloaded from nhgis.org 07/07/2017
		// Dataset: 2006-2012 ACS 5-year estimate, All counties within the United States
	keep name_e statea countya aba1e001 abfie001
	gen county=statea*1000+countya
	drop statea countya
	rename name_e countyname
	rename aba1e001 countypopulation
	rename abfie001 countypcincome // Per Capita Income in the Past 12 Months (in 2014 Inflation-Adjusted Dollars)
		
end			

*===========================================================================================
*===========================================================================================
*===========================================================================================
** Code to sample constant number of stores with market 

cap prog drop samplestores
prog def samplestores

syntax [anything], sampleN(integer) year(integer) market(string) [sampleV(string) channel(string)]

if 1 == 1 {
	dis "...get data on all stores"
		use ${RMSdata}/1_moduleyear/Data/stores_`year'.dta, replace
			// created in 0a_dataconstruct/RMS/0a_prepcharacteristicinfor_2017.do
		isid store_code_uc

	dis "...drop problem chain"
		drop if retailer_code==9104 //problematic chain
	
	if "`channel'" == "_FM" {
		di "*keep only food and mass merchandiser"
		keep if channel_code=="F" | channel_code=="M"
	}
	if "`channel'" == "_F" {
		di "*keep only food and mass merchandiser"
		keep if channel_code=="F" 
	}
	
	dis "...identify each market a store belongs to"
		gen county = fips_state_code*1000+fips_county_code
			drop fips* 
		
		if "`market'"=="cbsa" {
			merge m:1 store_code_uc using "${data}/storetocbsa_`year'`channel'.dta", keep(1 3) nogen
					// created above
					// previously created below in storetocbsa subprogram 
		}

	dis "...look at distribution of stores by market"
		drop if `market' == . 
		bys `market': egen numstores = count(store_code_uc)
		bys `market': gen tag = _n == 1
		sum numstores if tag == 1, det
		
	dis "...look at distribution of store by market population"
		cap confirm file ${data}/populationcount_`market'.dta
		if _rc != 0 popcrosswalk
		merge m:1 `market' using ${data}/populationcount_`market'.dta, keep(1 3) nogen

		gen storepercap = numstores/`market'_pop
		replace storepercap = storepercap*1000
		sum storepercap if tag == 1, det

	dis "...set number of stores to sample per market"
		local cbsa_numstore = `sampleN'
	
	dis "...limit to markets with correct number of stores"
		keep if numstores >= ``market'_numstore'
		distinct `market'

	dis "...sample stores for markets with more than desired number"

		local seed = `sampleN'*100000
		if "`sampleV'"!="" {
			local v_seed = subinstr("`sampleV'", "_v", "", .)
			local seed = `seed'+`v_seed'*100000
		}       

		set seed `seed'
		bys `market' (store_code_uc): gen rand = runiform()
		bys `market' (rand): gen order = _n
		keep if order <= ``market'_numstore'
				
	dis "...check that each market has the same number of stores"
		drop numstores
		bys `market': gen numstores = _N
		sum numstores
		assert r(mean) == ``market'_numstore'

	dis "...save crosswalk for sampling"
		keep `market' store_code_uc year
		isid `market' store_code_uc
	
		save ${data}/StoreSample_Crosswalks/storecodesample`sampleN'_`market'`channel'`sampleV'_`year'.dta, replace
						
}
end

*===========================================================================================
*===========================================================================================
*===========================================================================================
** Code to sample stores per market based on CBP establishment counts (for county or cbsa markets only)

cap prog drop samplestores_cbpwt
prog def samplestores_cbpwt

	syntax [anything], year(integer) market(string) sampleN(string) [sampleV(string) channel(string)]
if 1==1 {
	** Two options: 
		** sample a given (sampleN) percentage of the CBP count of establishments in that market (x channel)
			** pass in sampleN = "cbp20" (for example)
		** sample as if within a given (sampleN) km radius based on average CBP store density in that market (x channel)
			** i.e.: sampleN^2 * pi * ( cbp store count / market land area )
			** pass in sampleN = "cbp10dens" (for example)
	if strpos("`sampleN'", "dens") local density "density"
	else local density ""

	local sample_arg = subinstr("`sampleN'", "cbp", "", .)
	local sample_arg = subinstr("`sample_arg'", "dens", "", .)
	
	dis "...get data on all stores"
		use ${terminal}/../KiltsProcessing/RMS/1_moduleyear/Data/stores_`year'.dta, replace
			// created in KiltsProcessing
		isid store_code_uc

	dis "...drop problem chain"
		drop if retailer_code==9104 //problematic chain
	
	if "`channel'" == "_FM" {
		di "*keep only food and mass merchandiser"
		keep if channel_code=="F" | channel_code=="M"
	}
	if "`channel'" == "_F" {
		di "*keep only food"
		keep if channel_code=="F" 
	}

	dis "...identify each market a store belongs to"
		gen county = fips_state_code*1000+fips_county_code
		drop fips* 
		
		if "`market'"=="cbsa" {
			capture confirm file ${data}/storetocbsa_`year'`channel'.dta
			if _rc!=0 storetocbsa
			merge m:1 store_code_uc using "$terminal/2_preestimation_analysis/STATAData/storetocbsa_`year'`channel'.dta", keep(1 3) nogen
					// created above
		}

	dis "...look at distribution of stores by market x channel"
		drop if `market' == . 
		bys `market' channel_code: egen numstores = count(store_code_uc)
		bys `market' channel_code: gen tag = _n == 1
		sum numstores if tag == 1, det

	dis "...bring in CBP retail establishment counts"
		preserve
			use ${rawcbp}/county_retail_counts_from_cbp.dta, clear
				// created directly from CBP raw data downloaded at https://www.census.gov/programs-surveys/cbp/data/datasets.html
			keep if year == `year'
			drop all_retail_estabs
			rename (grocery_estabs massmerch_estabs convenience_estabs drug_estabs) (cbp_estF cbp_estM cbp_estC cbp_estD)
			reshape long cbp_est, i(fips_state fips_county) j(channel_code) string
			if "`market'" == "cbsa" {
				destring cbsa, replace
				collapse (sum) cbp_est, by(cbsa channel_code)
				tempfile cbpcounts 
				save `cbpcounts'
			}
			else if "`market'" == "county" {
				destring fips_state fips_county, replace
				gen county = fips_state*1000+fips_county
				keep county channel_code cbp_est
				tempfile cbpcounts 
				save `cbpcounts'
			}
		restore
		merge m:1 `market' channel_code using `cbpcounts', keep(1 3) nogen

		dis "...look at distribution of ratio of Nielsen stores to CBP stores by market x channel"
			gen storepercbpstore = numstores/cbp_est

	if "`density'" != "" {
		dis "...merge in `market' land area"
			preserve
				* fields from 2014 county / cbsa shapefiles
				* downloaded from nhgis.org 08/31/2020
				if "`market'" == "cbsa" {
					insheet using "${rawNHGIS}/2014/nhgis0004_shapefile_tl2014_us_cbsa_2014/US_cbsa_2014.csv", names comma clear
					keep cbsafp aland
					replace aland = aland/(1000*1000) // area in square km
					rename (cbsafp aland) (cbsa area)
				}
				else if "`market'" == "county" {
					insheet using "${rawNHGIS}/2014/nhgis0005_shapefile_tl2014_us_county_2014/US_county_2014.csv", names comma clear
					gen county = statefp*1000+countyfp
					keep county aland
					replace aland = aland/(1000*1000) // area in square km
					rename aland area
				}
				tempfile area
				save `area'
			restore
			merge m:1 `market' using `area', keep(1 3) nogen
	}
	
	dis "...set number of stores to sample per market x channel"
		if "`density'" == "" {
			bys `market' channel_code: gen sample_numstore = round(`sample_arg' / 100 * cbp_est)
		}
		else {
			bys `market' channel_code: gen sample_numstore = round(`sample_arg'*`sample_arg' * 3.14159 * cbp_est / area)
		}
		bys `market' channel_code: gen temp=(_n==1)
		bys channel_code: sum sample_numstore if temp==1, d
	
	dis "...limit to markets with at least sample_n stores, and where sample_n is at least 1, for each channel"
		distinct `market'
		preserve
			keep `market' channel_code sample_numstore
			bys `market' channel_code: gen n=_N
			bys `market' channel_code: keep if _n==_N
			gen channel_ok = (n >= sample_numstore & sample_numstore >= 1)
			bys `market': egen market_ok = min(channel_ok)
			keep if market_ok == 1
			collapse (sum) n, by(`market')
			drop n
			tempfile `market'_select
			save ``market'_select'
		restore
		merge m:1 `market' using ``market'_select', keep(3) nogen
		distinct `market'

	dis "...sample stores for market x channels with more than desired number"

		local seed = `sample_arg'*100000
		if "`sampleV'"!="" {
			local v_seed = subinstr("`sampleV'", "_v", "", .)
			local seed = `seed'+`v_seed'*100000
		}       

		set seed `seed'
		bys `market' channel_code (store_code_uc): gen rand = runiform()
		bys `market' channel_code (rand): gen order = _n
		keep if order <= sample_numstore
				
	dis "...check that each market x channel has the correct number of stores"
		drop numstores storepercbpstore
		bys `market' channel_code: gen numstores = _N
		if "`density'" == "" {
			local sample_cbp_pc = `sample_arg'/100
			gen storepercbpstore = numstores/cbp_est
			sum storepercbpstore
			assert round(r(mean), 0.1) == round(`sample_cbp_pc', 0.1)
		}
		else {
			local sample_area = `sample_arg'*`sample_arg' * 3.14159
			disp "`sample_area'"
			gen storepercbpstoredensity = numstores/(cbp_est/area*`sample_area')
			sum storepercbpstoredensity, d
			assert round(r(mean), 1) == 1 
		}

	dis "...save crosswalk for sampling"
		keep `market' store_code_uc year
		isid `market' store_code_uc
		
		save ${data}/StoreSample_Crosswalks/storecodesample`sampleN'_`market'`channel'`sampleV'_`year'.dta, replace
}		
end


*==================================================================================================
*==================================================================================================
*==================================================================================================
* Code to create county and cbsa population crosswalks 

if 1 == 1 {
cap prog drop popcrosswalk
prog def popcrosswalk
	syntax[anything]

	preserve

	** county population 

		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
			// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
			//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		rename county fipscounty
		destring fipscounty, replace
		drop if cbsa==""

		destring pop10, replace
		rename pop10 county_pop
		
		rename fipscounty county
		keep county county_pop	
		save ${data}/populationcount_county.dta, replace


	** cbsa population 
		
		import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
			// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
			//  maps into panelist fips codes perfectly and NHGIS data for all but PR
		destring cbsa pop10, replace
		drop if cbsa==.
		duplicates drop
		keep cbsa pop10
		bys cbsa: egen cbsa_pop = sum(pop10)
		keep cbsa cbsa_pop
		bys cbsa: keep if _n == 1
		save ${data}/populationcount_cbsa.dta, replace

	restore
		
end
}


*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	set linesize 200
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*==================================================================================================
