 *===========================================================================================
*** 3_nonRMSpurchasedatacheck.do
** to check whether the share of LI purchases reflected in the RMS data drops with CBSA income more for LI households than HI households

*==========================================================================================

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	global currentstep "$terminal/2_preestimation_analysis"	

* Set RepoOutput on Git
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	local a=strpos("$currentsteprepo","2_preestimation_analysis")
	if strpos("$currentsteprepo","2_preestimation_analysis")==0 {
		 disp "Need to run from step-specific directory"
		 exit
	}
	cd ${dir}

*Set-up standard directories	
	global data "$currentstep/STATAData"	
	global logs "$currentstep/STATALogs"
	global output "$currentsteprepo/RepoOutput"

*Directory to tmp data
	global temp "${data}/temp"

*===========================================================================================
*For log files:

	global name="2a_nonRMSexpsharecheck"
	
*===========================================================================================================================================
*===========================================================================================================================================

**** Program to run sub-programs

capture program drop main
program define main	

	global marketvarcbsa="cbsa"
	global cbsalab="CBSA"
	global market="cbsa"
	global incg=10
		
	if 1==1 {
		
		** market data
			tempfile tempHHmkt tempcbsa tempcountycbsa tempstores				
			foreach tempdataset in tempHHmkt tempcbsa tempcountycbsa tempstores {
				global `tempdataset' ``tempdataset''
				disp "`tempdataset': ${`tempdataset'}"
			}
			p_mktdata,  market("${market}") y(2012)  
	
		** process CBSA availablility data
			p_productsbyCBSA,  market("${market}") y(2012)  
					// identifies products available in RMS sample for each city
		
		** process purchase data
			p_incdecprodshares,  market("${market}") incg(${incg}) y(2012)  
					// calculates expenditures shares by income on products in RMS sample
		
		** analyze data
			nonRMSregcheck, market("${market}") incg(${incg}) y(2012) 
					// regression output relative expenditure shares against city income + runs regressions 

		}
	
	
end 

*==================================================================================================
** Subprograms ** 
*==================================================================================================	
*** Market-level datasets

cap prog drop p_mktdata
prog define p_mktdata

	syntax [anything], market(string) y(integer)

if 1==1 {
	
	di "*=================================================================================================="
	di "*Prep market data"
		
	foreach arg in market y test {
		di "`arg' ``arg''"
	}
	
	*==================================================================================================	
	*==================================================================================================	
	*==================================================================================================	
	*** Create temp market-type-specific datasets

	**===========================================================================================================
		di "*Prep income data at the CBSA level"
		
		*merge in 2000-2014 ACS data with 2013 CBSA codes (6/25/2019 commit switched from 2010 dicennial census data with 2003 CBSA codes)
			nhgis_pcincomepop_cbsa
			rename cbsa marketid
			merge 1:1 marketid using ${data}/cbsa_abbr.dta, keep(1 3)	nogen
				// created manually for list of 126 CBSA with 50 or more stores
			rename marketid cbsa
			save ${tempcbsa}, replace	
				// overwritten below to only keep CBSAs with 50 or more stores

			
		**===========================================================================================================
		di "*Prep county to CBSA cross-walk"
			import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
				// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
					//  maps into panelist fips codes perfectly and NHGIS data for all but PR
					// CBSA codes = new 2013 codes 
			destring county cbsa, replace
			drop if cbsa==.
			save ${tempcountycbsa}, replace
		
		**===========================================================================================================
		di "Identify cbsa for each HH"	
			use household_code panel_year fips_state_code fips_county_code using ${HMSdata}/panelists`y'.dta, clear
				// created in ${nyx}\Kilts_Consumer\Stata\Programs\0_dataimport_vN.do
			gen county = fips_state_code *1000 + fips_county_code
			merge m:1 county using ${tempcountycbsa}, keep(1 3) nogen
				// created above
			keep cbsa cbsaname fips_state_code household_code panel_year
			rename cbsa marketid
			
			save ${tempHHmkt}, replace

		**===========================================================================================================
		dis "Store-cbsa concordance"
		

			* merge with store list by county code
				use "${RMSdata}/1_moduleyear/Data/stores_`y'.dta", clear
				gen county = fips_state_code *1000 + fips_county_code
				merge m:1 county using ${tempcountycbsa}, keep(1 3) nogen
					// created above
				drop if county == . 
				cap noisily replace county = 12086 if county == 12025	// MIAMI-DADE
					// make sure fipscodes correspond to 2010 cbsa codes
				keep cbsa cbsaname fips_state_code store_code_uc 
				duplicates drop
				tempvar a
				bys store_code_uc: gen `a'=_N
				list if `a'>1 // no stores in multiple CBSAs
				bys store_code_uc: keep if _n==1
				sort store_code_uc
				keep store_code_uc cbsa cbsaname
				destring cbsa, replace
				save ${data}/storetocbsa_`y'`channel'.dta, replace
					// used here and in step 4/2_moduleindex_... code
						
				disp "- number of stores per CBSA in whole sample:"
					isid store_code_uc
					bys cbsa: gen numstores = _N

				drop numstores
				rename store_code_uc store
				save ${tempstores}, replace
}
		
end
		
*==================================================================================================	
*** Calculate product-level market sales
		
cap prog drop p_productsbyCBSA
prog define p_productsbyCBSA

	syntax [anything], market(string) y(integer) 

if 1==1 {

	di "Load store-level data"
		use ${data}/product_`y'_sales_storelevel.dta, clear
			// created in 2_stylizedfact2.do

	di "Merge in market ids for each store (and drop stores not under consideration - problem chain + non-food and mass merch, if relevant)"
		cap drop marketid
		rename store_code_uc store
		merge m:1 store using ${tempstores}, keep(3) nogen keepusing(cbsa) 
			// created above in p_mktdata: store to cbsa/county concordance
			
	di "Collapse data to `market'-product level"
		bys productid cbsa year: keep if _n==1

	save ${data}/productsinRMS_bycbsa_`y'.dta, replace

}
end

*==================================================================================================	
*** Calculate product expenditure shares by income decile
		
cap prog drop p_incdecprodshares
prog define p_incdecprodshares

	syntax [anything], incg(integer) market(string) y(integer) 

if 1==1 {
	di "*=================================================================================================="
	di "*Prep HH size-adjusted income"
	
		use household_code panel_year income using ${step0bdata}/incomeadj.dta, clear
			// created in: 0b_dataimport/1b_HMS_demographicdata.do
			drop if income==.
			xtile pct=income, nq(100) 
			local incg `incg'
			foreach k in `incg' {
				gen incgroup`k'=floor(pct/(100/`k'))+1
				replace incgroup`k'=`k' if incgroup`k'==`k'+1
				bys incgroup`k': egen income`k'=median(income)
				bys incgroup`k': egen minincome`k'=min(income)
				bys incgroup`k': egen medincome`k'=median(income)
				bys incgroup`k': egen maxincome`k'=max(income)
				disp "`k'"
			}
			tab incgroup`incg' income`incg'
			compress
			sort household_code
			tempfile temphhs
			save `temphhs', replace
			
	di "Load HH purchase data"
		use household_code productid year store_code_uc value if year == `y' using "${step0bdata}/HMSstoreleveldata_month.dta", clear
			// created by /0b_dataimport/Code/1a_HMS_purchasedata_v[].do
			// contains HH purchases (quantity, value, amt) at product-HH-store_code_uc-month level, observations identified by household_code year month productid store_code_uc
		collapsesum, sumvars("value") byvars(household_code year productid store_code_uc)
		rename year panel_year
		
	di "Only keep purchases in non-RMS retailers"
		preserve
			use store_code_uc using ${data}/product_`y'_sales_storelevel.dta, clear
			// created in 2_stylizedfact2.do
			bys store_code_uc: keep if _n==1
			tempfile temp
			save `temp', replace
		restore
		merge m:1 store_code_uc using `temp', keep(1)

	di "Merge in HH market"
		merge m:1 household_code panel_year using ${tempHHmkt}, keep(3) nogen 
			// created above in p_mktdata
		
	di "Merge in HH size-adjusted income"
		merge m:1 household_code panel_year using `temphhs', keep(3) keepusing(incgroup`incg' income`incg') nogen
			// created above in p_mktdata
							
	di "Collapse data to market-income-product level"
		collapsesum, sumvars("value") byvars(productid marketid incgroup`incg')
		
		keep marketid incgroup`incg' productid value
		
	di "Merge with list of product ids in the RMS data for a given city"
		drop if marketid==.
		rename marketid cbsa
		merge m:1 cbsa productid using ${data}/productsinRMS_bycbsa_`y'.dta, keep(1 3)
			// created in p_productsbyCBSA above
		rename _merge inRMS
		replace inRMS = (inRMS==3)
		collapsesum, sumvars("value") byvars(inRMS cbsa incgroup`incg')
		reshape wide value, i(cbsa incgroup`incg') j(inRMS)
		replace value0=0 if value0==.
		replace value1=0 if value1==.
		gen shareinRMS = value1/(value0+value1)
		save ${data}/expshareinRMS_bycbsa_`y'.dta, replace
}				
end


*==================================================================================================
** Create regression tables and trend plots for different market levels

cap prog drop nonRMSregcheck
prog define nonRMSregcheck

syntax [anything], incg(integer) market(string) y(integer)
	
if 1==1 {
	di "*=================================================================================================="	
		use ${data}/expshareinRMS_bycbsa_`y'.dta, clear
	
	di "Merge in market per capita income"
		merge m:1 ${marketvar`market'} using ${temp`market'}, keep(3) nogen
		gen lnpcincome=log(${marketvar`market'}pcincome)
		rename ${marketvar`market'}population population
		gen lnpop=log(population)
		
		local esttabopts2=subinstr("${esttabopts}", "nocons", "", .)

	di "Regression by income group"
		foreach wgt in "" "wgt" {
			_eststo clear
			forv incgrp =1/10 {
					if "`wgt'"=="wgt" local weight = "[aweight=population]"
					
					quietly sum lnpcincome if incgroup`incg'==`incgrp' `weight'
					gen zlnpcincome = (lnpcincome - `r(mean)')/`r(sd)'
					quietly sum lnpop if incgroup`incg'==`incgrp' `weight'
					gen zlnpop = (lnpop - `r(mean)')/`r(sd)'
					
					quietly reg shareinRMS zlnpcincome `weight' if incgroup`incg'==`incgrp'
					eststo a`incgrp'`wgt'
						if "`wgt'"=="wgt" estadd local weights "Population"
						if "`wgt'"=="" estadd local weights "None"
					quietly reg shareinRMS zlnpcincome zlnpop `weight' if incgroup`incg'==`incgrp'
					eststo b`incgrp'`wgt'
							if "`wgt'"=="wgt" estadd local weights "Population"
							if "`wgt'"=="" estadd local weights "None"
							
					drop zlnpcincome zlnpop
			} // end of income groups	

			esttab a1`wgt' a2`wgt' a3`wgt' a4`wgt' a5`wgt' a6`wgt' a7`wgt' a8`wgt' a9`wgt' a10`wgt' using "${output}/reg`wgt'_shareinRMS_lnpcinc_`y'_byinc.tex", replace /// 
				label  wrap `esttabopts2' ///
				stats(N r2, fmt(%9.0gc 2) labels("Observations" "\$R^2\$")) ///
				coeflabel(zlnpcincome "Ln(CBSA PC Income) (standardized)" cons "Constant") ///
					prehead("{ \begin{tabular}{l*{@M}{c}} \toprule & \multicolumn{10}{c}{Dependent Variable: Share of Non-RMS Store Expenditure on Products Sold in Local RMS Stores}\\" ///
					" \multicolumn{1}{r}{Income Decile:}& 1 & 2 & 3 & 4 & 5 & 6 & 7 & 8 & 9 & 10 \\") 
			
			esttab b1`wgt' b2`wgt' b3`wgt' b4`wgt' b5`wgt' b6`wgt' b7`wgt' b8`wgt' b9`wgt' b10`wgt' using "${output}/reg`wgt'_shareinRMS_lnpcinclnpop_`y'_byinc.tex", replace /// 
				label  wrap `esttabopts2' ///
				stats(N r2, fmt(%9.0gc 2) labels("Observations" "\$R^2\$")) ///
				coeflabel(zlnpcincome "Ln(CBSA PC Income) (standardized)" zlnpop "Ln(CBSA Population) (standardized)"  cons "Constant") ///
				prehead("{ \begin{tabular}{l*{@M}{c}} \toprule & \multicolumn{10}{c}{Dependent Variable: Share of Income Decile's Expenditure on Products Sold in CBSA's RMS Sample}\\" ///
					" \multicolumn{1}{r}{Income Decile:}& 1 & 2 & 3 & 4 & 5 & 6 & 7 & 8 & 9 & 10 \\") 
			
		} // end of weights
	
}
end


*==================================================================================================
*==================================================================================================
** Reference Programs 
*==================================================================================================
*==================================================================================================

*==================================================================================================
capture program drop nhgis_pcincomepop_cbsa
		program define nhgis_pcincomepop_cbsa
		
		syntax [anything]
		
	*2000-2014 ACS data with 2013 CBSA codes (6/25/2019 commit switched from 2010 dicennial census data with 2003 CBSA codes)
	insheet using "${rawNHGIS}/../2014/nhgis0007_ds206_20145_2014_cbsa.csv", names comma clear // downloaded from nhgis.org 06/25/2019
	*	// Dataset: 2010 Dicennial Census, All CBSAs within the United States, per capita income
			// ds175 also contains household counts by buckets as well as median household income
		// uses old 2003 CBSA codes
	rename aba1e001 cbsapopulation
	rename abfie001 cbsapcincome // Per Capita Income in the Past 12 Months (in 2014 Inflation-Adjusted Dollars)
	rename cbsa cbsaname
	rename cbsaa cbsa
	keep cbsaname cbsa cbsapcincome cbsapopulation


end

*==================================================================================================
capture program drop nhgis_pcincomepop_county  // used in dataprep
	program define nhgis_pcincomepop_county
	
	syntax [anything]
	
	insheet using "${rawNHGIS}/../2014/nhgis0008_ds206_20145_2014_county.csv", names comma clear 
		// downloaded from nhgis.org 07/07/2017
		// Dataset: 2006-2012 ACS 5-year estimate, All counties within the United States
	keep name_e statea countya aba1e001 abfie001
	gen county=statea*1000+countya
	drop statea countya
	rename name_e countyname
	rename aba1e001 countypopulation
	rename abfie001 countypcincome // Per Capita Income in the Past 12 Months (in 2014 Inflation-Adjusted Dollars)
		
end			
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	set linesize 200
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*==================================================================================================
