#!/bin/bash
# -N step3_0_estimation
#$ -P real_handbury_team
#$ -q all.q
#$ -l m_mem_free=250G
# note: this is the maximum amount of RAM required by any module, most require only 4GB
#$ -t 1-859:1
#$ -j y

#======================================================================================================
# Specify the set of modules that you are running the estimation for...	
# Note: prior to running this code, you may need to dos2unix the list of arguments (modules). 

pmodule=$( head -n$SGE_TASK_ID /home/real/handbury/NHP_Revision/3_estimation/3a_withinmodule/STATA/Output/fulldim_month_county_prodidchain.txt | tail -n1 )

#======================================================================================================
#======================================================================================================
# Estimation command:

#function  function runmicroblp(env,jobid,modid,nlestimate,checkgradients,objfuntest,origmicro,time,sample,ns,
#		simT,simJ,maxJTsize,maxT,bounds,outsidegoodscutoff,residinstr,
#		alpha0start,alpha1start,gammastart,pcacutoff,gridstartvalues)

#where:
# env = 1 
# jobid - spec identifier
# modid fed in from $pmodule specified above
# nlestimate = 1 to for non-linear estimation
# checkgradients = 1 to check gradients; set to 0 for running estimation
# objfuntest = 1 to get estimates of how long the objective function takes to calculate
# micro = 2 when using micro moments, 0 otherwise
# time = month (or quarter depending on frequency of data being used)
# sample = 3 		% drop any markets where the outside good makes up less than X% of the sales (alternative: 1)
# ns=1             % number of quantiles to use to simulate market income distribution
# if running for simulated data:
	# simT=1000         % number of markets to simulate data for
	# simJ=20           % number of products to simulate data for
# maxJTsize=1000     % maximum product x market matrix size (to also be expanded by household and ns) - to chunk up data for parallel or serial processing - can alter RAM and processing time requirements
# maxT=1000         % maximum number of markets to randomly sample for estimation -- gets moved around to balance identification/RAM requirements
#					% set equal to negative number if no limit requested
# bounds=5   		% implies -N to N bounds for alpha1 and gamma
# outsidegoodscutoff='60'  % input data is for a outside goods cutoff
# residinstr=0        % 1 if residualizing instrument Z2 from Z1; 
						# 2 if running OLS; 
						# 3 if using both residualized and Z2; 
						# 4 if using Z2 but with only observations with Z1
#  alpha0start=2       % default alpha0 starting value
#  alpha1start=0.1     % default alpha1 starting value
#  gammastart=0.1       % default gamma starting value
# pcacutoff=-1.4 		% how much variation we will require is explained by the PCA factors that are used for instruments. if >0, this is the target cumulative percentage explained; if <0, this is -delta to determine the eigenvalue cutoff (compared to average)
						#		if negative, refers to theta for eigenvalue cutoff
# gridstartvalues=1;	% 1: re-run estimation from a grid of starting values if doesn't land on interior estimates

#======================================================================================================

# Main specification:
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,1,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'60',0,2,0.1,0.1,-1.4,1)"

#-------------------------------------------------
# Robustness specifications:

# OG40
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,2,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'40',0,2,0.1,0.1,-1.4,1)"

# OG80
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,3,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'80',0,2,0.1,0.1,-1.4,1)"

# Quarterly data
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,4,$pmodule,1,0,1,2,'quarter',3,1,0,0,1000,1000,5,'60',0,2,0.1,0.1,-1.4,1)"

# Drop markets with less than 1% outside good share (instead of less than 3%)
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,5,$pmodule,1,0,1,2,'month',1,1,0,0,1000,1000,5,'60',0,2,0.1,0.1,-1.4,1)"

# Residualized instrument 
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,6,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'60',1,2,0.1,0.1,-1.4,1)"

#-------------------------------------------------
# Additional specs for instrument checks

# OLS
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,7,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'60',2,2,0.1,0.1,-1.4,1)"

# Both base and residualized instrument
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,8,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'60',3,2,0.1,0.1,-1.4,1)"

# Main instrument with residualized instrument observations
matlab -nosplash -nodisplay -nodesktop -r "runmicroblp(1,9,$pmodule,1,0,1,2,'month',3,1,0,0,1000,1000,5,'60',4,2,0.1,0.1,-1.4,1)"