function runmicroblp(env,jobid,modid,nlestimate,checkgradients,objfuntest,origmicro,time,sample,ns,simT,simJ,maxJTsize,maxT,bounds,outsidegoodscutoff,residinstr,...
    alpha0start,alpha1start,gammastart,pcacutoff,gridstartvalues)  

% NOTE: This code uses ndSparse and knitro. knitromatlab and fsolve cannot handle ndSparse output.	
        
    clear global
    
    global env bounds jobid modid T J B micro origmicro time ns data hhdata draws dist ids deltain OGdata scalingfactors pcacutoff terminal
    
	% set default argument options:
		if (nargin<1), return;	end
        if (nargin<2), jobid=1;	end             % identifier for output
        if (nargin<3), modid=0; end				% module (default (0) = "main" simulated data, other negative numbers are for alternative simulations for monte carlo)
		if (nargin<4), nlestimate=1; end        % whether to conduct non-linear estimation (1) or not (0)
        if (nargin<5), checkgradients=0; end 	% check gradient functions
        if (nargin<6), objfuntest=1; end        % test & times objective function
		if (nargin<7), origmicro=2; end         % estimate micro moments? either 0 or 2 (for 2 micro moments)
		if (nargin<8), time='month'; end		% frequency of data to use 
		if (nargin<9), 
			if modid<=0, sample=0; else sample=3; end
        end                                     % drop any markets where the outside good makes up less than X% of the sales    
		if (nargin<10), ns=50; end              % number of quantiles to use to simulate income distribution from
		if (nargin<11), simT=100; end             % number of markets to simulate data for
		if (nargin<12), simJ=10; end             % number of products to simulate data for
        if (nargin<13), maxJTsize=600; end      % maximum product x market matrix size (to also be expanded by household and ns)
        if (nargin<14), maxT=1000; end           % maximum number of markets to randomly sample for estimation
                                                % set equal to negative number if no limit requested
        if (nargin<15), bounds=5; end           % implies -N to N for alpha1 and gamma, -100 to 100 for deltas
        if (nargin<16), outsidegoodscutoff='60'; end  % input data is for a outside goods cutoff
        if (nargin<17), residinstr=0; end       % 1 if residualizing instrument Z2 from Z1; 
                                                % 2 if running OLS; 3 if using both residualized and Z2
                                                % 4 if using Z2 but with only observations with Z1
        if (nargin<18), alpha0start=2; end        % default alpha0 starting value
        if (nargin<19), alpha1start=0.1; end     % default alpha1 starting value5,
        if (nargin<20), gammastart=0.1; end       % default gamma starting value
        if (nargin<21), pcacutoff=-1.4; end         % cutoff of pca score when selecting IVs
                                                    % if >0, this is the target cumulative percentage explained
                                                    % if <0, this is -delta to determine the eigenvalue cutoff (compared to average)
        if (nargin<22), gridstartvalues=0; end      % run through a grid of starting values if initial starting values don't yield interior estimates

    %% set path
    terminal='/home/real/handbury/NHP_Revision';
		
	% identify/create folder in which to save output files
        outputdir=strcat(terminal,'/3_estimation/MATLAB/OutputData/',num2str(jobid))
        try code=cd(outputdir); 
        catch
            disp 'creating output folder...'
            code=cd(strcat(terminal,'/3_estimation/MATLAB/OutputData/'))
            mkdir(num2str(jobid))
            cd(outputdir)
        end
        cd(code)
		
        disp(['running for module ',num2str(modid)])
        
	% identify/create folder in which to save output files
        outputdir=strcat(terminal,'/3_estimation/MATLAB/OutputData/',num2str(jobid))
        try code=cd(outputdir); 
        catch
            disp 'creating output folder...'
            code=cd(strcat(terminal,'/3_estimation/MATLAB/OutputData/'))
            mkdir(num2str(jobid))
            cd(outputdir)
        end
        cd(code)

%****************************************************************************************************************************
%% Data Work    

disp '% Initial datawork'
       
    [data,hhdata,dist,draws,ids,T,J,B,sumJt,minmaxJt,micro,pca_pctexpl,nz,ncomp]=...
            step0_datawork(env,modid,origmicro,time,sample,ns,simT,simJ,maxJTsize,maxT,...
            outsidegoodscutoff,residinstr);

%% Output stats for computing diagnostics

disp '% Output dimensions for diagnostics'          
    disp 'Dimensions: [modid N L T J B ns micro sumJt minmaxJt pca_pctexpl nz ncomp]' 
        dimensions=[modid size(data.relZ) T J B ns origmicro micro sumJt minmaxJt pca_pctexpl nz ncomp];
        results_ms=dataset({dimensions,'modulenum','N','L','T','J','B','ns','micromoments','microdata','sumJt','minmaxJt','pctexpl','nz','ncomp'})
        code=cd(outputdir)
            export(results_ms,'file',strcat('MATLABdimensions_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
        cd(code)

%% Linear estimation

    if objfuntest==0 || nlestimate==1 
        disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%% Get linear estimates %%%%%%%%%%%%%%%%%%%%%%%%%%%%'       
        [out]=step1_microblp(0,0,0,alpha0start,alpha1start,gammastart,gridstartvalues);
        
        code=cd(outputdir)     
            disp 'Export linear thetas'
                results_kn = [ones(3,1)*modid,[eye(3)],out.theta_lin]
                theta=dataset({results_kn,'modulenum','alpha0','alpha1','gamma','thetahat_lin_m1','thetahat_lin_m2','thetahat_lin_m3','thetahat_lin_m4'}); 
                export(theta,'file',strcat('MATLABthetas_lin_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
            disp 'Export linear betas'
				B=max(data.brandid);
				results_kn = [ones(B,1)*modid,[1:B]',unique(data.rawbrand),out.beta_lin];  
				betas=dataset({results_kn,'modulenum','newbrandid','brandid','thetahat_lin_m1','thetahat_lin_m2','thetahat_lin_m3','thetahat_lin_m4'});
				export(betas,'file',strcat('MATLABbetas_lin_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',',');               
        cd(code)       
    end
    
%% Test non-linear objective function

    if objfuntest>0 && (checkgradients+nlestimate)==0
        disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%% Test objective function %%%%%%%%%%%%%%%%%%%%%%%%%%%%'       
           [out]=step1_microblp(0,0,1,alpha0start,alpha1start,gammastart,gridstartvalues); 
         disp 'Export calculation times'
            code=cd(outputdir)
                pwd
                results_ms=dataset({out.objfuntime,'modulenum','microdata','estgamma','estalpha1','objtime','f'})
                export(results_ms,'file',strcat('MATLABobjfun_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
            cd(code)
    end
        
%% Check gradients

    if checkgradients>0     
        disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%% Check gradients %%%%%%%%%%%%%%%%%%%%%%%%%%%%'       
           [out]=step1_microblp(0,checkgradients,objfuntest,alpha0start,alpha1start,gammastart,gridstartvalues); 
                % nlestimate = 1 if running nl estimation
                % checkgradients = 1 if checking gradients
                % objfuntest = 1 if testing objfunction
        code=cd(outputdir)
            disp 'Export gradient checks'
                results_ms=dataset({out.gradientmatch,'modulenum','microdata','estgamma','estalpha1','microrel','jacobianmatch'})
                export(results_ms,'file',strcat('MATLABgradchecks_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
        cd(code)            
    end
    
%% Run estimation
    if nlestimate>0
         disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Run estimation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
         
            [out]=step1_microblp(nlestimate,0,objfuntest,alpha0start,alpha1start,gammastart,gridstartvalues);
            
        disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Output results %%%%%%%%%%%%%%%%%%%%%%%%%%%%'

           code = cd(outputdir)
            disp 'Export model selection info and nl estimation diagnostics' % - one row for each model
                modelselection = [out.modelstats]; 
                results_ms=dataset({modelselection,'modulenum','microdata','estalpha1','estgamma','microrel','f','exitflag','firstorderopt','iterations','ms_oldexit'});
                export(results_ms,'file',strcat('MATLABmodel_nl_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
           disp 'Export thetas' % - one row for each parameter, one parameter estimate variable for each model
                results_kn = [ones(3,1)*modid,[eye(3)],out.theta_hat,out.theta_stderr];
                theta=dataset({results_kn,'modulenum','alpha0','alpha1','gamma','thetahat_m1','thetahat_m2','thetahat_m3','thetahat_m4','stderror_m1','stderror_m2','stderror_m3','stderror_m4'});
                export(theta,'file',strcat('MATLABthetas_nl_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
           disp 'Export betas' % - one row for each parameter, one parameter estimate variable for each model
                B=max(data.brandid);
                results_kn = [ones(B,1)*modid,[[1:B]'],unique(data.rawbrand),out.beta_hat,out.beta_stderr];
                betas=dataset({results_kn,'modulenum','newbrandid','brandid','thetahat_m1','thetahat_m2','thetahat_m3','thetahat_m4','stderror_m1','stderror_m2','stderror_m3','stderror_m4'});
                export(betas,'file',strcat('MATLABbetas_nl_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
           disp 'Export deltas' % - one row for each parameter, one parameter estimate variable for each model
                data=data(data.OG==0,:);
                results_kn = [ones(size(data.mktid))*modid,data.rawmkt,data.rawprod,data.rawbrand,data.mktid,data.brandid,out.delta];
                deltas=dataset({results_kn,'modulenum','rawmkt','rawprod','rawbrand','mktid','brandid','thetahat_m1','thetahat_m2','thetahat_m3','thetahat_m4'}); %,'stderror_m1','stderror_m2','stderror_m3','stderror_m4'});
                export(deltas,'file',strcat('MATLABdeltas_nl_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Delimiter',','); 
           disp 'Export var-covar matrices'
                Vs = [repmat([ones(3+B,1)*modid,[eye(3); zeros(B,3)],[zeros(3,2); [[1:B]',unique(data.rawbrand)]]],[4 1]),full(out.V)];  
                % variables in out.V: 'estalpha1','estgamma','f',then V matrices
                % variables in Vs: 'modulenum','alpha0','alpha1','gamma','newbrandid','brandid','estalpha1','estgamma','f',then V matrices
                save(strcat('MATLABVs_mod',num2str(modid),'_micro',num2str(origmicro),'_',time,'outside',outsidegoodscutoff,'.txt'),'Vs','-ascii','-double', '-tabs');
            disp 'Export fit stats'
                fitstats_dataset=dataset({[ones(size(out.fitstats,1),1)*modid,full(out.fitstats)],'modulenum','microdata','estalpha1','estgamma','microrel','Jeff','macroJeff','macroJest','N','wgtmatrescale','g2sum','N2','g3sum','N3'});
                    export(fitstats_dataset,'file',strcat('MATLABfitstats_mod',num2str(modid),'.txt'),'Delimiter',','); 
         cd(code)
    end 

    disp 'Code finished.'
end   
