%
% This generates data to estimate JMP with store- and household-level moments.
% 
% SD 10/20/2018: current version only works for new store income distribution
% (instopt=1 to 4) & micro0 (code related to dhhs has not been updated yet)
% runmicroblp(1,0,0,1,0,1,0,'month',5,50,100,10,1000,0,1,5,'','60',0,2,0.1,0.1,'',4,1,-1.4,0,0,0)

function [ds,dist,param,dhhs]=step0a_generatedata(theta,T,J,ns,nhh)
	
	rng('shuffle')
    
    global terminal

% define dimensions of data
    %T=50;      % T=number of markets;
    %ns=1000;   % number of customers in each store;
    %nhh=5;     % number of households we observe in each store;
    %J=25;      % J=number of products;
    B=min(J,10);        % B=number of brands;
	D=1;        % D=number of instruments;
    
% set parameters
    sigma_jt=0.005; % variance of unobserved store-specific product quality - draws from normal with mean zero;
    sigma_j=0.001; % variance of unobserved product quality - draws from normal with mean zero;
    sigmax_jt=1; % scaling parameter for random shocks to prices and instruments;
    a=1; b=0;  %linear transform of prices and instruments (p=a*(p'-min(p'))+b)
    beta=linspace(0, 1, B)'; % unobserved brand quality;
    %iota=linspace(0, 1, T)'; % unobserved market quality;
    param.theta1=[beta; theta(1,:)];
    param.theta2=theta(2:3);

% subscripts and transformation matrices
    [j,t] = ind2sub([J,T],1:T*J);
    b = ceil(j/(J/B))';
    tsf.T = sparse(1:T*J,t,1,T*J,T); % Transformation matrix: tj -> t (an entry = 1 if product tj belongs to market t)
    tsf.J = sparse(1:T*J,j,1,T*J,J); % Transformation matrix: tj -> j
    tsf.B = sparse(1:T*J,b,1,T*J,B); % Transformation matrix: tj -> b
    ds.brandid=b;
    ds.prodid=j';
    ds.mktid=t'; 
    xiorig=tsf.J*randn(J,1)*sigma_j+rand(J*T,1)*sigma_jt; % unobserved market-specific product quality shock;

 % drop 70% of market-product observations (to reflect low overlap in products between markets)
        k=0.5
        r = rand([1 T*J]);
        j=j(r>k);
        b=b(r>k);
        t=t(r>k);
        tsf.T=tsf.T(r>k,:);
        tsf.J=tsf.J(r>k,:);
        tsf.B=tsf.B(r>k,:);
        keep=(r>k);
        ds.brandid=ds.brandid(find(keep'),:);
        ds.prodid=ds.prodid(find(keep'),:);
        ds.mktid=ds.mktid(find(keep'),:);
        xi = xiorig(find(keep'),:);
        unique([tsf.B*beta b j'],'rows')
        sumJt = size(ds.prodid,1);
       
% generate characteristics by product-market
   %    sorted by market then by brand then by product

    delta = xi+tsf.B*beta; %+tsf.T*iota;
    u1=gamrnd(2,2,[sumJt 1])*sigmax_jt; % noise for prices (gamma distribution: thinner tail than log normal)
    u2=rand(sumJt,D)*sigmax_jt; % noise for instruments;
    ds.X = u1 +  delta - min(delta); % ** prices; 
    ds.X = a*ds.X + b;
    ds.Z = u2 + repmat(u1,[1 D]); % ** price instruments; 
    ds.Z = bsxfun(@plus,a*ds.Z, b);
    ds.x=log(ds.X);
    ds.z=log(ds.Z);
    
% generate distributions to pull customer/household characteristics from
    
%{
% old code: 
    dist.mktid=[1:T]';
    dist.meanhhinc = normrnd(log(37500),1,[T,1]);
    dist.vhhinc = unifrnd(0.3,0.7,[T,1]);
    dist.meanlninc = normrnd(log(37500),1,[T,1]);
    dist.vlninc = unifrnd(0.1,0.5,[T,1]);
    dist.a = lognrnd(log(4),1,[T,1]);
    dist.b = lognrnd(log(50000),1,[T,1]);
    dist.p = lognrnd(log(0.4),1,[T,1]);
    dist.value = ones(size(dist.meanhhinc));

    dist=struct2dataset(dist);

%}  

% SD 10.18.2018: load existing store income distribution data
    time = 'month';
    if exist(strcat('dist_raw_',time,'.mat'))==2, % & 1==2,  
        load(strcat('dist_raw_',time,'.mat'))
        disp 'load existing'
    else
        dist_raw=dataset('File', strcat(terminal,'/1_dataprep/STATAOutput/dataMatLab_incbrkt_nocd/storeincdist_logincpctiles_', time, '_nocd.csv'),'Delimiter',',');
        % one observation for each of T markets
        % variables: 
        % dist.store_code_inc  
        % dist.weight`i' & avginc`i' for i=1 to 50
        % dist.`freq' (only month for now)
        % dist.mktid: market identifiers (not 1 through T) matches those from store data;
        % dist.year
        % dist.value: sales
        dist_raw.Properties.VarNames{size(dist_raw,2)-3} = 'freq'; 
        dist_raw = dist_raw((strcmp(dist_raw.freq,'2012m6')),:); % keep one observation per store
        dist_raw = dist_raw(isnan(dist_raw.value)==0,:); % drop markets with missing sales value
        save(strcat('dist_raw_',time,'.mat'),'dist_raw')
    end
    
   
    dist = datasample(dist_raw,T,'Replace',false);
    dist.mktid=[1:T]';
    dist.value = ones(T,1);
    
    
%{
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Store-Level Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%}
    
% generate store customer characteristics    
%       sorted by household id, market id, then product id;
% Generate market income and draw incomes at random to generate market shares


% old code to generate data for introption=0
    grid = linspace(-3,3,ns);
    density = normpdf(grid,0,1);
    w = density/sum(density);
    %{
    lninc = bsxfun(@plus,dist.meanlninc, bsxfun(@times,dist.vlninc,grid));
    lninc = tsf.T*lninc;
    lnincbar=mean(mean(lninc)); %mean national income
    lninc = lninc - lnincbar;    
        % market-customer incomes (one obs per market-specific customer draw);
            %       sorted by customer id then market id;
%}

%
    dist_ns = 50
        varlist1 = genvarname(repmat({'avginc'},1, dist_ns+1));
        lninc_raw = double(dist(:,[varlist1(2:dist_ns+1)]));
        
        varlist2 = genvarname(repmat({'weight'},1, dist_ns+1));
        w_raw = double(dist(1,[varlist2(2:dist_ns+1)]));
        
        
        lninc = zeros(T,ns);
        for ind = 1:T
                lninc(ind,:) = randsample(lninc_raw(ind,:), ns, true, w_raw);
        end

        lninc = tsf.T*lninc;
        lnincbar=log(mean(mean((exp(lninc)))));
        lninc = lninc - lnincbar; 

%
    %save('-v7.3',strcat('test_sim_data.mat'));

% Income-specific coefficients
    alpha_i = theta(1)+theta(2)*lninc;
    gamma_i = 1+theta(3)*lninc;
    if min(alpha_i)<0; error('negative alpha_i'); end
    if min(gamma_i)<0; error('negative gamma_i'); end

% Utility & market shares
    utils = bsxfun(@times,alpha_i,-ds.x)+bsxfun(@times,alpha_i.*gamma_i,delta);
    utils = exp(utils);
    denom = tsf.T*(tsf.T'*utils);
    sijt = utils./denom;
    ds.sjt = sum(bsxfun(@times,w,sijt),2);
    ds.vjt = ds.sjt;
    if max(isnan(ds.sjt))==1 || max(ds.sjt==0)==1, disp 'non-existent or zero shares'; return; end
    
    ds=struct2dataset(ds);
    
%{
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Household-Level Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%}
   % SD 10/20/2018 not simulating for micro2 for now
    dhhs.mktid=0; dhhs.hhid=0; dhhs.selection=0; dhhs.lninc=0; dhhs.units=0; dhhs.w=0;
    dhhs = struct2dataset(dhhs);
   
% generate household characteristics
%{
   % dhhs.lninc = reshape(repmat(dist.meanlninc,[1,nhh])+repmat(dist.vlninc,[1 nhh]).*randn(T,nhh),[nhh*T,1]);    
    unif = rand(T,nhh);  b=repmat(dist.b,[1 nhh]);  p=repmat(dist.p,[1 nhh]);  a=repmat(dist.a,[1 nhh]);
    dhhs.lninc = log(b.*(unif.^(-1./p)-1).^(-1./a)); % T x nhh
        % market-customer incomes (one obs per market-specific customer draw);
        %       sorted by customer id then market id;
    dhhs.lninc = dhhs.lninc - lnincbar; %demean from national income
    
% identify product purchased by each household
    lninc=permute(dhhs.lninc,[2 3 1]); % nhh x 1 x T 
    alpha_i=theta(1)+theta(2)*lninc;
    gamma_i=1+theta(3)*lninc;
    brandidmat=permute(ndSparse.build([ds.prodid ds.mktid],beta(ds.brandid)),[3 1 2]); % 1 x J x T
    xmat=permute(ndSparse.build([ds.prodid ds.mktid],ds.x),[3 1 2]); % 1 x J x T
    subsvec = (ds.mktid-1).*max(ds.prodid,1)+1+ds.prodid;
    ximat=permute(ndSparse.build([ds.prodid ds.mktid],xi),[3 1 2]); % 1 x J x T
    utility = bsxfun(@plus,ximat,bsxfun(@times,alpha_i.*gamma_i,brandidmat)-bsxfun(@times,alpha_i,xmat));  % nhh x J x T
    hhsubs = [reshape(repmat([1:nhh],sumJt,1),[],1) repmat([ds.prodid ds.mktid],nhh,1)];
    utility = utility + ndSparse.build(hhsubs,random('gev',0,1,0,sumJt*nhh,1));   % nhh x J x T
    [~,prodidmax] = max(permute(utility,[3 1 2]),[],3);  % T x nhh x J --> T x nhh 
    dhhs.selection=reshape(sparse2d(prodidmax)',nhh*T,1); 
        % nhh*T ordered by market then by household (all of the householdata in mkt 1, all in mkt 2, etc.)
    prodbrands = accumarray(ds.prodid, ds.brandid, [], @mean, 0);
    dhhs.brandselection=prodbrands(dhhs.selection,1);
    
% -->  household market subscripts
    dhhs.mktid = sortrows(repmat([1:T]',[nhh 1]),1);
    dhhs.hhid = repmat([1:nhh]',[T 1]);
    dhhs.lninc = reshape(dhhs.lninc,[],1); % T x nhh --> T*nhh x 1
    dhhs.w =  ones(nhh*T,1)./(nhh*T); %household transaction weights (assume one transaction per household)
    dhhs=struct2dataset(dhhs);
 %}  
    
end