function [data,OGdata,hhdata,dist,micro]=step0b_alignidentifiers(data,hhdata,dist,micro)

	%generate market and intermediate product identifiers (1:T and 1:J)
		data.rawmkt=data.mktid;
		[~,~,data.mktid]=unique([data.rawmkt],'rows');
	   data.rawprod=data.prodid;
		[~,~,data.prodidint]=unique([data.rawprod],'rows');
	   data.rawbrand=data.brandid;
		[~,~,data.brandidint]=unique([data.rawbrand],'rows');

    % drop products that only appear twice in the subsample
        dropprod=(accumarray(data.prodidint,ones(size(data.prodid)))<3);
        disp(['Products sold in less than 3 markets: ' num2str(sum(dropprod==1)) ' out of ' num2str(size(dropprod,1)) ' total'])
        data=data(dropprod(data.prodidint)==0,:);       
        [~,~,data.prodidint]=unique([data.rawprod],'rows');
        
    %drop markets that don't sell at least one outside good
        dropmkt=(accumarray(data.mktid,data.OG==1)==0);
        disp(['Markets without an/the outside good: ' num2str(sum(dropmkt==1)) ' out of ' num2str(size(dropmkt,1)) ' total'])
        data=data(dropmkt(data.mktid)==0,:);       
        [~,~,data.mktid]=unique([data.rawmkt],'rows');
        
	%make sure that market product count is greater than one (excluding base or outside product)
		tempOGdata=data(data.OG==1,:);
        Jt=accumarray(data.mktid,ones(size(data.mktid)))-accumarray(tempOGdata.mktid,ones(size(tempOGdata.mktid)));
		i=1;
        while i<2,
            dropmkt=(Jt<i+1);
            disp(['Markets with fewer than ' num2str(i) ' inside goods: ' num2str(sum(dropmkt>0)) ' out of ' num2str(size(dropmkt,1)) ' total'])
            i=i+1;
        end
		data=data(dropmkt(data.mktid)==0,:);       
		[~,~,data.mktid]=unique([data.rawmkt],'rows');
       
	%only keep income distribution and outside good data for those markets
		[rawmkts,~,data.mktid]=unique([data.rawmkt],'rows');
		dist.rawmkt=dist.mktid;
		mkts=dataset({rawmkts,'rawmkt'},{[1:size(rawmkts,1)]','mktid'});
			%checked: mktid is simply an index for the rawmkts included in data
        dist.mktid=[];
		dist=join(mkts,dist,'rawmkt');

	%generate product id (1:J), recasting productids of outside good observations to take a single low value
		data.prodid=[];
		data.prodidint(data.OG==1)=min(data.prodidint)-1;
		[~,~,data.prodid]=unique([data.prodidint],'rows');

	%generate brand id (1:B) - recasting the outside good products into brand 1, with quality normalized to zero
		data.brandidint(data.OG==1)=0;
		[~,~,data.brandid]=unique([data.brandidint],'rows');

	%sort
		data=sortrows(data,{'mktid' 'prodid'});

		disp(['Total markets remaining after data cleaning: ' num2str(max(data.mktid))])

%% Pull out and accumulate relevant outside good data then append back onto full dataset
        tempOGdata=data(data.OG==1,:);
        
    % markets...
        OGdata.mktid=accumarray(tempOGdata.mktid,tempOGdata.mktid)./accumarray(tempOGdata.mktid,ones(size(tempOGdata.mktid)));	

    % data
        OGdata.vjt=accumarray(tempOGdata.mktid,tempOGdata.vjt);
        OGdata.sjt=accumarray(tempOGdata.mktid,tempOGdata.sjt);
        OGdata.X=accumarray(tempOGdata.mktid,tempOGdata.sjt.*tempOGdata.X)./OGdata.sjt;
		OGdata.Z=ones(size(OGdata.X,1),size(data.Z,2));
		for z=1:size(data.Z,2)
			OGdata.Z(:,z)=accumarray(tempOGdata.mktid,tempOGdata.sjt.*tempOGdata.Z(:,z))./OGdata.sjt;
        end
        OGdata.x=log(OGdata.X);
		OGdata.z=log(OGdata.Z);

    % brands and products
		OGdata.brandid=tempOGdata.brandid(1:size(OGdata.x,1),:);
		OGdata.rawbrand(1:size(OGdata.x,1),:)=-99;
        OGdata.prodid=tempOGdata.prodid(1:size(OGdata.x,1),:);
        OGdata.rawprod(1:size(OGdata.x,1),:)=-99;
        OGdata.OG(1:size(OGdata.x,1),:)=1;
		OGdata=struct2dataset(OGdata);
        
    % merge in raw markets
        OGdata=join(mkts,OGdata,'mktid');
        
    % drop OG data from main dataset, drop variables not in accumulated OG data, and append with accumulated dataset
        data=data(data.OG==0,:);
		data.prodidint=[]; data.brandidint=[]; %
        
 		data=[OGdata; data];
		
	%sort
		data=sortrows(data,{'mktid' 'prodid'});

%% Household data...
    if micro>0,
        % hhdata.mktid: market identifiers (not 1 through T) matches those from store data;
        % hhdata.hhid: convert to be household subscripts (1...nhh)
        % hhdata.selection: product selected - matches raw product identifiers (not 1 through J) from store data;
        % hhdata.lninc: household income
        % hhdata.units: number of units purchased by a household)
        % hhdata.w: hhdata.units/sum(hhdata.units)
        
            hhdata = sortrows(hhdata,{'mktid','hhid'});
            hhdata.rawhhid=hhdata.hhid;
            hhdata.hhid=[1:size(hhdata,1)]'; 
                % treating each HH purchase as unique
            hhdata.rawmkt=hhdata.mktid;
            hhdata.mktid=[];
            hhdata.rawprod=hhdata.selection;
            hhdata.selection=[];
            
    %drop households buying the outside good...
            fulldata = [data(data.OG==0,{'rawmkt' 'mktid' 'rawprod' 'prodid' 'brandid'})];
            mktprods=dataset({unique([fulldata.rawmkt fulldata.mktid fulldata.rawprod fulldata.prodid fulldata.brandid],'rows'),...
                                'rawmkt','mktid','rawprod','prodid','brandid'});

            hhdata=join(mktprods,hhdata,'Type','inner','MergeKeys',true);
            hhdata.brandselection = hhdata.brandid;
            hhdata.brandid = [];
            hhdata.selection = hhdata.prodid;
            hhdata.prodid = [];
            if size(hhdata,1)==0, 
                    disp '...insufficient households buying remaining products...'
                    micro=0
            end
                
    end
end
        