function out=step3b_solvefordeltas(mktdelta0,theta,...
            mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,...
            nargs,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend,tolerance)

   % assign linear solution as default value when alpha1 and gamma are both zero
		fdeltat=[]; contractiont=[]; out.error = 0;
    
        % quasi-newton algorithm when alpha1 or gamma are non-zero (using constrained optimization)
        	ub=100*ones(size(mktdelta0));
            lb=-100*ones(size(mktdelta0));
            
            confunc = @(deltat) confungrad(deltat,theta,...
                mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,nargs,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend); 
            
            deltahessian = @(deltat,lambda) deltahess(lambda,deltat,theta,...
                mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend);
       
         op = optimset('Display','none', 'GradObj','on','GradConstr','on','Algorithm','interior-point',...
                    'MaxIter',100,'MaxFunEvals',200,...
					'TolFun',tolerance,'SubproblemAlgorithm','cg','DerivativeCheck','off',...
                    'Hessian','user-supplied','HessFcn',deltahessian);
                
       try 
            [out.deltat,~,exitflag]=fmincon(@objfungrad,mktdelta0,[],[],[],[],lb,ub,confunc,op);
            if exitflag<0, out.error = 1; end	
        catch me
            out.error = 1; 
            me
            theta
        end
                   
        if out.error==1,
            disp('unable to solve for delta - set to starting value')
                out.deltat = mktdelta0;
        end    
		
   end   % EOC
        
%functions for objective and nonlcon
    function [f,gradf] = objfungrad(deltat)
        f=0;
        if nargout>1,
            gradf=zeros(size(deltat));
        end
    end
    
    function [c,ceq,DC,DCeq]=confungrad(deltat,theta,...
			mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,nargs,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend)

		c=[]; DC=[]; 
		out=step3c_cons_s_par(deltat,theta,...
			mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,2,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend);
                % note: nargs set to 1 so as not to calculate dFdtheta but only dFddelta
		ceq=out.con_s;
		DCeq=out.dFdmktdelta'; 

    end
    
    function out=deltahess(lambda,deltat,theta,...
			mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend)

		c=[]; DC=[]; 
        mktlambda = lambda.eqnonlin;
        d2FdX2=step3d_d2Fddelta2_par(mktlambda,deltat,theta,...
                         mktdata,mktidssubs,mktidssubsmkt,mktdrawslninc,mktdrawsw,esta1,estg,sumJt,ntheta,ns,minT,maxT,mktstart,mktend);

        out=full(d2FdX2.d2Fddelta2_sub);
		
    end
          