*=================================================================================================
*** 1_estimatessave
*** 	this do file formats estimates from MATLAB
*=================================================================================================

	args source pmodule year freq spec micro outsidegoodscutoff estdir

	if "`source'"=="" {
		local source = "matlab"
		local pmodule=1034 
		local year=2012
		local freq= "month" 
		local spec "_nl" 
		local micro = 2 
		local outsidegoodscutoff ="60" 
		local estdir = 1 // name of the directory that stores within-module estimates
	}
	
			
	foreach arg in source pmodule year freq spec micro outsidegoodscutoff estdir {
		global `arg' "``arg''"
	}

*===========================================================================================
*** Directory Set-up
	
	do ../../SetFilePaths.do
	
	global currentstep "$terminal/3_estimation/STATA"

* Set-up standard directories	
	global logs "$currentstep/Logs"
	global data "$currentstep/Data"	
	global output "$currentstep/Output"

* directory for within-module estimation result (inputs)
	global matlabestimates "$terminal/3_estimation/MATLAB/OutputData"

* directory for RMS data
	global storedata "${terminal/1_dataprep/STATAOutput/${basedir}/storecsv_${freq}/${year}/outsidedef0/" 

* directory for household moment data
	global hhdata "$terminal/1_dataprep/STATAData/dataMatLab_cbsa/"

* directory for within-module estimation result
	global estimatesoutput "${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"

	cap mkdir ${data}/estimates
	cap mkdir ${data}/estimates/${freq}
	cap mkdir ${data}/estimates/${freq}/${source}estimates	
	cap mkdir ${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}
	cap mkdir ${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}
	cap mkdir ${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module
	cap mkdir ${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}

*===========================================================================================
*===========================================================================================
*===========================================================================================
**** Main Program to Import Data 


capture program drop main
program define main 
	
if 1==1 {
		
	*import and save estimates
		importestimates, spec(${spec}) micro(${micro}) jobid(${estdir}) source("${source}") outsidegoodscutoff(${outsidegoodscutoff}) freq("${freq}") 
		gen outsidegoodscutoff = ${outsidegoodscutoff}
		save ${estimatesoutput}/withinestimates_module${pmodule}.dta, replace
				
	*for non-linear models, calculate betas (from deltas)
		if "${spec}"=="_nl" {
			use ${estimatesoutput}/withinestimates_module${pmodule}.dta, clear
			sum b_delta
			if `r(N)'>0 {
					disp "calculate betas from deltas for nl estimates"
					calcbetas
					save ${estimatesoutput}/withinestimates_betas_module${pmodule}.dta, replace
						// to be used in 4_postestimationanalysis/2_moduleindex_modbymod - at the model, brandid level
			}	
		}
	*for non-linear models, import data dimensions
		if "${spec}"=="_nl" {
			
			disp "import dimensions of data for nl estimates"
				quietly import delimited using "${matlabestimates}/${estdir}/MATLABdimensions_mod${pmodule}_micro${micro}_${freq}outside${outsidegoodscutoff}.txt", clear
				drop modulenum
				gen product_module_code=${pmodule}
				gen jobid=${estdir}
				expand 4
				gen model=_n
				save `dimensions', replace
						// contains one obs per module and model and data for n l t j b ns micromoments microdata sumjt minmaxjt pca_pctexpl nz ncomp
		}
	}
	
	disp "merge dimensions of data with model stats for selection analysis"
		use ${estimatesoutput}/withinestimates_module${pmodule}.dta, clear
		capture sum jeff
		if _rc==0 keep product_module_code model exitflag f nltime nlknitro firstorderopt microrel jeff macrojeff macrojest n wgtmatrescale g2sum n2 g3sum n3
		else keep product_module_code model exitflag f nltime nlknitro firstorderopt 
		drop if f==.
		bys product_module_code model: keep if _n==1
		merge 1:1 product_module_code model using `dimensions', nogen
		save  ${estimatesoutput}/withinestimates_modelselection_module${pmodule}.dta, replace
		
}	
end

*===========================================================================================
**** Code to Import Estimates

capture program drop importestimates
program define importestimates 
	
	syntax [anything], spec(string) micro(integer) jobid(integer) source(string) [cbsa(string)] outsidegoodscutoff(integer) freq(string)

if 1==1 {
	
	di "*load raw data (at market-product level) to get base module (necessary for beta estimation)"
		insheet using "${storedata}/outside`outsidegoodscutoff'/`cbsa'/store_module${pmodule}_data.csv", clear
		
		if "`spec'"=="_nl" {
			keep mktid prodid brandid outsidegoods vjt
		}
		else if "`spec'"=="_lin" {
			keep brandid
			bys brandid: keep if _n==1
		}
	tempfile tempraw
	save `tempraw', replace
	
	di "*prepare estimation results (beta, alpha0, alpha1, and gamma)"
		importresults_matlab, spec(`spec') micro(`micro') jobid(`jobid') outsidegoodscutoff(`outsidegoodscutoff') freq("`freq'")
		drop modulenum

	di "*merge in data with outside good to identify markets without the base product"
		if "`spec'"=="_nl" {
			rename brandid matlabbrandid
			rename raw* *id
			merge m:1 mktid brandid prodid using `tempraw'
			bys mktid: egen maxmerge=max(_merge)
			tab maxmerge 
				// maxmerge==1 if mkts didn't have the base product
				// maxmerge==2 if markets in raw data weren't sampled for estimation
			drop if maxmerge==2
			
			di "*identify a base product: common (non-outside good) product in the estimation sample for in max number of markets, keep markets that sell the base product"
				bys prodid outsidegoods: gen nmkts=_N
				bys prodid outsidegoods: egen totalvalue=total(vjt)
				sum nmkts if outsidegoods==0
				local maxmkts=`r(max)'
				tab prodid nmkts if nmkts==`maxmkts' & outsidegoods==0
				quietly sum totalvalue if nmkt==`maxmkts' & outsidegoods==0 
				tab prodid totalvalue if nmkt==`maxmkts' & outsidegoods==0 & totalvalue==`r(max)'
				assert `r(r)'==1
				gsort outsidegoods -nmkts -totalvalue
				bys outsidegoods: gen temp=(_n==1 & outsidegoods==0)
				bys prodid: egen baseprod=max(temp)
				tab prodid if baseprod==1
				gsort mktid -baseprod
				by mktid: egen nobaseprod=max(baseprod)
				replace nobaseprod=1-nobaseprod
				tab nobaseprod
				drop totalvalue vjt

			di "*identify outside good products from raw estimation data"
			*for markets that were sampled for estimation, identify outside goods
				tab _merge outsidegoods
				gen outside = (_merge == 2 | matlabbrandid==0)
		}
		else if "`spec'"=="_lin" {
			merge 1:1 brandid using `tempraw' 
			gen outside = (_merge == 2 | brandid==0)
		}
		keep if _m==3 | outside==1
		drop _merge maxmerge

	di "*drop data for markets that don't have a base product"
		keep if nobaseprod==0
		
	di "*fill-in estimates for outside goods - both intentional and unintentional, due to collinearity"
		fillinestimates, spec(`spec')  
		gen product_module_code=${pmodule}
		
	if "`spec'"=="_nl" {		
		di "*difference delta estimates from base product delta estimates"
			preserve
				keep if baseprod==1
				rename b_delta b_deltabase
				keep model mktid prodid b_deltabase
				rename prodid baseprodid
				tempfile tempbase
				save `tempbase'
			restore
			merge m:1 model mktid using `tempbase', nogen
			replace b_delta=b_delta-b_deltabase
			drop b_deltabase

	}

}
	
end

*===========================================================================================
** Sub-program to Import Estimation Results from MATLAB

capture program drop importresults_matlab
program define importresults_matlab

	syntax [anything], spec(string) micro(integer) jobid(integer) [cbsa(string)] outsidegoodscutoff(integer) freq(string)

if 1==1 {

	if "`spec'"=="_nl" local quality="delta"
	else local quality="beta"
	
	clear
	tempfile temp
	disp "module ${pmodule} - spec `spec' - micro `micro'"
		disp "import results..."
		foreach estimatetype in thetas `quality's {
			if "`estimatetype'"!="deltas" local incse="se*"
			else local incse=""
				sub_importresults, filename("MATLAB`estimatetype'`spec'_mod${pmodule}_micro`micro'_`freq'outside`outsidegoodscutoff'") spec("`spec'") jobid(`jobid')
				foreach v in brandid alpha0 alpha1 gamma rawmkt rawprod rawbrand {
					capture gen `v' = . // brandid only needs to be created for thetas, other parameters for betas
							    // rawmkt rawprod rawbrand brandid only available for deltas
				}	 
				gen parm=""
				foreach v in alpha0 alpha1 gamma {
					replace parm = "`v'" if `v'==1
				}
				replace parm = "`quality'" if parm==""
				cap rename thetahat_m* thetahat*_
				cap rename stderror_m* se*_
				keep modulenum parm rawmkt rawprod rawbrand brandid thetahat* `incse'
				reshape wide thetahat*_ `incse', i(modulenum rawmkt rawprod rawbrand brandid) j(parm) string
				rename thetahat* b* 
				if "`estimatetype'"=="thetas" quietly save `temp', replace
				else if "`estimatetype'"=="`quality's" merge m:1 modulenum using `temp', nogen
		}
		tempfile tempest
		save `tempest', replace
		
	if "`spec'"=="_nl" {
			
		disp "import and merge in  model stats for non-linear models..."
			sub_importresults, filename("MATLABmodel`spec'_mod${pmodule}_micro`micro'_`freq'outside`outsidegoodscutoff'") spec("`spec'") jobid(`jobid')
			keep modulenum microdata estgamma estalpha1 exitflag f nltime nlknitro firstorderopt
			tempfile tempmodel
			save `tempmodel', replace
			
			// import and merge in other fit stats
				capture sub_importresults, filename("MATLABfitstats_mod${pmodule}") spec("`spec'") jobid(`jobid')
				if _rc==0 {
					merge 1:1 modulenum microdata estalpha1 estgamma using `tempmodel', nogen
					local extravars "microrel jeff macrojeff macrojest n wgtmatrescale g2sum g2n g3sum g3n"
					rename n2 g2n 
					rename n3 g3n
				}	
			
			// specify model
				gen model=1 if estalpha1+estgamma==0
				replace model=2 if estalpha1==1 & estgamma==0
				replace model=3 if estalpha1==0 & estgamma==1
				replace model=4 if estalpha1+estgamma==2
				drop estgamma estalpha1 
			
			reshape wide exitflag f nltime nlknitro firstorderopt `extravars', i(modulenum microdata) j(model 1 2 3 4) 
				
			merge 1:m modulenum using `tempest', nogen
	}
}	
end


*===========================================================================================
** Sub-sub-program to import Matlab estimates and model results

capture program drop sub_importresults
program define sub_importresults
	
	syntax [anything], filename(string) spec(string) jobid(integer)

if 1==1 {
	
	disp "${matlabestimates}/`jobid'/`filename'.txt"
	quietly import delimited using ${matlabestimates}/`jobid'/`filename'.txt, clear
		// variables: modulenum, alpha0 alpha1 gamma (or brandid), thetahat's, 

	unab estlist: *
	foreach v in `estlist' {
		capture replace `v'="" if `v'=="NaN" | `v'=="-Inf" | `v'=="Inf"
		capture replace `v'=substr(`v',1,strpos(`v',"+")-1) if strpos(`v',"i")!=0
		quietly destring `v', replace
	}

}
end

*===========================================================================================
** Sub-program to clean estimation results

capture program drop fillinestimates
program define fillinestimates
		
syntax [anything], spec(string)


if 1==1 {
	
	if "`spec'"=="_nl" {
		local quality="delta"
		local statlist="exitflag* f* nltime* nlknitro* firstorderopt*"
		local statlist2="exitflag f nltime nlknitro firstorderopt"
		capture sum jeff1
		if _rc==0 {
			local statlist="`statlist' microrel* jeff* macrojeff* macrojest* n* wgtmatrescale* g2sum* g2n* g3sum* g3n*"
			local statlist2="`statlist2' microrel jeff macrojeff macrojest n wgtmatrescale g2sum g2n g3sum g3n"
		}
	}
	else local quality="beta"
	
	di "...reshape long - stacking estimates for each model"
		forvalues model=1/4 {
			rename b`model'_* b_*_`model'
			rename se`model'_* se_*_`model'
		}
		if "`spec'"== "_nl" {
			keep b_*_* se_*_* mktid prodid brandid outside baseprod `statlist'
			reshape long b_`quality'_ b_alpha0_ b_alpha1_ b_gamma_ se_alpha0_ se_alpha1_ se_gamma_ `statlist2', i(mktid prodid brandid outside baseprod) j(model 1 2 3 4)
		}
		else if "`spec'"=="_lin" | "`spec'"=="_hh" {
			keep b_*_* se_*_* brandid outside 
			reshape long b_beta_ b_alpha0_ b_alpha1_ b_gamma_ se_alpha0_ se_alpha1_ se_gamma_, i(brandid outside) j(model 1 2 3 4)
		}
		rename b_*_ b_* 
		rename se_*_ se_*
		capture rename (g2n g3n) (n2 n3)
		
	if "`spec'"=="_nl" {
		disp "drop estimates for models that didn't converge or hit bounds"
			tab exitflag
			gen dropest=0
				replace dropest=1 if exitflag<=-300
				replace dropest=1 if (exitflag<=-200 & exitflag>-300 & firstorderopt>1e-8)
				replace dropest=1 if (exitflag<-100 & exitflag>-200)
				*	(see https://www.artelys.com/tools/knitro_doc/3_referenceManual/knitromatlabReference.html#note-on-exit-flags) for details on the flags
				replace dropest=1 if (b_alpha0>=29.5 & b_alpha0!=.) | (b_alpha0<=0.06 & b_alpha0!=.) | (abs(b_alpha1)>=4.95 & b_alpha1!=.) | (abs(b_gamma)>=4.95 & b_gamma!=.)
	}
	if "`spec'"=="_hh" {
		disp "drop estimates models that hit +-100 bounds in alpha1, gamma or betas"
			gen dropest=0
			replace dropest=1 if abs(b_alpha1)==100 | abs(b_gamma)==100 | abs(b_beta)==100
			
	}
	
	* re-set estimates hitting bounds or errors to missing
	tab dropest model
	unab estlist: b_* se_*
	foreach v in `estlist' {
		replace `v'=. if dropest==1
	}
	
	
	di "...assign `quality' = 0 for outside good brands"
		replace b_`quality' = 0 if outside==1
		
	di "...spread out module-level results to outside good brands"
		tab outside
		foreach sub in b se {
			forvalues model = 1/4 { 
				foreach v in alpha0 alpha1 gamma {
					quietly count if `sub'_`v' == . & model==`model' & dropest==0
					if `r(N)'>0 {
						quietly count if `sub'_`v' != . & model==`model'
						if `r(N)'>0 {
							quietly sum `sub'_`v' if model==`model'
							replace `sub'_`v'=`r(mean)' if `sub'_`v'==. & model==`model'
						}
						else replace `sub'_`v'=0 if `sub'_`v'==. & model==`model'
					}
				} 
			}
		}
}
end


*===========================================================================================
*===========================================================================================
*===========================================================================================
** Sub-program to calculate betas

capture program drop calcbetas
program define calcbetas
	
	syntax [anything]

if 1==1 {


	di "*Take mean relative (to base product) delta by brand"
		keep if b_delta!=. 
		
		*find most commonly occuring brand delta is estimated for across markets
		preserve
			keep if baseprod==0 & outside==0
			isid model mktid brandid
			keep model brandid
			bys model brandid: gen n=_N
			gsort model -n
			by model: keep if _n==1
			rename brandid commonbrandid
			drop n
			tempfile commonbrands
			save `commonbrands', replace
		restore
		*normalize delta to common brand across markets (rather than outside product)
			keep mktid product_module_code model brandid *_alpha0 *_alpha1 *_gamma *_delta
			merge m:1 model using `commonbrands', nogen
			gen commonbrand=(brandid==commonbrandid)
			gen commondelta=commonbrand*b_delta
			gsort model mktid -commonbrand
			by model mktid: gen contcommonbrand=sum(commonbrand)
			by model mktid: replace commondelta=sum(commondelta)
			gen b_deltadiff=b_delta-commondelta if contcommonbrand>0
			gen b_deltass=b_delta if contcommonbrand>0
		*beta = mean delta and differenced delta:
			sort model brandid
			by model brandid: gen sumb_delta=sum(b_delta)
			by model brandid: gen n=_N
			gen b_beta=sumb_delta/n
			by model brandid: gen sumb_deltadiff=sum(b_deltadiff)
			by model brandid: gen sumb_deltass=sum(b_deltass)
			by model brandid: gen ndiff=sum(contcommonbrand)
			gen b_betadiff=sumb_deltadiff/ndiff
			gen b_betass=sumb_deltass/ndiff
			by model: egen nmktswithcommon=total(commonbrand)
			by model: egen nmkts=nvals(mktid)
			by model brandid: keep if _n==_N
			drop *b_delta* contcommonbrand commondelta mktid

} // end collapse
			
end


*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	global logsuffix "`cdate'_`ctime'"
	log using "${logs}/1_estimatessave_mod${pmodule}_${logsuffix}.txt", replace text
	main
	cap log close

*==================================================================================================
*==================================================================================================
