*=================================================================================================
*** 2_estimatesoutput.do
*** 	formats and outputs plots and tables of within-module parameter estimates
*===========================================================================================

	args source freq spec micro outsidegoodscutoff estdir
	

	if "`source'"=="" { 
		local source = "matlab"
		local freq="month" 
		local spec ="_nl" 
		local micro =2 
		local outsidegoodscutoff =60 
		local estdir = "1" 
	}
	
	foreach arg in source freq spec micro outsidegoodscutoff estdir {
		global `arg' "``arg''"
	}
*===========================================================================================
*** Directory Set-up
	
	do ../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	cd ${dir}/..
	global currentsteprepo: pwd
	cd ${dir}
	global currentstep "$terminal/3_estimation"

*Set-up standard directories	
	global logs "$currentstep/STATA/Logs"
	global data "$currentstep/STATA/Data"	
	global repooutput "${currentsteprepo}/RepoOutput"
	capture mkdir "${repooutput}/${freq}_micro${micro}${spec}/"
	capture mkdir "${repooutput}/${freq}_micro${micro}${spec}/${estdir}"
	capture mkdir "${repooutput}/${freq}_micro${micro}${spec}/${estdir}/Plots"
	global output "${repooutput}/${freq}_micro${micro}${spec}/${estdir}"
	
*Set-up relevant directories for this step
	global estimates "${currentstep}/MATLAB/OutputData/" 
	
*Set-up relevant directories for this step
	global RMSmkts "${step1data}/RMSmkts_bymodule_incbrkt_nocd/${freq}/2012/outsidedef0/outside${outsidegoodscutoff}"
	global estimatesinput "${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"
	
*Install programs used here
*	net install grc1leg2, replace from(http://www.cgdev.org/doc/stata/MO/Misc/)
	
	set printcolor auto // auto
	set scheme s2color // s1mono


*===========================================================================================
*For log files:

	global name="2_estimatesoutput"

*===========================================================================================
*===========================================================================================
*===========================================================================================
**** Program to run sub-programs

capture program drop main
program define main	
if 1 == 1 {
	
	global lab_lin = "Linear Estimates"
	global lab_nl = "Non-Linear Estimates"
	global lab_micro2 = "MicroBLP"
	global lab_micro0 = "BLP"
	
	*
	***import data
		collapsemodulesales // load raw sales
		appendestimates

	***within-spec  stats
		summarizeestimates, spec(${spec}) micro(${micro}) freq(${freq}) salesyear(2012)

	** model selection and product examples
		if "${spec}"=="_nl" {

			appendestimates, filetype(_modelselection)		
			modelselection, spec(${spec}) micro(${micro}) freq(${freq}) salesyear(2012) statlist("bic aic J") 

		}	
	
	** study quality
	if "${spec}"=="_nl" comparebetas,  estdir(${estdir}) 
	if "${spec}"=="_nl" studyquality, incg(10) estdir(${estdir}) 
	
}


end

*===========================================================================================
*===========================================================================================
*===========================================================================================
** Code to import estimates

capture program drop appendestimates
program define appendestimates

	syntax [anything] [, filetype(string)]

if 1==1 {
	clear

	
	disp "append files...."
		local files: dir "${estimatesinput}" files "withinestimates`filetype'_module*.dta"
				// created by 2_estimatessave_vN.do
		local first=1
		tempfile temp

		foreach f of local files {
			disp "...appending `f'"
			
			use ${estimatesinput}/`f', clear
			capture drop if f==.
			capture rename product_module_code modulenum		
			
			
			if "`filetype'"=="" {
				quietly drop if baseprod==1 
					// drop "base" observations so that dropest is consistent within (modulenum model)
				drop b_delta mktid prodid brandid baseprod baseprodid
				quietly bys modulenum model:keep if _n==1
			}
		
			if `first'==0 quietly append using `temp'
			quietly save `temp', replace
			
			local first=0
		}
				
		save "${estimatesinput}/appended_wihthinestimates`filetype'.dta", replace
}	

end

*==================================================================================================	
*==================================================================================================
** Code to summarize estimates in table

capture program drop summarizeestimates
program define summarizeestimates

if 1==1 {
	syntax [anything], spec(string) micro(integer) freq(string) salesyear(integer)

	disp "*******************************************************************************"
	disp "*******************************************************************************"
	disp "summary stats for parameter estimates..."
		use "${estimatesinput}/appended_wihthinestimates.dta", clear
				// created in: appendestimates (subprogram above)

		* merge in module-level sales
		gen year = `salesyear'
		merge m:1 modulenum year using "${step0bdata}/HMSdata_year_modulesales.dta", keepusing(value) keep(1 3) nogen
			// created in: collapsemodulesales (subprogram above)
		rename value total_sales
		gen total_sales_rounded = round(total_sales)
		
		reshape long b_ se_, i(model modulenum f exitflag firstorderopt nltime nlknitro dropest) j(parm) string
		
		gen bound=0
		replace bound=1 if abs(b_)>0.99*5 & (parm=="alpha1" || parm=="gamma")
		replace bound=1 if (b_<0.06 | b_>0.99*30) & parm=="alpha0"
		bys modulenum model: egen anybound=total(bound)
		gen nonbound_=b_ if anybound==0
		
		preserve
			keep modulenum model anybound
			replace anybound=(anybound>0)
			duplicates drop
			save "${estimatesinput}/module_models_hittingbounds.dta", replace
				// to be used below to limit model selection attention to non-bound hitting specs
		restore
	
		gen sig_=b_ if abs(b_)>1.96*se_ & b_!=. & anybound==0
		gen sigpos_=b_ if b_>1.96*se_ & b_!=. & anybound==0
		gen signeg_=b_ if b_<-1.96*se_ & b_!=. & anybound==0
		drop bound anybound
		
		reshape wide b_ se_ sig_ sigpos_ signeg_ nonbound_, i(modulenum model) j(parm) string
		rename sig_* b_*sig
		rename sigpos_* b_*sigpos
		rename signeg_* b_*signeg
		rename nonbound_* b_*nonbound
		gen id=""
		
		preserve
		tempfile temp
		foreach stat in mean sd min p10 p25 median p75 p90 max count {
			restore, preserve
			collapse (`stat') b_alpha0* b_alpha1*  b_gamma* , by(model id) fast
			gen statistic="`stat'"
			if "`stat'"!="mean" {
				append using `temp'
			}
			sort model statistic id
			save `temp', replace
		}

		* aweight by module sales
		foreach stat in mean sd min p10 p25 median p75 p90 max count {
			restore, preserve
			collapse (`stat') b_alpha0* b_alpha1*  b_gamma* [aw=total_sales_rounded], by(model id) fast
			gen statistic="`stat'_w"
			append using `temp'
			sort model statistic id
			save `temp', replace
		}
		
		foreach stat in count {
			restore, preserve
			foreach v in b_alpha0 b_alpha1 b_gamma {
				replace `v'=. if `v'<=0
				capture replace `v'sig=. if `v'sig<=0
			}
			collapse (`stat') b_alpha0* b_alpha1*  b_gamma* , by(model id) fast
			gen statistic="`stat'pos"
			append using `temp'
			sort model  statistic id
			save `temp', replace
		}
		
		restore, preserve
		foreach var in alpha0 alpha1 gamma {
			gen se_`var'sig=se_`var'*(b_`var'sig!=.)
			gen se_`var'sigpos=se_`var'*(b_`var'sigpos!=.)
			gen se_`var'signeg=se_`var'*(b_`var'signeg!=.)
			gen se_`var'nonbound=se_`var'*(b_`var'nonbound!=.)
			foreach s in "" sig sigpos signeg nonbound {
				egen temp=iqr(b_`var'`s')
				egen temp1=median(b_`var'`s')
				replace se_`var'`s'=. if abs(b_`var'`s'-temp1)>temp & id==""
				drop temp temp1
				replace b_`var'`s'=b_`var'`s'/(se_`var'`s'^2)
				gen weight`var'`s'=1/(se_`var'`s'^2)
			}
		}
		
		collapse (sum) b_alpha0* b_alpha1* b_gamma*  weight*, by(model id) fast
		foreach var in alpha0 alpha1 gamma {
			foreach s in "" sig sigpos signeg nonbound {
				replace b_`var'`s'=b_`var'`s'/weight`var'`s'
			}
		}
		gen statistic="wmean"
		append using `temp'
		sort model statistic id
		save `temp', replace
		
		restore
		use `temp', clear
	
		sort model stat id
		order model stat id
		save "${output}/maincoefficients.dta", replace
	
	*create .tex summary table
		foreach wgt in "_w" {
			maincoef_table, sig("nonbound") wgt("`wgt'")
		}
}
end

*************************************************************************************************
** Code to create tex table from maincoef dataset

cap prog drop maincoef_table
prog define maincoef_table

	syntax [anything], [sig(string)] [wgt(string)]

if 1==1 {
	use "${output}/maincoefficients.dta", clear
	eststo clear

	foreach mod in 1 2 3 4 {
		foreach varname in alpha0 alpha1 gamma { 
			eststo m`mod'`varname': quietly reg b_alpha0 b_alpha0sig b_alpha0nonbound if model == `mod'	
			foreach stat in "count" "mean" p25 "median" p75  {
				sum b_`varname'`sig' if model == `mod' & statistic == "`stat'`wgt'"
				if "`stat'"=="count" estadd local v_`stat' = strofreal(round(r(mean),0.01),"%3.0f")
				else estadd local v_`stat' = strofreal(round(r(mean),0.01),"%3.2f")
			}
			sum b_`varname'sigpos if model == `mod' & statistic == "count`wgt'"
			estadd local v_countsigpos = strofreal(round(r(mean),0.01),"%3.0f")
			sum b_`varname'signeg if model == `mod' & statistic == "count`wgt'"
			estadd local v_countsigneg = strofreal(round(r(mean),0.01),"%3.0f")
		}
	}
	
	esttab m1alpha0 m3alpha0 m3gamma m2alpha0 m2alpha1 m4alpha0 m4alpha1 m4gamma  ///
		using "${output}/maincoefficients`sig'`wgt'_fulltable.tex", replace ///
		scalars("v_count Count"  "v_countsigpos \qquad with t>1.96" "v_countsigneg \qquad with t<-1.96" "v_mean Mean" "v_p25 p25" "v_median p50" "v_p75 p75") cells(none) noobs nonumber ///
		mlabel("$\alpha_m^0$" "$\alpha_m^0$" "$\gamma_m$"  "$\alpha_m^0$" "$\alpha_m^1$" "$\alpha_m^0$"  "$\alpha_m^1$" "$\gamma_m$") ///
		substitute(\_ _) booktabs ///
		prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{@M}{c}} " ///
		\toprule " Model: & Homothetic & \multicolumn{2}{c}{NH in Quality} & \multicolumn{2}{c}{NH in Price} & \multicolumn{3}{c}{NH in Quality and Price}  \\ " ///
		"Restrictions: & $\alpha_m^1=0\ \&\ \gamma_m=0$ & \multicolumn{2}{c}{$\alpha_m^1=0$} & \multicolumn{2}{c}{$\gamma_m=0$}  & \multicolumn{3}{c}{None} \\ " ///
		 " & [1] & [2] & [3] & [4] & [5] & [6] & [7] & [8]\\ " ///
		\toprule "Parameter:" )
	eststo clear

}	
end

*===========================================================================================
*===========================================================================================
** Code to import raw module-level sales

capture program drop collapsemodulesales
program define collapsemodulesales

	syntax [anything]

if 1==1 {
	clear
		
	cap noisily confirm file "${step0bdata}/HMSdata_year_modulesales.dta"

	if _rc!=0 {
		di "collapse sales data"
		
		use "${step0bdata}/HMSdata_year.dta", clear
		
		rename pm modulenum
		keep modulenum value year
		
		rename value old
		sort modulenum year
		by modulenum year: gen value = sum(old)
		drop old 
		by modulenum year: keep if _n==_N
		
		qui sum value,d
		di `r(sum)'
	
		save "${step0bdata}/HMSdata_year_modulesales.dta", replace
	}
}	

end
*===========================================================================================
*===========================================================================================
** Code to Pull Out PCA Stats for Paper

capture program drop pcastats
program define pcastats

if 1==1 {

	syntax [anything], spec(string) micro(integer) freq(string) salesyear(integer) statlist(string)
	
	disp "*******************************************************************************"
	disp "*******************************************************************************"
	disp "pca stats..."
	
	use modulenum model pctexpl nz ncomp using "${estimatesinput}/appended_wihthinestimates_modelselection.dta", clear
		// created in: appendestimates (subprogram above), includes...
			// stats: exitflag f nltime nlknitro firstorderopt 
			// dimensions: n l j b t sumjt ns pctexpl nz ncomp

		drop model
		duplicates drop
		bys modulenum: gen a=_N
		tab a
		
		gen ninstrkept = ncomp/nz*100
		
		sum pctexpl ninstrkept, d
		
		
}
end 
*===========================================================================================
** Code to Study Model Selection

capture program drop modelselection
program define modelselection

if 1==1 {

	syntax [anything], spec(string) micro(integer) freq(string) salesyear(integer) statlist(string)
	
	disp "*******************************************************************************"
	disp "*******************************************************************************"
	disp "model selection analysis..."
	
	use "${estimatesinput}/appended_wihthinestimates_modelselection.dta", clear
		// created in: appendestimates (subprogram above), includes...
			// stats: exitflag f nltime nlknitro firstorderopt 
			// dimensions: n l j b t sumjt ns

		drop microdata minmaxjt t j ns

		*merge in module-level sales
		gen year = `salesyear'
		merge m:1 modulenum year using "${step0bdata}/HMSdata_year_modulesales.dta", keepusing(value) keep(1 3) nogen
			// created in: collapsemodulesales (subprogram above)
		rename value total_sales
		gen total_sales_rounded = round(total_sales)
			
		merge 1:1 modulenum model using "${estimatesinput}/module_models_hittingbounds.dta", nogen
			// created in: summarizeestimates (subprogram above)
		drop if anybound>0
		
		drop if model==1
		
		bys modulenum: keep if _N==3
		
	*data formatting
		foreach v in n n2 n3 l b {
			local vupper=upper("`v'")
			rename `v' `vupper'
		}
		capture gen estalpha1=(mod(model,2)==0)
		capture gen estgamma=(model>2)

	*calculate model selection stats
		gen K=1+estalpha1+estgamma+B 
			//+sumjt+micromoments

		foreach v in N L {
			bys modulenum: egen n`v's=nvals(`v')
			tab n`v's if model==1
			drop if n`v's>1
		}
		
		*macro moments (J stat + aic/bic)...
			gen J=jeff*2
			gen bic=J-(L-K)*ln(N+N2)
			gen aic=J-2*(L-K)
		
		preserve
		
		di "*Save intermediate dataset with both parameter values and model selection criteria"
		
			tempfile tempcriteria
			save `tempcriteria', replace
			
			use "${estimatesinput}/appended_wihthinestimates.dta", clear
					// created in: appendestimates (subprogram above)
								
			keep model modulenum b_alpha0 se_alpha0 b_alpha1 se_alpha1 b_gamma se_gamma
			merge 1:1 model modulenum using `tempcriteria'
			keep if _m==3
			drop _m
			
			save "${estimatesinput}/appended_wihthinestimates_criterion.dta", replace
	
		restore
			
	*Criteria relative to each model
		foreach cri in `statlist' {
			gen `cri'hom=`cri' if model==1
			bys module: egen rel`cri'=max(`cri'hom)
			replace rel`cri'=(`cri'-rel`cri')/abs(rel`cri')
			gen `cri'NHP=`cri' if model==2
			bys module: egen rel`cri'NHP=max(`cri'NHP)
			replace rel`cri'NHP=(`cri'-rel`cri'NHP)/abs(rel`cri'NHP)
			forvalues m=1/4 {
				gen temp=`cri' if model==`m'
				bys module: egen `cri'`m'=max(temp)
				gen rel`cri'`m'=(`cri'-`cri'`m')/abs(`cri'`m')
				gen beats`m'in`cri'=(`cri'<`cri'`m') if model!=`m'
				drop temp
			}
		}	
		
	*Summary statistics
		preserve 
	
		capture gen id=""
		
		rename total_sales pmvalue
		*capture gen pmvalue=1
		
		replace id="0" if id=="" 
		foreach cri in `statlist' {
			capture drop `cri'rank
			sort id modulenum `cri'
			by id modulenum (`cri'): gen `cri'rank=_n
		}
		foreach cri in `statlist' { 
			gen `cri'top=(`cri'rank==1)
		}
		foreach cri in `statlist' {
			foreach v in "" top rank  {
				gen `cri'`v'_w=`cri'`v'*pmvalue
			}
		}	
	
		local toplist=subinstr("`statlist'"," ","top* ",.)+"top*"
		local ranklist=subinstr("`statlist'"," ","rank* ",.)+"rank*"
		foreach p in 10 25 50 75 90 {
			local p`p'list=subinstr("`statlist'"," ","_p`p' ",.)+"_p`p'"
			foreach cri in `statlist' {
				gen `cri'_p`p'=`cri'
			}
		}
		tempfile keep
		save `keep', replace
		disp "`statlist'...`toplist'...`ranklist'"
		collapse (sum) value=pmvalue (count) count=J  ///
			(mean) `statlist' `toplist' `ranklist' ///
			(p10) `p10list' (p25) `p25list' (p50) `p50list' (p75) `p75list' ///
			(p90) `p90list', by(id model) fast
		tempfile temp
		save `temp', replace
		use `keep', clear
		collapse (mean) `statlist' `toplist' `ranklist' ///
			(p10) `p10list' (p25) `p25list' (p50) `p50list' (p75) `p75list' ///
			(p90) `p90list' [aw=pmvalue], by(id model) fast
		foreach cri in `statlist' {
			rename *`cri'* *`cri'*_w
		}
		merge 1:1 id model using `temp'
		local i=0
		gen modeltitle=""
		foreach modeltitle in "Homothetic" "Non-Homothetic in Price" ///
			 "Non-Homothetic in Quality" "Non-Homothetic in Price and Quality" { 
			local i=`i'+1
			capture replace modeltitle="`modeltitle'" if model=="`i'"
			local v`i'="`modeltitle'"
		}
		save "$output/modelselection.dta", replace
		
	* export excel table for further modification
		*for each model and statistic, the share and sales share of modules for which that model dominates 
		*and the average and sales-weighted average of each statistic across modules		
		foreach cri in `statlist' {
			use "$output/modelselection.dta", clear
			keep model `cri'top `cri'top_w `cri' `cri'_w 
			order model `cri'top `cri'top_w `cri' `cri'_w 
			sort model
			label var `cri'top "share dominating"
			label var `cri'top_w "sales share dominating"
			label var `cri' "average"
			label var `cri'_w "sales-weighted average"
			disp "** Model Selection Criteria `cri':"
			list
		}
		
	restore 

*Bilateral comparisons
	if 1==1 {
		local tt1 = "Homothetic"
		local tt2 = "Non-Homothetic in Price"
		local tt3 = "Non-Homothetic in Quality"
		local tt4 = "Non-Homothetic in Quality and Price"
		
		local par1 = "$\gamma_m =0,\alpha_m^1 = 0$"
		local par2 = "$\gamma_m =0$"
		local par3 = "$\alpha_m^1 = 0$"
		local par4 = "None"
	
	
		rename total_sales pmvalue  
		
		cap gen id = 0
		keep id model modulenum `statlist' pmvalue total_sales_rounded
	
		duplicates drop
		reshape wide `statlist', i(modulenum pmvalue total_sales_rounded) j(model) 
		foreach cri in `statlist' {
			forvalues i=2/4 {
				forvalues j=2/4 {
					gen rel`cri'_`i'`j' = ln(`cri'`i'/`cri'`j')
					gen `cri'_`i'`j'=(`cri'`i'<`cri'`j')
					gen value`cri'_`i'`j'=pmvalue*`cri'_`i'`j'
				}
			}
		}
		rename pmvalue value
		
		drop rel*
		
		local varlist=""
		local varlist2=""
		foreach cri in `statlist' {
			local varlist="`varlist' `cri'_* value`cri'_*"
			local varlist2="`varlist2' `cri'_ value`cri'_"
		}
		disp "`varlist'"
		collapse (sum) `varlist' value (count) count=aic_22, by(id) fast
		disp "`varlist2'"
		reshape long `varlist2', i(value count id) j(modelpair) 
		foreach v in `statlist' {
			replace `v'_=`v'_/count
			replace value`v'_=value`v'_/value
		}
		order id modelpair
		
		*save data for 4*4 table 
		tempfile bilateralshare
		save `bilateralshare', replace
	 
	* export bilateral comparison tables (4*4 table for each criterion, row dominates column)
		*4 x 4 bilateral model selection tables for each statistic (including g2sum and g3sum) that show the share of modules the 
		*row dominates the column below the diagonal and the sales share of modules that the row dominates the column above the diagonal. 
		preserve
		foreach cri in `statlist' {
			
			use modelpair `cri'_ value`cri'_ using `bilateralshare', clear
			tostring modelpair, replace
			gen model1 = real(substr(modelpair,1,1))
			gen model2 = real(substr(modelpair,2,1))
			drop modelpair
			
			rename value`cri'_ `cri'_sales
			reshape long `cri', i(model1 model2) j(wgt) string
			
			*for model1>model2 (below diagonal), keep unweighted shares; 
			*for model2>model1 (above diagonal), keep weighted shares;
			drop if model1>model2 & wgt=="_sales"
			drop if model1<=model2 & wgt=="_"
			drop wgt
		
			reshape wide `cri', i(model1) j(model2) 
			disp "**Bilateral Model Selection Criteria `cri':"
			list
			
		} // end of statlist
		restore	

} // end of bilateral analysis

} // end of subprogram collapse
			
end


*===========================================================================================
*===========================================================================================
** Code to Study Reasonable-ness of Quality Estimates

capture program drop studyquality
program define studyquality

	syntax [anything], incg(integer) estdir(string) 

if 1==1 {
	
	disp "*******************************************************************************"
	di "prep HH size-adjusted income"
		use household_code panel_year income using ${step0bdata}/incomeadj.dta, clear
			// created in: 0_dataimport/1b_HMS_demographicdata_v[].do
			drop if income==.
			xtile pct=income, nq(100) 
			local incg `incg'
			foreach k in `incg' {
				gen incgroup`k'=floor(pct/(100/`k'))+1
				replace incgroup`k'=`k' if incgroup`k'==`k'+1
				bys incgroup`k': egen income`k'=median(income)
				bys incgroup`k': egen minincome`k'=min(income)
				bys incgroup`k': egen medincome`k'=median(income)
				bys incgroup`k': egen maxincome`k'=max(income)
				disp "`k'"
			}
			tab incgroup`incg' income`incg'
			compress
			sort household_code
			tempfile temphhs
			save `temphhs', replace

	disp "*******************************************************************************"
	disp "*******************************************************************************"
	disp "study brand quality estimates..."

	di "*** Identify 10 highest and 10 lowest quality non-control brands and display with their high- and low-income expenditure shares"

	di "- Calculate expenditure share of each product among HI/LI HHs"
	
		di "Load HH purchase data"
			use household_code year productid value brand pm if year == 2012 using ${step0bdata}/HMSdata_year.dta, clear
				// created by /0_dataimport/Code/1a_HMS_purchasedata_v[].do
					// contains HH purchase at product-HH-year level, observations identified by household_code  productid
			
			rename brand brandid					
			rename value valueold
			bys household_code year pm brandid: gen value=sum(valueold)
			by household_code year pm brandid: keep if _n==_N
			drop *old 
		
		di "Merge in HH size-adjusted income"
			rename year panel_year
			merge m:1 household_code panel_year using `temphhs', keep(1 3) keepusing(incgroup`incg')
			drop if _merge < 3
			drop _merge
			bys pm: egen pmvalue=total(value)
			bys pm brandid: egen brandvalue=total(value)
			
		di "Collapse data to market-income-brand level"
			collapse (sum) value, by(pm pmvalue brandid brandvalue incgroup`incg') fast
			bys incgroup`incg' pm: egen pmexpsh= total(value)
			replace pmexpsh = value/pmexpsh
			bys incgroup`incg': egen expsh= total(value)
			replace expsh = value/expsh
			keep pm pmvalue brandid brandvalue incgroup`incg' expsh pmexpsh value
			reshape wide pmexpsh expsh value, i(pm pmvalue brandid brandvalue) j(incgroup`incg') 
			levelsof pm, local(modules)
			tempfile brandshares
			save `brandshares'
	
	di "- Merge with estimates and output"
		local first=1
		foreach module in `modules' {
			capture confirm file "${estimatesinput}/withinestimates_betas_module`module'.dta"
			if _rc==0 {
				if `first'==1 {
					use ${estimatesinput}/withinestimates_betas_module`module'.dta, clear
						// created in 1_estimatessave - at the model, brandid level
					gen pm=`module'
					local first=0
					preserve
				}
				else {
					restore
					append using ${estimatesinput}/withinestimates_betas_module`module'.dta
					replace pm=`module' if pm==.
					preserve
				}
			}
		}
		merge m:1 pm brandid using `brandshares'
		drop if _merge<3
		drop _merge
		gsort model pm -b_beta
		by model pm: gen rank=_n
		gen brandshare=brandvalue/pmvalue
		gsort model -pmvalue rank
		keep model pm brandid rank pmvalue brandshare b_beta pmexpsh* expsh* value*
		
		capture drop _merge
		merge 1:1 model pm brandid using "${data}/appendedbetaestimates.dta", keepusing(b_betadiff) nogen
		gen brandval=brandshare*pmvalue
		replace b_beta=b_beta+b_beta0_m
		replace b_betadiff=b_betadiff+b_beta0_m
		gen b_betaerr=b_betadiff-b_beta
		gen decile=_n if _n<=`incg'
		foreach suf in "" "err" {
			gen e_expbeta`suf'=.
			gen se_e_expbeta`suf'=.
			forvalues k=1/`incg' {
				capture gen lnval`k'=ln(value`k')
				quietly eststo qual`k': areg lnval`k' b_beta`suf' if model==3  [aw=pmval], absorb(pm) //  [aw=brandval] [aw=brandval]
				replace e_expbeta`suf'=  _b[b_beta`suf'] if _n==`k'
				replace se_e_expbeta`suf' = _se[b_beta`suf'] if _n==`k'
			}

			preserve
				serrbar e_expbeta`suf' se_e_expbeta`suf' decile, scale(1.96) ///  
						xtitle("Household Income Decile") ytitle("Elasticity of Product Expenditure w.r.t. ${b_beta`suf'lab}") ///
						graphregion(color(white)) bgcolor(white) name(plot`suf', replace)
				graph export "$output/quality`suf'correlations_plot_`incg'groups.eps", as(eps) replace
				eststo clear
			restore
		}
	
}	

end

*===========================================================================================
*===========================================================================================
** Code to Compare Quality Estimates with Alternative Quality Estimates

capture program drop comparebetas
program define comparebetas

	syntax [anything], estdir(string) 

if 1==1 {

	di "Load HH purchase data for weights"
			use year value brand pm if year == 2012 using ${step0bdata}/HMSdata_year.dta, clear
				// created by /0_dataimport/Code/1a_HMS_purchasedata_v[].do
					// contains HH purchase at product-HH-year level, observations identified by household_code  productid
			
			rename brand brandid
			bys pm brandid: gen brandval=sum(value)
			by pm brandid: keep if _n==_N
			keep pm brandid brandval
			tempfile brandvalues
			save `brandvalues', replace
	*
	disp "*******************************************************************************"
	disp "append brand quality estimates..."
	
		local files: dir "${estimatesinput}" files "withinestimates_betas_module*.dta"
			// created in 2_estimatessave_vN - at the model, brandid level
		local first=1
		foreach f of local files {
			local mod=subinstr(subinstr("`f'","withinestimates_betas_module","",.),".dta","",.)
			if `first'==1 {
				use ${estimatesinput}/`f', clear
				gen pm=`mod'
				local first=0
			}
			else {
				append using ${estimatesinput}/`f'
				quietly replace pm=`mod' if pm==.
			}
		}
		merge m:1 pm brandid using `brandvalues', nogen

	di "**Run regressions to check correlation with mean raw beta (normalized only wrt outside good) and normalized beta (normalized wrt a common inside good)"
		capture gen b_betass=sumb_deltass/ndiff
		capture gen commonbrand=(b_betadiff==0)
		gsort pm model -commonbrand
		by pm model: gen commonbrandnonmiss=sum(commonbrand)
		by pm model: gen b_betacommon=b_beta*commonbrand
		by pm model: replace b_betacommon=sum(b_betacommon)
		replace b_betacommon=. if commonbrandnonmiss==0
		tab commonbrandnonmiss
		replace b_beta=b_beta-b_betacommon
		bys pm model: egen pmval=total(brandval)
	
	*share of markets included in product quality calculation when normalizing by common product
		gen nshare=ndiff/n
		keep if model==3
		sum n ndiff nshare, d
		count if nshare==0

	*correlations:
		sort model pm
		egen betacorr=corr(b_beta b_betadiff), by(model pm)
		egen betasscorr=corr(b_betass b_betadiff), by(model pm)
		bys pm: keep if _n==_N
		twoway (kdensity betacorr  [aw=pmval]),  ///
			ytitle("Sales-Weighted Density")  xtitle("Correlation within Module") graphregion(color(white) lcolor(white))  /// 
			legend(off)
		graph export ${output}/betadiff`suf'corr_model3.eps, replace	

}

end

*==================================================================================================	
*==================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "${logs}/${name}_`cdate'_`ctime'.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*==================================================================================================
*==================================================================================================

