*=================================================================================================
*** 3_identificationchecks.do
*** compares estimates for identification robustness specs
*=================================================================================================

args source freq spec micro outsidegoodscutoff estdir
	
	if "`machine'"=="" {
		local source = "matlab"
		local freq="month" 
		local spec ="_nl"
		local micro = 2 
		local outsidegoodscutoff =60 
		local estdir = 1 
		
	}
	
	foreach arg in source freq spec micro outsidegoodscutoff estdir {
		if "``arg''"=="0" local `arg'=""
	}
	
	foreach arg in source freq spec micro outsidegoodscutoff estdir {
		global `arg' "``arg''"
	}
	
*===========================================================================================
*** Directory Set-up
	
	do ../../SetFilePaths.do
	cd ${dir}/..
	global currentsteprepo: pwd
	cd ${dir}
	global currentstep "$terminal/3_estimation"

*Set-up standard directories	
	global logs "$currentstep/STATA/Logs"
	global data "$currentstep/STATA/Data"	
	global output "$currentstep/STATA/Output"
	global repooutputstub "${currentsteprepo}/RepoOutput"
	global repooutput "${repooutputstub}/${estdir}"
	cap mkdir "${repooutputstub}/${estdir}"
	cap mkdir "${repooutputstub}/${estdir}/robust"

*Set-up relevant directories for this step
	global estimates "${currentstep}/MATLAB/OutputData/" 
	
	global name "2a_speccomptables"

*Install programs used here
*	net install grc1leg2, replace from(http://www.cgdev.org/doc/stata/MO/Misc/)

	set printcolor auto // auto
	set scheme s2color // s1mono

*===========================================================================================
*===========================================================================================
*===========================================================================================
**** Program to run sub-programs

capture program drop main
program define main	

	**Set labels:
	
	global lab_lin = "Linear"
	global lab_nl = "Non-Linear"
	
	global lab_micro2 = "MicroBLP"
	global lab_micro0 = "BLP"
	
	global titlealpha0="alpha0" 
	global titlegamma = "gamma" 
	global titlestdbeta="std(beta)"
	global titlealphagamma="alpha0*gamma"
	global title alpha1="alpha1" 

	
	**Code to compare estimates graphically across two specs at a time & create summary statistic table:
		
	local dontdraw="nodraw" // "nodraw" // Option to not make any of the parameter estimate comparison plots

		
	********************************************
	**Instrument checks	
*
	**OLS vs two sets of instruments)
			local label "_OLS"
			local job1 "7"
			local lab1 "OLS" 
			local spec1 "_nl"
			local job2 "1" 
			local spec2 "_nl"
			local lab2 "Base"	
			local job3 "6"
			local lab3 "Residualized Instruments"
			local spec3 "_nl"
			
			est_results_compkdensity,  dontdraw("draw") label("`label'") joblist("`job1' `job2' `job3'") speclist("`spec1' `spec2' `spec3'") lab1("`lab1'") lab2("`lab2'") lab3("`lab3'") 
*
	**Base+Resid vs Resid for limited sample estimates
		local job1 "8" 
		local spec1 "_nl"
		local lab1 "Base + Resid"	
*
			local label "_Ctest"
			local job2 "9"
			local lab2 "Residualized Instruments"
			local spec2 "_nl"
		
			est_results_Ctest, label("`label'") joblist("`job1' `job2'") speclist("`spec1' `spec2'") lab1("`lab1'") lab2("`lab2'") 
*

end 

*===================================================================================================================
*** Subprograms for Robustness Comparison
*===================================================================================================================

*===========================================================================================
* dataprep

capture program drop dataprep
program define dataprep

	syntax [anything], lab(string) spec(string) job(string) m(integer) v(string) est(integer) ///
		[outsidegoodscutoff(string) freq(string) extrastats(string)]
*
if 1==1 {	

	if "`importestimates'"=="" local importestimates="${defaultimportestimates}"
		local jobname_in "`job'_qacct_output"
		local jobname_out "`spec'_`job'"

		if "`spec'"=="_hhold" {
			import delimited using "${terminal}/../NHP/STATAOutput/20110803/allcoefficients.xls", clear
			gen model = real(substr(modeltitle,1,1))
			cap drop modulenum
			rename pm modulenum
			keep if model==`m'
			gen anybound_m`m'=(b_alpha0==0.05 | b_alpha0>30) 
			replace anybound_m`m'=1 if (abs(b_gamma)>30 & b_gamma!=.) | (abs(b_alpha1)>30 & b_alpha1!=.)
			keep modulenum model b_`v' anybound_m`m'
			rename b_`v' thetahat`spec'_m`m'
			gen `v'=1
		}
		else if "`spec'"=="_hh" {
			use "${data}/tempres`jobname_out'.dta" if thetahat_m`m'!=0  & thetahat_m`m'!=., clear
				// created in 0a_qacctprep_v[].do
			* fix parameter name in _hh outputs
			gen temp=(thetahat_m`m'==0.05) if alpha0==1
			replace temp=1 if abs(thetahat_m`m')>=29 & (gamma==1 | alpha1==1)
			bys modulenum: egen anybound_m`m'=total(temp)
			drop temp
			keep if `v'==1
			rename thetahat_m`m' thetahat`spec'_m`m'
		}
		else {
			if "`lab'"!="Base" {
				if "`outsidegoodscutoff'"=="" local outsidegoodscutoff="${outsidegoodscutoff}"
				if "`freq'"=="" local freq="${freq}"
				global estimatesinput "${data}/estimates/`freq'/${source}estimates/micro${micro}${spec}/outside`outsidegoodscutoff'/module/`job'"
			}
			else global estimatesinput "${data}/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/`job'"
			use model modulenum exitflag firstorderopt b_* using "${estimatesinput}/appended_wihthinestimates.dta", clear
				// created in 1_estimatessave.do
			merge 1:1 model modulenum using "${estimatesinput}/appended_wihthinestimates_modelselection.dta", keepusing(l `extrastats') nogen
				// created in: 1_estimatessave
			reshape long b_, i(model modulenum exitflag firstorderopt `extrastats' l) j(parm) string
			foreach var in alpha0 alpha1 gamma stdbeta iqrbeta corrbeta {
				gen `var'=(parm=="`var'")
			}
			rename b_ thetahat_nl_m
			foreach var in exitflag firstorderopt `extrastats' l {
				rename `var' `var'_m
				local varlist_m="`varlist_m' `var'_m"
			}
			reshape wide thetahat_nl_m `varlist_m', i(modulenum parm) j(model)
			gen thetas_nl=1
			
			* merge in hitting bounds info
			if "`spec'"=="_nl"  {
				
				* run the bound checks for each job (checks all parameters, only need to run once for each job)
					if "`v'"=="alpha0" bounds_check, lab("`lab'") jobname_in("`jobname_in'") jobname_out("`jobname_out'")
					
					rename modulenum module
					merge m:1 module using "${output}/flags_bounds/tempres`jobname_out'_hitbounds.dta", keepusing(*bound* *start* anyflag*) nogen
						// created above by subprogram [bounds_check]
					rename module modulenum
			}
			
		}
		
		* merge in module-annual sales
			gen year=2012
			merge m:1 modulenum year using "${step0bdata}/HMSdata_year_modulesales.dta", keepusing(value) keep(1 3) nogen
			// created in: 2_estimatesoutput, subprogram [collapsemodulesales]
			drop year		
		
		keep if `v'==1 
		sum thetahat`spec'_m`m', d
		di "est: `est'; obs: `r(N)'"
		local N = `r(N)'
		
		if `N'>0 {
		
			di "m `m', v `v', p50: `r(p50)'; `r(p10)', `r(p90)'"
			gen meandev = thetahat`spec'_m`m' - `r(p50)'
			gen outlier = 0

			replace outlier = 1 if anybound_m`m'!=0 
			if "`spec'"=="_nl" replace outlier = 1 if anyflag_m`m'!=0
			
			cap drop stderror* 
			cap drop thetahat*raw
			
			 rename (outlier thetahat*_m*) (outlier`est' thetahat*_m*`est') 
			 foreach var in `extrastats' l {
				rename `var'_m* `var'_m*`est'
			 }
			 capture rename t t`est'

		} // end of if N>0
} // end of if 1==1

end

*===========================================================================================
* est_results_compkdensity
** Comparing three sets of estimates

capture program drop est_results_compkdensity
program define est_results_compkdensity

	syntax [anything], [dontdraw(string) lab3(string)] label(string) joblist(string) speclist(string) lab1(string) lab2(string) ///
		[ogcutofflist(string) freqlist(string) importlist(string)]

if 1==1 {	

	local id =0
	
	forv i = 1/3 {
		local spec`i': word `i' of `speclist'
		local job`i': word `i' of `joblist'
		local outsidegoodscutoff`i': word `i' of `ogcutofflist'
		local freq`i': word `i' of `freqlist'
		local dontimport`i': word `i' of `importlist'
		di "JOB `i': `spec`i'', `job`i'', `lab`i''"
	}
	
	tempfile tempest
		 
	forvalues m=3(1)3 {
	
		local kernellistcomb=""
		local kernellistcomb_com=""

		foreach v in alpha0 alpha1 gamma {
			local histlist=""
			
			local exist=0
			foreach est in 1 2 3 {
			
				disp "spec: `spec`est'' ; est: `est'"
				local  spec "`spec`est''"
				local job `job`est''
				local lab "`lab`est''"
				local  freq "`freq`est''"
				local outsidegoodscutoff "`outsidegoodscutoff`est''"
				
				dataprep, lab(`lab') spec(`spec') job(`job')  m(`m') v(`v') est(`est') outsidegoodscutoff(`outsidegoodscutoff') freq(`freq')  
		
				count if thetahat`spec1'_m`m'!=0 & thetahat`spec1'_m`m'!=. & parm=="`v'" 
				if `r(N)'==0 continue
				local exist=1
				sum thetahat`spec'_m`m'`est' if outlier`est'==0
				
				if `est'>1 {
					merge 1:1 modulenum using `tempest' 
					cap gen evermiss=0
					replace evermiss=1 if _merge<3
					drop _merge
				}
				save `tempest', replace
				
			} // end of job `est'
		
		if `exist'==1 {
			foreach com in "" "_com" {
				preserve
			
				if "`com'"=="_com" keep if evermiss==0
				twoway (kdensity thetahat`spec1'_m`m'1 if parm=="`v'" & outlier1==0 [aw=value], lp(dash) lcolor(marooon) `xrange' ) ///
					(kdensity thetahat`spec'_m`m'2  if parm=="`v'" & outlier2==0  [aw=value], lp(l) lcolor(navy) `xrange') ///
					(kdensity thetahat`spec'_m`m'3 if parm=="`v'" & outlier3==0  [aw=value], lp(dash) `xrange'),  ///
					xtitle("") graphregion(color(white) lcolor(white))  /// 
					legend(label(1 "`lab1'") label(2 "`lab2'") label(3 "`lab3'") rows(1) )
				graph export ${repooutput}/robust/triple_scatcomp`label'_model`m'_`v'`com'_drop2.eps, replace	
			
				twoway (kdensity thetahat`spec1'_m`m'1 if parm=="`v'" & outlier1==0 [aw=value], lp(dash) lcolor(marooon) `xrange' ) ///
					(kdensity thetahat`spec'_m`m'2  if parm=="`v'" & outlier2==0  [aw=value], lp(l) lcolor(navy) `xrange') ///
					(kdensity thetahat`spec'_m`m'3 if parm=="`v'" & outlier3==0  [aw=value], lp(dash) `xrange'),  ///
					title("${title`v'}") xtitle("") graphregion(color(white) lcolor(white)) name(kernel`com'_`v', replace) /// 
					legend(label(1 "`lab1'") label(2 "`lab2'") label(3 "`lab3'") rows(1) )
				local kernellistcomb`com'="`kernellistcomb`com'' kernel`com'_`v'"
				
				sum thetahat`spec1'_m`m'1 if outlier1==0, d
				sum thetahat`spec'_m`m'2  if outlier2==0, d
				sum thetahat`spec'_m`m'3 if outlier3==0 , d
			restore
			} // end of all obs, common obs	
		
		}
		
	} // end of variable `v'
	
	foreach com in "" "_com" {
		grc1leg2 `kernellistcomb`com'', row(1) graphregion(color(white) lcolor(white))  // note("`dropnote'", size(small))
		graph export ${repooutput}/robust/triple_kerncomp`label'_model`m'`com'_drop2.eps, replace
	}
	
	} // end of model m 
		
}	// end of if 1==1

end

*===========================================================================================
** Compare J-statistics for two sets of moments

capture program drop est_results_Ctest
program define est_results_Ctest

	syntax [anything], label(string) joblist(string) speclist(string) lab1(string) lab2(string) ///
		[outsidegoodscutoff(string) freq(string)]
*
if 1==1 {	
	
	forv i = 1/2 {
		local spec`i': word `i' of `speclist'
		local job`i': word `i' of `joblist'
		local dontimport`i': word `i' of `importlist'
		di "JOB `i': `spec`i'', `job`i'', `lab`i''"
	}
	
	tempfile tempest
	
**dataprep and plots
	 
	forvalues m=3/3 {
	
			local histlist=""
			
			foreach est in 1 2 {
			* separate graphs
				
				disp "variable: `v', spec: `spec`est'' ; est: `est'"
				local  spec "`spec`est''"
				local job `job`est''
				local lab "`lab`est''"
				clear
				dataprep, extrastats(jeff) lab(`lab') spec(`spec') job(`job')  ///
					m(`m') v(alpha0) est(`est') outsidegoodscutoff(`outsidegoodscutoff') freq(`freq') 
				if `est'>1 merge 1:1 modulenum using `temp`v'1', keep(3)  nogen 
				tempfile temp`v'`est'
				save `temp`v'`est'', replace
				
			} // end of `est'==2			
		
			gen jdiff=jeff_m`m'1-jeff_m`m'2
			sum jdiff, d
			gen ldiff=l_m`m'1-l_m`m'2
			sum ldiff, d
			gen pvalue`m'=chi2tail(ldiff,jdiff)
			drop if pvalue`m'==.
			gen reject=(pvalue`m'<0.05)
			sum pvalue`m', d
			collapse (count) nmodules=value (sum) value, by(reject) fast
			gen modshare=nmodules/(nmodules[1]+nmodules[2])
			gen valshare=value/(value[1]+value[2])
			list
			
	} // end of model m 
	
			
}	// end of if 1==1

end


*===========================================================================================
* identify modules hitting bounds and save datasets on relevant info

cap prog drop bounds_check 
prog define bounds_check

syntax[anything], jobname_in(string) jobname_out(string) [lab(string)]

if 1==1 {

preserve

	rename modulenum module
	foreach m in 1 2 3 4 {	
		
	*check module-models hitting bounds in different models for different parameters
		gen alpha0lowerbound_m`m' = (thetahat_nl_m`m'<0.06 & thetahat_nl_m`m'!=. & alpha0==1)
		gen alpha0upperbound_m`m' = (thetahat_nl_m`m'>0.99*30 & thetahat_nl_m`m'!=. & alpha0==1)
		gen alpha0bound_m`m' = alpha0lowerbound_m`m' + alpha0upperbound_m`m'

		gen alpha1bound_m`m'= (abs(thetahat_nl_m`m')>0.99*5 & thetahat_nl_m`m'!=. & alpha1==1)
		gen gammabound_m`m'= (abs(thetahat_nl_m`m')>0.99*5 & thetahat_nl_m`m'!=. & gamma==1)
		
		*sum across parameters
		gen anybound_m`m'= (alpha0bound_m`m'+alpha1bound_m`m'+gammabound_m`m'>0) 

	*drop module-models hitting start values
		gen alpha0start_m`m'=( abs(thetahat_nl_m`m'-2)<0.01 & alpha0==1)
		gen alpha1start_m`m'=( abs(thetahat_nl_m`m'-0.1)<0.01 & alpha1==1)
		gen gammastart_m`m'=( abs(thetahat_nl_m`m'-0.1)<0.01 & gamma==1)
		
		*sum across parameters
		gen anystart_m`m'=alpha0start_m`m'+alpha1start_m`m'+gammastart_m`m' if thetas_nl==1

		gen anyflag_m`m' = ((exitflag_m`m'<=-300) | (exitflag_m`m'<=-200 & exitflag_m`m'>-300 & firstorderopt_m`m'>1e-8) | (exitflag_m`m'<-100 & exitflag_m`m'>-200))
				*	(see https://www.artelys.com/tools/knitro_doc/3_referenceManual/knitromatlabReference.html#note-on-exit-flags) for details on the flags
	}
	
	* sum across models
	collapse (sum) *bound* *start_m* (mean) exitflag_m* anyflag_m*, by(module thetas_nl) fast // job jobid taskid sumjt


	foreach v in alpha0 alpha1 gamma  {
		gen `v'bound = `v'bound_m1 + `v'bound_m2 + `v'bound_m3 +`v'bound_m4
		gen `v'start = `v'start_m1 + `v'start_m2 + `v'start_m3 +`v'start_m4
	}
	gen alpha0upperbound = alpha0upperbound_m1 + alpha0upperbound_m2 + alpha0upperbound_m3 + alpha0upperbound_m4
	
	* sum across models and parameters
	gen anybound = (anybound_m1+anybound_m2+anybound_m3+anybound_m4>0)
	gen anystart = (anystart_m1+anystart_m2+anystart_m3+anystart_m4>0)
	gen anyflag = (anyflag_m1+anyflag_m2+anyflag_m3+anyflag_m4>0)
	
	* label the counts by parameters
	foreach v in alpha0 alpha1 gamma  {
		lab def `v'bound 0 "`v'bound=0" 1 "`v'bound=1"  2 "`v'bound=2" 3 "`v'bound=3"  4 "`v'bound=4" , modify
		lab val  `v'bound  `v'bound 
	}
	*  label the counts by models
	foreach m in 1 2 3 4 {
		lab def anybound_m`m' 0 "anybound_m`m'=0" 1 "anybound_m`m'=1"  2 "anybound_m`m'=2" 3 "anybound_m`m'=3"  4 "anybound_m`m'=4" , modify
		label val anybound_m`m' anybound_m`m'
	}
	
	sort module
	save "${output}/flags_bounds/tempres`jobname_out'_hitbounds.dta", replace
	
restore	

}

end

*===================================================================================================================
*===================================================================================================================
**** Run programs and reset directory

	capture log close
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	log using "$logs/${name}_`cdate'_`ctime'.log", replace
	cd ${programs}
	main
	cd ${programs}
	capture log close
	
*===================================================================================================================
*===================================================================================================================
