*=================================================================================================
*** 2_moduleindex_allmods.do
*** 	this do file calculates module-level price indexes for each market and income group
*=================================================================================================

	args market year source freq spec micro outsidegoodscutoff cbsa estdir sample incgrp sampleV pm channel
	
	if "`market'"=="" {
		local market = "cbsa"
		local year = 2012 
		local source = "matlab"
		local freq = "month"
		local spec = "_nl" 
		local micro = 2 
		local outsidegoodscutoff = 60 
		local estdir = 1
		local sample "_limit50" 
		local incgrp "det" 
		local sampleV "_v1" 
		local pm "0" 
		local channel "0" // "0" if keep stores of all channels; "_F" if keep food and mass merchanise only
		local nooverwrite "1"
	}
	
	foreach arg in pdef sample sampleV pm channel nooverwrite {
		if "``arg''"=="0" local `arg' ""
	}

	disp "`market' `year' `source' `freq' `spec' `micro' `outsidegoodscutoff' `estdir' `sample' `incgrp' `sampleV' `pm' `channel' `nooverwrite'"
	
	foreach arg in market year source freq spec micro outsidegoodscutoff estdir sample incgrp sampleV pm channel nooverwrite {
		global `arg' "``arg''"
		dis "`arg' = ${`arg'}"
	}
	
	
*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/4_postestimation_analysis"

*Set-up standard directories	
	global rawdata "$currentstep/RawData"
	global data "$currentstep/Data"	
	global output "$currentstep/Output"
	global logs "$currentstep/Logs/2_modindexes"
	
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	global repooutput "$currentsteprepo/RepoOutput"
	
*Extra data necessary
	global incdistdata "$terminal/1_dataprep/STATAData/storeincdist_${freq}.dta"
			// created by /1_dataprep/Code/2a_outputforMATLAB_prep_v[].do (storelnincdistcsv)
	global estimates "${currentstep}/../3_estimation/3a_withinmodule/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"
			// created by 3a_withinestimates/STATA/Code/2_estimatessave_v1.do
	global step2data "$terminal/2_preestimation_analysis/STATAData"
	
*Directory to store module-level price and index datasets
	global storemoduleprices "$data/module_level"
	global storemoduleindexes "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}/module"
	capture mkdir "$data/indexes"
	capture mkdir "$data/indexes/${freq}"
	capture mkdir "$data/indexes/${freq}/${source}estimates"
	capture mkdir "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}"
	capture mkdir "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}"
	capture mkdir "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}"
	capture mkdir "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}/module"

*===========================================================================================
*===========================================================================================
*===========================================================================================
**** Main Program to Import Data and Calculate Module-Market-Level Price Indices

if 1==1 {

capture program drop main
program define main 


	if "${pm}"=="" { // looping through all modules

		* Import all modules (859 in total)
		import delimited modulenum using "${terminal}/0_dataimport/Code/productmodule_list_noncount.txt", clear
		levelsof modulenum, local(modulelist)
		
		* Looping over modules
		foreach pm of local modulelist {	
			cap noisily main_module, pmodule(`pm') market("${market}") year(${year}) sample("${sample}") sampleV("${sampleV}") incgrp("${incgrp}") spec("${spec}") channel("${channel}")
		}

	}
	else { // run for one single module

		main_module, pmodule(${pm}) market("${market}") year(${year}) sample("${sample}") sampleV("${sampleV}") incgrp("${incgrp}") spec("${spec}") channel("${channel}")

	}

end
}

*===========================================================================================
*===========================================================================================
capture program drop main_module
program define main_module

if 1==1 {

	syntax[anything], pmodule(integer) market(string) year(integer) incgrp(string) spec(string) [sample(string) sampleV(string) channel(string)]

	di "Module: `pmodule'; `market', `year'"

	di "*** Set suffix for filepath & index specifications"

		if "`sample'" != "" local sampleN = subinstr("`sample'", "_limit", "", .)

		if "`incgrp'" == "det" {
			local nincgrps 8	// 8 income groups from 25K to 200K
			local incfile "_incDetail"
		}

		local xextra "xN"

	di "*** DATA PREP ***"

		if "${nooverwrite}"!="" {
			di "*first check that the index hasn't been already calculated"
				capture confirm file "${storemoduleindexes}/mkt_priceindices_`market'_`year'_module`pmodule'`sample'`sampleV'`incfile'.dta"
				if _rc==0 {
					disp "index already exists"
					di "${storemoduleindexes}/mkt_priceindices_`market'_`year'_module`pmodule'`sample'`sampleV'`incfile'.dta"
					assert 1==2
				}
				else disp "output file not found - run code to write..."
		}
		
		di "*then confirm that we have price data and estimates"
			capture confirm file  "${storemoduleprices}/store_module`pmodule'_`year'_data.dta"
			di "use availibity data from: ${storemoduleprices}/store_module`pmodule'_`year'_data.dta"
					** created in /1_availability_modbymod_vN.do
					** variables: store_code_uc prodid (unique identifiers) brandid x vjt
			if _rc!=0 {
				disp "no price data"
				assert 1==2
			}
			capture confirm file  "${estimates}/withinestimates_module`pmodule'.dta"
			if _rc!=0 {
				disp "no estimates"
				di "${estimates}/withinestimates_module`pmodule'.dta"
				assert 1==2
			}	
						
		di "*specify mean income relative to which parameters are defined"
			local meanlninc=log(37500)
			
		di "*define income groups"
			defineincgrp_`incgrp', nquantiles(`nincgrps') 
				** sub-program defined below
		
	di "*** DATA PROCESSING ***"	
	
	di "*load raw data (at store-year-product level)"
		use "${storemoduleprices}/store_module`pmodule'_`year'_data.dta", clear
			** created in /1_availability_modbymod_vN.do
			** variables: store_code_uc prodid (unique identifiers) brandid x vjt
			
	di "*drop retailer code 9104 (problem chain) and (if relevant) keep only food and mass merchandiser stores"
		merge m:1 store_code_uc using ${RMSdata}/1_moduleyear/Data/stores_`year'.dta, keepusing(retailer_code channel_code) keep(1 3)
		drop if retailer_code == 9104
		drop retailer_code _merge
		if "`channel'" == "_FM" {
			di "*keep only food and mass merchandiser"
			keep if channel_code=="F" | channel_code=="M"
		}
		if "`channel'" == "_F" {
			di "*keep only food stores"
			keep if channel_code=="F"
		}
		drop channel_code
	
	di "*collapse data from store_code_uc-prodid level to `market'-prodid level"
		
		if "`market'"!="store_code_uc" {
			merge m:1 store_code_uc using ${RMSdata}/1_moduleyear/Data/stores_`year'.dta, keep(1 3) keepusing(store_code_uc fips_state_code fips_county_code) nogen
			gen county = fips_state_code*1000+fips_county_code
			drop fips* 
		}
		
		if "`market'"=="cbsa" {
			capture confirm file ${data}/storetocbsa_`year'`channel'.dta
			if _rc!=0 disp "!!! Need to run 2_stylizedfact2.do to get storetocbsa concordance !!!"
			merge m:1 store_code_uc using "$terminal/2_preestimation_analysis/STATAData/storetocbsa_`year'`channel'.dta", keep(1 3) nogen
					// created in 2_preestimation_analysis/2_stylizedfact2.do
					// previously created below in storetocbsa subprogram 
		}
		
		if "`market'"!="store_code_uc" {

				if strpos("`sample'", "_limit") > 0 { 
	
					** merge with crosswalk and only keep stores that are in random sample
					merge m:1 `market' store_code_uc using ${step2data}/StoreSample_Crosswalks/storecodesample`sampleN'_`market'`channel'`sampleV'_`year'.dta
						// created in 2_preestimation_analysis/2_stylizedfact2.do
					tab _merge
						// 1 = stores that are in this module that are not in random sample
						// 2 = stores that aren't in this modile that are in random sample
						// 3 = stores to keep in random sample
					keep if _merge == 3
					drop _merge
					
				}

				
				sort `market' prodid
				foreach v in x vjt {
					drop if ln(`v')==.
				}
				
				gen ujt = vjt/x
				foreach v in ujt vjt {
					rename `v' old 
					by `market' prodid: gen `v' = sum(old)
					drop old
				}
				replace x=vjt/ujt
				drop ujt*
				by mktid prodid: keep if _n==_N
		}
		
		rename `market' mktid
		drop if mktid==.  
		
	di "*calculate national average prices"
		sort prodid
		gen ujt = vjt/x
		foreach v in u v {
			by prodid: gen `v'N = sum(`v'jt)
		}
		by prodid: gen order=_n
		gsort prodid -order
		gen xN=vN/uN
		rename xN temp
		by prodid: replace temp=0 if _n>1
		by prodid: gen xN=sum(temp)
		drop temp ujt uN vN
			
	di "*Merge with estimates"
	if "`spec'"=="_nl" joinby brandid using  ${estimates}/withinestimates_betas_module`pmodule'.dta
			** created in 3_estimation/STATA/2_estimatessave_vN.do
				** variables: brandid model (unique identifiers) b_beta b_alpha0 b_alpha1 b_gamma 
				** also, if available, imports se_beta se_alpha0 se_alpha1 se_gamma
				** includes estimates for the base brand - any missing brandids were not in the estimation dataset		
				** joinby drops any observations for which the brandid is not in both datasets by default
		else if "`spec'"=="_hh"|"`spec'"=="_lin" joinby brandid using ${estimates}/withinestimates_module`pmodule'.dta
		
	di "*take logs of prices"
	
		foreach v in x `xextra' {
			gen ln`v' = ln(`v')
			quietly count if ln`v' == . 
	
			if _N == 0 {
				dis "*no observations left after taking logs of prices"
				assert 1 == 0 
			}
		}
		
	di "*before expanding, windsorize quality for any products for which parameters are such that some income group will have outlier components;"
	 di" and drop model-modules that will have outlier sigmas"
	 
		drop if b_beta==. | b_gamma==. | b_alpha0==. | b_alpha1==.
*	
		gen byte nproducts=1    
			
		**beta/gamma: 
			gen betagamma=b_beta*(1+b_gamma)
			sum betagamma, d
			gen byte nproducts_brandmiss=(abs(betagamma)>100) 
	
		**sigma:
			gen byte nproducts_sigmamiss=0
			foreach inc in 1 `nincgrps' {
				gen sigma`inc'=1+b_alpha0+b_alpha1*(${lninc`inc'} - `meanlninc')
				replace nproducts_sigmamiss=1 if (sigma`inc'<=1 | sigma`inc'>100) | abs(b_alpha1)>100 
			}
					
		**drop sigma & betagamma outliers:
			tab nproducts_sigmamiss nproducts_brandmiss
			gen drop = (nproducts_sigmamiss==1 | nproducts_brandmiss==1)
			foreach v in b_beta b_alpha0 b_alpha1 sigma1 sigma`nincgrps' {
				sum `v' if `v'!=0, d
				sum `v' if drop==0 & `v'!=0 
			}
			preserve
				bys model (drop): keep if _n==1
				list model drop b_gamma b_alpha0 b_alpha1 sigma1 sigma`nincgrps'
			restore

			drop if drop==1
			drop nproducts*

		if `r(N)'>0 {
		
			di "*identify various income points to calculate indexes for"
			sort model mktid prodid brandid
			isid model mktid prodid
			expand `nincgrps'
			desc
			count
			bys model mktid prodid: gen incgrp=_n
			count
			desc
			gen dmlninc = .
			
			forvalues inc=1/`nincgrps' {
				disp "`inc' of `nincgrps'"
					replace dmlninc = ${lninc`inc'} - `meanlninc' if incgrp==`inc'
					sum dmlninc if incgrp==`inc'
			}
					
			dis "*drop products for which beta == 0 (outside good)"		
				drop if b_beta == 0 
			
			di "*calculate indexes and save"
				calcindexes, xextra("`xextra'") pmodule(`pmodule') market(`market') pmodule(`pmodule') ///
					 year(`year') sample(`sample') sampleV(`sampleV') incfile(`incfile') 
						// sub-program defined below

			di "...save indexes"
				rename mktid `market'
				gen product_module_code = `pmodule'
				gen meanlninc = `meanlninc'
				save ${storemoduleindexes}/mkt_priceindices_`market'_`year'_module`pmodule'`sample'`sampleV'`incfile'.dta, replace
					
			
		}
}
end

*===========================================================================================
*===========================================================================================
*===========================================================================================
** Code to calculate price index components

capture program drop calcindexes
program define calcindexes
		
syntax [anything], xextra(string) pmodule(integer)  market(string) pmodule(string) year(string) incfile(string) [sample(string) sampleV(string)]
				

if 1==1 {
		
	di "...calculate beta and sigma's"
		gen B_brand=b_beta*(1+b_gamma*dmlninc)
		gen sigma=1+b_alpha0+b_alpha1*dmlninc
		
	di "...identify outliers for sigmas and beta/gammas"
		gen byte nproducts= 1    
		
	di "...calculate price index components and (if relevant) rename"
		foreach i in x `xextra' {
			gen adjp`i'=ln`i'-B_brand 
			sum adjp`i'
			gen A`i' = 0
			gen qtemp`i'=exp(A`i'-adjp`i')^(1-sigma) 
		}
		drop B_brand lnx*
	
	di "...keep only the set of products that has non-missing index components for all income levels and all income levels and models"
		gen byte nproducts_qnonmiss=(qtempx!=.)
		preserve
			* calculate the number of non-missing modulesbys product_module_code model mktid: gen n_qnonmiss_inc = sum(nmod_qnonmiss)
				bys prodid mktid model: gen n_qnonmiss_inc = sum(nproducts_qnonmiss) // number of non-missing observations (max should equal # income groups)
				by prodid mktid model: keep if _n==_N // keep one observation per product-market-model (i.e., drop income dimension)
				foreach suf in inc  {
					di "- summary of number of non-missing observations within a module-model-market, module-model"
						sum n_qnonmiss_`suf'
						gen commonprod_`suf' = (n_qnonmiss_`suf'==`r(max)')
					di "- number of module-model-markets included when requiring same set of modules across all income and income-models"
						tab commonprod_`suf' 
				}
				keep prodid mktid model commonprod_*
				sort prodid mktid model
				tempfile temp_qnonmiss
				save `temp_qnonmiss', replace
		restore
		capture drop _merge
		sort prodid mktid model 
		merge m:1 prodid mktid model using `temp_qnonmiss'
		
		foreach suf in inc {
			foreach i in x `xextra' { 
				gen qtemp`i'_`suf' = qtemp`i' if commonprod_`suf'==1
			}
		}	
	
	di "...collapse to model-mkt level"
		sort model mktid dmlninc (prodid)
		foreach v of varlist vjt qtemp* nproducts* commonprod_* {
			rename `v' old
			by model mktid dmlninc (prodid): gen `v' = sum(old)
			drop old
		}
		rename commonprod_* nproducts_common_*
		keep prodid model mktid dmlninc sigma* nproducts* A* vjt qtemp* dmlninc b_alpha0 b_alpha1 b_gamma b_beta
		by model mktid dmlninc (prodid): keep if _n==_N
		drop prodid
	
	di "...calculate product count and indexes"
		gen lncount=ln(nproducts_qnonmiss)
		foreach i in x `xextra' {
			gen V_m`i' = (qtemp`i'`suf'^(1/(1-sigma)))/exp(A`i')
			gen lnV_m`i' = (1/(1-sigma))*ln(qtemp`i'`suf')- A`i'
		}
		
}
end

*==================================================================================================
*==================================================================================================
*======================================================================================================
*** Code to define income categories

if 1==1{
cap prog drop defineincgrp_det
prog define defineincgrp_det

	syntax [anything], nquantiles(integer)

	local bounds 25000 35000 50000 70000 95000 125000 160000 200000

	forvalues i = 1(1)`nquantiles' {
		local a: word `i' of `bounds'
		global lninc`i' = ln(`a')
		dis "`i' is `a': ${lninc`i'}"
	}
		

end
}

*===========================================================================================
*===========================================================================================
*===========================================================================================
*======================================================================================================
**** Run programs and reset directory

	capture log close
	log using "${logs}/2_moduleindexes_allmods${sample}${sampleV}_${incgrp}_${market}${pm}.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	log close
//}

*==================================================================================================
*==================================================================================================
