*=================================================================================================
*** 3_aggindex_v[].do
*** 	this do file aggregate module-market-income level price indexes across modules.
*=================================================================================================

args market year source freq spec micro outsidegoodscutoff estdir test sample incgrp sampleV channel
	
	if "`market'"=="" {
		local market = "cbsa" 		// or "store_code_uc" for store-level indexes
		local year = 2012 
		local source = "matlab"
		local freq="month" 
		local spec ="_nl" 
		local micro = 2  
		local outsidegoodscutoff = 60 
		local estdir = 1
		local test = "0" 
		local sample = "_limit50"  	// "0" if market = "store_code_uc"
		local incgrp = "det"	
		local sampleV = "_v1" 		// "0" if market = "store_code_uc"
		local channel="0" 			// "_F" to only keep food stores if market = "store_code_uc"
	}
	
	foreach arg in cbsa test sample sampleV channel {
		if "``arg''"=="0" local `arg'=""
	}

	disp "`market' `year' `source' `pmodule' `freq' `spec' `micro' `outsidegoodscutoff' `estdir' `test' `sample' `incgrp' `sampleV' `channel'"
	
	foreach arg in machine task market year source pmodule freq spec micro outsidegoodscutoff estdir test sample incgrp sampleV channel {
		global `arg' "``arg''"
		dis "`arg' = ${`arg'}"
	}
	
	global xextra "xN"
	if "${market}"=="cbsa" global xextra "xN xH xL"
	
	if "${spec}"=="_lin" global stderrors=0
	
	if "${sample}" != "" global sampleN = subinstr("${sample}", "_limit", "", .)
	if "${sample}" != "" global sample "${sample}${sampleV}"	// combine sample suffix for naming data, ie _limit50_v2 = 2nd sampling of 50 stores 
	
	if "${incgrp}" == "det" {
		global nincgrps 8 
		global incfile "_incDetail"
	}
	
	
	dis "data suffix = ${sample}${incfile}" 

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
	
	global currentstep "$terminal/4_postestimation_analysis"

*Set-up standard directories	
	global data "$currentstep/Data"	
	global output "$currentstep/Output"
	global logs "$currentstep/Logs"

*Directory containing store sales data for Cobb-Douglas shares
	global step2data "${currentstep}/../2_preestimation_analysis/STATAData"
	
*Directory to indexes
	global moduleindexes "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}/module"
	global indexes "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}"
	global withinestimates "${currentstep}/../3_estimation/3a_withinmodule/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"

*===========================================================================================
*===========================================================================================
*===========================================================================================
**** Main Program to Import Data and Calculate Module-Market-Level Price Indices

if 1==1 {

capture program drop main
program define main 

	dis "${incgrp}, ${sample}, ${sampleN}"
	dis "data suffix = ${sample}${incfile}"

	if 1==1 {

	*calculate CD module weights
		modulesales
		
	*append module-level indexes and save
		appendmodindexes, market("${market}") channel("${channel}") year(${year}) sample("${sample}") incfile("${incfile}") test("${test}")

	*calculate upper-level indexes
		calcindexes, estdir(${estdir}) market("${market}") year(${year}) sample("${sample}") incfile("${incfile}") test("${test}") 

end

}

*===========================================================================================
*===========================================================================================
*===========================================================================================
** Code to calculate module-level sales shares for Cobb-Douglas (modulesales)

if 1==1 {

capture program drop modulesales
program define modulesales
		
syntax [anything]

di "*===================================================================="
	
	di "*** Calculate module-level sales shares"
	
		use store_code_uc pm productid year value commonunits using ${step2data}/product_${year}_sales_storelevel.dta, clear
			// created by /0_dataimport/Code/1c_RMS_datasetup_v[].do
	
		bys pm: gen totalvalue=sum(value)
		by pm: keep if _n==_N
		keep pm totalvalue
		rename totalvalue value
		rename pm product_module_code
		save ${data}/modulesales.dta, replace
	
end

}

*===========================================================================================
** Code to append module-level price indexes (appendmodindexes)

if 1==1 {

capture program drop appendmodindexes
program define appendmodindexes
		
syntax [anything], market(string) year(integer) [channel(string) sample(string) incfile(string) test(string)]

		di "*===================================================================="
		di "*** Append  module-level price indexes"

	disp "**non-homothetic price indexes"
		if "`test'"=="" local filelist: dir "${moduleindexes}" files "mkt_priceindices_`market'_`year'_module*`sample'`incfile'.dta"
		else local filelist: dir "${moduleindexes}" files "mkt_priceindices_`market'_`year'_module100*`sample'`incfile'.dta"
			// created by 2_moduleindex_allmods_v[].do
		
			local Nmod: word count `filelist'
			dis "there are `Nmod' modules created"
			assert `Nmod' > 0

		if ${stderrors}==1 local dVterms="dV*"
		local keepvars = "`market' product_module_code model meanlninc dmlninc sigma `dVterms' *V_* b_gamma vjt nproducts* b_beta"
		
		local first=1
		foreach f of local filelist{
				disp "`f'"
			if `first'==1 use `keepvars' using ${moduleindexes}/`f', clear
			else if "${test}"!="" & _N>100000 continue
			disp "appending `f'..."
			else append using ${moduleindexes}/`f', keep(`keepvars')
			local first=0
		}
		
		desc
		save ${indexes}/mkt_module_priceindices_`market'_`year'`test'`sample'`incfile'.dta, replace

		di "*===================================================================="
		di "*** Delete appended module-level price indexes"
			
			foreach f of local filelist{
				rm ${moduleindexes}/`f'
			}
			foreach f of local filelistCEPI{
				rm ${moduleindexes}/`f'
			}
		
end

}

*===========================================================================================
** Merge indexes with estimates and aggregate (calcindexes)

if 1==1 {

capture program drop calcindexes
program define calcindexes
		
syntax [anything], estdir(integer) market(string) year(integer) [channel(string) sample(string) incfile(string) test(string)]

	if "`sample'"!="" {
		local sampleN=subinstr("`sample'","limit","",.)
		use ${data}/StoreSample_Crosswalks/storecodesample${sampleN}_`market'`channel'${sampleV}_`year'.dta, clear
			// created in 2_preestimation_analysis/2_stylizedfact2.do
		bys `market': keep if _N>=10
		bys `market': keep if _n==_N
		keep `market'
		tempfile temp
		save `temp', replace
	}
	
	use ${indexes}/mkt_module_priceindices_`market'_`year'`test'`sample'`incfile'.dta if `market'!=., clear
		// created in in appendmodindexes above
	
		gduplicates drop 
		
	** only keep markets with many sampled stores
		if "`sample'"!="" merge m:1 `market' using `temp', keep(3) nogen
	
	if "`market'"!="cbsa" { 
		
	di "*Drop outlier module indexes"
		sort model product_module_code `market' 
		local looplist "x ${xextra}"
		foreach i of local looplist {
			preserve
				sort model product_module_code `market' dmlninc
				by model product_module_code `market' (dmlninc): gen min=lnV_m`i' if _n==1
				by model product_module_code `market' (dmlninc): gen max=lnV_m`i' if _n==_N
				by model product_module_code `market' (dmlninc): replace min=sum(min)
				by model product_module_code `market': keep if _n==_N
				gen gap=max-min
				keep model product_module_code `market' gap
				sort model product_module_code gap `market' 
				by model product_module_code (gap): gen jump=gap-gap[_n-1]
				by model product_module_code (gap): gen rank=_n/_N if gap!=.
				bys model: sum jump, d
				gen lim=10					
				sum rank if jump>lim, d
				gen dropdown=(jump>lim & rank>=0.5 & jump!=.)
				by model product_module_code (gap `market'): replace dropdown=sum(dropdown)
				gen dropup=(jump[_n+1]>lim & rank<0.5 & jump[_n+1]!=.)
				gsort model product_module_code -gap -`market'
				by model product_module_code: replace dropup=sum(dropup)
				gen drop=(dropup+dropdown>0)
				sum drop
				keep if drop==1
				keep product_module_code model `market'
				tempfile temp
				save `temp', replace
			restore
			merge m:1 product_module_code model `market' using `temp'
			replace lnV_m`i'=. if _merge==3
			drop _merge
		}	
	}

		rename `market' mktid 
		isid model mktid product_module_code dmlninc
		calcindexes, market("`market'") year(`year') sample("`sample'") incfile("`incfile'") test("`test'") 

	di "*Append and save indexes"
		preserve
			rename mktid `market'
			capture drop dV*
			
			save ${indexes}/mkt_priceindices_`market'_`year'`test'`sample'`incfile', replace
		
		restore
			
end

}

*===========================================================================================
** Code to calculate price index components (calcindexes)

if 1==1 {

capture program drop calcindexes
program define calcindexes
		
syntax [anything], market(string) year(string) [test(string) sample(string) incfile(string)]

	di "...drop modules with outlier standard deviations"
		local looplist "x ${xextra}"
		sort model product_module_code
		by model product_module_code: gen first=_n==1
		foreach i of local looplist {
			by model product_module_code: gegen sd=sd(lnV_m`i')
			bys model: egen p75=pctile(sd), p(75)
			replace lnV_m`i'=. if sd>10*p75
			tab product_module_code model if sd>10*p75
			gen b=sd/p75
			list model product_module_code b sd p75 if first & sd>10*p75
			drop sd p75 b
		}
		drop first

	di "...prep Cobb-Douglas aggregates"
		capture drop _merge
		merge m:1 product_module_code using ${data}/modulesales.dta
		foreach i in x ${xextra} {
			gen lnCD`i' = value*(lnV_m`i') 
			gen CDw`i' = value if lnCD`i' != .
		}
		
	di "...deal with missing obs..."
		gen nmod = 1
		gen nmod_qnonmiss = (lnV_mx!=.)				

	di "... keep only the set of modules that is common across all: income levels, incomes-markets, incomes-markets-models"
		
		if "`market'"!="cbsa" {
				
			di "...pre 1) drop modules that have data in less than 3/4 of the potential markets"
				capture drop nmkts
				bys model product_module_code dmlninc: egen nmkts=total(nmod_qnonmiss)
				forvalues m=1/4 {
					unique product_module_code if model==`m'
					sum nmkts if model==`m', d
					drop if nmkts<0.75*`r(max)' & model==`m'
					unique product_module_code if model==`m'
				}

			di "...pre 2) drop markets that are missing data for many modules"
				bys mktid model: egen nmodules=nvals(product_module_code)
				forvalues m=1/4 {
					unique mktid if model==`m'
					sum nmodules if model==`m', d
					drop if nmodules<0.75*`r(max)' & model==`m'
					unique mktid if model==`m'
				}
		}
		
		preserve
			sort product_module_code model mktid
			foreach i in x ${xextra} {
				gen a=(lnCD`i'!=.)
				by product_module_code model: gegen n_`v'`i'=total(a)
				drop a
			}
			by product_module_code model mktid: keep if _n==_N
			sort model
			foreach i in x ${xextra} {
				by model: gegen maxn_lnCD`i'=max(n_lnCD`i')
				gen keep_lnCD`i'=(n_lnCD`i'==maxn_lnCD`i')
		}
			keep product_module_code model mktid keep_*
			tempfile temp_nonmiss
			save `temp_nonmiss', replace
		restore
		
		capture drop _merge
		merge m:1 product_module_code model mktid using `temp_nonmiss'
		sort model mktid dmlninc
		foreach i in x ${xextra} {
			replace lnCD`i'=. if keep_lnCD`i'==0
			replace CDw`i' = value if lnCD`i' != .
		}
		drop keep_*
			
		
	di "...collapse to mkt level"
		sort model mktid dmlninc
		foreach v of varlist vjt lnCD* CD* {
			rename `v' old
			by model mktid dmlninc: gen `v' = sum(old)
			drop old
		}
		keep model mktid dmlninc vjt lnCD* CD*
		by model mktid dmlninc: keep if _n==_N

	di "...calculate indexes"
		foreach i in x ${xextra} {
			gen lnVCD`i' = lnCD`i'/CDw`i'
		}
	
	compress
	
end
}
					
*==================================================================================================
*==================================================================================================
**** Run programs and reset directory

	capture log close
	
	local cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	local ctime=hh(`t')*10000+mm(`t')*100+ss(`t')
	global logsuffix "`cdate'_`ctime'"
    
	log using "${logs}/3_agg_${market}${channel}_${year}_${freq}${sampleV}_${logsuffix}.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	log close

*==================================================================================================
*==================================================================================================
