*=================================================================================================
*** 4_indexcomparison_v[].do
*** 	this do file compares market indexes
*=================================================================================================

args market year source freq spec micro outsidegoodscutoff estdir test incgrp channel
	// arguments that specify which regression specification to call indices from - not changed 
	
	if "`market'"=="" {
		local market =  "cbsa" // alternatively "store_code_uc" 
		local year = 2012 
		local source = "matlab"
		local freq="month" 
		local spec ="_nl" 
		local micro = 2  
		local outsidegoodscutoff =60 
		local estdir = 1 
		local test = "0" 
		local incgrp = "det"	
		local channel="0" 		// "_F" to only keep food stores if market = "store_code_uc"
	}
	
	foreach arg in test channel  {
		if "``arg''"=="0" local `arg'=""
	}
	
	foreach arg in market year source pmodule freq spec micro outsidegoodscutoff estdir test incgrp channel {
		global `arg' "``arg''"
	}
	
	if "${incgrp}" == "det" {
		global nincgrps 8 
		global incfile "_incDetail"
	}

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	local a=strpos("$currentsteprepo","4_postestimation_analysis")
	if strpos("$currentsteprepo","4_postestimation_analysis")==0 {
		 disp "Need to run from step-specific directory"
		 exit
	}
	cd ${dir}
	global currentstep "$terminal/4_postestimation_analysis"	

*Set-up standard directories	
	global data "$currentstep/Data"	
	global logs "$currentstep/Logs"

	global outputbase "$currentsteprepo/RepoOutput/${freq}/${spec}"
	capture mkdir "$currentsteprepo/RepoOutput/${freq}"
	capture mkdir "$currentsteprepo/RepoOutput/${freq}/${spec}" 
	
*Directory for extra inputs
	global step2data "$currentstep/../2_preestimation_analysis/STATAData"	
	global kiltsdataprocessed "$terminal/../KiltsProcessing/RMS/1_moduleyear/Data"
	global processeddata "${currentstep}/../0_dataimport/STATAData"
	global estimates "${currentstep}/../3_estimation/3a_withinmodule/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"
	global estimatesinput "${currentstep}/../3_estimation/3a_withinmodule/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module"
	if "${cbsa}"!="" global estimatesinput "${estimatesinput}/${cbsa}"
	global estimatesinput "${estimatesinput}/${estdir}"
	
*Directory to indexes
	global indexes "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}"

	
*===========================================================================================
*For log files:

	global name="4_postest"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')

*===========================================================================================
* Preliminary Set-up						

	set scheme s2color, perm
	set printcolor auto, perm
	
*===========================================================================================================================================
*===========================================================================================================================================

capture program drop main
program define main	

	* create output folders
		cap mkdir "${outputbase}/micro${micro}"
		cap mkdir "${outputbase}/micro${micro}/${estdir}${channel}"				
		global output ${outputbase}/micro${micro}/${estdir}${channel}
		
	*analysis of store-level indexes
		if "`market'"=="store_code_uc" {
			store_results, year(${year}) market(${market}) level("") nincgrps(${nincgrps})  ///
				prices("") test("${test}") sample("${sample}") incgrp("${incgrp}") incfile("${incfile}") sampleV("`sampleV'")
		}
			
	*analysis of bootstrapped cbsa-level indexes	
		if "`market'"=="cbsa" {
			local sample = "_limit50"  	// "0" if market = "store_code_uc"
			local vmax ="100" 			// "0" if market = "store_code_uc"
			if "${sample}" != "" global sampleN = subinstr("${sample}", "_limit", "", .)
			
			foreach i in "" N { 
				cbsa_results, year(${year})  market(${market}) level("") nincgrps(${nincgrps})  ///
					prices("`i'") test("${test}") sample("${sample}") incgrp("${incgrp}")  incfile("${incfile}") totv(${vmax}) 
			}  // end of foreach i
			local rhsgrp "lninclnpcinc lninclnpop" // "base" choice of RHS variables
			local mktfe = ""  // "base" choice of marketfe
			p_comp_prices, name("${market}_${availabilitydata}_${clean}_${year}") rhsgrp("`rhsgrp'") market("${market}") ///
					incfile("${incfile}") test("${test}") sample("${sample}") 
		}		
end


********************************************************************************************************************************************
***** MASTER PROGRAMS FOR FULL AND/OR BOOTSTRAP SAMPLES
********************************************************************************************************************************************

********************************************************************************************************************************************
*** Results for single sample of store-level indexes

cap prog drop store_results
	prog def store_results 

	syntax [anything], year(integer)  ///
		market(string) nincgrps(integer) [ ///
		incfile(string) level(string) prices(string) ///
		test(string) sample(string) incgrp(string) ///
		sampleV(string)]

if 1==1 {

	dataprep, year(`year')  market(`market') level("") ///
		prices("`prices'") test("`test'") sample("`sample'") sampleV("`sampleV'") incfile("`incfile'") 
	
	* merge in store-level annual sales to use as weights
		rename marketid store_code_uc
		merge m:1 store_code_uc year using "${data}/store_RMS_annualsales.dta", keep(1 3)
			// created in subprogram[p_calc_store_annual_sales] below
		drop if _merge < 3
		drop _merge 
		rename store_code_uc marketid
		rename value sale				

	drop if parent_code==47

	output_regs_store, type("") name("`market'_`availabilitydata'_`clean'_`year'") cbsa("`cbsa'") market("`market'") ///
			prices("`prices'") sample("`sample'") test("`test'") incfile("`incfile'") 

}
end

********************************************************************************************************************************************
********************************************************************************************************************************************
*** Results for bootstrap samples of CBSA-level indexes

cap prog drop cbsa_results
	prog def cbsa_results 

	syntax [anything], year(integer) market(string) totv(integer) nincgrps(integer) [incfile(string) level(string) prices(string) test(string) sample(string) incgrp(string)] 

if 1==1 {
		dis "clear datasets to save results to"
			clear 
			save ${output}/`prices'citytocityreg_`market'_`year'`sample'`incfile'.dta, empty replace
		
		dis "** Loop over all `totv' boostrap samples"
			tempfile tempindexes // appended indexes to be saved here
			tempfile tempreginput // appended data for relasticity regression to be saved here
			forvalues bssample = 1(1)`totv' {
			di "sample version: `bssample'"
				local sampleV = "_v`bssample'"

			dataprep, year(`year')  market("`market'")  level("") ///
					prices("`prices'") test("`test'") sample("`sample'") sampleV("`sampleV'") incfile("`incfile'")

			if "`level'"==""  {	
				di "*Append indexes for excel export"
					preserve
						keep year model marketid marketname population lnpcincome lninc lnP
						if `bssample'>1 append using `tempindexes'
						save `tempindexes', replace
						di "...`bssample' out of `totv' done"
					restore
			}

				di "*Append and save data for elasticity regression data with all bssamples (and run regressions for last iteration)"
					preserve
						gen sampleid = `bssample'
						if `bssample'>1 append using `tempreginput'
						save `tempreginput', replace
						if `bssample'==`totv' {
							save ${output}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'.dta, replace
						}
					restore
			} // end of bssample
*

	di "**Excel output"
		use ${output}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'.dta, replace
		output_excel, bs(_bootstrap) market("`market'") prices("`prices'") type("`type'") test("`test'") sample("`sample'") incfile("`incfile'")
		
} // end of if 1==1 collapse	

end

********************************************************************************************************************************************
***** SUB-PROGRAMS USED FOR FULL AND/OR BOOTSTRAP SAMPLES
********************************************************************************************************************************************
capture program drop dataprep
	program define dataprep

	syntax [anything], year(integer) market(string) ///
		[level(string) prices(string) test(string) sample(string) sampleV(string) incfile(string)]

if 1==1 {

	tempfile tempindexes // used for exporting indexes below


	di "* Prep Market Data"
	if 1==1 {

		
		if "`market'"=="cbsa" {

			nhgis_pcincomepop_cbsa

			drop if cbsa==32580 
				//McAllen Texas
			
			tempfile tempcensus
				save `tempcensus', replace
				
		}	
		
		else if "`market'"=="store_code_uc" | "`market'"=="county" {

			nhgis_pcincomepop_county
				tempfile tempcensus
				save `tempcensus', replace
			
			if "`market'"=="store_code_uc" {
			
			di "Store-county concordance to infer store clientele income based on county income"
				use ${kiltsdataprocessed}/stores_`year'.dta, clear
						** created in grid: KiltsProcessing/RMS/1_moduleyear/Programs/0a_prepcharacteristicinfo_v[]
					gen county = fips_state_code*1000+fips_county_code
					keep county store_code_uc
					bys  county store_code_uc: keep if _n==1
					tempvar a
					bys store_code_uc: gen `a'=_N
					list if `a'>1
					bys store_code_uc: keep if _n==1
					sort store_code_uc
					merge m:1 county using `tempcensus', keep(3)
					keep store_code_uc county pcincome population
					tempfile tempcensus
					save `tempcensus'
					
				
				use "${terminal}/1_dataprep/STATAData/storeincdist_logincpctiles.dta", clear
					** created in 1_dataprep/2a_outputforMATLAB_prep_vN.do
					*** avginc in the 30th bucket of the weighted income distribution of tracts in the vicinity of the store
					
					forval i=1/50 {
						gen w_avginc_level`i'=exp(avginc`i')*weight`i'
					}
					egen sum_w = rowtotal(weight*)
					egen sum_avginc_level = rowtotal(w_avginc_level*)
					gen storemeaninc = sum_avginc_level/sum_w
					
					drop avginc* weight* w_avginc_level* sum_avginc_level sum_w

					merge 1:1 store_code_uc using `tempcensus', keep(3) nogen
					rename pcincome countypcincome
					rename storemeaninc pcincome
					save `tempcensus', replace
					
			}
		}
	}		
	
	di "*Price indexes...	"
		use `market' model dmlninc meanlninc nmod_* lnV* using ${indexes}/mkt_priceindices_`market'_`year'`test'`sample'`sampleV'`incfile'.dta, clear
				** created in 3_aggindex_v[].do
		drop if `market'==.	
		isid `market' model dmlninc
	

	di "*Model labels"
		duplicates drop
		local i=0
		gen modeltitle=""
		foreach modeltitle in "Homothetic" "Non-Homothetic in Price" "Non-Homothetic in Quality" "Non-Homothetic in Price and Quality" { 
			local i=`i'+1
			replace modeltitle="`i'. `modeltitle'" if model==`i'
		}
	
	di "*Merge in city-specific data"
		sort `market' 
		capture drop _merge
		merge m:1 `market' using `tempcensus'
		tab _merge
		keep if _merge==3
		drop _merge
		gen lnpop=ln(population)
		gen lnpcincome=ln(pcincome)
		rename `market' marketid
		capture rename `market'name marketname // doesn't exist for store-level data

	di "*Pull out price variable of interest"
		capture gen year=`year'
		rename lnVCDx`prices' lnV
		
	di "*Generate income variable and income group dummy*pc income interactions"
		tab dmlninc
		gen lninc = dmlninc+meanlninc
		sort lninc
		egen incomegroup=group(lninc)
		capture drop temp
		quietly tab incomegroup, gen(incomegroup_)
		local nincgrps=r(r)
		forvalues inc=1/`nincgrps' {
			quietly gen lnpcincome_`inc'=incomegroup_`inc'*lnpcincome
			quietly gen lnpop_`inc'=incomegroup_`inc'*lnpop
		}

	di "*Elasticity regression variables"
		bys modeltitle `level_var': egen lnincbar=mean(lninc)
		gen lnincint=lninc-lnincbar
		gen lninclnpcinc=lnincint*lnpcincome
		gen lninclnpop=lnincint*lnpop			
		drop lnincint lnincbar
*
	di "*Generate Price Indexes from V utility indexes"
		if "`incfile'"=="_incDecile" {
			gen lnVlessCEPI=lnV-lnVCEPI
			foreach cepivar in CEPI lessCEPI {
				gen lnP`cepivar'=-lnV`cepivar'
			}
		}
		gen lnP=-lnV

}
end


*==================================================================================================
capture program drop nhgis_pcincomepop_cbsa  // used in dataprep
	program define nhgis_pcincomepop_cbsa
	
	syntax [anything]
if 1==1 {	
	
	*2000-2014 ACS data with 2013 CBSA codes (downloaded from nhgis.org on 6/25/2019)
	insheet using "${rawNHGIS}/2014/nhgis0007_ds206_20145_2014_cbsa.csv", names comma clear 
	rename aba1e001 population
	rename abfie001 pcincome
	rename cbsa cbsaname
	rename cbsaa cbsacode
	keep cbsaname cbsacode population pcincome
	label var cbsacode "CBSA code"
	rename cbsacode cbsa

} 
end

*==================================================================================================
capture program drop nhgis_pcincomepop_county  // used in dataprep
	program define nhgis_pcincomepop_county
	
	syntax [anything]
if 1==1 {	
	
	*2000-2014 ACS data (downloaded from nhgis.org on 6/25/2019)
	insheet using "${rawNHGIS}/2014/nhgis0008_ds206_20145_2014_county.csv", names comma clear 
	keep name_e statea countya aba1e001 abfie001
	gen county=statea*1000+countya
	label var county "County Code"
	drop statea countya
	rename name_e countyname
	rename aba1e001 population
	rename abfie001 pcincome // Per Capita Income in the Past 12 Months (in 2012 Inflation-Adjusted Dollars)
}		
end

********************************************************************************************************************************************
*** output_excel
* Outputs indexes to excel
	
capture program drop output_excel
	program define output_excel
	
	syntax [anything], type(string) market(string) [bs(string) test(string) sample(string) incfile(string) prices(string)]
if 1==1 {	

	preserve
	
	di "*************************************************************************************"
	di "**Output city-level indexes by income group"

		tempfile tempindexes temphom
			
		di "*prep for re-shape"
			capture drop inc
			gen inc=floor(exp(lninc))
			rename marketname mkt
			drop if inc==.
			capture drop P

		di "...demean indexes relative to model and income group"
			bys model incomegroup: egen meanlnP=mean(lnP)	
			replace lnP=lnP-meanlnP
			
			gen P=exp(lnP)
			keep year model marketid mkt population lnpcincome inc P
			collapse (mean) P (sd) sdP = P, by (year model marketid mkt population lnpcincome inc)
			save `tempindexes', replace
		di "*extract homothetic indexes"
			keep if model==1
			bys year marketid mkt population lnpcincome: egen a=nvals(P)
			sum a
			assert `r(max)'==1
			by year marketid mkt population lnpcincome: keep if _n==1
			drop a model
			rename *P *Phom
			save `temphom', replace
		di "*reshape indexes model-by-model, merge with homothetic and export"
			forvalues m=2/4 {
				use `tempindexes', clear
				keep if model==`m'
				count
				if `r(N)'<2 disp "no observations for model `m'"
				else {
					drop model
					reshape wide *P, i(year marketid mkt population lnpcincome) j(inc)
					merge 1:1 year marketid mkt population lnpcincome using `temphom'
					aorder
					order marketid mkt population lnpcincome *Phom
					export excel using "${output}/`prices'cityindexes_`market'`bs'.xls", firstrow(var) ///
						sheet("_`m'`test'`sample'`incfile'") sheetreplace 
				}
			}
		
	restore
}

end

********************************************************************************************************************************************
*** output_regs_store
*** 	regressions including comparisons across HI and LI counties within CBSA for store-level indexes

capture program drop output_regs_store
	program define output_regs_store

	syntax [anything], name(string) market(string) [prices(string) type(string) test(string) sample(string) cbsa(string) incfile(string)  sampleV(string) bootstrap(string)]
	
if 1==1 {
	di "*************************************************************************************"

	di "* Load county inc group, CBSA affiliation and CBSA pcinc"
		preserve

			di "* Load county-CBSA crosswalk data"
				import excel ${rawMABEL}/county2cbsa10.xlsx, clear firstrow allstring
					// downloaded from MABLEGeocorr (https://www.psc.isr.umich.edu/dis/census/crosswalk.html) on 7/31/2017
					// maps into panelist fips codes perfectly and NHGIS data for all but PR
					// CBSA codes = 2010 codes 
				destring cbsa, replace
				destring county, replace
				keep county cbsa cbsaname 
				tempfile tempcounty2cbsa
				save `tempcounty2cbsa'

			di "* load cbsa income"
				nhgis_pcincomepop_cbsa
					tempfile tempcbsainc
					save `tempcbsainc', replace

				nhgis_sizeadjincome, market(cbsa) 
					merge 1:1 cbsa using `tempcbsainc', nogen
					drop pcincome
					rename medhhinc cbsapcincome
					rename population cbsapop
					gen lncbsapcincome=ln(cbsapcincome)
					gen lncbsapop=ln(cbsapop)
					save `tempcbsainc', replace

			di "*identify high- and low-income counties"
				insheet using "${rawNHGIS}/nhgis_2010_county/nhgis0004_ds191_20125_2012_county.csv", names comma clear 
					** downloaded from nhgis.org 07/07/2017
					** Dataset: 2006-2012 ACS 5-year estimate, All counties within the United States
				drop county 
				gen county=statea*1000+countya
				rename qspe001 population
				rename qwue001 pcincome 
					** Per Capita Income in the Past 12 Months (in 2012 Inflation-Adjusted Dollars)
				keep county pcincome population
				rename pcincome countypcincome 
				rename population countypop
				tempfile tempcountyinc
				save `tempcountyinc'

			di "* merge in county inc, CBSA affiliation and CBSA pcinc" 
				merge 1:1 county using `tempcounty2cbsa', keep(1 3) nogen
				merge m:1 cbsa using `tempcbsainc', keepusing(lncbsapcincome cbsapcincome cbsapop) keep(1 3) nogen
				tempfile tempmkt
				save `tempmkt'

		restore

	di "* Create county identifier and merge in CBSA info"

		if "`market'" == "county" {
			capture gen county = marketid
			local marketstr = "County"
		}
		else local marketstr = "Store"

		merge m:1 county using  `tempmkt', keep(1 3) nogen


	di "* Identify H and L income CBSAs, counties/neighborhoods"
		preserve
			capture gen store_code_uc=marketid
			gen store_code_ucpop=1
			gen store_code_ucpcincome=pcincome
			foreach mkt in `market' cbsa   {
				keep `mkt' `mkt'pcincome `mkt'pop
				duplicates drop
				xtile `mkt'inc=`mkt'pcincome, n(2) //  [aw=`mkt'pop]
				bys `mkt'inc: sum `mkt'pcincome
				gen `mkt'incgp="H" if `mkt'inc==2
				replace `mkt'incgp="L" if `mkt'inc==1
				keep `mkt' `mkt'incgp
				tempfile temp`mkt'incgp
				save `temp`mkt'incgp'
				restore, preserve
			}
		restore
		capture gen store_code_uc=marketid
		merge m:1 `market' using `temp`market'incgp', nogen		
		drop store_code_uc
		merge m:1 cbsa using `tempcbsaincgp', nogen		

	di "* Generate CBSA*HHincome interactions"
		egen cbsa_x_inc = group(cbsa lninc)
		if "`market'"=="store_code_uc" egen chain_x_inc = group(chain lninc)		
		
		bys modeltitle `level_var': egen lnincbar=mean(lninc)
		gen lninclncbsapcinc=(lninc-lnincbar)*lncbsapcincome
		drop lnincbar

	di "*Elasticity regressions" 

		foreach m in 3 {

			if  "`market'"=="store_code_uc" &  "`prices'"=="" local wgtsufs = "population" // "population exp expL expM expH" 
			else local wgtsufs = ""
			di "*`market', `prices', `wgtsufs'"

			foreach wgtsuf in "non" ""  `wgtsufs' { 

				if "`wgtsuf'"=="" {
						if "`market'"=="store_code_uc"  local wgt = "[aweight=sale]"
						else local wgt = "[aweight=population]"
					}
				else if "`wgtsuf'"=="non"  local wgt = ""
				else local wgt = "[aweight=`wgtsuf']"

				_eststo clear
				
				if "`market'"=="store_code_uc" local secondfes="chain_x_inc"
				
				foreach secondfes in "" `secondfes' {
				
					if "`secondfes'"=="" local chainincfelab="No"
					if "`secondfes'"=="chain_x_inc" local chainincfelab="Yes"
					
					reghdfe lnP`type' lnpcincome lninclnpcinc if  substr(modeltitle,1,1)=="`m'" `wgt', absorb(incomegroup  `secondfes') vce(cluster incomegroup marketid)
					eststo reg1`secondfes'
					estadd local lnincfe "Yes"
					estadd local cbsaincfe "No"
					estadd local chainincfe "`chainincfelab'"
					estadd local storeset "All"
					estadd local Nmkt `e(N_clust2)'
					estadd local Ncbsa "-"
					
					reghdfe lnP`type' lnpcincome lninclnpcinc if  substr(modeltitle,1,1)=="`m'" `wgt', absorb(cbsa_x_inc  `secondfes') vce(cluster incomegroup marketid)
					eststo reg2`secondfes'
					estadd local lnincfe "Yes"
					estadd local cbsaincfe "Yes"
					estadd local chainincfe "`chainincfelab'"
					estadd local storeset "All"
					estadd local Nmkt `e(N_clust2)'
					estadd local Ncbsa "-"
					
					reghdfe lnP`type' lncbsapcinc lninclncbsapcinc if substr(modeltitle,1,1)=="`m'"  `wgt', absorb(incomegroup  `secondfes') vce(cluster incomegroup cbsa)
					eststo reg3`secondfes'
					estadd local lnincfe "Yes"
					estadd local cbsaincfe "No"
					estadd local chainincfe "`chainincfelab'"
					estadd local storeset "All"
					local temp=e(N)/e(N_clust1)
					estadd local Nmkt `temp'
					estadd local Ncbsa  `e(N_clust2)'

					reghdfe lnP`type' lncbsapcinc lninclncbsapcinc  if substr(modeltitle,1,1)=="`m'" & `market'incgp=="H" `wgt', absorb(incomegroup  `secondfes') vce(cluster incomegroup cbsa)
					eststo reg4`secondfes'
					estadd local lnincfe "Yes"
					estadd local cbsaincfe "No"
					estadd local chainincfe "`chainincfelab'"
					estadd local storeset "High-Inc."
					local temp=e(N)/e(N_clust1)
					estadd local Nmkt `temp'
					estadd local Ncbsa `e(N_clust2)'
									
					reghdfe lnP`type' lncbsapcinc lninclncbsapcinc if substr(modeltitle,1,1)=="`m'" & `market'incgp=="L" `wgt', absorb(incomegroup  `secondfes') vce(cluster incomegroup cbsa)
					eststo reg5`secondfes'
					estadd local lnincfe "Yes"
					estadd local cbsaincfe "No"
					estadd local chainincfe "`chainincfelab'"
					estadd local storeset "Low-Inc."
					local temp=e(N)/e(N_clust1)
					estadd local Nmkt `temp'
					estadd local Ncbsa `e(N_clust2)'
				}	
				if "`market'"=="store_code_uc" {
					esttab reg1 reg3 reg4 reg5 reg1chain_x_inc reg3chain_x_inc using "${output}/`prices'HLreg`wgtsuf'_`name'_`m'`type'`test'`sample'`incfile'`sampleV'.tex", replace ///
						wrap varwidth(50) ${esttabopts}  coeflabel(lnpcincome "${lnstorepcinclab}" lncbsapcincome "${lncbsapcinclab}" lninclnpcinc "${lnstoreinclnpcinclab}" lninclncbsapcinc "${lninclncbsapcinclab}") ///
						prehead("{ \begin{tabular}{l*{@M}{c}}" "\toprule \multicolumn{6}{c}{Dependent Variable: Ln(Price Index for Representative Consumer \$k\$ in ${`market'lab} \$s\$ in CBSA \$c(s)\$)}\\" ///
						"& ${numline6} \\")  ///
						stats(lnincfe chainincfe storeset Nmkt Ncbsa N r2_a_within,  fmt(0 0 0 %9.0gc %9.0gc %9.0gc 2) labels("Income Group \$k\$ FEs" "Chain x Income Group FEs" "${`market'lab} Set (${`market'inclab} Per Capita Income\$_c\$)" "Number of ${`market'slab} (\$c\$)" "Number of CBSAs" "Observations" "adj. within \$R^2\$")) 
				}
				else {
					esttab reg1 reg3 reg4 reg5 using "${output}/`prices'HLreg`wgtsuf'_`name'_`m'`type'`test'`sample'`incfile'`sampleV'.tex", replace ///
						wrap varwidth(50) ${esttabopts}  coeflabel(lnpcincome "${lnpcinclab}" lncbsapcincome "${lncbsapcinclab}" lninclnpcinc "${lninclnpcinclab}" lninclncbsapcinc "${lninclncbsapcinclab}") ///
						prehead("{ \begin{tabular}{l*{@M}{c}}" "\toprule \multicolumn{5}{c}{Dependent Variable: Ln(Price Index for Representative Consumer \$k\$ in ${`market'lab} \$c\$)}\\" ///
						"& ${numline4} \\")  ///
						stats(lnincfe storeset Nmkt Ncbsa N r2_a_within,  fmt(0 0  %9.0gc %9.0gc %9.0gc 2) labels("Income Group \$k\$ FEs" "${`market'lab} Set (${`market'inclab} Per Capita Income\$_c\$)" "Number of ${`market'slab} (\$c\$)" "Number of CBSAs" "Observations" "adj. within \$R^2\$")) 
					
				}	
					
			} // end of weighting specification wgt
		} // end of model m
} // end of if 1==1 collapse

end

********************************************************************************************************************************************
*** compare regression results from differentt LHS price variables
	
capture program drop p_comp_prices
	program define p_comp_prices

	syntax [anything], name(string) rhsgrp(string) [type(string) incfile(string) test(string) sample(string) sampleV(string) market(string)]
	
if 1==1 {

	* append processed data with lnP from different price variables
		local pcount = 0 
		cap erase "${output}/temp_allp_city2city_`name'_`type'`test'`sample'`incfile'.dta"
		foreach prices in  "" "N" {	
			use ${output}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta, clear
				// created in subprogram [singlesample_restults] for _v1/ in [bootstrap_results] for appended samples
			gen prices = "`prices'"
			if `pcount'>0 append using "${output}/temp_allp_city2city_`name'_`type'`test'`sample'`incfile'.dta"
			save "${output}/temp_allp_city2city_`name'_`type'`test'`sample'`incfile'.dta", replace
			local pcount = `pcount' + 1
		}
		
		
	* create interaction term
	if "${vmax}"!="" & "`sampleV'"==""  {

		di "Include fe on terms interacted with sample ID when pooling bootstrap sample"
		tostring incomegroup, gen(str_incomegroup)
		tostring sampleid, gen(str_sampleid)
		tostring marketid, gen(str_mktid)

		gen temp = str_incomegroup + "_" + str_sampleid // "interaction term" to absorb
		egen incomegroup_sampleid = group(temp)
		drop temp
		gen temp = str_mktid + "_" + str_sampleid // "interaction term" tp absorb
		egen marketid_sampleid = group(temp)
		 
		drop str_incomegroup str_sampleid str_mktid temp

		local FEsuf "_sampleid"
	}
	else local FEsuf ""
		
		local rhsList "lnpcincome" "lnpcincome lninclnpcinc" "lnpcincome lnpop" "lnpcincome lnpop lninclnpcinc lninclnpop" 
		
		
		forvalues m=3/4 {
			
			count if lnP!=. & substr(modeltitle,1,1)=="`m'" 
			if `r(N)'<2 disp "no non-missing lnP for model `m'"
			else {
			
				foreach wgtsuf in "non" ""   {

					if "`wgtsuf'"=="" {
						if "`market'"=="store_code_uc"  local wgt = "[aweight=sale]"
						else local wgt = "[aweight=population]"
					}
					else if "`wgtsuf'"=="non"  local wgt = ""
					else local wgt = "[aweight=`wgtsuf']"

					_eststo clear

					forvalues i = 2(2)4 {
							
						local rhsgrp: word `i' of "`rhsList'"
						local rhsgrpfe=subinstr(subinstr("`rhsgrp'","lnpcincome ","",.),"lnpop ","",.)
						display "model: `m', RHS: `rhsgrp'"

						if "`bootstrap'"=="1" di "... Add iteration FE"

						foreach prices in  "" "N" {
							if trim("`rhsgrpfe'")!="" {
								reghdfe lnP `rhsgrpfe' if substr(modeltitle,1,1)=="`m'" & prices=="`prices'" `wgt', absorb(incomegroup`FEsuf' marketid`FEsuf') vce(cluster marketid incomegroup)
								eststo reg`i'a`prices'
								estadd local lnincfe "Yes"
								estadd local lninc2fe "No"
								estadd local cbsafe "Yes"
							}
							
							reghdfe lnP `rhsgrp' if substr(modeltitle,1,1)=="`m'" & prices=="`prices'"  `wgt', absorb(incomegroup`FEsuf') vce(cluster marketid incomegroup)
							eststo reg`i'b`prices'
							estadd local lnincfe "Yes"
							estadd local lninc2fe "No"
							estadd local cbsafe "No"		
						
						} // end of prices
					} // end of this RHS specifications

					esttab reg2b reg4b reg2bN reg4bN using "${output}/comp_p_citytocityreg`wgtsuf'_`name'_`m'`test'`sample'`incfile'_xbsfe.tex", replace ///
						wrap varwidth(50) label ${esttabopts} ///
						stats(lnincfe N_clust1 N r2_a_within, fmt(0 %9.0gc %9.0gc 2) labels("Income Group \$k\$*Bootstrap Sample FEs" "Number of ${`market'slab} (\$c\$)" "Observations" "adj. within \$R^2\$")) ///
						coeflabel(lnpcincome "${lnpcinclab}" lnpop "${lnpoplab}" lninclnpcinc "${lninclnpcinclab}" lninclnpop "${lninclnpoplab}") ///
						prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{@M}{c}} \toprule" "\multicolumn{5}{c}{Dependent Variable: Ln(Price Index for Household in Income Group \$k\$ in ${`market'lab} \$c\$)}\\" ///
							" & \multicolumn{2}{c}{Local Prices} & \multicolumn{2}{c}{National Prices}\\" ///
							" \cmidrule(lr){2-3} \cmidrule(lr){4-5} & ${numline4} \\") 

				} // end of weighting specification wgt
			} // end of obs check
		} // end of model m
	
} // end of if 1==1 collapse
end


*===========================================================================================================================================
* collapse previous datasets to create store annual sales from RMS

cap prog drop p_calc_store_annual_sales
	prog define p_calc_store_annual_sales

	syntax[anything]

if 1==1 {
	use "${terminal}/1_dataprep/STATAData/store_monthlysales.dta", clear
			// created by 1_dataprep/Code/0_RMS_montlysales_v[].do
	drop if store_code_uc==. | year ==.

	bys store_code_uc year (month): gen tempsum = sum(value)
	drop value month
	rename tempsum value
	by store_code_uc year : keep if _n==_N

	save "${data}/store_RMS_annualsales.dta", replace
}
end


*===========================================================================================================================================
*===========================================================================================================================================

*** Run programs and reset directory

	capture log close
	log using "$logs/${name}_${cdate}_${ctime}${vmax}.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*===========================================================================================================================================
*===========================================================================================================================================
