*=================================================================================================
*** 4a_indexcomparison_speccomptables.do
*** 	this do file runs different robustness specifications of the index analysis
*=================================================================================================

args  market year source freq spec micro outsidegoodscutoff estdir test sample incgrp vmax channel
	// arguments that specify which regression specification to call indices from - not changed 
	
	if "`market'"=="" {
		local market = "cbsa"
		local year =2012
		local source = "matlab"
		local freq="month"
		local spec ="_nl"
		local micro = 2 // 0 
		local outsidegoodscutoff =60 
		local estdir = 1 
		local test = "0" 
		local sample = "_limit50" 
		local incgrp = "det" 
		local vmax ="100" 
		local channel= "0" 
	}
	
	foreach arg in test vmax sample channel CD {
		if "``arg''"=="0" local `arg'=""
	}
	
	foreach arg in  market year source pmodule freq spec micro outsidegoodscutoff  estdir test sample incgrp vmax channel {
		global `arg' "``arg''"
	}
	
	if "${sample}" != "" global sampleN = subinstr("${sample}", "_limit", "", .)

	if "${incgrp}" == "det" {
		global nincgrps 8 
		global incfile "_incDetail"
	}

*===========================================================================================
*** Directory Set-up
	
*Set project directories	

	do ../../SetFilePaths.do
			// $terminal = Server directory where project is located
			// $dir = GitHub repo directory where this code is located (output from pwd)
	
	cd ${dir}/..
	pwd
	global currentsteprepo: pwd
	disp "$currentsteprepo"
	local a=strpos("$currentsteprepo","4_postestimation_analysis")
	if strpos("$currentsteprepo","4_postestimation_analysis")==0 {
		 disp "Need to run from step-specific directory"
		 exit
	}
	cd ${dir}
	global currentstep "$terminal/4_postestimation_analysis"	

*Set-up standard directories	
	global data "$currentstep/Data"	
	global logs "$currentstep/Logs"

	global outputbase "$currentsteprepo/RepoOutput/${freq}/${cbsa}/${spec}"
	
*Directory for extra inputs
	global step2data "$currentstep/../2_preestimation_analysis/STATAData"	
	global kiltsdataprocessed "$terminal/../KiltsProcessing/RMS/1_moduleyear/Data"
	global processeddata "${currentstep}/../0_dataimport/STATAData"
	global estimates "${currentstep}/../3_estimation/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module/${estdir}"
	global estimatesinput "${currentstep}/../3_estimation/STATA/Data/estimates/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/module"
	global estimatesinput "${estimatesinput}/${estdir}"
	
*Directory to indexes
	global indexes "$data/indexes/${freq}/${source}estimates/micro${micro}${spec}/outside${outsidegoodscutoff}/${estdir}${channel}"

	
*===========================================================================================
*For log files:

	global name="4_postestrobust"
	global cdate : di %tdCCYY.NN.DD date(c(current_date),"DMY")
	local t=clock(c(current_time),"hms")
	global ctime=hh(`t')*10000+mm(`t')*100+ss(`t')

*===========================================================================================
* Preliminary Set-up						

	*set scheme s1mono, perm
	set scheme s2color, perm
	set printcolor auto, perm
	
*===========================================================================================================================================
*===========================================================================================================================================

capture program drop main
program define main	

	local rhsgrp "lninclnpcinc lninclnpop" 
	local mktfe = "" 
	global output ${outputbase}/micro${micro}/${estdir}${channel}/			

	p_comp_robustnesstable, name("${market}_${availabilitydata}_${clean}_${year}") rhsgrp("`rhsgrp'") market("${market}") ///
		type("${type}") incfile("${incfile}") test("${test}") sample("${sample}") 


end


********************************************************************************************************************************************
***** Sub-programs
********************************************************************************************************************************************
********************************************************************************************************************************************
*** compare regression results from a variety of different specs for robustness tabl
	
capture program drop p_comp_robustnesstable
	program define p_comp_robustnesstable

	syntax [anything], name(string) rhsgrp(string)  [type(string) incfile(string) test(string) sample(string) sampleV(string) market(string)]
	
if 1==1 {
	di "*************************************************************************************"
	di "*Elasticity regressions"

	local prices ""

	* append processed data with lnP from different price variables
	local pcount = 0
		use ${output}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta, clear
			// created in subprogram in [cbsa_results] for appended samples
		gen spec = "base"
		global speclist="base"
		global spectitles="\multicolumn{1}{r}{Estimation Specification:} &\multicolumn{1}{c}{Base} "
		global priceelasticities="\multicolumn{1}{l}{Median Price Elasticity ($\alpha_0$)}"
		global incomequality="\multicolumn{1}{l}{Median Income-Quality Elasticity ($\gamma$)}"
		preserve
			local estpath="${estimatesinput}"
			addparmstats, estpath(`estpath') // sub-program defined below
		restore
		local pcount=`pcount'+1
	*
		global outputalt=subinstr(subinstr("${output}", "${estdir}", "2", .),"outside${outsidegoodscutoff}","outside40",.)
		append using "${outputalt}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta"
		replace spec = "alt`pcount'" if spec==""
		global speclist="${speclist} alt`pcount'"
		global spectitles="${spectitles} & \multicolumn{1}{c}{OG 40\%}"
		preserve
			local estpath=subinstr(subinstr("${estimatesinput}","${estdir}","2",.),"outside${outsidegoodscutoff}","outside40",.)
			addparmstats, estpath(`estpath') // sub-program defined below	
		restore
		local pcount=`pcount'+1
	*	
		global outputalt=subinstr(subinstr("${output}", "${estdir}", "3", .),"outside${outsidegoodscutoff}","outside80",.)
		append using "${outputalt}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta"
		replace spec = "alt`pcount'" if spec==""
		global speclist="${speclist} alt`pcount'"
		global spectitles="${spectitles} & \multicolumn{1}{c}{OG 80\%}"
		preserve
			local estpath=subinstr(subinstr("${estimatesinput}","${estdir}","3",.),"outside${outsidegoodscutoff}","outside80",.)
			addparmstats, estpath(`estpath') // sub-program defined below		
		restore
		local pcount=`pcount'+1
	*	
		global outputalt=subinstr("${output}", "${estdir}", "4", .)
		append using "${outputalt}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta"
		replace spec = "alt`pcount'" if spec==""
		global speclist="${speclist} alt`pcount'"
		global spectitles="${spectitles} & \multicolumn{1}{c}{OG Sh > 1\%}"
		preserve
			local estpath=subinstr("${estimatesinput}","${estdir}","4",.)
			addparmstats, estpath(`estpath') // sub-program defined below		
		restore
		local pcount=`pcount'+1	
	*	
		global outputalt=subinstr(subinstr("${output}", "${estdir}", "5", .),"month","quarter",.)
		append using "${outputalt}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta"
		replace spec = "alt`pcount'" if spec==""
		global speclist="${speclist} alt`pcount'"
		global spectitles="${spectitles} & \multicolumn{1}{c}{Qtly Data}"
		preserve
			local estpath=subinstr(subinstr("${estimatesinput}","${estdir}","5",.),"month","quarter",.)
			addparmstats, estpath(`estpath') // sub-program defined below	 	
		restore
		local pcount=`pcount'+1

		global outputalt=subinstr("${output}", "${estdir}", "6", .)
		append using "${outputalt}/temp_`prices'city2city_`market'_`type'`test'`sample'`incfile'`sampleV'.dta"
		replace spec = "alt`pcount'" if spec==""
		global speclist="${speclist} alt`pcount'"
		global spectitles="${spectitles} & \multicolumn{1}{c}{Resid IV}"
		preserve
			local estpath=subinstr("${estimatesinput}","${estdir}","6",.)
			addparmstats, estpath(`estpath') // sub-program defined below		
		restore
		local pcount=`pcount'+1
		
	* create interaction term
		di "Include fe on terms interacted with sample ID when pooling bootstrap sample"
		tostring incomegroup, gen(str_incomegroup)
		tostring sampleid, gen(str_sampleid)
		tostring marketid, gen(str_mktid)

		gen incomegroup_sampleid = str_incomegroup + "_" + str_sampleid // "interaction term" to absorb
		gen marketid_sampleid = str_mktid + "_" + str_sampleid // "interaction term" tp absorb

		drop str_incomegroup str_sampleid str_mktid

		local FEsuf "_sampleid"
	
		local rhsList "lnpcincome" "lnpcincome lninclnpcinc" "lnpcincome lnpop" "lnpcincome lnpop lninclnpcinc lninclnpop" 
			
		forvalues m=3/3 {
			
			count if lnP!=. & substr(modeltitle,1,1)=="`m'" 
			if `r(N)'<2 disp "no non-missing lnP for model `m'"
			else {
				_eststo clear
				foreach wgtsuf in "" "non"  {

					if "`wgtsuf'"=="" {
						local wgt = "[aweight=population]"
					}
					else if "`wgtsuf'"=="non"  local wgt = ""
					else local wgt = "[aweight=`wgtsuf']"

					
					forvalues i = 2(2)2 {
							
						local rhsgrp: word `i' of "`rhsList'"
						display "model: `m', RHS: `rhsgrp'"

						if "`bootstrap'"=="1" di "... Add iteration FE"

						foreach spec in ${speclist} {

							reghdfe lnP `rhsgrp' if substr(modeltitle,1,1)=="`m'" & spec=="`spec'"  `wgt', absorb(incomegroup`FEsuf') vce(cluster marketid incomegroup)
							eststo `spec'
							estadd local lnincfe "Yes"
							estadd local lninc2fe "No"
							estadd local cbsafe "No"
							
						} // end of specs
					} // end of this RHS specifications

					esttab ${speclist} using "${output}/comptoallrobust_withparmest_p_citytocityreg`wgtsuf'_`name'_`m'`test'`sample'`incfile'_xbsfe.tex", replace ///
						label wrap varwidth(50) ${esttabopts} ///
						stats(lnincfe N_clust1 N r2_a_within, fmt(0 %9.0gc %9.0gc 2) labels("Income Group \$k\$*Bootstrap Sample FEs" "Number of ${`market'slab} (\$c\$)" "Observations" "adj. within \$R^2\$")) ///
						coeflabel(lnpcincome "${lnpcinclab}" lnpop "${lnpoplab}" lninclnpcinc "${lninclnpcinclab}" lninclnpop "${lninclnpoplab}") ///
						prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{@M}{c}} \multicolumn{`pcount'}{c}{Dependent Variable: Ln(Price Index for Household in Income Group \$k\$ in ${`market'lab} \$c\$)}\\ \toprule" ///
							" ${spectitles} \\ " ///
							"  \hline & ${numline`pcount'} \\ \hline ${priceelasticities} \\ ${incomequality} \\")
				} // end of weighting specification wgt
				
			
			} // end of obs check
		} // end of model m
	
	
} // end of if 1==1 collapse
end

*===========================================================================================================================================
* Sub-programs called above

capture program drop addparmstats
	program define addparmstats
	
	syntax [anything], estpath(string)
	
	capture confirm file  "`estpath'/appended_wihthinestimates.dta"
	if _rc==0 use "`estpath'/appended_wihthinestimates.dta", clear
	else appendestimates, estimatesinput(`estpath')
	
	*merge in module sales weights
		gen year = 2012
		quietly merge m:1 modulenum year using "${processeddata}/HMSdata_year_modulesales.dta", keepusing(value) keep(1 3) 
			// created in 3_aggindex.do
		rename value total_sales
		gen total_sales_rounded = round(total_sales)
	
	*drop bounded estimates or estimates at starting values 
		keep if model==3
		drop if b_alpha0 < 0.06 | b_alpha0 > 0.99*30 // | abs(b_alpha0-2)<0.01
		drop if abs(b_gamma) > 0.99*5 // | abs(b_gamma-0.1)<0.01
		
	*get stats
		quietly sum b_alpha0 [aw=total_sales_rounded], d
			local med=strofreal(`r(p50)',"%3.2f")
			global priceelasticities="${priceelasticities} &\multicolumn{1}{c}{`med'} "
		quietly sum b_gamma [aw=total_sales_rounded], d
			local med=strofreal(`r(p50)',"%3.2f")
			global incomequality="${incomequality} &\multicolumn{1}{c}{`med'} "
			
end

*===========================================================================================================================================

capture program drop appendestimates
program define appendestimates

	syntax [anything], estimatesinput(string) [ filetype(string)]

if 1==1 {
	clear

	
	disp "append files...."
		local files: dir "`estimatesinput'" files "withinestimates`filetype'_module*.dta"
				// created by 2_estimatessave_vN.do
		local first=1
		tempfile temp

		foreach f of local files {
			disp "...appending `f'"
			
			use ${estimatesinput}/`f', clear
			capture drop if f==.
			capture rename product_module_code modulenum		
			
			
			if "`filetype'"=="" {
				quietly drop if baseprod==1 
					// drop "base" observations so that dropest is consistent within (modulenum model)
				drop b_delta mktid prodid brandid baseprod baseprodid
				quietly bys modulenum model:keep if _n==1
			}
		
			if `first'==0 quietly append using `temp'
			quietly save `temp', replace
			
			local first=0
		}
				
		save "${estimatesinput}/appended_wihthinestimates`filetype'.dta", replace
}	

end

*===========================================================================================================================================
*===========================================================================================================================================

*** Run programs and reset directory

	capture log close
	log using "$logs/${name}_${cdate}_${ctime}${vmax}.log", replace
	cd "${programs}"
	main
	cd "${programs}"
	capture log close

*===========================================================================================================================================
*===========================================================================================================================================
