********************************************************************************
** STANDARD OPTIONS
********************************************************************************	

	clear all
	set maxvar 32767
	set matsize 11000
	set more off, perm
	#delimit cr
    	
********************************************************************************
** SET FILE PATHS
** 	These file paths are user-specific. 
**	They currently reflect the author's directory structure and need to be updated.
********************************************************************************	

	*Identify which directory we are running from (code location)
		global dir : pwd 
		global programs "${dir}"


	*Identify path to common data directory from current
		if "`c(hostname)'"=="REAL-VAN-DF003" | "`c(hostname)'"=="REAL-VAN-431" |  "`c(hostname)'"=="REAL-RA-11" global machine "Z:"
		if "`c(hostname)'"=="REAL-VAN-DR004" global machine "Z:/handbury"
		if "`c(os)'"=="Unix" & ( strpos("`c(hostname)'","hpcc")!=0 | strpos("`c(hostname)'","aws-real")!=0 ) global machine "/home/real/handbury"
		if "$machine"=="" {
			disp "host machine not identified; cannot set filepaths; terminating"
			exit
		}	

	**Raw data locations
		global rawmisc "${machine}/rawdata_inputs"
		global rawMABEL "${machine}/rawdata_inputs/Census_mabelGeocorr"
		global rawNHGIS "${machine}/rawdata_inputs/NHGIS/2010"
		global rawcensus "${machine}/rawdata_inputs/Census"
		global rawcbp 	"${machine}/rawdata_inputs/CBP"
		global rawsocial "${machine}/rawdata_inputs/SocialExplorer"

		global rawHMS "/data/nielsen/nielsen_extracts/HMS"	
		global rawRMS "/data/nielsen/nielsen_extracts/RMS"	

	**Directory where project working files will be stored
		global terminal "${machine}/NHPworking"
		global HMSdata "${terminal}/0a_dataconstruct/HMS/Data"
		global RMSdata "${terminal}/0a_dataconstruct/RMS/Data"
		global step0bdata "${terminal}/0b_dataimport/STATAData"
		global step1data "${terminal}/1_dataprep/STATAData"
		global step2data "${terminal}/2_preestimation_analysis/STATAData"
		global step3data "${terminal}/3_estimation/STATA/Data"
		global step4data "${terminal}/4_postestimation_analysis/Data"	
	
********************************************************************************
** SET PRINT OPTIONS
********************************************************************************	

	set printcolor gs3, perm // auto
	graph set eps fontface Times
	graph set eps logo off
	set scheme s1mono, perm // s2color
	set printcolor auto, perm	
	
	global esttabopts="nonotes nocons se(a2) b(a2) star(* 0.10 ** 0.05 *** 0.01) varwidth(25) nodepvars nobaselevels nomti mlabel(none) booktabs nonumber substitute(\_ _)" //  bracket
	global numline1=" [1]"
	forvalues i=2/12 {
		local j=`i'-1
		global numline`i'="${numline`j'}" + "&[" + "`i'" + "]"
	}
	
********************************************************************************
** INSTALL PACKAGES
********************************************************************************	
	
	cap noisily ssc install regsave
	cap noisily ssc install egenmore
	cap noisily ssc install gzsave 

********************************************************************************
** VARIABLE LABELS (primarily used for index regressions - STEP4_4 code)
********************************************************************************	

	global cbsalab="CBSA"
	global countylab="County"
	global store_code_uclab="Store"
	global cbsaslab="CBSAs"
	global countyslab="Counties"
	global store_code_ucslab="Stores"
	global cbsainclab="CBSA"
	global countyinclab="County"
	global store_code_ucinclab="Local"
	
	global lnpcinclab=				"Ln(Per Capita Income\$\_c\$) (\$\beta_1 \$)"
	global lninclnpcinclab= 		"Ln(Per Capita Income\$\_c\$)\$^*               \$ \qquad Demeaned Ln(HH Income\$\_k\$) (\$\beta_2\$)"
	global lnstorepcinclab=			"Ln(Per Capita Income\$\_s\$) (\$\beta_1 \$)"
	global lnstoreinclnpcinclab= 	"Ln(Per Capita Income\$\_s\$)\$^*               \$ \qquad Demeaned Ln(HH Income\$\_k\$)  (\$\beta_2\$)"
	global lncbsapcinclab=			"Ln(Per Capita Inc\$\_c(s)\$) (\$\beta_3 \$)"
	global lninclncbsapcinclab=		"Ln(Per Capita Income\$\_c(s)\$)\$^*            \$ \qquad Demeaned Ln(HH Income\$\_k\$) (\$\beta_4\$)"	
	global lnpoplab=				"Ln(Population\$\_c\$) (\$\beta_3 \$)"
	global lninclnpoplab=			"Ln(Population\$\_c\$)\$^*                      \$ \qquad Demeaned Ln(HH Income\$\_k\$) (\$\beta_4\$)"
	global lninclnpcinclab2=		"Ln(Per Capita Income\$\_c\$)\$^*               \$ \qquad Demeaned Ln(HH Income\$\_k\$) (\$\beta_2\$)"
	global lninclnpoplab2=			"Ln(Population\$\_c\$)\$*                       \$ \qquad Demeaned Ln(HH Income\$\_k\$) (\$\beta_4\$)"	


********************************************************************************
** USEFUL SUB CODE
********************************************************************************	

capture program drop collapsesum
program define collapsesum

syntax [anything], sumvars(string) byvars(string)

	sort `byvars'
	foreach v in `sumvars' {
		rename `v' old
		by `byvars': gen `v'=sum(old)
		drop old
	}
	by  `byvars': keep if _n==_N
	keep  `byvars' `sumvars'
	
end
	
capture program drop outliermlabs
program define outliermlabs
	syntax [anything], labelvar(string) newlabelvar(string) [x(string) y(string) cutofflow(string) cutoffhigh(string) cutoffvar(string) cutoffvarlevel(string)]
	
	capture drop eps `newlabelvar'
	gen `newlabelvar'=""
	if "`y'"!="" {
		reg `y' `x'
		predict eps, resid
		foreach v in eps `y' `x' {
			quietly sum `v', d
			replace `newlabelvar'=`labelvar' if `v'>`r(`cutoffhigh')' | `v'<`r(`cutofflow')' // abs(`v'-`r(mean)')>2*`r(sd)'
		}
	}
	if "`cutoffvar'"!="" replace mlabels=cbsaabbr if `cutoffvar'>`cutoffvarlevel'
	
end

capture program drop dollarlablist
program define dollarlablist
	syntax [anything], labvals(string) [outvarname(string)]
	
	if "`outvarname'"=="" local outvarname xlab
	local xlabin ""
	local xlabnonlogin ""
	foreach v in `labvals' {
		local temp = ln(`v')
		local templab = substr("`v'", 1, 2) + ","+substr("`v'", -3, .)
		local xlabin `"`xlabin' `temp' "$`templab'""'
		local xlabnonlogin `"`xlabnonlogin' `v' "$`templab'""'
	}
	c_local `outvarname'=`"`xlabin'"'
	c_local `outvarname'nonlog=`"`xlabnonlogin'"'

end
		

	
	
	
	
